Class ActionLocalPortDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ActionLocalPortDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ActionLocalPortDetails.Builder,ActionLocalPortDetails>
@Generated("software.amazon.awssdk:codegen")
public final class ActionLocalPortDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ActionLocalPortDetails.Builder,ActionLocalPortDetails>
For NetworkConnectionAction and PortProbeDetails, LocalPortDetails provides
information about the local port that was involved in the action.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Integerport()The number of the port.final StringportName()The port name of the local connection.static Class<? extends ActionLocalPortDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
port
The number of the port.
- Returns:
- The number of the port.
-
portName
The port name of the local connection.
Length Constraints: 128.
- Returns:
- The port name of the local connection.
Length Constraints: 128.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ActionLocalPortDetails.Builder,ActionLocalPortDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-