Class Actor
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Actor
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Actor.Builder,Actor>
@Generated("software.amazon.awssdk:codegen")
public final class Actor
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Actor.Builder,Actor>
Information about the threat actor identified in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Actor.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The ID of the threat actor.static Class<? extends Actor.Builder>final ActorSessionsession()Contains information about the user session where the activity initiated.final StringtoString()Returns a string representation of this object.final ActorUseruser()Contains information about the user credentials used by the threat actor.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The ID of the threat actor.
- Returns:
- The ID of the threat actor.
-
user
Contains information about the user credentials used by the threat actor.
- Returns:
- Contains information about the user credentials used by the threat actor.
-
session
Contains information about the user session where the activity initiated.
- Returns:
- Contains information about the user session where the activity initiated.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Actor.Builder,Actor>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-