java.lang.Object
software.amazon.awssdk.services.securityhub.model.ActorUser
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<ActorUser.Builder,ActorUser>

@Generated("software.amazon.awssdk:codegen") public final class ActorUser extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ActorUser.Builder,ActorUser>

Contains information about the credentials used by the threat actor identified in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

See Also:
  • Method Details

    • name

      public final String name()

      The name of the threat actor.

      Returns:
      The name of the threat actor.
    • uid

      public final String uid()

      The unique identifier of the threat actor.

      Returns:
      The unique identifier of the threat actor.
    • type

      public final String type()

      The type of user.

      Returns:
      The type of user.
    • credentialUid

      public final String credentialUid()

      Unique identifier of the threat actor’s user credentials.

      Returns:
      Unique identifier of the threat actor’s user credentials.
    • account

      public final UserAccount account()

      The account of the threat actor.

      Returns:
      The account of the threat actor.
    • toBuilder

      public ActorUser.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<ActorUser.Builder,ActorUser>
    • builder

      public static ActorUser.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ActorUser.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo