Enum AllowedOperators
- java.lang.Object
-
- java.lang.Enum<AllowedOperators>
-
- software.amazon.awssdk.services.securityhub.model.AllowedOperators
-
- All Implemented Interfaces:
Serializable,Comparable<AllowedOperators>
@Generated("software.amazon.awssdk:codegen") public enum AllowedOperators extends Enum<AllowedOperators>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description ANDORUNKNOWN_TO_SDK_VERSION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static AllowedOperatorsfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<AllowedOperators>knownValues()StringtoString()static AllowedOperatorsvalueOf(String name)Returns the enum constant of this type with the specified name.static AllowedOperators[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
AND
public static final AllowedOperators AND
-
OR
public static final AllowedOperators OR
-
UNKNOWN_TO_SDK_VERSION
public static final AllowedOperators UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static AllowedOperators[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (AllowedOperators c : AllowedOperators.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static AllowedOperators valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<AllowedOperators>
-
fromValue
public static AllowedOperators fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- AllowedOperators corresponding to the value
-
knownValues
public static Set<AllowedOperators> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownAllowedOperatorss
-
-