Class AssociatedStandard
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AssociatedStandard
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AssociatedStandard.Builder,AssociatedStandard>
@Generated("software.amazon.awssdk:codegen")
public final class AssociatedStandard
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AssociatedStandard.Builder,AssociatedStandard>
Information about an enabled security standard in which a security control is enabled.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic AssociatedStandard.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AssociatedStandard.Builder>final StringThe unique identifier of a standard in which a control is enabled.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsId
The unique identifier of a standard in which a control is enabled. This field consists of the resource portion of the Amazon Resource Name (ARN) returned for a standard in the DescribeStandards API response.
- Returns:
- The unique identifier of a standard in which a control is enabled. This field consists of the resource portion of the Amazon Resource Name (ARN) returned for a standard in the DescribeStandards API response.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AssociatedStandard.Builder,AssociatedStandard>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-