Class AssociationSetDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AssociationSetDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AssociationSetDetails.Builder,AssociationSetDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AssociationSetDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AssociationSetDetails.Builder,AssociationSetDetails>
The associations between a route table and one or more subnets or a gateway.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal AssociationStateDetailsThe state of the association between a route table and a subnet or gateway.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe ID of the internet gateway or virtual private gateway.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Booleanmain()Indicates whether this is the main route table.final StringThe ID of the association.final StringThe ID of the route table.static Class<? extends AssociationSetDetails.Builder>final StringsubnetId()The ID of the subnet.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
associationState
The state of the association between a route table and a subnet or gateway.
- Returns:
- The state of the association between a route table and a subnet or gateway.
-
gatewayId
The ID of the internet gateway or virtual private gateway.
- Returns:
- The ID of the internet gateway or virtual private gateway.
-
main
Indicates whether this is the main route table.
- Returns:
- Indicates whether this is the main route table.
-
routeTableAssociationId
The ID of the association.
- Returns:
- The ID of the association.
-
routeTableId
The ID of the route table.
- Returns:
- The ID of the route table.
-
subnetId
The ID of the subnet. A subnet ID is not returned for an implicit association.
- Returns:
- The ID of the subnet. A subnet ID is not returned for an implicit association.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AssociationSetDetails.Builder,AssociationSetDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-