Class AutomationRulesAction
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AutomationRulesAction.Builder,AutomationRulesAction>
One or more actions that Security Hub CSPM takes when a finding matches the defined criteria of a rule.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) Specifies that the automation rule action is an update to a finding field.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AutomationRulesAction.Builder>final StringtoString()Returns a string representation of this object.type()Specifies the type of action that Security Hub CSPM takes when a finding matches the defined criteria of a rule.final StringSpecifies the type of action that Security Hub CSPM takes when a finding matches the defined criteria of a rule.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
Specifies the type of action that Security Hub CSPM takes when a finding matches the defined criteria of a rule.
If the service returns an enum value that is not available in the current SDK version,
typewill returnAutomationRulesActionType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- Specifies the type of action that Security Hub CSPM takes when a finding matches the defined criteria of a rule.
- See Also:
-
typeAsString
Specifies the type of action that Security Hub CSPM takes when a finding matches the defined criteria of a rule.
If the service returns an enum value that is not available in the current SDK version,
typewill returnAutomationRulesActionType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- Specifies the type of action that Security Hub CSPM takes when a finding matches the defined criteria of a rule.
- See Also:
-
findingFieldsUpdate
Specifies that the automation rule action is an update to a finding field.
- Returns:
- Specifies that the automation rule action is an update to a finding field.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AutomationRulesAction.Builder,AutomationRulesAction>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-