Class AutomationRulesActionV2
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>
Allows you to configure automated responses.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) The settings for integrating automation rule actions with external systems or service.The changes to be applied to fields in a security finding when an automation rule is triggered.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AutomationRulesActionV2.Builder>final StringtoString()Returns a string representation of this object.type()The category of action to be executed by the automation rule.final StringThe category of action to be executed by the automation rule.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
The category of action to be executed by the automation rule.
If the service returns an enum value that is not available in the current SDK version,
typewill returnAutomationRulesActionTypeV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The category of action to be executed by the automation rule.
- See Also:
-
typeAsString
The category of action to be executed by the automation rule.
If the service returns an enum value that is not available in the current SDK version,
typewill returnAutomationRulesActionTypeV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The category of action to be executed by the automation rule.
- See Also:
-
findingFieldsUpdate
The changes to be applied to fields in a security finding when an automation rule is triggered.
- Returns:
- The changes to be applied to fields in a security finding when an automation rule is triggered.
-
externalIntegrationConfiguration
The settings for integrating automation rule actions with external systems or service.
- Returns:
- The settings for integrating automation rule actions with external systems or service.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-