Interface AutomationRulesActionV2.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>,SdkBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>,SdkPojo
- Enclosing class:
- AutomationRulesActionV2
@Mutable @NotThreadSafe public static interface AutomationRulesActionV2.Builder extends SdkPojo, CopyableBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default AutomationRulesActionV2.BuilderexternalIntegrationConfiguration(Consumer<ExternalIntegrationConfiguration.Builder> externalIntegrationConfiguration)The settings for integrating automation rule actions with external systems or service.AutomationRulesActionV2.BuilderexternalIntegrationConfiguration(ExternalIntegrationConfiguration externalIntegrationConfiguration)The settings for integrating automation rule actions with external systems or service.default AutomationRulesActionV2.BuilderfindingFieldsUpdate(Consumer<AutomationRulesFindingFieldsUpdateV2.Builder> findingFieldsUpdate)The changes to be applied to fields in a security finding when an automation rule is triggered.AutomationRulesActionV2.BuilderfindingFieldsUpdate(AutomationRulesFindingFieldsUpdateV2 findingFieldsUpdate)The changes to be applied to fields in a security finding when an automation rule is triggered.AutomationRulesActionV2.Buildertype(String type)The category of action to be executed by the automation rule.AutomationRulesActionV2.Buildertype(AutomationRulesActionTypeV2 type)The category of action to be executed by the automation rule.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
type
AutomationRulesActionV2.Builder type(String type)
The category of action to be executed by the automation rule.
- Parameters:
type- The category of action to be executed by the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
AutomationRulesActionTypeV2,AutomationRulesActionTypeV2
-
type
AutomationRulesActionV2.Builder type(AutomationRulesActionTypeV2 type)
The category of action to be executed by the automation rule.
- Parameters:
type- The category of action to be executed by the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
AutomationRulesActionTypeV2,AutomationRulesActionTypeV2
-
findingFieldsUpdate
AutomationRulesActionV2.Builder findingFieldsUpdate(AutomationRulesFindingFieldsUpdateV2 findingFieldsUpdate)
The changes to be applied to fields in a security finding when an automation rule is triggered.
- Parameters:
findingFieldsUpdate- The changes to be applied to fields in a security finding when an automation rule is triggered.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingFieldsUpdate
default AutomationRulesActionV2.Builder findingFieldsUpdate(Consumer<AutomationRulesFindingFieldsUpdateV2.Builder> findingFieldsUpdate)
The changes to be applied to fields in a security finding when an automation rule is triggered.
This is a convenience method that creates an instance of theAutomationRulesFindingFieldsUpdateV2.Builderavoiding the need to create one manually viaAutomationRulesFindingFieldsUpdateV2.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tofindingFieldsUpdate(AutomationRulesFindingFieldsUpdateV2).- Parameters:
findingFieldsUpdate- a consumer that will call methods onAutomationRulesFindingFieldsUpdateV2.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
findingFieldsUpdate(AutomationRulesFindingFieldsUpdateV2)
-
externalIntegrationConfiguration
AutomationRulesActionV2.Builder externalIntegrationConfiguration(ExternalIntegrationConfiguration externalIntegrationConfiguration)
The settings for integrating automation rule actions with external systems or service.
- Parameters:
externalIntegrationConfiguration- The settings for integrating automation rule actions with external systems or service.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
externalIntegrationConfiguration
default AutomationRulesActionV2.Builder externalIntegrationConfiguration(Consumer<ExternalIntegrationConfiguration.Builder> externalIntegrationConfiguration)
The settings for integrating automation rule actions with external systems or service.
This is a convenience method that creates an instance of theExternalIntegrationConfiguration.Builderavoiding the need to create one manually viaExternalIntegrationConfiguration.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toexternalIntegrationConfiguration(ExternalIntegrationConfiguration).- Parameters:
externalIntegrationConfiguration- a consumer that will call methods onExternalIntegrationConfiguration.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
externalIntegrationConfiguration(ExternalIntegrationConfiguration)
-
-