Class AutomationRulesFindingFieldsUpdateV2
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AutomationRulesFindingFieldsUpdateV2
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>
@Generated("software.amazon.awssdk:codegen")
public final class AutomationRulesFindingFieldsUpdateV2
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>
Allows you to define the structure for modifying specific fields in security findings.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringcomment()Notes or contextual information for findings that are modified by the automation rule.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AutomationRulesFindingFieldsUpdateV2.Builder>final IntegerThe severity level to be assigned to findings that match the automation rule criteria.final IntegerstatusId()The status to be applied to findings that match automation rule criteria.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
severityId
The severity level to be assigned to findings that match the automation rule criteria.
- Returns:
- The severity level to be assigned to findings that match the automation rule criteria.
-
comment
Notes or contextual information for findings that are modified by the automation rule.
- Returns:
- Notes or contextual information for findings that are modified by the automation rule.
-
statusId
The status to be applied to findings that match automation rule criteria.
- Returns:
- The status to be applied to findings that match automation rule criteria.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>
-
builder
-
serializableBuilderClass
public static Class<? extends AutomationRulesFindingFieldsUpdateV2.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-