Interface AutomationRulesFindingFieldsUpdateV2.Builder

    • Method Detail

      • severityId

        AutomationRulesFindingFieldsUpdateV2.Builder severityId​(Integer severityId)

        The severity level to be assigned to findings that match the automation rule criteria.

        Parameters:
        severityId - The severity level to be assigned to findings that match the automation rule criteria.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • comment

        AutomationRulesFindingFieldsUpdateV2.Builder comment​(String comment)

        Notes or contextual information for findings that are modified by the automation rule.

        Parameters:
        comment - Notes or contextual information for findings that are modified by the automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • statusId

        AutomationRulesFindingFieldsUpdateV2.Builder statusId​(Integer statusId)

        The status to be applied to findings that match automation rule criteria.

        Parameters:
        statusId - The status to be applied to findings that match automation rule criteria.
        Returns:
        Returns a reference to this object so that method calls can be chained together.