Class AutomationRulesMetadata
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AutomationRulesMetadata.Builder,AutomationRulesMetadata>
Metadata for automation rules in the calling account. The response includes rules with a RuleStatus of
ENABLED and DISABLED.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final InstantA timestamp that indicates when the rule was created.final StringThe principal that created a rule.final StringA description of the rule.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanSpecifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria.final StringruleArn()The Amazon Resource Name (ARN) for the rule.final StringruleName()The name of the rule.final IntegerAn integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings.final RuleStatusWhether the rule is active after it is created.final StringWhether the rule is active after it is created.static Class<? extends AutomationRulesMetadata.Builder>final StringtoString()Returns a string representation of this object.final InstantA timestamp that indicates when the rule was most recently updated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
ruleArn
The Amazon Resource Name (ARN) for the rule.
- Returns:
- The Amazon Resource Name (ARN) for the rule.
-
ruleStatus
Whether the rule is active after it is created. If this parameter is equal to
ENABLED, Security Hub CSPM starts applying the rule to findings and finding updates after the rule is created. To change the value of this parameter after creating a rule, useBatchUpdateAutomationRules.If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- Whether the rule is active after it is created. If this parameter is equal to
ENABLED, Security Hub CSPM starts applying the rule to findings and finding updates after the rule is created. To change the value of this parameter after creating a rule, useBatchUpdateAutomationRules. - See Also:
-
ruleStatusAsString
Whether the rule is active after it is created. If this parameter is equal to
ENABLED, Security Hub CSPM starts applying the rule to findings and finding updates after the rule is created. To change the value of this parameter after creating a rule, useBatchUpdateAutomationRules.If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- Whether the rule is active after it is created. If this parameter is equal to
ENABLED, Security Hub CSPM starts applying the rule to findings and finding updates after the rule is created. To change the value of this parameter after creating a rule, useBatchUpdateAutomationRules. - See Also:
-
ruleOrder
An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings. Security Hub CSPM applies rules with lower values for this parameter first.
- Returns:
- An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings. Security Hub CSPM applies rules with lower values for this parameter first.
-
ruleName
The name of the rule.
- Returns:
- The name of the rule.
-
description
A description of the rule.
- Returns:
- A description of the rule.
-
isTerminal
Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria. This is useful when a finding matches the criteria for multiple rules, and each rule has different actions. If a rule is terminal, Security Hub CSPM applies the rule action to a finding that matches the rule criteria and doesn't evaluate other rules for the finding. By default, a rule isn't terminal.
- Returns:
- Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria. This is useful when a finding matches the criteria for multiple rules, and each rule has different actions. If a rule is terminal, Security Hub CSPM applies the rule action to a finding that matches the rule criteria and doesn't evaluate other rules for the finding. By default, a rule isn't terminal.
-
createdAt
A timestamp that indicates when the rule was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- A timestamp that indicates when the rule was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
updatedAt
A timestamp that indicates when the rule was most recently updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- A timestamp that indicates when the rule was most recently updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
createdBy
The principal that created a rule.
- Returns:
- The principal that created a rule.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AutomationRulesMetadata.Builder,AutomationRulesMetadata>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-