Interface AutomationRulesMetadataV2.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<AutomationRulesMetadataV2.Builder,AutomationRulesMetadataV2>,SdkBuilder<AutomationRulesMetadataV2.Builder,AutomationRulesMetadataV2>,SdkPojo
- Enclosing class:
- AutomationRulesMetadataV2
@Mutable @NotThreadSafe public static interface AutomationRulesMetadataV2.Builder extends SdkPojo, CopyableBuilder<AutomationRulesMetadataV2.Builder,AutomationRulesMetadataV2>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description AutomationRulesMetadataV2.Builderactions(Collection<AutomationRulesActionTypeObjectV2> actions)The list of action to be performed when the rule criteria is met.AutomationRulesMetadataV2.Builderactions(Consumer<AutomationRulesActionTypeObjectV2.Builder>... actions)The list of action to be performed when the rule criteria is met.AutomationRulesMetadataV2.Builderactions(AutomationRulesActionTypeObjectV2... actions)The list of action to be performed when the rule criteria is met.AutomationRulesMetadataV2.BuildercreatedAt(Instant createdAt)The timestamp for when the automation rule was created.AutomationRulesMetadataV2.Builderdescription(String description)An explanation for the purpose and funcitonality of the automation rule.AutomationRulesMetadataV2.BuilderruleArn(String ruleArn)The ARN of the automation rule.AutomationRulesMetadataV2.BuilderruleId(String ruleId)The ID of the automation rule.AutomationRulesMetadataV2.BuilderruleName(String ruleName)The name of the automation rule.AutomationRulesMetadataV2.BuilderruleOrder(Float ruleOrder)The value for the rule priority.AutomationRulesMetadataV2.BuilderruleStatus(String ruleStatus)The status of the automation rule.AutomationRulesMetadataV2.BuilderruleStatus(RuleStatusV2 ruleStatus)The status of the automation rule.AutomationRulesMetadataV2.BuilderupdatedAt(Instant updatedAt)The timestamp for the most recent modification to the automation rule.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
ruleArn
AutomationRulesMetadataV2.Builder ruleArn(String ruleArn)
The ARN of the automation rule.
- Parameters:
ruleArn- The ARN of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleId
AutomationRulesMetadataV2.Builder ruleId(String ruleId)
The ID of the automation rule.
- Parameters:
ruleId- The ID of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleOrder
AutomationRulesMetadataV2.Builder ruleOrder(Float ruleOrder)
The value for the rule priority.
- Parameters:
ruleOrder- The value for the rule priority.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleName
AutomationRulesMetadataV2.Builder ruleName(String ruleName)
The name of the automation rule.
- Parameters:
ruleName- The name of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleStatus
AutomationRulesMetadataV2.Builder ruleStatus(String ruleStatus)
The status of the automation rule.
- Parameters:
ruleStatus- The status of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
ruleStatus
AutomationRulesMetadataV2.Builder ruleStatus(RuleStatusV2 ruleStatus)
The status of the automation rule.
- Parameters:
ruleStatus- The status of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
description
AutomationRulesMetadataV2.Builder description(String description)
An explanation for the purpose and funcitonality of the automation rule.
- Parameters:
description- An explanation for the purpose and funcitonality of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
AutomationRulesMetadataV2.Builder actions(Collection<AutomationRulesActionTypeObjectV2> actions)
The list of action to be performed when the rule criteria is met.
- Parameters:
actions- The list of action to be performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
AutomationRulesMetadataV2.Builder actions(AutomationRulesActionTypeObjectV2... actions)
The list of action to be performed when the rule criteria is met.
- Parameters:
actions- The list of action to be performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
AutomationRulesMetadataV2.Builder actions(Consumer<AutomationRulesActionTypeObjectV2.Builder>... actions)
The list of action to be performed when the rule criteria is met.
This is a convenience method that creates an instance of theAutomationRulesActionTypeObjectV2.Builderavoiding the need to create one manually viaAutomationRulesActionTypeObjectV2.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#actions(List.) - Parameters:
actions- a consumer that will call methods onAutomationRulesActionTypeObjectV2.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#actions(java.util.Collection)
-
createdAt
AutomationRulesMetadataV2.Builder createdAt(Instant createdAt)
The timestamp for when the automation rule was created.
- Parameters:
createdAt- The timestamp for when the automation rule was created.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
updatedAt
AutomationRulesMetadataV2.Builder updatedAt(Instant updatedAt)
The timestamp for the most recent modification to the automation rule.
- Parameters:
updatedAt- The timestamp for the most recent modification to the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-