Class AwsAthenaWorkGroupConfigurationResultConfigurationDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsAthenaWorkGroupConfigurationResultConfigurationDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsAthenaWorkGroupConfigurationResultConfigurationDetails.Builder,AwsAthenaWorkGroupConfigurationResultConfigurationDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsAthenaWorkGroupConfigurationResultConfigurationDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsAthenaWorkGroupConfigurationResultConfigurationDetails.Builder,AwsAthenaWorkGroupConfigurationResultConfigurationDetails>
The location in Amazon Simple Storage Service (Amazon S3) where query and calculation results are stored and the encryption option, if any, used for query and calculation results. These are known as client-side settings. If workgroup settings override client-side settings, then the query uses the workgroup settings.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Specifies the method used to encrypt the user’s data stores in the Athena workgroup.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsAthenaWorkGroupConfigurationResultConfigurationDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
encryptionConfiguration
public final AwsAthenaWorkGroupConfigurationResultConfigurationEncryptionConfigurationDetails encryptionConfiguration()Specifies the method used to encrypt the user’s data stores in the Athena workgroup.
- Returns:
- Specifies the method used to encrypt the user’s data stores in the Athena workgroup.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsAthenaWorkGroupConfigurationResultConfigurationDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-