Class AwsAutoScalingLaunchConfigurationMetadataOptions
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsAutoScalingLaunchConfigurationMetadataOptions
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsAutoScalingLaunchConfigurationMetadataOptions.Builder,AwsAutoScalingLaunchConfigurationMetadataOptions>
@Generated("software.amazon.awssdk:codegen")
public final class AwsAutoScalingLaunchConfigurationMetadataOptions
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsAutoScalingLaunchConfigurationMetadataOptions.Builder,AwsAutoScalingLaunchConfigurationMetadataOptions>
The metadata options for the instances.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringEnables or disables the HTTP metadata endpoint on your instances.final IntegerThe HTTPPUTresponse hop limit for instance metadata requests.final StringIndicates whether token usage isrequiredoroptionalfor metadata requests.static Class<? extends AwsAutoScalingLaunchConfigurationMetadataOptions.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
httpEndpoint
Enables or disables the HTTP metadata endpoint on your instances. By default, the metadata endpoint is enabled.
- Returns:
- Enables or disables the HTTP metadata endpoint on your instances. By default, the metadata endpoint is enabled.
-
httpPutResponseHopLimit
The HTTP
PUTresponse hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.- Returns:
- The HTTP
PUTresponse hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.
-
httpTokens
Indicates whether token usage is
requiredoroptionalfor metadata requests. By default, token usage isoptional.- Returns:
- Indicates whether token usage is
requiredoroptionalfor metadata requests. By default, token usage isoptional.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsAutoScalingLaunchConfigurationMetadataOptions.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-