Class AwsBackupBackupPlanRuleCopyActionsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsBackupBackupPlanRuleCopyActionsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsBackupBackupPlanRuleCopyActionsDetails.Builder,AwsBackupBackupPlanRuleCopyActionsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsBackupBackupPlanRuleCopyActionsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsBackupBackupPlanRuleCopyActionsDetails.Builder,AwsBackupBackupPlanRuleCopyActionsDetails>
An array of CopyAction objects, each of which contains details of the copy operation.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringAn Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()Defines when a protected resource is transitioned to cold storage and when it expires.static Class<? extends AwsBackupBackupPlanRuleCopyActionsDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
destinationBackupVaultArn
An Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup.
- Returns:
- An Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup.
-
lifecycle
Defines when a protected resource is transitioned to cold storage and when it expires. Backup transitions and expires backups automatically according to the lifecycle that you define. If you don't specify a lifecycle, Backup applies the lifecycle policy of the source backup to the destination backup.
Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days.
- Returns:
- Defines when a protected resource is transitioned to cold storage and when it expires. Backup transitions
and expires backups automatically according to the lifecycle that you define. If you don't specify a
lifecycle, Backup applies the lifecycle policy of the source backup to the destination backup.
Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsBackupBackupPlanRuleCopyActionsDetails.Builder,AwsBackupBackupPlanRuleCopyActionsDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsBackupBackupPlanRuleCopyActionsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-