Class AwsCloudFrontDistributionDefaultCacheBehavior
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCloudFrontDistributionDefaultCacheBehavior.Builder,AwsCloudFrontDistributionDefaultCacheBehavior>
Contains information about the default cache configuration for the CloudFront distribution.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsCloudFrontDistributionDefaultCacheBehavior.Builder>final StringtoString()Returns a string representation of this object.final StringThe protocol that viewers can use to access the files in an origin.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
viewerProtocolPolicy
The protocol that viewers can use to access the files in an origin. You can specify the following options:
-
allow-all- Viewers can use HTTP or HTTPS. -
redirect-to-https- CloudFront responds to HTTP requests with an HTTP status code of 301 (Moved Permanently) and the HTTPS URL. The viewer then uses the new URL to resubmit. -
https-only- CloudFront responds to HTTP request with an HTTP status code of 403 (Forbidden).
- Returns:
- The protocol that viewers can use to access the files in an origin. You can specify the following
options:
-
allow-all- Viewers can use HTTP or HTTPS. -
redirect-to-https- CloudFront responds to HTTP requests with an HTTP status code of 301 (Moved Permanently) and the HTTPS URL. The viewer then uses the new URL to resubmit. -
https-only- CloudFront responds to HTTP request with an HTTP status code of 403 (Forbidden).
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsCloudFrontDistributionDefaultCacheBehavior.Builder,AwsCloudFrontDistributionDefaultCacheBehavior>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCloudFrontDistributionDefaultCacheBehavior.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-