Class AwsCloudFrontDistributionDetails

    • Method Detail

      • cacheBehaviors

        public final AwsCloudFrontDistributionCacheBehaviors cacheBehaviors()

        Provides information about the cache configuration for the distribution.

        Returns:
        Provides information about the cache configuration for the distribution.
      • defaultRootObject

        public final String defaultRootObject()

        The object that CloudFront sends in response to requests from the origin (for example, index.html) when a viewer requests the root URL for the distribution (http://www.example.com) instead of an object in your distribution (http://www.example.com/product-description.html).

        Returns:
        The object that CloudFront sends in response to requests from the origin (for example, index.html) when a viewer requests the root URL for the distribution (http://www.example.com) instead of an object in your distribution (http://www.example.com/product-description.html).
      • domainName

        public final String domainName()

        The domain name corresponding to the distribution.

        Returns:
        The domain name corresponding to the distribution.
      • eTag

        public final String eTag()

        The entity tag is a hash of the object.

        Returns:
        The entity tag is a hash of the object.
      • lastModifiedTime

        public final String lastModifiedTime()

        Indicates when that the distribution was last modified.

        For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

        Returns:
        Indicates when that the distribution was last modified.

        For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      • logging

        public final AwsCloudFrontDistributionLogging logging()

        A complex type that controls whether access logs are written for the distribution.

        Returns:
        A complex type that controls whether access logs are written for the distribution.
      • origins

        public final AwsCloudFrontDistributionOrigins origins()

        A complex type that contains information about origins for this distribution.

        Returns:
        A complex type that contains information about origins for this distribution.
      • originGroups

        public final AwsCloudFrontDistributionOriginGroups originGroups()

        Provides information about the origin groups in the distribution.

        Returns:
        Provides information about the origin groups in the distribution.
      • viewerCertificate

        public final AwsCloudFrontDistributionViewerCertificate viewerCertificate()

        Provides information about the TLS/SSL configuration that the distribution uses to communicate with viewers.

        Returns:
        Provides information about the TLS/SSL configuration that the distribution uses to communicate with viewers.
      • status

        public final String status()

        Indicates the current status of the distribution.

        Returns:
        Indicates the current status of the distribution.
      • webAclId

        public final String webAclId()

        A unique identifier that specifies the WAF web ACL, if any, to associate with this distribution.

        Returns:
        A unique identifier that specifies the WAF web ACL, if any, to associate with this distribution.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)