Class AwsCloudFrontDistributionLogging
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCloudFrontDistributionLogging
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCloudFrontDistributionLogging.Builder,AwsCloudFrontDistributionLogging>
@Generated("software.amazon.awssdk:codegen")
public final class AwsCloudFrontDistributionLogging
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsCloudFrontDistributionLogging.Builder,AwsCloudFrontDistributionLogging>
A complex type that controls whether access logs are written for the CloudFront distribution.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringbucket()The S3 bucket to store the access logs in.builder()final Booleanenabled()With this field, you can enable or disable the selected distribution.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanSpecifies whether you want CloudFront to include cookies in access logs.final Stringprefix()An optional string that you want CloudFront to use as a prefix to the access log filenames for this distribution.static Class<? extends AwsCloudFrontDistributionLogging.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
bucket
The S3 bucket to store the access logs in.
- Returns:
- The S3 bucket to store the access logs in.
-
enabled
With this field, you can enable or disable the selected distribution.
- Returns:
- With this field, you can enable or disable the selected distribution.
-
includeCookies
Specifies whether you want CloudFront to include cookies in access logs.
- Returns:
- Specifies whether you want CloudFront to include cookies in access logs.
-
prefix
An optional string that you want CloudFront to use as a prefix to the access log filenames for this distribution.
- Returns:
- An optional string that you want CloudFront to use as a prefix to the access log filenames for this distribution.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsCloudFrontDistributionLogging.Builder,AwsCloudFrontDistributionLogging>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-