Class AwsCloudFrontDistributionOriginCustomOriginConfig

java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCloudFrontDistributionOriginCustomOriginConfig
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<AwsCloudFrontDistributionOriginCustomOriginConfig.Builder,AwsCloudFrontDistributionOriginCustomOriginConfig>

@Generated("software.amazon.awssdk:codegen") public final class AwsCloudFrontDistributionOriginCustomOriginConfig extends Object implements SdkPojo, Serializable, ToCopyableBuilder<AwsCloudFrontDistributionOriginCustomOriginConfig.Builder,AwsCloudFrontDistributionOriginCustomOriginConfig>

A custom origin. A custom origin is any origin that is not an Amazon S3 bucket, with one exception. An Amazon S3 bucket that is configured with static website hosting is a custom origin.

See Also: