Class AwsCloudFrontDistributionOriginGroupFailoverStatusCodes
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCloudFrontDistributionOriginGroupFailoverStatusCodes
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCloudFrontDistributionOriginGroupFailoverStatusCodes.Builder,AwsCloudFrontDistributionOriginGroupFailoverStatusCodes>
@Generated("software.amazon.awssdk:codegen")
public final class AwsCloudFrontDistributionOriginGroupFailoverStatusCodes
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsCloudFrontDistributionOriginGroupFailoverStatusCodes.Builder,AwsCloudFrontDistributionOriginGroupFailoverStatusCodes>
The status codes that cause an origin group to fail over.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasItems()For responses, this returns true if the service returned a value for the Items property.items()The list of status code values that can cause a failover to the next origin.final Integerquantity()The number of status codes that can cause a failover.static Class<? extends AwsCloudFrontDistributionOriginGroupFailoverStatusCodes.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasItems
public final boolean hasItems()For responses, this returns true if the service returned a value for the Items property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
items
The list of status code values that can cause a failover to the next origin.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasItems()method.- Returns:
- The list of status code values that can cause a failover to the next origin.
-
quantity
The number of status codes that can cause a failover.
- Returns:
- The number of status codes that can cause a failover.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCloudFrontDistributionOriginGroupFailoverStatusCodes.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-