Class AwsCloudFrontDistributionOriginItem
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCloudFrontDistributionOriginItem.Builder,AwsCloudFrontDistributionOriginItem>
A complex type that describes the Amazon S3 bucket, HTTP server (for example, a web server), or other server from which CloudFront gets your files.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()An origin that is not an Amazon S3 bucket, with one exception.final StringAmazon S3 origins: The DNS name of the S3 bucket from which you want CloudFront to get objects for this origin.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()A unique identifier for the origin or origin group.final StringAn optional element that causes CloudFront to request your content from a directory in your Amazon S3 bucket or your custom origin.An origin that is an S3 bucket that is not configured with static website hosting.static Class<? extends AwsCloudFrontDistributionOriginItem.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domainName
Amazon S3 origins: The DNS name of the S3 bucket from which you want CloudFront to get objects for this origin.
- Returns:
- Amazon S3 origins: The DNS name of the S3 bucket from which you want CloudFront to get objects for this origin.
-
id
A unique identifier for the origin or origin group.
- Returns:
- A unique identifier for the origin or origin group.
-
originPath
An optional element that causes CloudFront to request your content from a directory in your Amazon S3 bucket or your custom origin.
- Returns:
- An optional element that causes CloudFront to request your content from a directory in your Amazon S3 bucket or your custom origin.
-
s3OriginConfig
An origin that is an S3 bucket that is not configured with static website hosting.
- Returns:
- An origin that is an S3 bucket that is not configured with static website hosting.
-
customOriginConfig
An origin that is not an Amazon S3 bucket, with one exception. If the Amazon S3 bucket is configured with static website hosting, use this attribute. If the Amazon S3 bucket is not configured with static website hosting, use the
S3OriginConfigtype instead.- Returns:
- An origin that is not an Amazon S3 bucket, with one exception. If the Amazon S3 bucket is configured with
static website hosting, use this attribute. If the Amazon S3 bucket is not configured with static website
hosting, use the
S3OriginConfigtype instead.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsCloudFrontDistributionOriginItem.Builder,AwsCloudFrontDistributionOriginItem>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCloudFrontDistributionOriginItem.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-