Class AwsCloudFrontDistributionOriginS3OriginConfig
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCloudFrontDistributionOriginS3OriginConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCloudFrontDistributionOriginS3OriginConfig.Builder,AwsCloudFrontDistributionOriginS3OriginConfig>
@Generated("software.amazon.awssdk:codegen")
public final class AwsCloudFrontDistributionOriginS3OriginConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsCloudFrontDistributionOriginS3OriginConfig.Builder,AwsCloudFrontDistributionOriginS3OriginConfig>
Information about an origin that is an Amazon S3 bucket that is not configured with static website hosting.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe CloudFront origin access identity to associate with the origin.static Class<? extends AwsCloudFrontDistributionOriginS3OriginConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
originAccessIdentity
The CloudFront origin access identity to associate with the origin.
- Returns:
- The CloudFront origin access identity to associate with the origin.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsCloudFrontDistributionOriginS3OriginConfig.Builder,AwsCloudFrontDistributionOriginS3OriginConfig>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCloudFrontDistributionOriginS3OriginConfig.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-