Class AwsCodeBuildProjectArtifactsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCodeBuildProjectArtifactsDetails.Builder,AwsCodeBuildProjectArtifactsDetails>
Information about the build artifacts for the CodeBuild project.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAn identifier for the artifact definition.builder()final BooleanIndicates whether to disable encryption on the artifact.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringlocation()Only used whenTypeisS3.final Stringname()Only used when Type is S3.final StringOnly used whenTypeisS3.final BooleanWhether the name specified in the buildspec file overrides the artifact name.final StringOnly used whenTypeisS3.final Stringpath()Only used whenTypeisS3.static Class<? extends AwsCodeBuildProjectArtifactsDetails.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of build artifact.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
artifactIdentifier
An identifier for the artifact definition.
- Returns:
- An identifier for the artifact definition.
-
encryptionDisabled
Indicates whether to disable encryption on the artifact. Only valid when
TypeisS3.- Returns:
- Indicates whether to disable encryption on the artifact. Only valid when
TypeisS3.
-
location
Only used when
TypeisS3. The name of the S3 bucket where the artifact is located.- Returns:
- Only used when
TypeisS3. The name of the S3 bucket where the artifact is located.
-
name
Only used when Type is S3. The name of the artifact. Used with
NamepaceTypeandPathto determine the pattern for storing the artifact.- Returns:
- Only used when Type is S3. The name of the artifact. Used with
NamepaceTypeandPathto determine the pattern for storing the artifact.
-
namespaceType
Only used when
TypeisS3. The value to use for the namespace. Used withNameandPathto determine the pattern for storing the artifact.- Returns:
- Only used when
TypeisS3. The value to use for the namespace. Used withNameandPathto determine the pattern for storing the artifact.
-
overrideArtifactName
Whether the name specified in the buildspec file overrides the artifact name.
- Returns:
- Whether the name specified in the buildspec file overrides the artifact name.
-
packaging
Only used when
TypeisS3. The type of output artifact to create.- Returns:
- Only used when
TypeisS3. The type of output artifact to create.
-
path
Only used when
TypeisS3. The path to the artifact. Used withNameandNamespaceTypeto determine the pattern for storing the artifact.- Returns:
- Only used when
TypeisS3. The path to the artifact. Used withNameandNamespaceTypeto determine the pattern for storing the artifact.
-
type
The type of build artifact.
- Returns:
- The type of build artifact.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsCodeBuildProjectArtifactsDetails.Builder,AwsCodeBuildProjectArtifactsDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCodeBuildProjectArtifactsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-