Class AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails.Builder,AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails.Builder,AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails>
Information about an environment variable that is available to builds for the build project.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the environment variable.static Class<? extends AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of environment variable.final Stringvalue()The value of the environment variable.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the environment variable.
- Returns:
- The name of the environment variable.
-
type
The type of environment variable.
- Returns:
- The type of environment variable.
-
value
The value of the environment variable.
- Returns:
- The value of the environment variable.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-