Class AwsCodeBuildProjectEnvironmentRegistryCredential
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCodeBuildProjectEnvironmentRegistryCredential
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCodeBuildProjectEnvironmentRegistryCredential.Builder,AwsCodeBuildProjectEnvironmentRegistryCredential>
@Generated("software.amazon.awssdk:codegen")
public final class AwsCodeBuildProjectEnvironmentRegistryCredential
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsCodeBuildProjectEnvironmentRegistryCredential.Builder,AwsCodeBuildProjectEnvironmentRegistryCredential>
The credentials for access to a private registry.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe ARN or name of credentials created using Secrets Manager.final StringThe service that created the credentials to access a private Docker registry.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsCodeBuildProjectEnvironmentRegistryCredential.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
credential
The ARN or name of credentials created using Secrets Manager.
The credential can use the name of the credentials only if they exist in your current Amazon Web Services Region.
- Returns:
- The ARN or name of credentials created using Secrets Manager.
The credential can use the name of the credentials only if they exist in your current Amazon Web Services Region.
-
credentialProvider
The service that created the credentials to access a private Docker registry.
The valid value,
SECRETS_MANAGER, is for Secrets Manager.- Returns:
- The service that created the credentials to access a private Docker registry.
The valid value,
SECRETS_MANAGER, is for Secrets Manager.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCodeBuildProjectEnvironmentRegistryCredential.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-