Class AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails.Builder,AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails.Builder,AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails>
Information about CloudWatch Logs for the build project.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe group name of the logs in CloudWatch Logs.final inthashCode()static Class<? extends AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails.Builder>final Stringstatus()The current status of the logs in CloudWatch Logs for a build project.final StringThe prefix of the stream name of the CloudWatch Logs.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
groupName
The group name of the logs in CloudWatch Logs.
- Returns:
- The group name of the logs in CloudWatch Logs.
-
status
The current status of the logs in CloudWatch Logs for a build project.
- Returns:
- The current status of the logs in CloudWatch Logs for a build project.
-
streamName
The prefix of the stream name of the CloudWatch Logs.
- Returns:
- The prefix of the stream name of the CloudWatch Logs.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-