Class AwsCorsConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCorsConfiguration.Builder,AwsCorsConfiguration>
Contains the cross-origin resource sharing (CORS) configuration for the API. CORS is only supported for HTTP APIs.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal BooleanIndicates whether the CORS request includes credentials.The allowed headers for CORS requests.The allowed methods for CORS requests.The allowed origins for CORS requests.static AwsCorsConfiguration.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) The exposed headers for CORS requests.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the AllowHeaders property.final booleanFor responses, this returns true if the service returned a value for the AllowMethods property.final booleanFor responses, this returns true if the service returned a value for the AllowOrigins property.final booleanFor responses, this returns true if the service returned a value for the ExposeHeaders property.final inthashCode()final IntegermaxAge()The number of seconds for which the browser caches preflight request results.static Class<? extends AwsCorsConfiguration.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasAllowOrigins
public final boolean hasAllowOrigins()For responses, this returns true if the service returned a value for the AllowOrigins property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
allowOrigins
The allowed origins for CORS requests.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAllowOrigins()method.- Returns:
- The allowed origins for CORS requests.
-
allowCredentials
Indicates whether the CORS request includes credentials.
- Returns:
- Indicates whether the CORS request includes credentials.
-
hasExposeHeaders
public final boolean hasExposeHeaders()For responses, this returns true if the service returned a value for the ExposeHeaders property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
exposeHeaders
The exposed headers for CORS requests.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasExposeHeaders()method.- Returns:
- The exposed headers for CORS requests.
-
maxAge
The number of seconds for which the browser caches preflight request results.
- Returns:
- The number of seconds for which the browser caches preflight request results.
-
hasAllowMethods
public final boolean hasAllowMethods()For responses, this returns true if the service returned a value for the AllowMethods property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
allowMethods
The allowed methods for CORS requests.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAllowMethods()method.- Returns:
- The allowed methods for CORS requests.
-
hasAllowHeaders
public final boolean hasAllowHeaders()For responses, this returns true if the service returned a value for the AllowHeaders property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
allowHeaders
The allowed headers for CORS requests.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAllowHeaders()method.- Returns:
- The allowed headers for CORS requests.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsCorsConfiguration.Builder,AwsCorsConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-