Class AwsDmsReplicationTaskDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDmsReplicationTaskDetails.Builder,AwsDmsReplicationTaskDetails>
Provides details about an Database Migration Service (DMS) replication task. A replication task moves a set of data from the source endpoint to the target endpoint.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringIndicates when you want a change data capture (CDC) operation to start.final StringIndicates the start time for a CDC operation.final StringIndicates when you want a CDC operation to stop.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The identifier of the replication task.final StringThe migration type.final StringThe Amazon Resource Name (ARN) of a replication instance.final StringThe user-defined replication task identifier or name.final StringThe settings for the replication task.final StringA display name for the resource identifier at the end of theEndpointArnresponse parameter.static Class<? extends AwsDmsReplicationTaskDetails.Builder>final StringThe ARN of the source endpoint.final StringThe table mappings for the replication task, in JSON format.final StringThe ARN of the target endpoint.final StringtaskData()Supplemental information that the task requires to migrate the data for certain source and target endpoints.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
cdcStartPosition
Indicates when you want a change data capture (CDC) operation to start.
CCdcStartPositionorCCdcStartTimespecifies when you want a CDC operation to start. Only a value for one of these fields is included.- Returns:
- Indicates when you want a change data capture (CDC) operation to start.
CCdcStartPositionorCCdcStartTimespecifies when you want a CDC operation to start. Only a value for one of these fields is included.
-
cdcStartTime
Indicates the start time for a CDC operation.
CdcStartPositionorCCdcStartTimespecifies when you want a CDC operation to start. Only a value for one of these fields is included.- Returns:
- Indicates the start time for a CDC operation.
CdcStartPositionorCCdcStartTimespecifies when you want a CDC operation to start. Only a value for one of these fields is included.
-
cdcStopPosition
Indicates when you want a CDC operation to stop. The value can be either server time or commit time.
- Returns:
- Indicates when you want a CDC operation to stop. The value can be either server time or commit time.
-
migrationType
The migration type.
- Returns:
- The migration type.
-
id
The identifier of the replication task.
- Returns:
- The identifier of the replication task.
-
resourceIdentifier
A display name for the resource identifier at the end of the
EndpointArnresponse parameter. If you don't specify aResourceIdentifiervalue, DMS generates a default identifier value for the end ofEndpointArn.- Returns:
- A display name for the resource identifier at the end of the
EndpointArnresponse parameter. If you don't specify aResourceIdentifiervalue, DMS generates a default identifier value for the end ofEndpointArn.
-
replicationInstanceArn
The Amazon Resource Name (ARN) of a replication instance.
- Returns:
- The Amazon Resource Name (ARN) of a replication instance.
-
replicationTaskIdentifier
The user-defined replication task identifier or name.
- Returns:
- The user-defined replication task identifier or name.
-
replicationTaskSettings
The settings for the replication task.
- Returns:
- The settings for the replication task.
-
sourceEndpointArn
The ARN of the source endpoint.
- Returns:
- The ARN of the source endpoint.
-
tableMappings
The table mappings for the replication task, in JSON format.
- Returns:
- The table mappings for the replication task, in JSON format.
-
targetEndpointArn
The ARN of the target endpoint.
- Returns:
- The ARN of the target endpoint.
-
taskData
Supplemental information that the task requires to migrate the data for certain source and target endpoints.
- Returns:
- Supplemental information that the task requires to migrate the data for certain source and target endpoints.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDmsReplicationTaskDetails.Builder,AwsDmsReplicationTaskDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-