Class AwsDynamoDbTableAttributeDefinition
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableAttributeDefinition
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDynamoDbTableAttributeDefinition.Builder,AwsDynamoDbTableAttributeDefinition>
@Generated("software.amazon.awssdk:codegen")
public final class AwsDynamoDbTableAttributeDefinition
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsDynamoDbTableAttributeDefinition.Builder,AwsDynamoDbTableAttributeDefinition>
Contains a definition of an attribute for the table.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe name of the attribute.final StringThe type of the attribute.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsDynamoDbTableAttributeDefinition.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
attributeName
The name of the attribute.
- Returns:
- The name of the attribute.
-
attributeType
The type of the attribute.
- Returns:
- The type of the attribute.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDynamoDbTableAttributeDefinition.Builder,AwsDynamoDbTableAttributeDefinition>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsDynamoDbTableAttributeDefinition.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-