Class AwsDynamoDbTableBillingModeSummary
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableBillingModeSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDynamoDbTableBillingModeSummary.Builder,AwsDynamoDbTableBillingModeSummary>
@Generated("software.amazon.awssdk:codegen")
public final class AwsDynamoDbTableBillingModeSummary
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsDynamoDbTableBillingModeSummary.Builder,AwsDynamoDbTableBillingModeSummary>
Provides information about the billing for read/write capacity on the table.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe method used to charge for read and write throughput and to manage capacity.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringIf the billing mode isPAY_PER_REQUEST, indicates when the billing mode was set to that value.static Class<? extends AwsDynamoDbTableBillingModeSummary.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
billingMode
The method used to charge for read and write throughput and to manage capacity.
- Returns:
- The method used to charge for read and write throughput and to manage capacity.
-
lastUpdateToPayPerRequestDateTime
If the billing mode is
PAY_PER_REQUEST, indicates when the billing mode was set to that value.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- If the billing mode is
PAY_PER_REQUEST, indicates when the billing mode was set to that value.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDynamoDbTableBillingModeSummary.Builder,AwsDynamoDbTableBillingModeSummary>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsDynamoDbTableBillingModeSummary.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-