Class AwsDynamoDbTableKeySchema
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableKeySchema
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDynamoDbTableKeySchema.Builder,AwsDynamoDbTableKeySchema>
@Generated("software.amazon.awssdk:codegen")
public final class AwsDynamoDbTableKeySchema
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsDynamoDbTableKeySchema.Builder,AwsDynamoDbTableKeySchema>
A component of the key schema for the DynamoDB table, a global secondary index, or a local secondary index.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe name of the key schema attribute.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringkeyType()The type of key used for the key schema attribute.static Class<? extends AwsDynamoDbTableKeySchema.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
attributeName
The name of the key schema attribute.
- Returns:
- The name of the key schema attribute.
-
keyType
The type of key used for the key schema attribute. Valid values are
HASHorRANGE.- Returns:
- The type of key used for the key schema attribute. Valid values are
HASHorRANGE.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDynamoDbTableKeySchema.Builder,AwsDynamoDbTableKeySchema>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-