Class AwsDynamoDbTableProjection
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableProjection
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDynamoDbTableProjection.Builder,AwsDynamoDbTableProjection>
@Generated("software.amazon.awssdk:codegen")
public final class AwsDynamoDbTableProjection
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsDynamoDbTableProjection.Builder,AwsDynamoDbTableProjection>
For global and local secondary indexes, identifies the attributes that are copied from the table into the index.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the NonKeyAttributes property.The nonkey attributes that are projected into the index.final StringThe types of attributes that are projected into the index.static Class<? extends AwsDynamoDbTableProjection.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasNonKeyAttributes
public final boolean hasNonKeyAttributes()For responses, this returns true if the service returned a value for the NonKeyAttributes property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
nonKeyAttributes
The nonkey attributes that are projected into the index. For each attribute, provide the attribute name.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasNonKeyAttributes()method.- Returns:
- The nonkey attributes that are projected into the index. For each attribute, provide the attribute name.
-
projectionType
The types of attributes that are projected into the index. Valid values are as follows:
-
ALL -
INCLUDE -
KEYS_ONLY
- Returns:
- The types of attributes that are projected into the index. Valid values are as follows:
-
ALL -
INCLUDE -
KEYS_ONLY
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDynamoDbTableProjection.Builder,AwsDynamoDbTableProjection>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-