Class AwsDynamoDbTableRestoreSummary

java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableRestoreSummary
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<AwsDynamoDbTableRestoreSummary.Builder,AwsDynamoDbTableRestoreSummary>

@Generated("software.amazon.awssdk:codegen") public final class AwsDynamoDbTableRestoreSummary extends Object implements SdkPojo, Serializable, ToCopyableBuilder<AwsDynamoDbTableRestoreSummary.Builder,AwsDynamoDbTableRestoreSummary>

Information about the restore for the table.

See Also:
  • Method Details

    • sourceBackupArn

      public final String sourceBackupArn()

      The ARN of the source backup from which the table was restored.

      Returns:
      The ARN of the source backup from which the table was restored.
    • sourceTableArn

      public final String sourceTableArn()

      The ARN of the source table for the backup.

      Returns:
      The ARN of the source table for the backup.
    • restoreDateTime

      public final String restoreDateTime()

      Indicates the point in time that the table was restored to.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      Returns:
      Indicates the point in time that the table was restored to.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

    • restoreInProgress

      public final Boolean restoreInProgress()

      Whether a restore is currently in progress.

      Returns:
      Whether a restore is currently in progress.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<AwsDynamoDbTableRestoreSummary.Builder,AwsDynamoDbTableRestoreSummary>
    • builder

      public static AwsDynamoDbTableRestoreSummary.Builder builder()
    • serializableBuilderClass

      public static Class<? extends AwsDynamoDbTableRestoreSummary.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo