Interface AwsDynamoDbTableRestoreSummary.Builder

    • Method Detail

      • sourceBackupArn

        AwsDynamoDbTableRestoreSummary.Builder sourceBackupArn​(String sourceBackupArn)

        The ARN of the source backup from which the table was restored.

        Parameters:
        sourceBackupArn - The ARN of the source backup from which the table was restored.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • sourceTableArn

        AwsDynamoDbTableRestoreSummary.Builder sourceTableArn​(String sourceTableArn)

        The ARN of the source table for the backup.

        Parameters:
        sourceTableArn - The ARN of the source table for the backup.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • restoreInProgress

        AwsDynamoDbTableRestoreSummary.Builder restoreInProgress​(Boolean restoreInProgress)

        Whether a restore is currently in progress.

        Parameters:
        restoreInProgress - Whether a restore is currently in progress.
        Returns:
        Returns a reference to this object so that method calls can be chained together.