Class AwsDynamoDbTableSseDescription
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableSseDescription
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDynamoDbTableSseDescription.Builder,AwsDynamoDbTableSseDescription>
@Generated("software.amazon.awssdk:codegen")
public final class AwsDynamoDbTableSseDescription
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsDynamoDbTableSseDescription.Builder,AwsDynamoDbTableSseDescription>
Information about the server-side encryption for the table.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringIf the key is inaccessible, the date and time when DynamoDB detected that the key was inaccessible.final StringThe ARN of the KMS key that is used for the KMS encryption.static Class<? extends AwsDynamoDbTableSseDescription.Builder>final StringsseType()The type of server-side encryption.final Stringstatus()The status of the server-side encryption.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
inaccessibleEncryptionDateTime
If the key is inaccessible, the date and time when DynamoDB detected that the key was inaccessible.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- If the key is inaccessible, the date and time when DynamoDB detected that the key was inaccessible.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
status
The status of the server-side encryption.
- Returns:
- The status of the server-side encryption.
-
sseType
The type of server-side encryption.
- Returns:
- The type of server-side encryption.
-
kmsMasterKeyArn
The ARN of the KMS key that is used for the KMS encryption.
- Returns:
- The ARN of the KMS key that is used for the KMS encryption.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDynamoDbTableSseDescription.Builder,AwsDynamoDbTableSseDescription>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-