Class AwsEc2InstanceMetadataOptions
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEc2InstanceMetadataOptions
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEc2InstanceMetadataOptions.Builder,AwsEc2InstanceMetadataOptions>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEc2InstanceMetadataOptions
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEc2InstanceMetadataOptions.Builder,AwsEc2InstanceMetadataOptions>
Metadata options that allow you to configure and secure the Amazon EC2 instance.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringEnables or disables the HTTP metadata endpoint on the instance.final StringEnables or disables the IPv6 endpoint for the instance metadata service.final IntegerThe desired HTTP PUT response hop limit for instance metadata requests.final StringThe state of token usage for your instance metadata requests.final StringSpecifies whether to allow access to instance tags from the instance metadata.static Class<? extends AwsEc2InstanceMetadataOptions.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
httpEndpoint
Enables or disables the HTTP metadata endpoint on the instance.
- Returns:
- Enables or disables the HTTP metadata endpoint on the instance.
-
httpProtocolIpv6
Enables or disables the IPv6 endpoint for the instance metadata service.
- Returns:
- Enables or disables the IPv6 endpoint for the instance metadata service.
-
httpPutResponseHopLimit
The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.
- Returns:
- The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.
-
httpTokens
The state of token usage for your instance metadata requests.
- Returns:
- The state of token usage for your instance metadata requests.
-
instanceMetadataTags
Specifies whether to allow access to instance tags from the instance metadata.
- Returns:
- Specifies whether to allow access to instance tags from the instance metadata.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsEc2InstanceMetadataOptions.Builder,AwsEc2InstanceMetadataOptions>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-