Class AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails.Builder,AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails.Builder,AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails>
Information about a block device mapping for an Amazon Elastic Compute Cloud (Amazon EC2) launch template.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe device name.ebs()Parameters used to automatically set up Amazon EBS volumes when the instance is launched.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringnoDevice()Omits the device from the block device mapping when an empty string is specified.static Class<? extends AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails.Builder>final StringtoString()Returns a string representation of this object.final StringThe virtual device name (ephemeralN).Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
deviceName
The device name.
- Returns:
- The device name.
-
ebs
Parameters used to automatically set up Amazon EBS volumes when the instance is launched.
- Returns:
- Parameters used to automatically set up Amazon EBS volumes when the instance is launched.
-
noDevice
Omits the device from the block device mapping when an empty string is specified.
- Returns:
- Omits the device from the block device mapping when an empty string is specified.
-
virtualName
The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for
ephemeral0andephemeral1. The number of available instance store volumes depends on the instance type.- Returns:
- The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance
type with 2 available instance store volumes can specify mappings for
ephemeral0andephemeral1. The number of available instance store volumes depends on the instance type.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-