Class AwsEc2NetworkInterfaceAttachment
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEc2NetworkInterfaceAttachment.Builder,AwsEc2NetworkInterfaceAttachment>
Information about the network interface attachment.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe identifier of the network interface attachmentfinal StringIndicates when the attachment initiated.builder()final BooleanIndicates whether the network interface is deleted when the instance is terminated.final IntegerThe device index of the network interface attachment on the instance.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ID of the instance.final StringThe Amazon Web Services account ID of the owner of the instance.static Class<? extends AwsEc2NetworkInterfaceAttachment.Builder>final Stringstatus()The attachment state.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
attachTime
Indicates when the attachment initiated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the attachment initiated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
attachmentId
The identifier of the network interface attachment
- Returns:
- The identifier of the network interface attachment
-
deleteOnTermination
Indicates whether the network interface is deleted when the instance is terminated.
- Returns:
- Indicates whether the network interface is deleted when the instance is terminated.
-
deviceIndex
The device index of the network interface attachment on the instance.
- Returns:
- The device index of the network interface attachment on the instance.
-
instanceId
The ID of the instance.
- Returns:
- The ID of the instance.
-
instanceOwnerId
The Amazon Web Services account ID of the owner of the instance.
- Returns:
- The Amazon Web Services account ID of the owner of the instance.
-
status
The attachment state.
Valid values:
attaching|attached|detaching|detached- Returns:
- The attachment state.
Valid values:
attaching|attached|detaching|detached
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsEc2NetworkInterfaceAttachment.Builder,AwsEc2NetworkInterfaceAttachment>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-