Class AwsEc2NetworkInterfaceDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEc2NetworkInterfaceDetails.Builder,AwsEc2NetworkInterfaceDetails>
Details about the network interface
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionThe network interface attachment.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the IpV6Addresses property.final booleanFor responses, this returns true if the service returned a value for the PrivateIpAddresses property.final booleanFor responses, this returns true if the service returned a value for the SecurityGroups property.The IPv6 addresses associated with the network interface.final StringThe ID of the network interface.The private IPv4 addresses associated with the network interface.final StringThe public DNS name of the network interface.final StringpublicIp()The address of the Elastic IP address bound to the network interface.Security groups for the network interface.static Class<? extends AwsEc2NetworkInterfaceDetails.Builder>final BooleanIndicates whether traffic to or from the instance is validated.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
attachment
The network interface attachment.
- Returns:
- The network interface attachment.
-
networkInterfaceId
The ID of the network interface.
- Returns:
- The ID of the network interface.
-
hasSecurityGroups
public final boolean hasSecurityGroups()For responses, this returns true if the service returned a value for the SecurityGroups property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
securityGroups
Security groups for the network interface.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSecurityGroups()method.- Returns:
- Security groups for the network interface.
-
sourceDestCheck
Indicates whether traffic to or from the instance is validated.
- Returns:
- Indicates whether traffic to or from the instance is validated.
-
hasIpV6Addresses
public final boolean hasIpV6Addresses()For responses, this returns true if the service returned a value for the IpV6Addresses property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
ipV6Addresses
The IPv6 addresses associated with the network interface.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasIpV6Addresses()method.- Returns:
- The IPv6 addresses associated with the network interface.
-
hasPrivateIpAddresses
public final boolean hasPrivateIpAddresses()For responses, this returns true if the service returned a value for the PrivateIpAddresses property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
privateIpAddresses
The private IPv4 addresses associated with the network interface.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasPrivateIpAddresses()method.- Returns:
- The private IPv4 addresses associated with the network interface.
-
publicDnsName
The public DNS name of the network interface.
- Returns:
- The public DNS name of the network interface.
-
publicIp
The address of the Elastic IP address bound to the network interface.
- Returns:
- The address of the Elastic IP address bound to the network interface.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsEc2NetworkInterfaceDetails.Builder,AwsEc2NetworkInterfaceDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-