Class AwsEcrRepositoryImageScanningConfigurationDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcrRepositoryImageScanningConfigurationDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcrRepositoryImageScanningConfigurationDetails.Builder,AwsEcrRepositoryImageScanningConfigurationDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcrRepositoryImageScanningConfigurationDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcrRepositoryImageScanningConfigurationDetails.Builder,AwsEcrRepositoryImageScanningConfigurationDetails>
The image scanning configuration for a repository.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanWhether to scan images after they are pushed to a repository.static Class<? extends AwsEcrRepositoryImageScanningConfigurationDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
scanOnPush
Whether to scan images after they are pushed to a repository.
- Returns:
- Whether to scan images after they are pushed to a repository.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcrRepositoryImageScanningConfigurationDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-