Class AwsEcsClusterConfigurationExecuteCommandConfigurationDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsClusterConfigurationExecuteCommandConfigurationDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsClusterConfigurationExecuteCommandConfigurationDetails.Builder,AwsEcsClusterConfigurationExecuteCommandConfigurationDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsClusterConfigurationExecuteCommandConfigurationDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsClusterConfigurationExecuteCommandConfigurationDetails.Builder,AwsEcsClusterConfigurationExecuteCommandConfigurationDetails>
Contains the run command configuration for the cluster.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringkmsKeyId()The identifier of the KMS key that is used to encrypt the data between the local client and the container.The log configuration for the results of the run command actions.final Stringlogging()The log setting to use for redirecting logs for run command results.static Class<? extends AwsEcsClusterConfigurationExecuteCommandConfigurationDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
kmsKeyId
The identifier of the KMS key that is used to encrypt the data between the local client and the container.
- Returns:
- The identifier of the KMS key that is used to encrypt the data between the local client and the container.
-
logConfiguration
public final AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails logConfiguration()The log configuration for the results of the run command actions. Required if
LoggingisNONE.- Returns:
- The log configuration for the results of the run command actions. Required if
LoggingisNONE.
-
logging
The log setting to use for redirecting logs for run command results.
- Returns:
- The log setting to use for redirecting logs for run command results.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsClusterConfigurationExecuteCommandConfigurationDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-