Class AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails.Builder,AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails.Builder,AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails>
The log configuration for the results of the run command actions.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final BooleanWhether to enable encryption on the CloudWatch logs.final StringThe name of the CloudWatch log group to send the logs to.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the S3 bucket to send logs to.final BooleanWhether to encrypt the logs that are sent to the S3 bucket.final StringIdentifies the folder in the S3 bucket to send the logs to.static Class<? extends AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
cloudWatchEncryptionEnabled
Whether to enable encryption on the CloudWatch logs.
- Returns:
- Whether to enable encryption on the CloudWatch logs.
-
cloudWatchLogGroupName
The name of the CloudWatch log group to send the logs to.
- Returns:
- The name of the CloudWatch log group to send the logs to.
-
s3BucketName
The name of the S3 bucket to send logs to.
- Returns:
- The name of the S3 bucket to send logs to.
-
s3EncryptionEnabled
Whether to encrypt the logs that are sent to the S3 bucket.
- Returns:
- Whether to encrypt the logs that are sent to the S3 bucket.
-
s3KeyPrefix
Identifies the folder in the S3 bucket to send the logs to.
- Returns:
- Identifies the folder in the S3 bucket to send the logs to.
-
toBuilder
-
builder
public static AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails.Builder builder() -
serializableBuilderClass
public static Class<? extends AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-