Class AwsEcsClusterDefaultCapacityProviderStrategyDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsClusterDefaultCapacityProviderStrategyDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsClusterDefaultCapacityProviderStrategyDetails.Builder,AwsEcsClusterDefaultCapacityProviderStrategyDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsClusterDefaultCapacityProviderStrategyDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsClusterDefaultCapacityProviderStrategyDetails.Builder,AwsEcsClusterDefaultCapacityProviderStrategyDetails>
The default capacity provider strategy for the cluster. The default capacity provider strategy is used when services or tasks are run without a specified launch type or capacity provider strategy.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionfinal Integerbase()The minimum number of tasks to run on the specified capacity provider.builder()final StringThe name of the capacity provider.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsEcsClusterDefaultCapacityProviderStrategyDetails.Builder>final StringtoString()Returns a string representation of this object.final Integerweight()The relative percentage of the total number of tasks launched that should use the capacity provider.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
base
The minimum number of tasks to run on the specified capacity provider.
- Returns:
- The minimum number of tasks to run on the specified capacity provider.
-
capacityProvider
The name of the capacity provider.
- Returns:
- The name of the capacity provider.
-
weight
The relative percentage of the total number of tasks launched that should use the capacity provider.
- Returns:
- The relative percentage of the total number of tasks launched that should use the capacity provider.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsClusterDefaultCapacityProviderStrategyDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-