Class AwsEcsServiceCapacityProviderStrategyDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsServiceCapacityProviderStrategyDetails.Builder,AwsEcsServiceCapacityProviderStrategyDetails>
Strategy item for the capacity provider strategy that the service uses.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionfinal Integerbase()The minimum number of tasks to run on the capacity provider.builder()final StringThe short name of the capacity provider.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsEcsServiceCapacityProviderStrategyDetails.Builder>final StringtoString()Returns a string representation of this object.final Integerweight()The relative percentage of the total number of tasks that should use the capacity provider.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
base
The minimum number of tasks to run on the capacity provider. Only one strategy item can specify a value for
Base.The value must be between 0 and 100000.
- Returns:
- The minimum number of tasks to run on the capacity provider. Only one strategy item can specify a value
for
Base.The value must be between 0 and 100000.
-
capacityProvider
The short name of the capacity provider.
- Returns:
- The short name of the capacity provider.
-
weight
The relative percentage of the total number of tasks that should use the capacity provider.
If no weight is specified, the default value is 0. At least one capacity provider must have a weight greater than 0.
The value can be between 0 and 1000.
- Returns:
- The relative percentage of the total number of tasks that should use the capacity provider.
If no weight is specified, the default value is 0. At least one capacity provider must have a weight greater than 0.
The value can be between 0 and 1000.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsEcsServiceCapacityProviderStrategyDetails.Builder,AwsEcsServiceCapacityProviderStrategyDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsServiceCapacityProviderStrategyDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-