Class AwsEcsServiceDeploymentControllerDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsServiceDeploymentControllerDetails.Builder,AwsEcsServiceDeploymentControllerDetails>
Information about the deployment controller type that the service uses.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsEcsServiceDeploymentControllerDetails.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The rolling update (ECS) deployment type replaces the current running version of the container with the latest version.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
The rolling update (
ECS) deployment type replaces the current running version of the container with the latest version.The blue/green (
CODE_DEPLOY) deployment type uses the blue/green deployment model that is powered by CodeDeploy. This deployment model a new deployment of a service can be verified before production traffic is sent to it.The external (
EXTERNAL) deployment type allows the use of any third-party deployment controller for full control over the deployment process for an Amazon ECS service.Valid values:
ECS|CODE_DEPLOY|EXTERNAL- Returns:
- The rolling update (
ECS) deployment type replaces the current running version of the container with the latest version.The blue/green (
CODE_DEPLOY) deployment type uses the blue/green deployment model that is powered by CodeDeploy. This deployment model a new deployment of a service can be verified before production traffic is sent to it.The external (
EXTERNAL) deployment type allows the use of any third-party deployment controller for full control over the deployment process for an Amazon ECS service.Valid values:
ECS|CODE_DEPLOY|EXTERNAL
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsEcsServiceDeploymentControllerDetails.Builder,AwsEcsServiceDeploymentControllerDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsServiceDeploymentControllerDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-