Class AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails>
A dependency that is defined for container startup and shutdown.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe dependency condition of the dependent container.final StringThe name of the dependent container.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
condition
The dependency condition of the dependent container. Indicates the required status of the dependent container before the current container can start. Valid values are as follows:
-
COMPLETE -
HEALTHY -
SUCCESS -
START
- Returns:
- The dependency condition of the dependent container. Indicates the required status of the dependent
container before the current container can start. Valid values are as follows:
-
COMPLETE -
HEALTHY -
SUCCESS -
START
-
-
-
containerName
The name of the dependent container.
- Returns:
- The name of the dependent container.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-