Class AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails>
A file that contain environment variables to pass to a container.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of environment file.final Stringvalue()The ARN of the S3 object that contains the environment variable file.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
The type of environment file. The valid value is
s3.- Returns:
- The type of environment file. The valid value is
s3.
-
value
The ARN of the S3 object that contains the environment variable file.
- Returns:
- The ARN of the S3 object that contains the environment variable file.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-