Class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails>
The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionadd()The Linux capabilities for the container that are added to the default configuration provided by Docker.builder()drop()The Linux capabilities for the container that are dropped from the default configuration provided by Docker.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanhasAdd()For responses, this returns true if the service returned a value for the Add property.final booleanhasDrop()For responses, this returns true if the service returned a value for the Drop property.final inthashCode()static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasAdd
public final boolean hasAdd()For responses, this returns true if the service returned a value for the Add property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
add
The Linux capabilities for the container that are added to the default configuration provided by Docker. Valid values are as follows:
Valid values:
"ALL"|"AUDIT_CONTROL"|"AUDIT_WRITE"|"BLOCK_SUSPEND"|"CHOWN"|"DAC_OVERRIDE"|"DAC_READ_SEARCH"|"FOWNER"|"FSETID"|"IPC_LOCK"|"IPC_OWNER"|"KILL"|"LEASE"|"LINUX_IMMUTABLE"|"MAC_ADMIN"|"MAC_OVERRIDE"|"MKNOD"|"NET_ADMIN"|"NET_BIND_SERVICE"|"NET_BROADCAST"|"NET_RAW"|"SETFCAP"|"SETGID"|"SETPCAP"|"SETUID"|"SYS_ADMIN"|"SYS_BOOT"|"SYS_CHROOT"|"SYS_MODULE"|"SYS_NICE"|"SYS_PACCT"|"SYS_PTRACE"|"SYS_RAWIO"|"SYS_RESOURCE"|"SYS_TIME"|"SYS_TTY_CONFIG"|"SYSLOG"|"WAKE_ALARM"Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAdd()method.- Returns:
- The Linux capabilities for the container that are added to the default configuration provided by Docker.
Valid values are as follows:
Valid values:
"ALL"|"AUDIT_CONTROL"|"AUDIT_WRITE"|"BLOCK_SUSPEND"|"CHOWN"|"DAC_OVERRIDE"|"DAC_READ_SEARCH"|"FOWNER"|"FSETID"|"IPC_LOCK"|"IPC_OWNER"|"KILL"|"LEASE"|"LINUX_IMMUTABLE"|"MAC_ADMIN"|"MAC_OVERRIDE"|"MKNOD"|"NET_ADMIN"|"NET_BIND_SERVICE"|"NET_BROADCAST"|"NET_RAW"|"SETFCAP"|"SETGID"|"SETPCAP"|"SETUID"|"SYS_ADMIN"|"SYS_BOOT"|"SYS_CHROOT"|"SYS_MODULE"|"SYS_NICE"|"SYS_PACCT"|"SYS_PTRACE"|"SYS_RAWIO"|"SYS_RESOURCE"|"SYS_TIME"|"SYS_TTY_CONFIG"|"SYSLOG"|"WAKE_ALARM"
-
hasDrop
public final boolean hasDrop()For responses, this returns true if the service returned a value for the Drop property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
drop
The Linux capabilities for the container that are dropped from the default configuration provided by Docker.
Valid values:
"ALL"|"AUDIT_CONTROL"|"AUDIT_WRITE"|"BLOCK_SUSPEND"|"CHOWN"|"DAC_OVERRIDE"|"DAC_READ_SEARCH"|"FOWNER"|"FSETID"|"IPC_LOCK"|"IPC_OWNER"|"KILL"|"LEASE"|"LINUX_IMMUTABLE"|"MAC_ADMIN"|"MAC_OVERRIDE"|"MKNOD"|"NET_ADMIN"|"NET_BIND_SERVICE"|"NET_BROADCAST"|"NET_RAW"|"SETFCAP"|"SETGID"|"SETPCAP"|"SETUID"|"SYS_ADMIN"|"SYS_BOOT"|"SYS_CHROOT"|"SYS_MODULE"|"SYS_NICE"|"SYS_PACCT"|"SYS_PTRACE"|"SYS_RAWIO"|"SYS_RESOURCE"|"SYS_TIME"|"SYS_TTY_CONFIG"|"SYSLOG"|"WAKE_ALARM"Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasDrop()method.- Returns:
- The Linux capabilities for the container that are dropped from the default configuration provided by
Docker.
Valid values:
"ALL"|"AUDIT_CONTROL"|"AUDIT_WRITE"|"BLOCK_SUSPEND"|"CHOWN"|"DAC_OVERRIDE"|"DAC_READ_SEARCH"|"FOWNER"|"FSETID"|"IPC_LOCK"|"IPC_OWNER"|"KILL"|"LEASE"|"LINUX_IMMUTABLE"|"MAC_ADMIN"|"MAC_OVERRIDE"|"MKNOD"|"NET_ADMIN"|"NET_BIND_SERVICE"|"NET_BROADCAST"|"NET_RAW"|"SETFCAP"|"SETGID"|"SETPCAP"|"SETUID"|"SYS_ADMIN"|"SYS_BOOT"|"SYS_CHROOT"|"SYS_MODULE"|"SYS_NICE"|"SYS_PACCT"|"SYS_PTRACE"|"SYS_RAWIO"|"SYS_RESOURCE"|"SYS_TIME"|"SYS_TTY_CONFIG"|"SYSLOG"|"WAKE_ALARM"
-
toBuilder
-
builder
public static AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.Builder builder() -
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-