Class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails>
A host device to expose to the container.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe path inside the container at which to expose the host device.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Permissions property.final StringhostPath()The path for the device on the host container instance.The explicit permissions to provide to the container for the device.static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
containerPath
The path inside the container at which to expose the host device.
- Returns:
- The path inside the container at which to expose the host device.
-
hostPath
The path for the device on the host container instance.
- Returns:
- The path for the device on the host container instance.
-
hasPermissions
public final boolean hasPermissions()For responses, this returns true if the service returned a value for the Permissions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
permissions
The explicit permissions to provide to the container for the device. By default, the container has permissions for read, write, and
mknodfor the device.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasPermissions()method.- Returns:
- The explicit permissions to provide to the container for the device. By default, the container has
permissions for read, write, and
mknodfor the device.
-
toBuilder
-
builder
public static AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.Builder builder() -
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-