Class AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails>
A secret to pass to the log configuration.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the secret.static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails.Builder>final StringtoString()Returns a string representation of this object.final StringThe secret to expose to the container.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the secret.
- Returns:
- The name of the secret.
-
valueFrom
The secret to expose to the container.
The value is either the full ARN of the Secrets Manager secret or the full ARN of the parameter in the Systems Manager Parameter Store.
- Returns:
- The secret to expose to the container.
The value is either the full ARN of the Secrets Manager secret or the full ARN of the parameter in the Systems Manager Parameter Store.
-
toBuilder
-
builder
public static AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails.Builder builder() -
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-