Class AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails>
A mount point for the data volumes in the container.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe path on the container to mount the host volume at.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanreadOnly()Whether the container has read-only access to the volume.static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails.Builder>final StringThe name of the volume to mount.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
containerPath
The path on the container to mount the host volume at.
- Returns:
- The path on the container to mount the host volume at.
-
readOnly
Whether the container has read-only access to the volume.
- Returns:
- Whether the container has read-only access to the volume.
-
sourceVolume
The name of the volume to mount. Must match the name of a volume listed in
VolumeDetailsfor the task definition.- Returns:
- The name of the volume to mount. Must match the name of a volume listed in
VolumeDetailsfor the task definition.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-