Class AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails>
A port mapping for the container.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final IntegerThe port number on the container that is bound to the user-specified or automatically assigned host port.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerhostPort()The port number on the container instance to reserve for the container.final Stringprotocol()The protocol used for the port mapping.static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
containerPort
The port number on the container that is bound to the user-specified or automatically assigned host port.
- Returns:
- The port number on the container that is bound to the user-specified or automatically assigned host port.
-
hostPort
The port number on the container instance to reserve for the container.
- Returns:
- The port number on the container instance to reserve for the container.
-
protocol
The protocol used for the port mapping. The default is
tcp.- Returns:
- The protocol used for the port mapping. The default is
tcp.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-