Class AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails.Builder,AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails>
A resource to assign to a container.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringtoString()Returns a string representation of this object.final Stringtype()The type of resource to assign to a container.final Stringvalue()The value for the specified resource type.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
The type of resource to assign to a container. Valid values are
GPUorInferenceAccelerator.- Returns:
- The type of resource to assign to a container. Valid values are
GPUorInferenceAccelerator.
-
value
The value for the specified resource type.
For
GPU, the value is the number of physical GPUs the Amazon ECS container agent reserves for the container.For
InferenceAccelerator, the value should match theDeviceNameattribute of an entry inInferenceAccelerators.- Returns:
- The value for the specified resource type.
For
GPU, the value is the number of physical GPUs the Amazon ECS container agent reserves for the container.For
InferenceAccelerator, the value should match theDeviceNameattribute of an entry inInferenceAccelerators.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-