Class AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails.Builder,AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails>
Information about a Docker volume.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionfinal BooleanWhether to create the Docker volume automatically if it does not already exist.builder()final Stringdriver()The Docker volume driver to use.A map of Docker driver-specific options that are passed through.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the DriverOpts property.final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Labels property.labels()Custom metadata to add to the Docker volume.final Stringscope()The scope for the Docker volume that determines its lifecycle.static Class<? extends AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
autoprovision
Whether to create the Docker volume automatically if it does not already exist.
- Returns:
- Whether to create the Docker volume automatically if it does not already exist.
-
driver
The Docker volume driver to use.
- Returns:
- The Docker volume driver to use.
-
hasDriverOpts
public final boolean hasDriverOpts()For responses, this returns true if the service returned a value for the DriverOpts property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
driverOpts
A map of Docker driver-specific options that are passed through.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasDriverOpts()method.- Returns:
- A map of Docker driver-specific options that are passed through.
-
hasLabels
public final boolean hasLabels()For responses, this returns true if the service returned a value for the Labels property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
labels
Custom metadata to add to the Docker volume.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasLabels()method.- Returns:
- Custom metadata to add to the Docker volume.
-
scope
The scope for the Docker volume that determines its lifecycle. Docker volumes that are scoped to a task are provisioned automatically when the task starts and destroyed when the task stops. Docker volumes that are shared persist after the task stops. Valid values are
sharedortask.- Returns:
- The scope for the Docker volume that determines its lifecycle. Docker volumes that are scoped to a task
are provisioned automatically when the task starts and destroyed when the task stops. Docker volumes that
are shared persist after the task stops. Valid values are
sharedortask.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-