Class AwsEcsTaskVolumeDetails

java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskVolumeDetails
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<AwsEcsTaskVolumeDetails.Builder,AwsEcsTaskVolumeDetails>

@Generated("software.amazon.awssdk:codegen") public final class AwsEcsTaskVolumeDetails extends Object implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskVolumeDetails.Builder,AwsEcsTaskVolumeDetails>

Provides information about a data volume that's used in a task definition.

See Also:
  • Method Details

    • name

      public final String name()

      The name of the volume. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed. This name is referenced in the sourceVolume parameter of container definition mountPoints.

      Returns:
      The name of the volume. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed. This name is referenced in the sourceVolume parameter of container definition mountPoints.
    • host

      public final AwsEcsTaskVolumeHostDetails host()

      This parameter is specified when you use bind mount host volumes. The contents of the host parameter determine whether your bind mount host volume persists on the host container instance and where it's stored.

      Returns:
      This parameter is specified when you use bind mount host volumes. The contents of the host parameter determine whether your bind mount host volume persists on the host container instance and where it's stored.
    • toBuilder

      public AwsEcsTaskVolumeDetails.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<AwsEcsTaskVolumeDetails.Builder,AwsEcsTaskVolumeDetails>
    • builder

      public static AwsEcsTaskVolumeDetails.Builder builder()
    • serializableBuilderClass

      public static Class<? extends AwsEcsTaskVolumeDetails.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo