Class AwsElbLoadBalancerAccessLog
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsElbLoadBalancerAccessLog
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsElbLoadBalancerAccessLog.Builder,AwsElbLoadBalancerAccessLog>
@Generated("software.amazon.awssdk:codegen")
public final class AwsElbLoadBalancerAccessLog
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsElbLoadBalancerAccessLog.Builder,AwsElbLoadBalancerAccessLog>
Contains information about the access log configuration for the load balancer.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final IntegerThe interval in minutes for publishing the access logs.final Booleanenabled()Indicates whether access logs are enabled for the load balancer.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the S3 bucket where the access logs are stored.final StringThe logical hierarchy that was created for the S3 bucket.static Class<? extends AwsElbLoadBalancerAccessLog.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
emitInterval
The interval in minutes for publishing the access logs.
You can publish access logs either every 5 minutes or every 60 minutes.
- Returns:
- The interval in minutes for publishing the access logs.
You can publish access logs either every 5 minutes or every 60 minutes.
-
enabled
Indicates whether access logs are enabled for the load balancer.
- Returns:
- Indicates whether access logs are enabled for the load balancer.
-
s3BucketName
The name of the S3 bucket where the access logs are stored.
- Returns:
- The name of the S3 bucket where the access logs are stored.
-
s3BucketPrefix
The logical hierarchy that was created for the S3 bucket.
If a prefix is not provided, the log is placed at the root level of the bucket.
- Returns:
- The logical hierarchy that was created for the S3 bucket.
If a prefix is not provided, the log is placed at the root level of the bucket.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsElbLoadBalancerAccessLog.Builder,AwsElbLoadBalancerAccessLog>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-