Class AwsElbLoadBalancerHealthCheck
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsElbLoadBalancerHealthCheck.Builder,AwsElbLoadBalancerHealthCheck>
Contains information about the health checks that are conducted on the load balancer.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe number of consecutive health check successes required before the instance is moved to the Healthy state.final Integerinterval()The approximate interval, in seconds, between health checks of an individual instance.static Class<? extends AwsElbLoadBalancerHealthCheck.Builder>final Stringtarget()The instance that is being checked.final Integertimeout()The amount of time, in seconds, during which no response means a failed health check.final StringtoString()Returns a string representation of this object.final IntegerThe number of consecutive health check failures that must occur before the instance is moved to the Unhealthy state.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
healthyThreshold
The number of consecutive health check successes required before the instance is moved to the Healthy state.
- Returns:
- The number of consecutive health check successes required before the instance is moved to the Healthy state.
-
interval
The approximate interval, in seconds, between health checks of an individual instance.
- Returns:
- The approximate interval, in seconds, between health checks of an individual instance.
-
target
The instance that is being checked. The target specifies the protocol and port. The available protocols are TCP, SSL, HTTP, and HTTPS. The range of valid ports is 1 through 65535.
For the HTTP and HTTPS protocols, the target also specifies the ping path.
For the TCP protocol, the target is specified as
TCP: <port>.For the SSL protocol, the target is specified as
SSL.<port>.For the HTTP and HTTPS protocols, the target is specified as
<protocol>:<port>/<path to ping>.- Returns:
- The instance that is being checked. The target specifies the protocol and port. The available protocols
are TCP, SSL, HTTP, and HTTPS. The range of valid ports is 1 through 65535.
For the HTTP and HTTPS protocols, the target also specifies the ping path.
For the TCP protocol, the target is specified as
TCP: <port>.For the SSL protocol, the target is specified as
SSL.<port>.For the HTTP and HTTPS protocols, the target is specified as
<protocol>:<port>/<path to ping>.
-
timeout
The amount of time, in seconds, during which no response means a failed health check.
- Returns:
- The amount of time, in seconds, during which no response means a failed health check.
-
unhealthyThreshold
The number of consecutive health check failures that must occur before the instance is moved to the Unhealthy state.
- Returns:
- The number of consecutive health check failures that must occur before the instance is moved to the Unhealthy state.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsElbLoadBalancerHealthCheck.Builder,AwsElbLoadBalancerHealthCheck>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-