Class AwsGuardDutyDetectorDataSourcesDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsGuardDutyDetectorDataSourcesDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsGuardDutyDetectorDataSourcesDetails.Builder,AwsGuardDutyDetectorDataSourcesDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsGuardDutyDetectorDataSourcesDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsGuardDutyDetectorDataSourcesDetails.Builder,AwsGuardDutyDetectorDataSourcesDetails>
Describes which data sources are activated for the detector.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()An object that contains information on the status of CloudTrail as a data source for the detector.dnsLogs()An object that contains information on the status of DNS logs as a data source for the detector.final booleanfinal booleanequalsBySdkFields(Object obj) flowLogs()An object that contains information on the status of VPC Flow Logs as a data source for the detector.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()An object that contains information on the status of Kubernetes data sources for the detector.An object that contains information on the status of Malware Protection as a data source for the detector.s3Logs()An object that contains information on the status of S3 Data event logs as a data source for the detector.static Class<? extends AwsGuardDutyDetectorDataSourcesDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
cloudTrail
An object that contains information on the status of CloudTrail as a data source for the detector.
- Returns:
- An object that contains information on the status of CloudTrail as a data source for the detector.
-
dnsLogs
An object that contains information on the status of DNS logs as a data source for the detector.
- Returns:
- An object that contains information on the status of DNS logs as a data source for the detector.
-
flowLogs
An object that contains information on the status of VPC Flow Logs as a data source for the detector.
- Returns:
- An object that contains information on the status of VPC Flow Logs as a data source for the detector.
-
kubernetes
An object that contains information on the status of Kubernetes data sources for the detector.
- Returns:
- An object that contains information on the status of Kubernetes data sources for the detector.
-
malwareProtection
An object that contains information on the status of Malware Protection as a data source for the detector.
- Returns:
- An object that contains information on the status of Malware Protection as a data source for the detector.
-
s3Logs
An object that contains information on the status of S3 Data event logs as a data source for the detector.
- Returns:
- An object that contains information on the status of S3 Data event logs as a data source for the detector.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsGuardDutyDetectorDataSourcesDetails.Builder,AwsGuardDutyDetectorDataSourcesDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsGuardDutyDetectorDataSourcesDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-