Class AwsGuardDutyDetectorDataSourcesFlowLogsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsGuardDutyDetectorDataSourcesFlowLogsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsGuardDutyDetectorDataSourcesFlowLogsDetails.Builder,AwsGuardDutyDetectorDataSourcesFlowLogsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsGuardDutyDetectorDataSourcesFlowLogsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsGuardDutyDetectorDataSourcesFlowLogsDetails.Builder,AwsGuardDutyDetectorDataSourcesFlowLogsDetails>
An object that contains information on the status of VPC Flow Logs as a data source for the detector.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsGuardDutyDetectorDataSourcesFlowLogsDetails.Builder>final Stringstatus()Describes whether VPC Flow Logs are activated as a data source for the detector.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
status
Describes whether VPC Flow Logs are activated as a data source for the detector.
- Returns:
- Describes whether VPC Flow Logs are activated as a data source for the detector.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsGuardDutyDetectorDataSourcesFlowLogsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-