Class AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails.Builder,AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails.Builder,AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails>
An object that contains information on the status of Malware Protection as a data source for the detector.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()Describes the configuration of Malware Protection for EC2 instances with findings.static Class<? extends AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails.Builder>final StringThe GuardDuty Malware Protection service role.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
scanEc2InstanceWithFindings
public final AwsGuardDutyDetectorDataSourcesMalwareProtectionScanEc2InstanceWithFindingsDetails scanEc2InstanceWithFindings()Describes the configuration of Malware Protection for EC2 instances with findings.
- Returns:
- Describes the configuration of Malware Protection for EC2 instances with findings.
-
serviceRole
The GuardDuty Malware Protection service role.
- Returns:
- The GuardDuty Malware Protection service role.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-