Class AwsIamAccessKeySessionContext
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsIamAccessKeySessionContext
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsIamAccessKeySessionContext.Builder,AwsIamAccessKeySessionContext>
@Generated("software.amazon.awssdk:codegen")
public final class AwsIamAccessKeySessionContext
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsIamAccessKeySessionContext.Builder,AwsIamAccessKeySessionContext>
Provides information about the session that the key was used for.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionAttributes of the session that the key was used for.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsIamAccessKeySessionContext.Builder>Information about the entity that created the session.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
attributes
Attributes of the session that the key was used for.
- Returns:
- Attributes of the session that the key was used for.
-
sessionIssuer
Information about the entity that created the session.
- Returns:
- Information about the entity that created the session.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsIamAccessKeySessionContext.Builder,AwsIamAccessKeySessionContext>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-