Class AwsIamAccessKeySessionContextAttributes
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsIamAccessKeySessionContextAttributes
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsIamAccessKeySessionContextAttributes.Builder,AwsIamAccessKeySessionContextAttributes>
@Generated("software.amazon.awssdk:codegen")
public final class AwsIamAccessKeySessionContextAttributes
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsIamAccessKeySessionContextAttributes.Builder,AwsIamAccessKeySessionContextAttributes>
Attributes of the session that the key was used for.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringIndicates when the session was created.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanIndicates whether the session used multi-factor authentication (MFA).static Class<? extends AwsIamAccessKeySessionContextAttributes.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
mfaAuthenticated
Indicates whether the session used multi-factor authentication (MFA).
- Returns:
- Indicates whether the session used multi-factor authentication (MFA).
-
creationDate
Indicates when the session was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the session was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsIamAccessKeySessionContextAttributes.Builder,AwsIamAccessKeySessionContextAttributes>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsIamAccessKeySessionContextAttributes.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-