Class AwsIamAccessKeySessionContextSessionIssuer
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsIamAccessKeySessionContextSessionIssuer
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsIamAccessKeySessionContextSessionIssuer.Builder,AwsIamAccessKeySessionContextSessionIssuer>
@Generated("software.amazon.awssdk:codegen")
public final class AwsIamAccessKeySessionContextSessionIssuer
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsIamAccessKeySessionContextSessionIssuer.Builder,AwsIamAccessKeySessionContextSessionIssuer>
Information about the entity that created the session.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe identifier of the Amazon Web Services account that created the session.final Stringarn()The ARN of the session.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe principal ID of the principal (user, role, or group) that created the session.static Class<? extends AwsIamAccessKeySessionContextSessionIssuer.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of principal (user, role, or group) that created the session.final StringuserName()The name of the principal that created the session.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
The type of principal (user, role, or group) that created the session.
- Returns:
- The type of principal (user, role, or group) that created the session.
-
principalId
The principal ID of the principal (user, role, or group) that created the session.
- Returns:
- The principal ID of the principal (user, role, or group) that created the session.
-
arn
The ARN of the session.
- Returns:
- The ARN of the session.
-
accountId
The identifier of the Amazon Web Services account that created the session.
- Returns:
- The identifier of the Amazon Web Services account that created the session.
-
userName
The name of the principal that created the session.
- Returns:
- The name of the principal that created the session.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsIamAccessKeySessionContextSessionIssuer.Builder,AwsIamAccessKeySessionContextSessionIssuer>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsIamAccessKeySessionContextSessionIssuer.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-