Class AwsIamInstanceProfile
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsIamInstanceProfile.Builder,AwsIamInstanceProfile>
Information about an instance profile.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The ARN of the instance profile.builder()final StringIndicates when the instance profile was created.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasRoles()For responses, this returns true if the service returned a value for the Roles property.final StringThe identifier of the instance profile.final StringThe name of the instance profile.final Stringpath()The path to the instance profile.final List<AwsIamInstanceProfileRole>roles()The roles associated with the instance profile.static Class<? extends AwsIamInstanceProfile.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
arn
The ARN of the instance profile.
- Returns:
- The ARN of the instance profile.
-
createDate
Indicates when the instance profile was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the instance profile was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
instanceProfileId
The identifier of the instance profile.
- Returns:
- The identifier of the instance profile.
-
instanceProfileName
The name of the instance profile.
- Returns:
- The name of the instance profile.
-
path
The path to the instance profile.
- Returns:
- The path to the instance profile.
-
hasRoles
public final boolean hasRoles()For responses, this returns true if the service returned a value for the Roles property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
roles
The roles associated with the instance profile.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasRoles()method.- Returns:
- The roles associated with the instance profile.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsIamInstanceProfile.Builder,AwsIamInstanceProfile>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-