Class AwsIamInstanceProfileRole
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsIamInstanceProfileRole
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsIamInstanceProfileRole.Builder,AwsIamInstanceProfileRole>
@Generated("software.amazon.awssdk:codegen")
public final class AwsIamInstanceProfileRole
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsIamInstanceProfileRole.Builder,AwsIamInstanceProfileRole>
Information about a role associated with an instance profile.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The ARN of the role.final StringThe policy that grants an entity permission to assume the role.builder()final StringIndicates when the role was created.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringpath()The path to the role.final StringroleId()The identifier of the role.final StringroleName()The name of the role.static Class<? extends AwsIamInstanceProfileRole.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
arn
The ARN of the role.
- Returns:
- The ARN of the role.
-
assumeRolePolicyDocument
The policy that grants an entity permission to assume the role.
- Returns:
- The policy that grants an entity permission to assume the role.
-
createDate
Indicates when the role was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the role was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
path
The path to the role.
- Returns:
- The path to the role.
-
roleId
The identifier of the role.
- Returns:
- The identifier of the role.
-
roleName
The name of the role.
- Returns:
- The name of the role.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsIamInstanceProfileRole.Builder,AwsIamInstanceProfileRole>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-