Class AwsIamPolicyVersion
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsIamPolicyVersion
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsIamPolicyVersion.Builder,AwsIamPolicyVersion>
@Generated("software.amazon.awssdk:codegen")
public final class AwsIamPolicyVersion
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsIamPolicyVersion.Builder,AwsIamPolicyVersion>
A version of an IAM policy.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic AwsIamPolicyVersion.Builderbuilder()final StringIndicates when the version was created.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanWhether the version is the default version.static Class<? extends AwsIamPolicyVersion.Builder>final StringtoString()Returns a string representation of this object.final StringThe identifier of the policy version.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
versionId
The identifier of the policy version.
- Returns:
- The identifier of the policy version.
-
isDefaultVersion
Whether the version is the default version.
- Returns:
- Whether the version is the default version.
-
createDate
Indicates when the version was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the version was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsIamPolicyVersion.Builder,AwsIamPolicyVersion>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-