Class AwsKmsKeyDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsKmsKeyDetails.Builder,AwsKmsKeyDetails>
Contains metadata about an KMS key.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe twelve-digit account ID of the Amazon Web Services account that owns the KMS key.static AwsKmsKeyDetails.Builderbuilder()final DoubleIndicates when the KMS key was created.final StringA description of the KMS key.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringkeyId()The globally unique identifier for the KMS key.final StringThe manager of the KMS key.final BooleanWhether the key has key rotation enabled.final StringkeyState()The state of the KMS key.final Stringorigin()The source of the KMS key material.static Class<? extends AwsKmsKeyDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
awsAccountId
The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
- Returns:
- The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
-
creationDate
Indicates when the KMS key was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the KMS key was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
keyId
The globally unique identifier for the KMS key.
- Returns:
- The globally unique identifier for the KMS key.
-
keyManager
The manager of the KMS key. KMS keys in your Amazon Web Services account are either customer managed or Amazon Web Services managed.
- Returns:
- The manager of the KMS key. KMS keys in your Amazon Web Services account are either customer managed or Amazon Web Services managed.
-
keyState
The state of the KMS key. Valid values are as follows:
-
Disabled -
Enabled -
PendingDeletion -
PendingImport -
Unavailable
- Returns:
- The state of the KMS key. Valid values are as follows:
-
Disabled -
Enabled -
PendingDeletion -
PendingImport -
Unavailable
-
-
-
origin
The source of the KMS key material.
When this value is
AWS_KMS, KMS created the key material.When this value is
EXTERNAL, the key material was imported from your existing key management infrastructure or the KMS key lacks key material.When this value is
AWS_CLOUDHSM, the key material was created in the CloudHSM cluster associated with a custom key store.- Returns:
- The source of the KMS key material.
When this value is
AWS_KMS, KMS created the key material.When this value is
EXTERNAL, the key material was imported from your existing key management infrastructure or the KMS key lacks key material.When this value is
AWS_CLOUDHSM, the key material was created in the CloudHSM cluster associated with a custom key store.
-
description
A description of the KMS key.
- Returns:
- A description of the KMS key.
-
keyRotationStatus
Whether the key has key rotation enabled.
- Returns:
- Whether the key has key rotation enabled.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsKmsKeyDetails.Builder,AwsKmsKeyDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-