Class AwsMountPoint
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsMountPoint
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsMountPoint.Builder,AwsMountPoint>
@Generated("software.amazon.awssdk:codegen")
public final class AwsMountPoint
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsMountPoint.Builder,AwsMountPoint>
Details for a volume mount point that's used in a container definition.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic AwsMountPoint.Builderbuilder()final StringThe path on the container to mount the host volume at.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsMountPoint.Builder>final StringThe name of the volume to mount.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
sourceVolume
The name of the volume to mount. Must be a volume name referenced in the
nameparameter of task definitionvolume.- Returns:
- The name of the volume to mount. Must be a volume name referenced in the
nameparameter of task definitionvolume.
-
containerPath
The path on the container to mount the host volume at.
- Returns:
- The path on the container to mount the host volume at.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsMountPoint.Builder,AwsMountPoint>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-