Class AwsNetworkFirewallRuleGroupDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsNetworkFirewallRuleGroupDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsNetworkFirewallRuleGroupDetails.Builder,AwsNetworkFirewallRuleGroupDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsNetworkFirewallRuleGroupDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsNetworkFirewallRuleGroupDetails.Builder,AwsNetworkFirewallRuleGroupDetails>
Details about an Network Firewall rule group. Rule groups are used to inspect and control network traffic. Stateless rule groups apply to individual packets. Stateful rule groups apply to packets in the context of their traffic flow.
Rule groups are referenced in firewall policies.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Integercapacity()The maximum number of operating resources that this rule group can use.final StringA description of the rule group.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final RuleGroupDetailsDetails about the rule group.final StringThe ARN of the rule group.final StringThe identifier of the rule group.final StringThe descriptive name of the rule group.static Class<? extends AwsNetworkFirewallRuleGroupDetails.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of rule group.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
capacity
The maximum number of operating resources that this rule group can use.
- Returns:
- The maximum number of operating resources that this rule group can use.
-
description
A description of the rule group.
- Returns:
- A description of the rule group.
-
ruleGroup
Details about the rule group.
- Returns:
- Details about the rule group.
-
ruleGroupArn
The ARN of the rule group.
- Returns:
- The ARN of the rule group.
-
ruleGroupId
The identifier of the rule group.
- Returns:
- The identifier of the rule group.
-
ruleGroupName
The descriptive name of the rule group.
- Returns:
- The descriptive name of the rule group.
-
type
The type of rule group. A rule group can be stateful or stateless.
- Returns:
- The type of rule group. A rule group can be stateful or stateless.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsNetworkFirewallRuleGroupDetails.Builder,AwsNetworkFirewallRuleGroupDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsNetworkFirewallRuleGroupDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-