Class AwsOpenSearchServiceDomainClusterConfigDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsOpenSearchServiceDomainClusterConfigDetails.Builder,AwsOpenSearchServiceDomainClusterConfigDetails>
Details about the configuration of an OpenSearch cluster.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final IntegerThe number of instances to use for the master node.final BooleanWhether to use a dedicated master node for the OpenSearch domain.final StringThe hardware configuration of the computer that hosts the dedicated master node.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe number of data nodes to use in the OpenSearch domain.final StringThe instance type for your data nodes.static Class<? extends AwsOpenSearchServiceDomainClusterConfigDetails.Builder>final StringtoString()Returns a string representation of this object.final IntegerThe number of UltraWarm instances.final BooleanWhether UltraWarm is enabled.final StringwarmType()The type of UltraWarm instance.Configuration options for zone awareness.final BooleanWhether to enable zone awareness for the OpenSearch domain.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
instanceCount
The number of data nodes to use in the OpenSearch domain.
- Returns:
- The number of data nodes to use in the OpenSearch domain.
-
warmEnabled
Whether UltraWarm is enabled.
- Returns:
- Whether UltraWarm is enabled.
-
warmCount
The number of UltraWarm instances.
- Returns:
- The number of UltraWarm instances.
-
dedicatedMasterEnabled
Whether to use a dedicated master node for the OpenSearch domain. A dedicated master node performs cluster management tasks, but does not hold data or respond to data upload requests.
- Returns:
- Whether to use a dedicated master node for the OpenSearch domain. A dedicated master node performs cluster management tasks, but does not hold data or respond to data upload requests.
-
zoneAwarenessConfig
public final AwsOpenSearchServiceDomainClusterConfigZoneAwarenessConfigDetails zoneAwarenessConfig()Configuration options for zone awareness. Provided if
ZoneAwarenessEnabledistrue.- Returns:
- Configuration options for zone awareness. Provided if
ZoneAwarenessEnabledistrue.
-
dedicatedMasterCount
The number of instances to use for the master node. If this attribute is specified, then
DedicatedMasterEnabledmust betrue.- Returns:
- The number of instances to use for the master node. If this attribute is specified, then
DedicatedMasterEnabledmust betrue.
-
instanceType
The instance type for your data nodes.
For a list of valid values, see Supported instance types in Amazon OpenSearch Service in the Amazon OpenSearch Service Developer Guide.
- Returns:
- The instance type for your data nodes.
For a list of valid values, see Supported instance types in Amazon OpenSearch Service in the Amazon OpenSearch Service Developer Guide.
-
warmType
The type of UltraWarm instance.
- Returns:
- The type of UltraWarm instance.
-
zoneAwarenessEnabled
Whether to enable zone awareness for the OpenSearch domain. When zone awareness is enabled, OpenSearch Service allocates the cluster's nodes and replica index shards across Availability Zones (AZs) in the same Region. This prevents data loss and minimizes downtime if a node or data center fails.
- Returns:
- Whether to enable zone awareness for the OpenSearch domain. When zone awareness is enabled, OpenSearch Service allocates the cluster's nodes and replica index shards across Availability Zones (AZs) in the same Region. This prevents data loss and minimizes downtime if a node or data center fails.
-
dedicatedMasterType
The hardware configuration of the computer that hosts the dedicated master node.
If this attribute is specified, then
DedicatedMasterEnabledmust betrue.- Returns:
- The hardware configuration of the computer that hosts the dedicated master node.
If this attribute is specified, then
DedicatedMasterEnabledmust betrue.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsOpenSearchServiceDomainClusterConfigDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-