Class AwsOpenSearchServiceDomainDomainEndpointOptionsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainDomainEndpointOptionsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsOpenSearchServiceDomainDomainEndpointOptionsDetails.Builder,AwsOpenSearchServiceDomainDomainEndpointOptionsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsOpenSearchServiceDomainDomainEndpointOptionsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsOpenSearchServiceDomainDomainEndpointOptionsDetails.Builder,AwsOpenSearchServiceDomainDomainEndpointOptionsDetails>
Information about additional options for the domain endpoint.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe fully qualified URL for the custom endpoint.final StringThe ARN for the security certificate.final BooleanWhether to enable a custom endpoint for the domain.final BooleanWhether to require that all traffic to the domain arrive over HTTPS.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsOpenSearchServiceDomainDomainEndpointOptionsDetails.Builder>final StringThe TLS security policy to apply to the HTTPS endpoint of the OpenSearch domain.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
customEndpointCertificateArn
The ARN for the security certificate. The certificate is managed in ACM.
- Returns:
- The ARN for the security certificate. The certificate is managed in ACM.
-
customEndpointEnabled
Whether to enable a custom endpoint for the domain.
- Returns:
- Whether to enable a custom endpoint for the domain.
-
enforceHTTPS
Whether to require that all traffic to the domain arrive over HTTPS.
- Returns:
- Whether to require that all traffic to the domain arrive over HTTPS.
-
customEndpoint
The fully qualified URL for the custom endpoint.
- Returns:
- The fully qualified URL for the custom endpoint.
-
tlsSecurityPolicy
The TLS security policy to apply to the HTTPS endpoint of the OpenSearch domain.
- Returns:
- The TLS security policy to apply to the HTTPS endpoint of the OpenSearch domain.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsOpenSearchServiceDomainDomainEndpointOptionsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-