Class AwsOpenSearchServiceDomainMasterUserOptionsDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainMasterUserOptionsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsOpenSearchServiceDomainMasterUserOptionsDetails.Builder,AwsOpenSearchServiceDomainMasterUserOptionsDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsOpenSearchServiceDomainMasterUserOptionsDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsOpenSearchServiceDomainMasterUserOptionsDetails.Builder,AwsOpenSearchServiceDomainMasterUserOptionsDetails>
Specifies information about the master user of the domain.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe Amazon Resource Name (ARN) for the master user.final StringThe username for the master user.final StringThe password for the master user.static Class<? extends AwsOpenSearchServiceDomainMasterUserOptionsDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
masterUserArn
The Amazon Resource Name (ARN) for the master user.
- Returns:
- The Amazon Resource Name (ARN) for the master user.
-
masterUserName
The username for the master user.
- Returns:
- The username for the master user.
-
masterUserPassword
The password for the master user.
- Returns:
- The password for the master user.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsOpenSearchServiceDomainMasterUserOptionsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-