Class AwsOrganizationScope
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsOrganizationScope.Builder,AwsOrganizationScope>
Specifies an Organizations scope. Data from the specified organization or organizational unit is included in the response.
To scope to a specific organizational unit, provide OrganizationalUnitId. You can optionally include
OrganizationId. If you omit OrganizationId, Security Hub uses the caller's organization ID.
To scope to the delegated administrator's entire organization, provide only OrganizationId.
The organization ID and organizational unit must belong to the delegated administrator's own organization. Each
request must use one scoping approach: either scope to the entire organization by providing an
AwsOrganizationScope entry with only OrganizationId, or scope to specific organizational
units by providing AwsOrganizationScope entries with OrganizationalUnitId. You can't
combine both approaches in the same request.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic AwsOrganizationScope.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe unique identifier (ID) of the organizational unit (OU) (for example,ou-ab12-cd345678).final StringThe unique identifier (ID) of the organization (for example,o-abcd1234567890).static Class<? extends AwsOrganizationScope.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
organizationId
The unique identifier (ID) of the organization (for example,
o-abcd1234567890). The organization must be the delegated administrator's own organization. If you omit this value and provideOrganizationalUnitId, Security Hub uses the caller's organization ID.- Returns:
- The unique identifier (ID) of the organization (for example,
o-abcd1234567890). The organization must be the delegated administrator's own organization. If you omit this value and provideOrganizationalUnitId, Security Hub uses the caller's organization ID.
-
organizationalUnitId
The unique identifier (ID) of the organizational unit (OU) (for example,
ou-ab12-cd345678). The OU must exist within the delegated administrator's own organization. When specified, the results include only data from accounts in this OU.- Returns:
- The unique identifier (ID) of the organizational unit (OU) (for example,
ou-ab12-cd345678). The OU must exist within the delegated administrator's own organization. When specified, the results include only data from accounts in this OU.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsOrganizationScope.Builder,AwsOrganizationScope>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-