Class AwsRdsDbInstanceEndpoint
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsRdsDbInstanceEndpoint
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsRdsDbInstanceEndpoint.Builder,AwsRdsDbInstanceEndpoint>
@Generated("software.amazon.awssdk:codegen")
public final class AwsRdsDbInstanceEndpoint
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsRdsDbInstanceEndpoint.Builder,AwsRdsDbInstanceEndpoint>
Specifies the connection endpoint.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringaddress()Specifies the DNS address of the DB instance.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringSpecifies the ID that Amazon Route 53 assigns when you create a hosted zone.final Integerport()Specifies the port that the database engine is listening on.static Class<? extends AwsRdsDbInstanceEndpoint.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
address
Specifies the DNS address of the DB instance.
- Returns:
- Specifies the DNS address of the DB instance.
-
port
Specifies the port that the database engine is listening on.
- Returns:
- Specifies the port that the database engine is listening on.
-
hostedZoneId
Specifies the ID that Amazon Route 53 assigns when you create a hosted zone.
- Returns:
- Specifies the ID that Amazon Route 53 assigns when you create a hosted zone.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsRdsDbInstanceEndpoint.Builder,AwsRdsDbInstanceEndpoint>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-