Class AwsRedshiftClusterClusterParameterStatus
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsRedshiftClusterClusterParameterStatus
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsRedshiftClusterClusterParameterStatus.Builder,AwsRedshiftClusterClusterParameterStatus>
@Generated("software.amazon.awssdk:codegen")
public final class AwsRedshiftClusterClusterParameterStatus
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsRedshiftClusterClusterParameterStatus.Builder,AwsRedshiftClusterClusterParameterStatus>
The status of a parameter in a cluster parameter group for an Amazon Redshift cluster.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe error that prevented the parameter from being applied to the database.final StringThe status of the parameter.final StringThe name of the parameter.static Class<? extends AwsRedshiftClusterClusterParameterStatus.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
parameterName
The name of the parameter.
- Returns:
- The name of the parameter.
-
parameterApplyStatus
The status of the parameter. Indicates whether the parameter is in sync with the database, waiting for a cluster reboot, or encountered an error when it was applied.
Valid values:
in-sync|pending-reboot|applying|invalid-parameter|apply-deferred|apply-error|unknown-error- Returns:
- The status of the parameter. Indicates whether the parameter is in sync with the database, waiting for a
cluster reboot, or encountered an error when it was applied.
Valid values:
in-sync|pending-reboot|applying|invalid-parameter|apply-deferred|apply-error|unknown-error
-
parameterApplyErrorDescription
The error that prevented the parameter from being applied to the database.
- Returns:
- The error that prevented the parameter from being applied to the database.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsRedshiftClusterClusterParameterStatus.Builder,AwsRedshiftClusterClusterParameterStatus>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsRedshiftClusterClusterParameterStatus.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-