Class AwsRedshiftClusterClusterSecurityGroup
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsRedshiftClusterClusterSecurityGroup
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsRedshiftClusterClusterSecurityGroup.Builder,AwsRedshiftClusterClusterSecurityGroup>
@Generated("software.amazon.awssdk:codegen")
public final class AwsRedshiftClusterClusterSecurityGroup
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsRedshiftClusterClusterSecurityGroup.Builder,AwsRedshiftClusterClusterSecurityGroup>
A security group that is associated with the cluster.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe name of the cluster security group.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsRedshiftClusterClusterSecurityGroup.Builder>final Stringstatus()The status of the cluster security group.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
clusterSecurityGroupName
The name of the cluster security group.
- Returns:
- The name of the cluster security group.
-
status
The status of the cluster security group.
- Returns:
- The status of the cluster security group.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsRedshiftClusterClusterSecurityGroup.Builder,AwsRedshiftClusterClusterSecurityGroup>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsRedshiftClusterClusterSecurityGroup.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-