Class AwsRedshiftClusterDeferredMaintenanceWindow
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsRedshiftClusterDeferredMaintenanceWindow.Builder,AwsRedshiftClusterDeferredMaintenanceWindow>
A time windows during which maintenance was deferred for an Amazon Redshift cluster.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe end of the time window for which maintenance was deferred.final StringThe identifier of the maintenance window.final StringThe start of the time window for which maintenance was deferred.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsRedshiftClusterDeferredMaintenanceWindow.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
deferMaintenanceEndTime
The end of the time window for which maintenance was deferred.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- The end of the time window for which maintenance was deferred.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
deferMaintenanceIdentifier
The identifier of the maintenance window.
- Returns:
- The identifier of the maintenance window.
-
deferMaintenanceStartTime
The start of the time window for which maintenance was deferred.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- The start of the time window for which maintenance was deferred.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsRedshiftClusterDeferredMaintenanceWindow.Builder,AwsRedshiftClusterDeferredMaintenanceWindow>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsRedshiftClusterDeferredMaintenanceWindow.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-