Interface AwsRedshiftClusterDeferredMaintenanceWindow.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<AwsRedshiftClusterDeferredMaintenanceWindow.Builder,AwsRedshiftClusterDeferredMaintenanceWindow>,SdkBuilder<AwsRedshiftClusterDeferredMaintenanceWindow.Builder,AwsRedshiftClusterDeferredMaintenanceWindow>,SdkPojo
- Enclosing class:
- AwsRedshiftClusterDeferredMaintenanceWindow
@Mutable @NotThreadSafe public static interface AwsRedshiftClusterDeferredMaintenanceWindow.Builder extends SdkPojo, CopyableBuilder<AwsRedshiftClusterDeferredMaintenanceWindow.Builder,AwsRedshiftClusterDeferredMaintenanceWindow>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description AwsRedshiftClusterDeferredMaintenanceWindow.BuilderdeferMaintenanceEndTime(String deferMaintenanceEndTime)The end of the time window for which maintenance was deferred.AwsRedshiftClusterDeferredMaintenanceWindow.BuilderdeferMaintenanceIdentifier(String deferMaintenanceIdentifier)The identifier of the maintenance window.AwsRedshiftClusterDeferredMaintenanceWindow.BuilderdeferMaintenanceStartTime(String deferMaintenanceStartTime)The start of the time window for which maintenance was deferred.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
deferMaintenanceEndTime
AwsRedshiftClusterDeferredMaintenanceWindow.Builder deferMaintenanceEndTime(String deferMaintenanceEndTime)
The end of the time window for which maintenance was deferred.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Parameters:
deferMaintenanceEndTime- The end of the time window for which maintenance was deferred.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps a>.
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
deferMaintenanceIdentifier
AwsRedshiftClusterDeferredMaintenanceWindow.Builder deferMaintenanceIdentifier(String deferMaintenanceIdentifier)
The identifier of the maintenance window.
- Parameters:
deferMaintenanceIdentifier- The identifier of the maintenance window.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
deferMaintenanceStartTime
AwsRedshiftClusterDeferredMaintenanceWindow.Builder deferMaintenanceStartTime(String deferMaintenanceStartTime)
The start of the time window for which maintenance was deferred.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Parameters:
deferMaintenanceStartTime- The start of the time window for which maintenance was deferred.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps a>.
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-