Class AwsRedshiftClusterLoggingStatus
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsRedshiftClusterLoggingStatus.Builder,AwsRedshiftClusterLoggingStatus>
Provides information about the logging status of the cluster.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe name of the S3 bucket where the log files are stored.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe message indicating that the logs failed to be delivered.final StringThe last time when logs failed to be delivered.final StringThe last time that logs were delivered successfully.final BooleanIndicates whether logging is enabled.final StringProvides the prefix applied to the log file names.static Class<? extends AwsRedshiftClusterLoggingStatus.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
bucketName
The name of the S3 bucket where the log files are stored.
- Returns:
- The name of the S3 bucket where the log files are stored.
-
lastFailureMessage
The message indicating that the logs failed to be delivered.
- Returns:
- The message indicating that the logs failed to be delivered.
-
lastFailureTime
The last time when logs failed to be delivered.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- The last time when logs failed to be delivered.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
lastSuccessfulDeliveryTime
The last time that logs were delivered successfully.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- The last time that logs were delivered successfully.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
loggingEnabled
Indicates whether logging is enabled.
- Returns:
- Indicates whether logging is enabled.
-
s3KeyPrefix
Provides the prefix applied to the log file names.
- Returns:
- Provides the prefix applied to the log file names.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsRedshiftClusterLoggingStatus.Builder,AwsRedshiftClusterLoggingStatus>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-