Class AwsRedshiftClusterPendingModifiedValues
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsRedshiftClusterPendingModifiedValues.Builder,AwsRedshiftClusterPendingModifiedValues>
Changes to the Amazon Redshift cluster that are currently pending.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionfinal IntegerThe pending or in-progress change to the automated snapshot retention period.builder()final StringThe pending or in-progress change to the identifier for the cluster.final StringThe pending or in-progress change to the cluster type.final StringThe pending or in-progress change to the service version.final StringThe encryption type for a cluster.final BooleanIndicates whether to create the cluster with enhanced VPC routing enabled.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the maintenance track that the cluster changes to during the next maintenance window.final StringThe pending or in-progress change to the master user password for the cluster.final StringnodeType()The pending or in-progress change to the cluster's node type.final IntegerThe pending or in-progress change to the number of nodes in the cluster.final BooleanThe pending or in-progress change to whether the cluster can be connected to from the public network.static Class<? extends AwsRedshiftClusterPendingModifiedValues.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
automatedSnapshotRetentionPeriod
The pending or in-progress change to the automated snapshot retention period.
- Returns:
- The pending or in-progress change to the automated snapshot retention period.
-
clusterIdentifier
The pending or in-progress change to the identifier for the cluster.
- Returns:
- The pending or in-progress change to the identifier for the cluster.
-
clusterType
The pending or in-progress change to the cluster type.
- Returns:
- The pending or in-progress change to the cluster type.
-
clusterVersion
The pending or in-progress change to the service version.
- Returns:
- The pending or in-progress change to the service version.
-
encryptionType
The encryption type for a cluster.
- Returns:
- The encryption type for a cluster.
-
enhancedVpcRouting
Indicates whether to create the cluster with enhanced VPC routing enabled.
- Returns:
- Indicates whether to create the cluster with enhanced VPC routing enabled.
-
maintenanceTrackName
The name of the maintenance track that the cluster changes to during the next maintenance window.
- Returns:
- The name of the maintenance track that the cluster changes to during the next maintenance window.
-
masterUserPassword
The pending or in-progress change to the master user password for the cluster.
- Returns:
- The pending or in-progress change to the master user password for the cluster.
-
nodeType
The pending or in-progress change to the cluster's node type.
- Returns:
- The pending or in-progress change to the cluster's node type.
-
numberOfNodes
The pending or in-progress change to the number of nodes in the cluster.
- Returns:
- The pending or in-progress change to the number of nodes in the cluster.
-
publiclyAccessible
The pending or in-progress change to whether the cluster can be connected to from the public network.
- Returns:
- The pending or in-progress change to whether the cluster can be connected to from the public network.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsRedshiftClusterPendingModifiedValues.Builder,AwsRedshiftClusterPendingModifiedValues>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsRedshiftClusterPendingModifiedValues.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-