Class AwsRedshiftClusterRestoreStatus
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsRedshiftClusterRestoreStatus.Builder,AwsRedshiftClusterRestoreStatus>
Information about the status of a cluster restore action. It only applies if the cluster was created by restoring a snapshot.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final DoubleThe number of megabytes per second being transferred from the backup storage.final LongThe amount of time an in-progress restore has been running, or the amount of time it took a completed restore to finish.final booleanfinal booleanequalsBySdkFields(Object obj) final LongThe estimate of the time remaining before the restore is complete.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final LongThe number of megabytes that were transferred from snapshot storage.static Class<? extends AwsRedshiftClusterRestoreStatus.Builder>final LongThe size of the set of snapshot data that was used to restore the cluster.final Stringstatus()The status of the restore action.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
currentRestoreRateInMegaBytesPerSecond
The number of megabytes per second being transferred from the backup storage. Returns the average rate for a completed backup.
This field is only updated when you restore to DC2 and DS2 node types.
- Returns:
- The number of megabytes per second being transferred from the backup storage. Returns the average rate
for a completed backup.
This field is only updated when you restore to DC2 and DS2 node types.
-
elapsedTimeInSeconds
The amount of time an in-progress restore has been running, or the amount of time it took a completed restore to finish.
This field is only updated when you restore to DC2 and DS2 node types.
- Returns:
- The amount of time an in-progress restore has been running, or the amount of time it took a completed
restore to finish.
This field is only updated when you restore to DC2 and DS2 node types.
-
estimatedTimeToCompletionInSeconds
The estimate of the time remaining before the restore is complete. Returns 0 for a completed restore.
This field is only updated when you restore to DC2 and DS2 node types.
- Returns:
- The estimate of the time remaining before the restore is complete. Returns 0 for a completed restore.
This field is only updated when you restore to DC2 and DS2 node types.
-
progressInMegaBytes
The number of megabytes that were transferred from snapshot storage.
This field is only updated when you restore to DC2 and DS2 node types.
- Returns:
- The number of megabytes that were transferred from snapshot storage.
This field is only updated when you restore to DC2 and DS2 node types.
-
snapshotSizeInMegaBytes
The size of the set of snapshot data that was used to restore the cluster.
This field is only updated when you restore to DC2 and DS2 node types.
- Returns:
- The size of the set of snapshot data that was used to restore the cluster.
This field is only updated when you restore to DC2 and DS2 node types.
-
status
The status of the restore action.
Valid values:
starting|restoring|completed|failed- Returns:
- The status of the restore action.
Valid values:
starting|restoring|completed|failed
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsRedshiftClusterRestoreStatus.Builder,AwsRedshiftClusterRestoreStatus>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-