Class AwsS3BucketLoggingConfiguration
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsS3BucketLoggingConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsS3BucketLoggingConfiguration.Builder,AwsS3BucketLoggingConfiguration>
@Generated("software.amazon.awssdk:codegen")
public final class AwsS3BucketLoggingConfiguration
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsS3BucketLoggingConfiguration.Builder,AwsS3BucketLoggingConfiguration>
Information about logging for the S3 bucket
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe name of the S3 bucket where log files for the S3 bucket are stored.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe prefix added to log files for the S3 bucket.static Class<? extends AwsS3BucketLoggingConfiguration.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
destinationBucketName
The name of the S3 bucket where log files for the S3 bucket are stored.
- Returns:
- The name of the S3 bucket where log files for the S3 bucket are stored.
-
logFilePrefix
The prefix added to log files for the S3 bucket.
- Returns:
- The prefix added to log files for the S3 bucket.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsS3BucketLoggingConfiguration.Builder,AwsS3BucketLoggingConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-