Class AwsS3BucketNotificationConfiguration
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsS3BucketNotificationConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsS3BucketNotificationConfiguration.Builder,AwsS3BucketNotificationConfiguration>
@Generated("software.amazon.awssdk:codegen")
public final class AwsS3BucketNotificationConfiguration
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsS3BucketNotificationConfiguration.Builder,AwsS3BucketNotificationConfiguration>
The notification configuration for the S3 bucket.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Configurations for S3 bucket notifications.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Configurations property.final inthashCode()static Class<? extends AwsS3BucketNotificationConfiguration.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasConfigurations
public final boolean hasConfigurations()For responses, this returns true if the service returned a value for the Configurations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
configurations
Configurations for S3 bucket notifications.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasConfigurations()method.- Returns:
- Configurations for S3 bucket notifications.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsS3BucketNotificationConfiguration.Builder,AwsS3BucketNotificationConfiguration>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsS3BucketNotificationConfiguration.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-