Class AwsS3BucketObjectLockConfiguration

java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsS3BucketObjectLockConfiguration
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<AwsS3BucketObjectLockConfiguration.Builder,AwsS3BucketObjectLockConfiguration>

@Generated("software.amazon.awssdk:codegen") public final class AwsS3BucketObjectLockConfiguration extends Object implements SdkPojo, Serializable, ToCopyableBuilder<AwsS3BucketObjectLockConfiguration.Builder,AwsS3BucketObjectLockConfiguration>

The container element for S3 Object Lock configuration parameters. In Amazon S3, Object Lock can help prevent objects from being deleted or overwritten for a fixed amount of time or indefinitely.

See Also: