Class AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails.Builder,AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails.Builder,AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails>
The default S3 Object Lock retention mode and period that you want to apply to new objects placed in the specified Amazon S3 bucket.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Integerdays()The number of days that you want to specify for the default retention period.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringmode()The default Object Lock retention mode you want to apply to new objects placed in the specified bucket.static Class<? extends AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails.Builder>final StringtoString()Returns a string representation of this object.final Integeryears()The number of years that you want to specify for the default retention period.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
days
The number of days that you want to specify for the default retention period.
- Returns:
- The number of days that you want to specify for the default retention period.
-
mode
The default Object Lock retention mode you want to apply to new objects placed in the specified bucket.
- Returns:
- The default Object Lock retention mode you want to apply to new objects placed in the specified bucket.
-
years
The number of years that you want to specify for the default retention period.
- Returns:
- The number of years that you want to specify for the default retention period.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-