Class AwsS3BucketObjectLockConfigurationRuleDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsS3BucketObjectLockConfigurationRuleDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsS3BucketObjectLockConfigurationRuleDetails.Builder,AwsS3BucketObjectLockConfigurationRuleDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsS3BucketObjectLockConfigurationRuleDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsS3BucketObjectLockConfigurationRuleDetails.Builder,AwsS3BucketObjectLockConfigurationRuleDetails>
Specifies the S3 Object Lock rule for the specified object. In Amazon S3, Object Lock can help prevent objects from being deleted or overwritten for a fixed amount of time or indefinitely.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()The default Object Lock retention mode and period that you want to apply to new objects placed in the specified bucket.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AwsS3BucketObjectLockConfigurationRuleDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
defaultRetention
The default Object Lock retention mode and period that you want to apply to new objects placed in the specified bucket.
- Returns:
- The default Object Lock retention mode and period that you want to apply to new objects placed in the specified bucket.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsS3BucketObjectLockConfigurationRuleDetails.Builder,AwsS3BucketObjectLockConfigurationRuleDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsS3BucketObjectLockConfigurationRuleDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-