Class AwsS3BucketServerSideEncryptionByDefault
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsS3BucketServerSideEncryptionByDefault
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsS3BucketServerSideEncryptionByDefault.Builder,AwsS3BucketServerSideEncryptionByDefault>
@Generated("software.amazon.awssdk:codegen")
public final class AwsS3BucketServerSideEncryptionByDefault
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsS3BucketServerSideEncryptionByDefault.Builder,AwsS3BucketServerSideEncryptionByDefault>
Specifies the default server-side encryption to apply to new objects in the bucket.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringKMS key ID to use for the default encryption.static Class<? extends AwsS3BucketServerSideEncryptionByDefault.Builder>final StringServer-side encryption algorithm to use for the default encryption.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
sseAlgorithm
Server-side encryption algorithm to use for the default encryption. Valid values are
aws: kmsorAES256.- Returns:
- Server-side encryption algorithm to use for the default encryption. Valid values are
aws: kmsorAES256.
-
kmsMasterKeyID
KMS key ID to use for the default encryption.
- Returns:
- KMS key ID to use for the default encryption.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsS3BucketServerSideEncryptionByDefault.Builder,AwsS3BucketServerSideEncryptionByDefault>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsS3BucketServerSideEncryptionByDefault.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-