Class AwsStepFunctionStateMachineDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsStepFunctionStateMachineDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsStepFunctionStateMachineDetails.Builder,AwsStepFunctionStateMachineDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsStepFunctionStateMachineDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsStepFunctionStateMachineDetails.Builder,AwsStepFunctionStateMachineDetails>
Provides details about an Step Functions state machine, which is a workflow consisting of a series of event- driven steps.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringlabel()A user-defined or an auto-generated string that identifies aMapstate.Used to set CloudWatch Logs options.final Stringname()The name of the state machine.final StringroleArn()The Amazon Resource Name (ARN) of the IAM role used when creating this state machine.static Class<? extends AwsStepFunctionStateMachineDetails.Builder>final StringThe ARN that identifies the state machine.final Stringstatus()The current status of the state machine.final StringtoString()Returns a string representation of this object.Specifies whether X-Ray tracing is enabled.final Stringtype()The type of the state machine (STANDARD or EXPRESS).Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
label
A user-defined or an auto-generated string that identifies a
Mapstate. This parameter is present only if thestateMachineArnspecified in input is a qualified state machine ARN.- Returns:
- A user-defined or an auto-generated string that identifies a
Mapstate. This parameter is present only if thestateMachineArnspecified in input is a qualified state machine ARN.
-
loggingConfiguration
Used to set CloudWatch Logs options.
- Returns:
- Used to set CloudWatch Logs options.
-
name
The name of the state machine.
- Returns:
- The name of the state machine.
-
roleArn
The Amazon Resource Name (ARN) of the IAM role used when creating this state machine.
- Returns:
- The Amazon Resource Name (ARN) of the IAM role used when creating this state machine.
-
stateMachineArn
The ARN that identifies the state machine.
- Returns:
- The ARN that identifies the state machine.
-
status
The current status of the state machine.
- Returns:
- The current status of the state machine.
-
tracingConfiguration
Specifies whether X-Ray tracing is enabled.
- Returns:
- Specifies whether X-Ray tracing is enabled.
-
type
The type of the state machine (STANDARD or EXPRESS).
- Returns:
- The type of the state machine (STANDARD or EXPRESS).
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsStepFunctionStateMachineDetails.Builder,AwsStepFunctionStateMachineDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsStepFunctionStateMachineDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-