Class AwsStepFunctionStateMachineLoggingConfigurationDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsStepFunctionStateMachineLoggingConfigurationDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsStepFunctionStateMachineLoggingConfigurationDetails.Builder,AwsStepFunctionStateMachineLoggingConfigurationDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsStepFunctionStateMachineLoggingConfigurationDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsStepFunctionStateMachineLoggingConfigurationDetails.Builder,AwsStepFunctionStateMachineLoggingConfigurationDetails>
The LoggingConfiguration data type is used to set CloudWatch Logs options.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()An array of objects that describes where your execution history events will be logged.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Destinations property.final inthashCode()final BooleanDetermines whether execution data is included in your log.final Stringlevel()Defines which category of execution history events are logged.static Class<? extends AwsStepFunctionStateMachineLoggingConfigurationDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasDestinations
public final boolean hasDestinations()For responses, this returns true if the service returned a value for the Destinations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
destinations
public final List<AwsStepFunctionStateMachineLoggingConfigurationDestinationsDetails> destinations()An array of objects that describes where your execution history events will be logged.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasDestinations()method.- Returns:
- An array of objects that describes where your execution history events will be logged.
-
includeExecutionData
Determines whether execution data is included in your log. When set to false, data is excluded.
- Returns:
- Determines whether execution data is included in your log. When set to false, data is excluded.
-
level
Defines which category of execution history events are logged.
- Returns:
- Defines which category of execution history events are logged.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsStepFunctionStateMachineLoggingConfigurationDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-