Class AwsWafRateBasedRuleMatchPredicate
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsWafRateBasedRuleMatchPredicate.Builder,AwsWafRateBasedRuleMatchPredicate>
A match predicate. A predicate might look for characteristics such as specific IP addresses, geographic locations, or sizes.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringdataId()The unique identifier for the predicate.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Booleannegated()If set totrue, then the rule actions are performed on requests that match the predicate settings.static Class<? extends AwsWafRateBasedRuleMatchPredicate.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of predicate.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
dataId
The unique identifier for the predicate.
- Returns:
- The unique identifier for the predicate.
-
negated
If set to
true, then the rule actions are performed on requests that match the predicate settings.If set to
false, then the rule actions are performed on all requests except those that match the predicate settings.- Returns:
- If set to
true, then the rule actions are performed on requests that match the predicate settings.If set to
false, then the rule actions are performed on all requests except those that match the predicate settings.
-
type
The type of predicate. Valid values are as follows:
-
ByteMatch -
GeoMatch -
IPMatch -
RegexMatch -
SizeConstraint -
SqlInjectionMatch -
XssMatch
- Returns:
- The type of predicate. Valid values are as follows:
-
ByteMatch -
GeoMatch -
IPMatch -
RegexMatch -
SizeConstraint -
SqlInjectionMatch -
XssMatch
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsWafRateBasedRuleMatchPredicate.Builder,AwsWafRateBasedRuleMatchPredicate>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-