Class AwsXrayEncryptionConfigDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsXrayEncryptionConfigDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsXrayEncryptionConfigDetails.Builder,AwsXrayEncryptionConfigDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsXrayEncryptionConfigDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsXrayEncryptionConfigDetails.Builder,AwsXrayEncryptionConfigDetails>
Information about the encryption configuration for X-Ray.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringkeyId()The identifier of the KMS key that is used for encryption.static Class<? extends AwsXrayEncryptionConfigDetails.Builder>final Stringstatus()The current status of the encryption configuration.final StringtoString()Returns a string representation of this object.final Stringtype()The type of encryption.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
keyId
The identifier of the KMS key that is used for encryption. Provided if
TypeisKMS.- Returns:
- The identifier of the KMS key that is used for encryption. Provided if
TypeisKMS.
-
status
The current status of the encryption configuration. Valid values are
ACTIVEorUPDATING.When
Statusis equal toUPDATING, X-Ray might use both the old and new encryption.- Returns:
- The current status of the encryption configuration. Valid values are
ACTIVEorUPDATING.When
Statusis equal toUPDATING, X-Ray might use both the old and new encryption.
-
type
The type of encryption.
KMSindicates that the encryption uses KMS keys.NONEindicates the default encryption.- Returns:
- The type of encryption.
KMSindicates that the encryption uses KMS keys.NONEindicates the default encryption.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsXrayEncryptionConfigDetails.Builder,AwsXrayEncryptionConfigDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-