Class AzureProviderConfiguration
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AzureProviderConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AzureProviderConfiguration.Builder,AzureProviderConfiguration>
@Generated("software.amazon.awssdk:codegen")
public final class AzureProviderConfiguration
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AzureProviderConfiguration.Builder,AzureProviderConfiguration>
The configuration for connecting to an Azure environment.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe ARN of the multi-cloud configuration connector used to establish the connection to Azure.The list of Azure regions to monitor.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the AzureRegions property.final inthashCode()final AzureScopeConfigurationThe scope configuration that defines which Azure resources are monitored.static Class<? extends AzureProviderConfiguration.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
awsConfigConnectorArn
The ARN of the multi-cloud configuration connector used to establish the connection to Azure.
- Returns:
- The ARN of the multi-cloud configuration connector used to establish the connection to Azure.
-
scopeConfiguration
The scope configuration that defines which Azure resources are monitored.
- Returns:
- The scope configuration that defines which Azure resources are monitored.
-
hasAzureRegions
public final boolean hasAzureRegions()For responses, this returns true if the service returned a value for the AzureRegions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
azureRegions
The list of Azure regions to monitor.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAzureRegions()method.- Returns:
- The list of Azure regions to monitor.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AzureProviderConfiguration.Builder,AzureProviderConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-