Class AzureUpdateConfiguration
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AzureUpdateConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AzureUpdateConfiguration.Builder,AzureUpdateConfiguration>
@Generated("software.amazon.awssdk:codegen")
public final class AzureUpdateConfiguration
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AzureUpdateConfiguration.Builder,AzureUpdateConfiguration>
The configuration for updating an Azure connector's scope and regions.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionThe updated list of Azure regions to monitor.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the AzureRegions property.final inthashCode()final AzureScopeConfigurationThe updated scope configuration.static Class<? extends AzureUpdateConfiguration.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
scopeConfiguration
The updated scope configuration.
- Returns:
- The updated scope configuration.
-
hasAzureRegions
public final boolean hasAzureRegions()For responses, this returns true if the service returned a value for the AzureRegions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
azureRegions
The updated list of Azure regions to monitor.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAzureRegions()method.- Returns:
- The updated list of Azure regions to monitor.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AzureUpdateConfiguration.Builder,AzureUpdateConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-