Interface BatchDeleteAutomationRulesRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<BatchDeleteAutomationRulesRequest.Builder,,BatchDeleteAutomationRulesRequest> SdkBuilder<BatchDeleteAutomationRulesRequest.Builder,,BatchDeleteAutomationRulesRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- BatchDeleteAutomationRulesRequest
@Mutable
@NotThreadSafe
public static interface BatchDeleteAutomationRulesRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<BatchDeleteAutomationRulesRequest.Builder,BatchDeleteAutomationRulesRequest>
-
Method Summary
Modifier and TypeMethodDescriptionautomationRulesArns(String... automationRulesArns) A list of Amazon Resource Names (ARNs) for the rules that are to be deleted.automationRulesArns(Collection<String> automationRulesArns) A list of Amazon Resource Names (ARNs) for the rules that are to be deleted.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
automationRulesArns
BatchDeleteAutomationRulesRequest.Builder automationRulesArns(Collection<String> automationRulesArns) A list of Amazon Resource Names (ARNs) for the rules that are to be deleted.
- Parameters:
automationRulesArns- A list of Amazon Resource Names (ARNs) for the rules that are to be deleted.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
automationRulesArns
A list of Amazon Resource Names (ARNs) for the rules that are to be deleted.
- Parameters:
automationRulesArns- A list of Amazon Resource Names (ARNs) for the rules that are to be deleted.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
BatchDeleteAutomationRulesRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
BatchDeleteAutomationRulesRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-