Class BatchDisableStandardsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<BatchDisableStandardsRequest.Builder,BatchDisableStandardsRequest>

@Generated("software.amazon.awssdk:codegen") public final class BatchDisableStandardsRequest extends SecurityHubRequest implements ToCopyableBuilder<BatchDisableStandardsRequest.Builder,BatchDisableStandardsRequest>
  • Method Details

    • hasStandardsSubscriptionArns

      public final boolean hasStandardsSubscriptionArns()
      For responses, this returns true if the service returned a value for the StandardsSubscriptionArns property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • standardsSubscriptionArns

      public final List<String> standardsSubscriptionArns()

      The ARNs of the standards subscriptions to disable.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasStandardsSubscriptionArns() method.

      Returns:
      The ARNs of the standards subscriptions to disable.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<BatchDisableStandardsRequest.Builder,BatchDisableStandardsRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

      public static BatchDisableStandardsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends BatchDisableStandardsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo