Interface BatchDisableStandardsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<BatchDisableStandardsRequest.Builder,,BatchDisableStandardsRequest> SdkBuilder<BatchDisableStandardsRequest.Builder,,BatchDisableStandardsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- BatchDisableStandardsRequest
@Mutable
@NotThreadSafe
public static interface BatchDisableStandardsRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<BatchDisableStandardsRequest.Builder,BatchDisableStandardsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) standardsSubscriptionArns(String... standardsSubscriptionArns) The ARNs of the standards subscriptions to disable.standardsSubscriptionArns(Collection<String> standardsSubscriptionArns) The ARNs of the standards subscriptions to disable.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
standardsSubscriptionArns
BatchDisableStandardsRequest.Builder standardsSubscriptionArns(Collection<String> standardsSubscriptionArns) The ARNs of the standards subscriptions to disable.
- Parameters:
standardsSubscriptionArns- The ARNs of the standards subscriptions to disable.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
standardsSubscriptionArns
The ARNs of the standards subscriptions to disable.
- Parameters:
standardsSubscriptionArns- The ARNs of the standards subscriptions to disable.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
BatchDisableStandardsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
BatchDisableStandardsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-