Interface BatchGetAutomationRulesRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<BatchGetAutomationRulesRequest.Builder,,BatchGetAutomationRulesRequest> SdkBuilder<BatchGetAutomationRulesRequest.Builder,,BatchGetAutomationRulesRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- BatchGetAutomationRulesRequest
@Mutable
@NotThreadSafe
public static interface BatchGetAutomationRulesRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<BatchGetAutomationRulesRequest.Builder,BatchGetAutomationRulesRequest>
-
Method Summary
Modifier and TypeMethodDescriptionautomationRulesArns(String... automationRulesArns) A list of rule ARNs to get details for.automationRulesArns(Collection<String> automationRulesArns) A list of rule ARNs to get details for.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
automationRulesArns
A list of rule ARNs to get details for.
- Parameters:
automationRulesArns- A list of rule ARNs to get details for.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
automationRulesArns
A list of rule ARNs to get details for.
- Parameters:
automationRulesArns- A list of rule ARNs to get details for.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
BatchGetAutomationRulesRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
BatchGetAutomationRulesRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-