Class BatchGetConfigurationPolicyAssociationsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BatchGetConfigurationPolicyAssociationsResponse.Builder,BatchGetConfigurationPolicyAssociationsResponse>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Describes associations for the target accounts, OUs, or the root.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the ConfigurationPolicyAssociations property.final inthashCode()final booleanFor responses, this returns true if the service returned a value for the UnprocessedConfigurationPolicyAssociations property.static Class<? extends BatchGetConfigurationPolicyAssociationsResponse.Builder>final StringtoString()Returns a string representation of this object.An array of configuration policy associations, one for each configuration policy association identifier, that was specified in the request but couldn’t be processed due to an error.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasConfigurationPolicyAssociations
public final boolean hasConfigurationPolicyAssociations()For responses, this returns true if the service returned a value for the ConfigurationPolicyAssociations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
configurationPolicyAssociations
Describes associations for the target accounts, OUs, or the root.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasConfigurationPolicyAssociations()method.- Returns:
- Describes associations for the target accounts, OUs, or the root.
-
hasUnprocessedConfigurationPolicyAssociations
public final boolean hasUnprocessedConfigurationPolicyAssociations()For responses, this returns true if the service returned a value for the UnprocessedConfigurationPolicyAssociations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
unprocessedConfigurationPolicyAssociations
public final List<UnprocessedConfigurationPolicyAssociation> unprocessedConfigurationPolicyAssociations()An array of configuration policy associations, one for each configuration policy association identifier, that was specified in the request but couldn’t be processed due to an error.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUnprocessedConfigurationPolicyAssociations()method.- Returns:
- An array of configuration policy associations, one for each configuration policy association identifier, that was specified in the request but couldn’t be processed due to an error.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchGetConfigurationPolicyAssociationsResponse.Builder,BatchGetConfigurationPolicyAssociationsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends BatchGetConfigurationPolicyAssociationsResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-