Interface BatchGetSecurityControlsRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<BatchGetSecurityControlsRequest.Builder,BatchGetSecurityControlsRequest>, SdkBuilder<BatchGetSecurityControlsRequest.Builder,BatchGetSecurityControlsRequest>, SdkPojo, SdkRequest.Builder, SecurityHubRequest.Builder
Enclosing class:
BatchGetSecurityControlsRequest

  • Method Details

    • securityControlIds

      BatchGetSecurityControlsRequest.Builder securityControlIds(Collection<String> securityControlIds)

      A list of security controls (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.

      Parameters:
      securityControlIds - A list of security controls (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • securityControlIds

      BatchGetSecurityControlsRequest.Builder securityControlIds(String... securityControlIds)

      A list of security controls (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.

      Parameters:
      securityControlIds - A list of security controls (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      BatchGetSecurityControlsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder