Class BatchGetSecurityControlsResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<BatchGetSecurityControlsResponse.Builder,BatchGetSecurityControlsResponse>

@Generated("software.amazon.awssdk:codegen") public final class BatchGetSecurityControlsResponse extends SecurityHubResponse implements ToCopyableBuilder<BatchGetSecurityControlsResponse.Builder,BatchGetSecurityControlsResponse>
  • Method Details

    • hasSecurityControls

      public final boolean hasSecurityControls()
      For responses, this returns true if the service returned a value for the SecurityControls property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • securityControls

      public final List<SecurityControl> securityControls()

      An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control. The same information is returned whether the request includes SecurityControlId or SecurityControlArn.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasSecurityControls() method.

      Returns:
      An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control. The same information is returned whether the request includes SecurityControlId or SecurityControlArn.
    • hasUnprocessedIds

      public final boolean hasUnprocessedIds()
      For responses, this returns true if the service returned a value for the UnprocessedIds property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • unprocessedIds

      public final List<UnprocessedSecurityControl> unprocessedIds()

      A security control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) for which details cannot be returned.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasUnprocessedIds() method.

      Returns:
      A security control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) for which details cannot be returned.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<BatchGetSecurityControlsResponse.Builder,BatchGetSecurityControlsResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

    • serializableBuilderClass

      public static Class<? extends BatchGetSecurityControlsResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo