Class BatchGetStandardsControlAssociationsResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<BatchGetStandardsControlAssociationsResponse.Builder,BatchGetStandardsControlAssociationsResponse>

@Generated("software.amazon.awssdk:codegen") public final class BatchGetStandardsControlAssociationsResponse extends SecurityHubResponse implements ToCopyableBuilder<BatchGetStandardsControlAssociationsResponse.Builder,BatchGetStandardsControlAssociationsResponse>
  • Method Details

    • hasStandardsControlAssociationDetails

      public final boolean hasStandardsControlAssociationDetails()
      For responses, this returns true if the service returned a value for the StandardsControlAssociationDetails property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • standardsControlAssociationDetails

      public final List<StandardsControlAssociationDetail> standardsControlAssociationDetails()

      Provides the enablement status of a security control in a specified standard and other details for the control in relation to the specified standard.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasStandardsControlAssociationDetails() method.

      Returns:
      Provides the enablement status of a security control in a specified standard and other details for the control in relation to the specified standard.
    • hasUnprocessedAssociations

      public final boolean hasUnprocessedAssociations()
      For responses, this returns true if the service returned a value for the UnprocessedAssociations property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • unprocessedAssociations

      public final List<UnprocessedStandardsControlAssociation> unprocessedAssociations()

      A security control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) whose enablement status in a specified standard cannot be returned.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasUnprocessedAssociations() method.

      Returns:
      A security control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) whose enablement status in a specified standard cannot be returned.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<BatchGetStandardsControlAssociationsResponse.Builder,BatchGetStandardsControlAssociationsResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

    • serializableBuilderClass

      public static Class<? extends BatchGetStandardsControlAssociationsResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo