Class BatchUpdateAutomationRulesResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BatchUpdateAutomationRulesResponse.Builder,BatchUpdateAutomationRulesResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the ProcessedAutomationRules property.final booleanFor responses, this returns true if the service returned a value for the UnprocessedAutomationRules property.A list of properly processed rule ARNs.static Class<? extends BatchUpdateAutomationRulesResponse.Builder>final StringtoString()Returns a string representation of this object.final List<UnprocessedAutomationRule>A list of objects containingRuleArn,ErrorCode, andErrorMessage.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasProcessedAutomationRules
public final boolean hasProcessedAutomationRules()For responses, this returns true if the service returned a value for the ProcessedAutomationRules property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
processedAutomationRules
A list of properly processed rule ARNs.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasProcessedAutomationRules()method.- Returns:
- A list of properly processed rule ARNs.
-
hasUnprocessedAutomationRules
public final boolean hasUnprocessedAutomationRules()For responses, this returns true if the service returned a value for the UnprocessedAutomationRules property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
unprocessedAutomationRules
A list of objects containing
RuleArn,ErrorCode, andErrorMessage. This parameter tells you which automation rules the request didn't update and why.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUnprocessedAutomationRules()method.- Returns:
- A list of objects containing
RuleArn,ErrorCode, andErrorMessage. This parameter tells you which automation rules the request didn't update and why.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchUpdateAutomationRulesResponse.Builder,BatchUpdateAutomationRulesResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends BatchUpdateAutomationRulesResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-