Class BatchUpdateFindingsResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.BatchUpdateFindingsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BatchUpdateFindingsResponse.Builder,BatchUpdateFindingsResponse>
@Generated("software.amazon.awssdk:codegen")
public final class BatchUpdateFindingsResponse
extends SecurityHubResponse
implements ToCopyableBuilder<BatchUpdateFindingsResponse.Builder,BatchUpdateFindingsResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the ProcessedFindings property.final booleanFor responses, this returns true if the service returned a value for the UnprocessedFindings property.final List<AwsSecurityFindingIdentifier>The list of findings that were updated successfully.static Class<? extends BatchUpdateFindingsResponse.Builder>final StringtoString()Returns a string representation of this object.The list of findings that were not updated.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasProcessedFindings
public final boolean hasProcessedFindings()For responses, this returns true if the service returned a value for the ProcessedFindings property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
processedFindings
The list of findings that were updated successfully.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasProcessedFindings()method.- Returns:
- The list of findings that were updated successfully.
-
hasUnprocessedFindings
public final boolean hasUnprocessedFindings()For responses, this returns true if the service returned a value for the UnprocessedFindings property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
unprocessedFindings
The list of findings that were not updated.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUnprocessedFindings()method.- Returns:
- The list of findings that were not updated.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchUpdateFindingsResponse.Builder,BatchUpdateFindingsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-