Class BatchUpdateFindingsUnprocessedFinding
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<BatchUpdateFindingsUnprocessedFinding.Builder,BatchUpdateFindingsUnprocessedFinding>
A finding from a BatchUpdateFindings request that Security Hub CSPM was unable to update.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe code associated with the error.final StringThe message associated with the error.The identifier of the finding that was not updated.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends BatchUpdateFindingsUnprocessedFinding.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
findingIdentifier
The identifier of the finding that was not updated.
- Returns:
- The identifier of the finding that was not updated.
-
errorCode
The code associated with the error. Possible values are:
-
ConcurrentUpdateError- Another request attempted to update the finding while this request was being processed. This error may also occur if you callBatchUpdateFindingsandBatchImportFindingsat the same time. -
DuplicatedFindingIdentifier- The request included two or more findings with the sameFindingIdentifier. -
FindingNotFound- TheFindingIdentifierincluded in the request did not match an existing finding. -
FindingSizeExceeded- The finding size was greater than the permissible value of 240 KB. -
InternalFailure- An internal service failure occurred when updating the finding. -
InvalidInput- The finding update contained an invalid value that did not satisfy the Amazon Web Services Security Finding Format syntax.
- Returns:
- The code associated with the error. Possible values are:
-
ConcurrentUpdateError- Another request attempted to update the finding while this request was being processed. This error may also occur if you callBatchUpdateFindingsandBatchImportFindingsat the same time. -
DuplicatedFindingIdentifier- The request included two or more findings with the sameFindingIdentifier. -
FindingNotFound- TheFindingIdentifierincluded in the request did not match an existing finding. -
FindingSizeExceeded- The finding size was greater than the permissible value of 240 KB. -
InternalFailure- An internal service failure occurred when updating the finding. -
InvalidInput- The finding update contained an invalid value that did not satisfy the Amazon Web Services Security Finding Format syntax.
-
-
-
errorMessage
The message associated with the error. Possible values are:
-
Concurrent finding updates detected -
Finding Identifier is duplicated -
Finding Not Found -
Finding size exceeded 240 KB -
Internal service failure -
Invalid Input
- Returns:
- The message associated with the error. Possible values are:
-
Concurrent finding updates detected -
Finding Identifier is duplicated -
Finding Not Found -
Finding size exceeded 240 KB -
Internal service failure -
Invalid Input
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchUpdateFindingsUnprocessedFinding.Builder,BatchUpdateFindingsUnprocessedFinding>
-
builder
-
serializableBuilderClass
public static Class<? extends BatchUpdateFindingsUnprocessedFinding.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-