Interface BatchUpdateFindingsV2Request.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<BatchUpdateFindingsV2Request.Builder,,BatchUpdateFindingsV2Request> SdkBuilder<BatchUpdateFindingsV2Request.Builder,,BatchUpdateFindingsV2Request> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- BatchUpdateFindingsV2Request
-
Method Summary
Modifier and TypeMethodDescriptionThe updated value for a user provided comment about the finding.findingIdentifiers(Collection<OcsfFindingIdentifier> findingIdentifiers) Provides information to identify a specific V2 finding.findingIdentifiers(Consumer<OcsfFindingIdentifier.Builder>... findingIdentifiers) Provides information to identify a specific V2 finding.findingIdentifiers(OcsfFindingIdentifier... findingIdentifiers) Provides information to identify a specific V2 finding.metadataUids(String... metadataUids) The list of findingmetadata.uidto indicate findings to update.metadataUids(Collection<String> metadataUids) The list of findingmetadata.uidto indicate findings to update.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) severityId(Integer severityId) The updated value for the normalized severity identifier.The updated value for the normalized status identifier.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
metadataUids
The list of finding
metadata.uidto indicate findings to update. Findingmetadata.uidis a globally unique identifier associated with the finding. Customers cannot useMetadataUidstogether withFindingIdentifiers.- Parameters:
metadataUids- The list of findingmetadata.uidto indicate findings to update. Findingmetadata.uidis a globally unique identifier associated with the finding. Customers cannot useMetadataUidstogether withFindingIdentifiers.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
metadataUids
The list of finding
metadata.uidto indicate findings to update. Findingmetadata.uidis a globally unique identifier associated with the finding. Customers cannot useMetadataUidstogether withFindingIdentifiers.- Parameters:
metadataUids- The list of findingmetadata.uidto indicate findings to update. Findingmetadata.uidis a globally unique identifier associated with the finding. Customers cannot useMetadataUidstogether withFindingIdentifiers.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingIdentifiers
BatchUpdateFindingsV2Request.Builder findingIdentifiers(Collection<OcsfFindingIdentifier> findingIdentifiers) Provides information to identify a specific V2 finding.
- Parameters:
findingIdentifiers- Provides information to identify a specific V2 finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingIdentifiers
BatchUpdateFindingsV2Request.Builder findingIdentifiers(OcsfFindingIdentifier... findingIdentifiers) Provides information to identify a specific V2 finding.
- Parameters:
findingIdentifiers- Provides information to identify a specific V2 finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingIdentifiers
BatchUpdateFindingsV2Request.Builder findingIdentifiers(Consumer<OcsfFindingIdentifier.Builder>... findingIdentifiers) Provides information to identify a specific V2 finding.
This is a convenience method that creates an instance of theOcsfFindingIdentifier.Builderavoiding the need to create one manually viaOcsfFindingIdentifier.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tofindingIdentifiers(List<OcsfFindingIdentifier>).- Parameters:
findingIdentifiers- a consumer that will call methods onOcsfFindingIdentifier.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
comment
The updated value for a user provided comment about the finding. Minimum character length 1. Maximum character length 512.
- Parameters:
comment- The updated value for a user provided comment about the finding. Minimum character length 1. Maximum character length 512.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
severityId
The updated value for the normalized severity identifier. The severity ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 6, 99]. When customer provides the updated severity ID, the string sibling severity will automatically be updated in the finding.
- Parameters:
severityId- The updated value for the normalized severity identifier. The severity ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 6, 99]. When customer provides the updated severity ID, the string sibling severity will automatically be updated in the finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
statusId
The updated value for the normalized status identifier. The status ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 99]. When customer provides the updated status ID, the string sibling status will automatically be updated in the finding.
- Parameters:
statusId- The updated value for the normalized status identifier. The status ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 99]. When customer provides the updated status ID, the string sibling status will automatically be updated in the finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
BatchUpdateFindingsV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
BatchUpdateFindingsV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-