Interface BatchUpdateFindingsV2Response.Builder
-
- All Superinterfaces:
AwsResponse.Builder,Buildable,CopyableBuilder<BatchUpdateFindingsV2Response.Builder,BatchUpdateFindingsV2Response>,SdkBuilder<BatchUpdateFindingsV2Response.Builder,BatchUpdateFindingsV2Response>,SdkPojo,SdkResponse.Builder,SecurityHubResponse.Builder
- Enclosing class:
- BatchUpdateFindingsV2Response
@Mutable @NotThreadSafe public static interface BatchUpdateFindingsV2Response.Builder extends SecurityHubResponse.Builder, SdkPojo, CopyableBuilder<BatchUpdateFindingsV2Response.Builder,BatchUpdateFindingsV2Response>
-
-
Method Summary
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.core.SdkResponse.Builder
sdkHttpResponse, sdkHttpResponse
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubResponse.Builder
build, responseMetadata, responseMetadata
-
-
-
-
Method Detail
-
processedFindings
BatchUpdateFindingsV2Response.Builder processedFindings(Collection<BatchUpdateFindingsV2ProcessedFinding> processedFindings)
The list of findings that were updated successfully.
- Parameters:
processedFindings- The list of findings that were updated successfully.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
processedFindings
BatchUpdateFindingsV2Response.Builder processedFindings(BatchUpdateFindingsV2ProcessedFinding... processedFindings)
The list of findings that were updated successfully.
- Parameters:
processedFindings- The list of findings that were updated successfully.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
processedFindings
BatchUpdateFindingsV2Response.Builder processedFindings(Consumer<BatchUpdateFindingsV2ProcessedFinding.Builder>... processedFindings)
The list of findings that were updated successfully.
This is a convenience method that creates an instance of theBatchUpdateFindingsV2ProcessedFinding.Builderavoiding the need to create one manually viaBatchUpdateFindingsV2ProcessedFinding.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#processedFindings(List.) - Parameters:
processedFindings- a consumer that will call methods onBatchUpdateFindingsV2ProcessedFinding.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#processedFindings(java.util.Collection)
-
unprocessedFindings
BatchUpdateFindingsV2Response.Builder unprocessedFindings(Collection<BatchUpdateFindingsV2UnprocessedFinding> unprocessedFindings)
The list of V2 findings that were not updated.
- Parameters:
unprocessedFindings- The list of V2 findings that were not updated.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
unprocessedFindings
BatchUpdateFindingsV2Response.Builder unprocessedFindings(BatchUpdateFindingsV2UnprocessedFinding... unprocessedFindings)
The list of V2 findings that were not updated.
- Parameters:
unprocessedFindings- The list of V2 findings that were not updated.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
unprocessedFindings
BatchUpdateFindingsV2Response.Builder unprocessedFindings(Consumer<BatchUpdateFindingsV2UnprocessedFinding.Builder>... unprocessedFindings)
The list of V2 findings that were not updated.
This is a convenience method that creates an instance of theBatchUpdateFindingsV2UnprocessedFinding.Builderavoiding the need to create one manually viaBatchUpdateFindingsV2UnprocessedFinding.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#unprocessedFindings(List.) - Parameters:
unprocessedFindings- a consumer that will call methods onBatchUpdateFindingsV2UnprocessedFinding.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#unprocessedFindings(java.util.Collection)
-
-