Class BatchUpdateFindingsV2UnprocessedFinding
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>
The list of findings that were not updated.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) Indicates the specific type of error preventing successful processing of a finding during a batch update operation.final StringIndicates the specific type of error preventing successful processing of a finding during a batch update operation.final StringA detailed description of why a finding could not be processed during a batch update operation.final OcsfFindingIdentifierThe finding identifier of an unprocessed finding.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe metadata.uid of an unprocessed finding.static Class<? extends BatchUpdateFindingsV2UnprocessedFinding.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
findingIdentifier
The finding identifier of an unprocessed finding.
- Returns:
- The finding identifier of an unprocessed finding.
-
metadataUid
The metadata.uid of an unprocessed finding.
- Returns:
- The metadata.uid of an unprocessed finding.
-
errorCode
Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnBatchUpdateFindingsV2UnprocessedFindingErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
- See Also:
-
errorCodeAsString
Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnBatchUpdateFindingsV2UnprocessedFindingErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
- See Also:
-
errorMessage
A detailed description of why a finding could not be processed during a batch update operation.
- Returns:
- A detailed description of why a finding could not be processed during a batch update operation.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>
-
builder
-
serializableBuilderClass
public static Class<? extends BatchUpdateFindingsV2UnprocessedFinding.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-