Interface BatchUpdateFindingsV2UnprocessedFinding.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>,SdkBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>,SdkPojo
- Enclosing class:
- BatchUpdateFindingsV2UnprocessedFinding
@Mutable @NotThreadSafe public static interface BatchUpdateFindingsV2UnprocessedFinding.Builder extends SdkPojo, CopyableBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description BatchUpdateFindingsV2UnprocessedFinding.BuildererrorCode(String errorCode)Indicates the specific type of error preventing successful processing of a finding during a batch update operation.BatchUpdateFindingsV2UnprocessedFinding.BuildererrorCode(BatchUpdateFindingsV2UnprocessedFindingErrorCode errorCode)Indicates the specific type of error preventing successful processing of a finding during a batch update operation.BatchUpdateFindingsV2UnprocessedFinding.BuildererrorMessage(String errorMessage)A detailed description of why a finding could not be processed during a batch update operation.default BatchUpdateFindingsV2UnprocessedFinding.BuilderfindingIdentifier(Consumer<OcsfFindingIdentifier.Builder> findingIdentifier)The finding identifier of an unprocessed finding.BatchUpdateFindingsV2UnprocessedFinding.BuilderfindingIdentifier(OcsfFindingIdentifier findingIdentifier)The finding identifier of an unprocessed finding.BatchUpdateFindingsV2UnprocessedFinding.BuildermetadataUid(String metadataUid)The metadata.uid of an unprocessed finding.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
findingIdentifier
BatchUpdateFindingsV2UnprocessedFinding.Builder findingIdentifier(OcsfFindingIdentifier findingIdentifier)
The finding identifier of an unprocessed finding.
- Parameters:
findingIdentifier- The finding identifier of an unprocessed finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingIdentifier
default BatchUpdateFindingsV2UnprocessedFinding.Builder findingIdentifier(Consumer<OcsfFindingIdentifier.Builder> findingIdentifier)
The finding identifier of an unprocessed finding.
This is a convenience method that creates an instance of theOcsfFindingIdentifier.Builderavoiding the need to create one manually viaOcsfFindingIdentifier.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tofindingIdentifier(OcsfFindingIdentifier).- Parameters:
findingIdentifier- a consumer that will call methods onOcsfFindingIdentifier.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
findingIdentifier(OcsfFindingIdentifier)
-
metadataUid
BatchUpdateFindingsV2UnprocessedFinding.Builder metadataUid(String metadataUid)
The metadata.uid of an unprocessed finding.
- Parameters:
metadataUid- The metadata.uid of an unprocessed finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
errorCode
BatchUpdateFindingsV2UnprocessedFinding.Builder errorCode(String errorCode)
Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
- Parameters:
errorCode- Indicates the specific type of error preventing successful processing of a finding during a batch update operation.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
BatchUpdateFindingsV2UnprocessedFindingErrorCode,BatchUpdateFindingsV2UnprocessedFindingErrorCode
-
errorCode
BatchUpdateFindingsV2UnprocessedFinding.Builder errorCode(BatchUpdateFindingsV2UnprocessedFindingErrorCode errorCode)
Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
- Parameters:
errorCode- Indicates the specific type of error preventing successful processing of a finding during a batch update operation.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
BatchUpdateFindingsV2UnprocessedFindingErrorCode,BatchUpdateFindingsV2UnprocessedFindingErrorCode
-
errorMessage
BatchUpdateFindingsV2UnprocessedFinding.Builder errorMessage(String errorMessage)
A detailed description of why a finding could not be processed during a batch update operation.
- Parameters:
errorMessage- A detailed description of why a finding could not be processed during a batch update operation.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-