Enum BatchUpdateFindingsV2UnprocessedFindingErrorCode
- java.lang.Object
-
- java.lang.Enum<BatchUpdateFindingsV2UnprocessedFindingErrorCode>
-
- software.amazon.awssdk.services.securityhub.model.BatchUpdateFindingsV2UnprocessedFindingErrorCode
-
- All Implemented Interfaces:
Serializable,Comparable<BatchUpdateFindingsV2UnprocessedFindingErrorCode>
@Generated("software.amazon.awssdk:codegen") public enum BatchUpdateFindingsV2UnprocessedFindingErrorCode extends Enum<BatchUpdateFindingsV2UnprocessedFindingErrorCode>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description CONFLICT_EXCEPTIONINTERNAL_SERVER_EXCEPTIONRESOURCE_NOT_FOUND_EXCEPTIONUNKNOWN_TO_SDK_VERSIONVALIDATION_EXCEPTION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static BatchUpdateFindingsV2UnprocessedFindingErrorCodefromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<BatchUpdateFindingsV2UnprocessedFindingErrorCode>knownValues()StringtoString()static BatchUpdateFindingsV2UnprocessedFindingErrorCodevalueOf(String name)Returns the enum constant of this type with the specified name.static BatchUpdateFindingsV2UnprocessedFindingErrorCode[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
RESOURCE_NOT_FOUND_EXCEPTION
public static final BatchUpdateFindingsV2UnprocessedFindingErrorCode RESOURCE_NOT_FOUND_EXCEPTION
-
VALIDATION_EXCEPTION
public static final BatchUpdateFindingsV2UnprocessedFindingErrorCode VALIDATION_EXCEPTION
-
INTERNAL_SERVER_EXCEPTION
public static final BatchUpdateFindingsV2UnprocessedFindingErrorCode INTERNAL_SERVER_EXCEPTION
-
CONFLICT_EXCEPTION
public static final BatchUpdateFindingsV2UnprocessedFindingErrorCode CONFLICT_EXCEPTION
-
UNKNOWN_TO_SDK_VERSION
public static final BatchUpdateFindingsV2UnprocessedFindingErrorCode UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static BatchUpdateFindingsV2UnprocessedFindingErrorCode[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (BatchUpdateFindingsV2UnprocessedFindingErrorCode c : BatchUpdateFindingsV2UnprocessedFindingErrorCode.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static BatchUpdateFindingsV2UnprocessedFindingErrorCode valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<BatchUpdateFindingsV2UnprocessedFindingErrorCode>
-
fromValue
public static BatchUpdateFindingsV2UnprocessedFindingErrorCode fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- BatchUpdateFindingsV2UnprocessedFindingErrorCode corresponding to the value
-
knownValues
public static Set<BatchUpdateFindingsV2UnprocessedFindingErrorCode> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownBatchUpdateFindingsV2UnprocessedFindingErrorCodes
-
-