Interface BatchUpdateStandardsControlAssociationsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<BatchUpdateStandardsControlAssociationsRequest.Builder,,BatchUpdateStandardsControlAssociationsRequest> SdkBuilder<BatchUpdateStandardsControlAssociationsRequest.Builder,,BatchUpdateStandardsControlAssociationsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- BatchUpdateStandardsControlAssociationsRequest
-
Method Summary
Modifier and TypeMethodDescriptionoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) standardsControlAssociationUpdates(Collection<StandardsControlAssociationUpdate> standardsControlAssociationUpdates) Updates the enablement status of a security control in a specified standard.standardsControlAssociationUpdates(Consumer<StandardsControlAssociationUpdate.Builder>... standardsControlAssociationUpdates) Updates the enablement status of a security control in a specified standard.standardsControlAssociationUpdates(StandardsControlAssociationUpdate... standardsControlAssociationUpdates) Updates the enablement status of a security control in a specified standard.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
standardsControlAssociationUpdates
BatchUpdateStandardsControlAssociationsRequest.Builder standardsControlAssociationUpdates(Collection<StandardsControlAssociationUpdate> standardsControlAssociationUpdates) Updates the enablement status of a security control in a specified standard.
Calls to this operation return a
RESOURCE_NOT_FOUND_EXCEPTIONerror when the standard subscription for the control hasStandardsControlsUpdatablevalueNOT_READY_FOR_UPDATES.- Parameters:
standardsControlAssociationUpdates- Updates the enablement status of a security control in a specified standard.Calls to this operation return a
RESOURCE_NOT_FOUND_EXCEPTIONerror when the standard subscription for the control hasStandardsControlsUpdatablevalueNOT_READY_FOR_UPDATES.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
standardsControlAssociationUpdates
BatchUpdateStandardsControlAssociationsRequest.Builder standardsControlAssociationUpdates(StandardsControlAssociationUpdate... standardsControlAssociationUpdates) Updates the enablement status of a security control in a specified standard.
Calls to this operation return a
RESOURCE_NOT_FOUND_EXCEPTIONerror when the standard subscription for the control hasStandardsControlsUpdatablevalueNOT_READY_FOR_UPDATES.- Parameters:
standardsControlAssociationUpdates- Updates the enablement status of a security control in a specified standard.Calls to this operation return a
RESOURCE_NOT_FOUND_EXCEPTIONerror when the standard subscription for the control hasStandardsControlsUpdatablevalueNOT_READY_FOR_UPDATES.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
standardsControlAssociationUpdates
BatchUpdateStandardsControlAssociationsRequest.Builder standardsControlAssociationUpdates(Consumer<StandardsControlAssociationUpdate.Builder>... standardsControlAssociationUpdates) Updates the enablement status of a security control in a specified standard.
Calls to this operation return a
This is a convenience method that creates an instance of theRESOURCE_NOT_FOUND_EXCEPTIONerror when the standard subscription for the control hasStandardsControlsUpdatablevalueNOT_READY_FOR_UPDATES.StandardsControlAssociationUpdate.Builderavoiding the need to create one manually viaStandardsControlAssociationUpdate.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tostandardsControlAssociationUpdates(List<StandardsControlAssociationUpdate>).- Parameters:
standardsControlAssociationUpdates- a consumer that will call methods onStandardsControlAssociationUpdate.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
BatchUpdateStandardsControlAssociationsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
BatchUpdateStandardsControlAssociationsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-