java.lang.Object
software.amazon.awssdk.services.securityhub.model.Cell
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<Cell.Builder,Cell>

@Generated("software.amazon.awssdk:codegen") public final class Cell extends Object implements SdkPojo, Serializable, ToCopyableBuilder<Cell.Builder,Cell>

An occurrence of sensitive data detected in a Microsoft Excel workbook, comma-separated value (CSV) file, or tab-separated value (TSV) file.

See Also:
  • Method Details

    • column

      public final Long column()

      The column number of the column that contains the data. For a Microsoft Excel workbook, the column number corresponds to the alphabetical column identifiers. For example, a value of 1 for Column corresponds to the A column in the workbook.

      Returns:
      The column number of the column that contains the data. For a Microsoft Excel workbook, the column number corresponds to the alphabetical column identifiers. For example, a value of 1 for Column corresponds to the A column in the workbook.
    • row

      public final Long row()

      The row number of the row that contains the data.

      Returns:
      The row number of the row that contains the data.
    • columnName

      public final String columnName()

      The name of the column that contains the data.

      Returns:
      The name of the column that contains the data.
    • cellReference

      public final String cellReference()

      For a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data. For example, Sheet2!C5 for cell C5 on Sheet2.

      Returns:
      For a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data. For example, Sheet2!C5 for cell C5 on Sheet2.
    • toBuilder

      public Cell.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<Cell.Builder,Cell>
    • builder

      public static Cell.Builder builder()
    • serializableBuilderClass

      public static Class<? extends Cell.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo