Class CodeRepositoryDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.CodeRepositoryDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CodeRepositoryDetails.Builder,CodeRepositoryDetails>
@Generated("software.amazon.awssdk:codegen")
public final class CodeRepositoryDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CodeRepositoryDetails.Builder,CodeRepositoryDetails>
Details about an external code repository with which you can connect your Amazon Web Services resources. The connection is established through Amazon Inspector.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe Amazon Resource Name (ARN) of the code security integration associated with the repository.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the project in the code repository.final StringThe type of repository provider.static Class<? extends CodeRepositoryDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
providerType
The type of repository provider.
- Returns:
- The type of repository provider.
-
projectName
The name of the project in the code repository.
- Returns:
- The name of the project in the code repository.
-
codeSecurityIntegrationArn
The Amazon Resource Name (ARN) of the code security integration associated with the repository.
- Returns:
- The Amazon Resource Name (ARN) of the code security integration associated with the repository.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CodeRepositoryDetails.Builder,CodeRepositoryDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-