Class CodeVulnerabilitiesFilePath
java.lang.Object
software.amazon.awssdk.services.securityhub.model.CodeVulnerabilitiesFilePath
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CodeVulnerabilitiesFilePath.Builder,CodeVulnerabilitiesFilePath>
@Generated("software.amazon.awssdk:codegen")
public final class CodeVulnerabilitiesFilePath
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CodeVulnerabilitiesFilePath.Builder,CodeVulnerabilitiesFilePath>
Provides details about where a code vulnerability is located in your Lambda function.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final IntegerendLine()The line number of the last line of code in which the vulnerability is located.final booleanfinal booleanequalsBySdkFields(Object obj) final StringfileName()The name of the file in which the code vulnerability is located.final StringfilePath()The file path to the code in which the vulnerability is located.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CodeVulnerabilitiesFilePath.Builder>final IntegerThe line number of the first line of code in which the vulnerability is located.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
endLine
The line number of the last line of code in which the vulnerability is located.
- Returns:
- The line number of the last line of code in which the vulnerability is located.
-
fileName
The name of the file in which the code vulnerability is located.
- Returns:
- The name of the file in which the code vulnerability is located.
-
filePath
The file path to the code in which the vulnerability is located.
- Returns:
- The file path to the code in which the vulnerability is located.
-
startLine
The line number of the first line of code in which the vulnerability is located.
- Returns:
- The line number of the first line of code in which the vulnerability is located.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CodeVulnerabilitiesFilePath.Builder,CodeVulnerabilitiesFilePath>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-