Class ConfigurationOptions
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ConfigurationOptions.Builder,ConfigurationOptions>
The options for customizing a security control parameter.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfacestatic enum -
Method Summary
Modifier and TypeMethodDescriptionThe options for customizing a security control parameter that is a boolean.static ConfigurationOptions.Builderbuilder()The options for customizing a security control parameter that is a double.enumList()The options for customizing a security control parameter that is a list of enums.final EnumConfigurationOptionsThe options for customizing a security control parameter that is an enum.final booleanfinal booleanequalsBySdkFields(Object obj) static ConfigurationOptionsfromBooleanValue(Consumer<BooleanConfigurationOptions.Builder> booleanValue) Create an instance of this class withbooleanValue()initialized to the given value.static ConfigurationOptionsfromBooleanValue(BooleanConfigurationOptions booleanValue) Create an instance of this class withbooleanValue()initialized to the given value.static ConfigurationOptionsfromDoubleValue(Consumer<DoubleConfigurationOptions.Builder> doubleValue) Create an instance of this class withdoubleValue()initialized to the given value.static ConfigurationOptionsfromDoubleValue(DoubleConfigurationOptions doubleValue) Create an instance of this class withdoubleValue()initialized to the given value.static ConfigurationOptionsCreate an instance of this class withenumList()initialized to the given value.static ConfigurationOptionsfromEnumList(EnumListConfigurationOptions enumList) Create an instance of this class withenumList()initialized to the given value.static ConfigurationOptionsfromEnumValue(Consumer<EnumConfigurationOptions.Builder> enumValue) Create an instance of this class withenumValue()initialized to the given value.static ConfigurationOptionsfromEnumValue(EnumConfigurationOptions enumValue) Create an instance of this class withenumValue()initialized to the given value.static ConfigurationOptionsCreate an instance of this class withinteger()initialized to the given value.static ConfigurationOptionsfromInteger(IntegerConfigurationOptions integer) Create an instance of this class withinteger()initialized to the given value.static ConfigurationOptionsfromIntegerList(Consumer<IntegerListConfigurationOptions.Builder> integerList) Create an instance of this class withintegerList()initialized to the given value.static ConfigurationOptionsfromIntegerList(IntegerListConfigurationOptions integerList) Create an instance of this class withintegerList()initialized to the given value.static ConfigurationOptionsCreate an instance of this class withstring()initialized to the given value.static ConfigurationOptionsfromString(StringConfigurationOptions string) Create an instance of this class withstring()initialized to the given value.static ConfigurationOptionsfromStringList(Consumer<StringListConfigurationOptions.Builder> stringList) Create an instance of this class withstringList()initialized to the given value.static ConfigurationOptionsfromStringList(StringListConfigurationOptions stringList) Create an instance of this class withstringList()initialized to the given value.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()integer()The options for customizing a security control parameter that is an integer.The options for customizing a security control parameter that is a list of integers.static Class<? extends ConfigurationOptions.Builder>string()The options for customizing a security control parameter that is a string data type.The options for customizing a security control parameter that is a list of strings.final StringtoString()Returns a string representation of this object.type()Retrieve an enum value representing which member of this object is populated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
integer
The options for customizing a security control parameter that is an integer.
- Returns:
- The options for customizing a security control parameter that is an integer.
-
integerList
The options for customizing a security control parameter that is a list of integers.
- Returns:
- The options for customizing a security control parameter that is a list of integers.
-
doubleValue
The options for customizing a security control parameter that is a double.
- Returns:
- The options for customizing a security control parameter that is a double.
-
string
The options for customizing a security control parameter that is a string data type.
- Returns:
- The options for customizing a security control parameter that is a string data type.
-
stringList
The options for customizing a security control parameter that is a list of strings.
- Returns:
- The options for customizing a security control parameter that is a list of strings.
-
booleanValue
The options for customizing a security control parameter that is a boolean. For a boolean parameter, the options are
trueandfalse.- Returns:
- The options for customizing a security control parameter that is a boolean. For a boolean parameter, the
options are
trueandfalse.
-
enumValue
The options for customizing a security control parameter that is an enum.
- Returns:
- The options for customizing a security control parameter that is an enum.
-
enumList
The options for customizing a security control parameter that is a list of enums.
- Returns:
- The options for customizing a security control parameter that is a list of enums.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ConfigurationOptions.Builder,ConfigurationOptions>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
fromInteger
Create an instance of this class withinteger()initialized to the given value.The options for customizing a security control parameter that is an integer.
- Parameters:
integer- The options for customizing a security control parameter that is an integer.
-
fromInteger
public static ConfigurationOptions fromInteger(Consumer<IntegerConfigurationOptions.Builder> integer) Create an instance of this class withinteger()initialized to the given value.The options for customizing a security control parameter that is an integer.
- Parameters:
integer- The options for customizing a security control parameter that is an integer.
-
fromIntegerList
Create an instance of this class withintegerList()initialized to the given value.The options for customizing a security control parameter that is a list of integers.
- Parameters:
integerList- The options for customizing a security control parameter that is a list of integers.
-
fromIntegerList
public static ConfigurationOptions fromIntegerList(Consumer<IntegerListConfigurationOptions.Builder> integerList) Create an instance of this class withintegerList()initialized to the given value.The options for customizing a security control parameter that is a list of integers.
- Parameters:
integerList- The options for customizing a security control parameter that is a list of integers.
-
fromDoubleValue
Create an instance of this class withdoubleValue()initialized to the given value.The options for customizing a security control parameter that is a double.
- Parameters:
doubleValue- The options for customizing a security control parameter that is a double.
-
fromDoubleValue
public static ConfigurationOptions fromDoubleValue(Consumer<DoubleConfigurationOptions.Builder> doubleValue) Create an instance of this class withdoubleValue()initialized to the given value.The options for customizing a security control parameter that is a double.
- Parameters:
doubleValue- The options for customizing a security control parameter that is a double.
-
fromString
Create an instance of this class withstring()initialized to the given value.The options for customizing a security control parameter that is a string data type.
- Parameters:
string- The options for customizing a security control parameter that is a string data type.
-
fromString
Create an instance of this class withstring()initialized to the given value.The options for customizing a security control parameter that is a string data type.
- Parameters:
string- The options for customizing a security control parameter that is a string data type.
-
fromStringList
Create an instance of this class withstringList()initialized to the given value.The options for customizing a security control parameter that is a list of strings.
- Parameters:
stringList- The options for customizing a security control parameter that is a list of strings.
-
fromStringList
public static ConfigurationOptions fromStringList(Consumer<StringListConfigurationOptions.Builder> stringList) Create an instance of this class withstringList()initialized to the given value.The options for customizing a security control parameter that is a list of strings.
- Parameters:
stringList- The options for customizing a security control parameter that is a list of strings.
-
fromBooleanValue
Create an instance of this class withbooleanValue()initialized to the given value.The options for customizing a security control parameter that is a boolean. For a boolean parameter, the options are
trueandfalse.- Parameters:
booleanValue- The options for customizing a security control parameter that is a boolean. For a boolean parameter, the options aretrueandfalse.
-
fromBooleanValue
public static ConfigurationOptions fromBooleanValue(Consumer<BooleanConfigurationOptions.Builder> booleanValue) Create an instance of this class withbooleanValue()initialized to the given value.The options for customizing a security control parameter that is a boolean. For a boolean parameter, the options are
trueandfalse.- Parameters:
booleanValue- The options for customizing a security control parameter that is a boolean. For a boolean parameter, the options aretrueandfalse.
-
fromEnumValue
Create an instance of this class withenumValue()initialized to the given value.The options for customizing a security control parameter that is an enum.
- Parameters:
enumValue- The options for customizing a security control parameter that is an enum.
-
fromEnumValue
public static ConfigurationOptions fromEnumValue(Consumer<EnumConfigurationOptions.Builder> enumValue) Create an instance of this class withenumValue()initialized to the given value.The options for customizing a security control parameter that is an enum.
- Parameters:
enumValue- The options for customizing a security control parameter that is an enum.
-
fromEnumList
Create an instance of this class withenumList()initialized to the given value.The options for customizing a security control parameter that is a list of enums.
- Parameters:
enumList- The options for customizing a security control parameter that is a list of enums.
-
fromEnumList
public static ConfigurationOptions fromEnumList(Consumer<EnumListConfigurationOptions.Builder> enumList) Create an instance of this class withenumList()initialized to the given value.The options for customizing a security control parameter that is a list of enums.
- Parameters:
enumList- The options for customizing a security control parameter that is a list of enums.
-
type
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beConfigurationOptions.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beConfigurationOptions.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set. -
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-