Class ConfigurationPolicyAssociationSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ConfigurationPolicyAssociationSummary.Builder,ConfigurationPolicyAssociationSummary>
An object that contains the details of a configuration policy association that’s returned in a
ListConfigurationPolicyAssociations request.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionThe current status of the association between the specified target and the configuration.final StringThe current status of the association between the specified target and the configuration.final StringThe explanation for aFAILEDvalue forAssociationStatus.final AssociationTypeIndicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.final StringIndicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.builder()final StringThe universally unique identifier (UUID) of the configuration policy.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends ConfigurationPolicyAssociationSummary.Builder>final StringtargetId()The identifier of the target account, organizational unit, or the root.final TargetTypeSpecifies whether the target is an Amazon Web Services account, organizational unit, or the root.final StringSpecifies whether the target is an Amazon Web Services account, organizational unit, or the root.final StringtoString()Returns a string representation of this object.final InstantThe date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
configurationPolicyId
The universally unique identifier (UUID) of the configuration policy.
- Returns:
- The universally unique identifier (UUID) of the configuration policy.
-
targetId
The identifier of the target account, organizational unit, or the root.
- Returns:
- The identifier of the target account, organizational unit, or the root.
-
targetType
Specifies whether the target is an Amazon Web Services account, organizational unit, or the root.
If the service returns an enum value that is not available in the current SDK version,
targetTypewill returnTargetType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtargetTypeAsString().- Returns:
- Specifies whether the target is an Amazon Web Services account, organizational unit, or the root.
- See Also:
-
targetTypeAsString
Specifies whether the target is an Amazon Web Services account, organizational unit, or the root.
If the service returns an enum value that is not available in the current SDK version,
targetTypewill returnTargetType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtargetTypeAsString().- Returns:
- Specifies whether the target is an Amazon Web Services account, organizational unit, or the root.
- See Also:
-
associationType
Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
If the service returns an enum value that is not available in the current SDK version,
associationTypewill returnAssociationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationTypeAsString().- Returns:
- Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
- See Also:
-
associationTypeAsString
Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
If the service returns an enum value that is not available in the current SDK version,
associationTypewill returnAssociationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationTypeAsString().- Returns:
- Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
- See Also:
-
updatedAt
The date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.
- Returns:
- The date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.
-
associationStatus
The current status of the association between the specified target and the configuration.
If the service returns an enum value that is not available in the current SDK version,
associationStatuswill returnConfigurationPolicyAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationStatusAsString().- Returns:
- The current status of the association between the specified target and the configuration.
- See Also:
-
associationStatusAsString
The current status of the association between the specified target and the configuration.
If the service returns an enum value that is not available in the current SDK version,
associationStatuswill returnConfigurationPolicyAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationStatusAsString().- Returns:
- The current status of the association between the specified target and the configuration.
- See Also:
-
associationStatusMessage
The explanation for a
FAILEDvalue forAssociationStatus.- Returns:
- The explanation for a
FAILEDvalue forAssociationStatus.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ConfigurationPolicyAssociationSummary.Builder,ConfigurationPolicyAssociationSummary>
-
builder
-
serializableBuilderClass
public static Class<? extends ConfigurationPolicyAssociationSummary.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-