Class ConfigurationPolicySummary
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ConfigurationPolicySummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ConfigurationPolicySummary.Builder,ConfigurationPolicySummary>
@Generated("software.amazon.awssdk:codegen")
public final class ConfigurationPolicySummary
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ConfigurationPolicySummary.Builder,ConfigurationPolicySummary>
An object that contains the details of an Security Hub CSPM configuration policy that’s returned in a
ListConfigurationPolicies request.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The Amazon Resource Name (ARN) of the configuration policy.builder()final StringThe description of the configuration policy.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The universally unique identifier (UUID) of the configuration policy.final Stringname()The name of the configuration policy.static Class<? extends ConfigurationPolicySummary.Builder>final BooleanIndicates whether the service that the configuration policy applies to is enabled in the policy.final StringtoString()Returns a string representation of this object.final InstantThe date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
arn
The Amazon Resource Name (ARN) of the configuration policy.
- Returns:
- The Amazon Resource Name (ARN) of the configuration policy.
-
id
The universally unique identifier (UUID) of the configuration policy.
- Returns:
- The universally unique identifier (UUID) of the configuration policy.
-
name
The name of the configuration policy. Alphanumeric characters and the following ASCII characters are permitted:
-, ., !, *, /.- Returns:
- The name of the configuration policy. Alphanumeric characters and the following ASCII characters are
permitted:
-, ., !, *, /.
-
description
The description of the configuration policy.
- Returns:
- The description of the configuration policy.
-
updatedAt
The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
- Returns:
- The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
-
serviceEnabled
Indicates whether the service that the configuration policy applies to is enabled in the policy.
- Returns:
- Indicates whether the service that the configuration policy applies to is enabled in the policy.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ConfigurationPolicySummary.Builder,ConfigurationPolicySummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-