Enum ConnectorStatus
- java.lang.Object
-
- java.lang.Enum<ConnectorStatus>
-
- software.amazon.awssdk.services.securityhub.model.ConnectorStatus
-
- All Implemented Interfaces:
Serializable,Comparable<ConnectorStatus>
@Generated("software.amazon.awssdk:codegen") public enum ConnectorStatus extends Enum<ConnectorStatus>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description CONNECTEDFAILED_TO_CONNECTPENDING_AUTHORIZATIONPENDING_CONFIGURATIONUNKNOWN_TO_SDK_VERSION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ConnectorStatusfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<ConnectorStatus>knownValues()StringtoString()static ConnectorStatusvalueOf(String name)Returns the enum constant of this type with the specified name.static ConnectorStatus[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
CONNECTED
public static final ConnectorStatus CONNECTED
-
FAILED_TO_CONNECT
public static final ConnectorStatus FAILED_TO_CONNECT
-
PENDING_CONFIGURATION
public static final ConnectorStatus PENDING_CONFIGURATION
-
PENDING_AUTHORIZATION
public static final ConnectorStatus PENDING_AUTHORIZATION
-
UNKNOWN_TO_SDK_VERSION
public static final ConnectorStatus UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static ConnectorStatus[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ConnectorStatus c : ConnectorStatus.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ConnectorStatus valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<ConnectorStatus>
-
fromValue
public static ConnectorStatus fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- ConnectorStatus corresponding to the value
-
knownValues
public static Set<ConnectorStatus> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownConnectorStatuss
-
-