Interface ConnectorSummary.Builder

    • Method Detail

      • connectorArn

        ConnectorSummary.Builder connectorArn​(String connectorArn)

        The Amazon Resource Name (ARN) of the connectorV2.

        Parameters:
        connectorArn - The Amazon Resource Name (ARN) of the connectorV2.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • connectorId

        ConnectorSummary.Builder connectorId​(String connectorId)

        The UUID of the connectorV2 to identify connectorV2 resource.

        Parameters:
        connectorId - The UUID of the connectorV2 to identify connectorV2 resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • name

        ConnectorSummary.Builder name​(String name)

        The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.

        Parameters:
        name - The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • description

        ConnectorSummary.Builder description​(String description)

        The description of the connectorV2.

        Parameters:
        description - The description of the connectorV2.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • providerSummary

        ConnectorSummary.Builder providerSummary​(ProviderSummary providerSummary)

        The connectorV2 third party provider configuration summary.

        Parameters:
        providerSummary - The connectorV2 third party provider configuration summary.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • createdAt

        ConnectorSummary.Builder createdAt​(Instant createdAt)

        ISO 8601 UTC timestamp for the time create the connectorV2.

        Parameters:
        createdAt - ISO 8601 UTC timestamp for the time create the connectorV2.
        Returns:
        Returns a reference to this object so that method calls can be chained together.