Interface CreateAutomationRuleV2Request.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<CreateAutomationRuleV2Request.Builder,CreateAutomationRuleV2Request>,SdkBuilder<CreateAutomationRuleV2Request.Builder,CreateAutomationRuleV2Request>,SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- CreateAutomationRuleV2Request
@Mutable @NotThreadSafe public static interface CreateAutomationRuleV2Request.Builder extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<CreateAutomationRuleV2Request.Builder,CreateAutomationRuleV2Request>
-
-
Method Summary
-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
-
-
-
Method Detail
-
ruleName
CreateAutomationRuleV2Request.Builder ruleName(String ruleName)
The name of the V2 automation rule.
- Parameters:
ruleName- The name of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleStatus
CreateAutomationRuleV2Request.Builder ruleStatus(String ruleStatus)
The status of the V2 automation rule.
- Parameters:
ruleStatus- The status of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
ruleStatus
CreateAutomationRuleV2Request.Builder ruleStatus(RuleStatusV2 ruleStatus)
The status of the V2 automation rule.
- Parameters:
ruleStatus- The status of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
description
CreateAutomationRuleV2Request.Builder description(String description)
A description of the V2 automation rule.
- Parameters:
description- A description of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleOrder
CreateAutomationRuleV2Request.Builder ruleOrder(Float ruleOrder)
The value for the rule priority.
- Parameters:
ruleOrder- The value for the rule priority.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
criteria
CreateAutomationRuleV2Request.Builder criteria(Criteria criteria)
The filtering type and configuration of the automation rule.
- Parameters:
criteria- The filtering type and configuration of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
criteria
default CreateAutomationRuleV2Request.Builder criteria(Consumer<Criteria.Builder> criteria)
The filtering type and configuration of the automation rule.
This is a convenience method that creates an instance of theCriteria.Builderavoiding the need to create one manually viaCriteria.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tocriteria(Criteria).- Parameters:
criteria- a consumer that will call methods onCriteria.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
criteria(Criteria)
-
actions
CreateAutomationRuleV2Request.Builder actions(Collection<AutomationRulesActionV2> actions)
A list of actions to be performed when the rule criteria is met.
- Parameters:
actions- A list of actions to be performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
CreateAutomationRuleV2Request.Builder actions(AutomationRulesActionV2... actions)
A list of actions to be performed when the rule criteria is met.
- Parameters:
actions- A list of actions to be performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
CreateAutomationRuleV2Request.Builder actions(Consumer<AutomationRulesActionV2.Builder>... actions)
A list of actions to be performed when the rule criteria is met.
This is a convenience method that creates an instance of theAutomationRulesActionV2.Builderavoiding the need to create one manually viaAutomationRulesActionV2.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#actions(List.) - Parameters:
actions- a consumer that will call methods onAutomationRulesActionV2.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#actions(java.util.Collection)
-
tags
CreateAutomationRuleV2Request.Builder tags(Map<String,String> tags)
A list of key-value pairs associated with the V2 automation rule.
- Parameters:
tags- A list of key-value pairs associated with the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
clientToken
CreateAutomationRuleV2Request.Builder clientToken(String clientToken)
A unique identifier used to ensure idempotency.
- Parameters:
clientToken- A unique identifier used to ensure idempotency.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
CreateAutomationRuleV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreateAutomationRuleV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-