Interface CreateAutomationRuleV2Response.Builder

All Superinterfaces:
AwsResponse.Builder, Buildable, CopyableBuilder<CreateAutomationRuleV2Response.Builder,CreateAutomationRuleV2Response>, SdkBuilder<CreateAutomationRuleV2Response.Builder,CreateAutomationRuleV2Response>, SdkPojo, SdkResponse.Builder, SecurityHubResponse.Builder
Enclosing class:
CreateAutomationRuleV2Response

  • Method Details

    • ruleArn

      The ARN of the V2 automation rule.

      Parameters:
      ruleArn - The ARN of the V2 automation rule.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • ruleId

      The ID of the V2 automation rule.

      Parameters:
      ruleId - The ID of the V2 automation rule.
      Returns:
      Returns a reference to this object so that method calls can be chained together.