Class CreateConfigurationPolicyRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateConfigurationPolicyRequest.Builder,CreateConfigurationPolicyRequest>

@Generated("software.amazon.awssdk:codegen") public final class CreateConfigurationPolicyRequest extends SecurityHubRequest implements ToCopyableBuilder<CreateConfigurationPolicyRequest.Builder,CreateConfigurationPolicyRequest>
  • Method Details

    • name

      public final String name()

      The name of the configuration policy. Alphanumeric characters and the following ASCII characters are permitted: -, ., !, *, /.

      Returns:
      The name of the configuration policy. Alphanumeric characters and the following ASCII characters are permitted: -, ., !, *, /.
    • description

      public final String description()

      The description of the configuration policy.

      Returns:
      The description of the configuration policy.
    • configurationPolicy

      public final Policy configurationPolicy()

      An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).

      Returns:
      An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
    • hasTags

      public final boolean hasTags()
      For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • tags

      public final Map<String,String> tags()

      User-defined tags associated with a configuration policy. For more information, see Tagging Security Hub CSPM resources in the Security Hub CSPM user guide.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasTags() method.

      Returns:
      User-defined tags associated with a configuration policy. For more information, see Tagging Security Hub CSPM resources in the Security Hub CSPM user guide.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<CreateConfigurationPolicyRequest.Builder,CreateConfigurationPolicyRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends CreateConfigurationPolicyRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo