Class CreateConnectorResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateConnectorResponse.Builder,CreateConnectorResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe Amazon Resource Name (ARN) of the connector.final StringThe unique identifier of the connector.final CspmConnectorStatusThe connectivity status of the connector.final StringThe connectivity status of the connector.final CspmEnablementStatusThe enablement status of the connector.final StringThe enablement status of the connector.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CreateConnectorResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorArn
The Amazon Resource Name (ARN) of the connector.
- Returns:
- The Amazon Resource Name (ARN) of the connector.
-
connectorId
The unique identifier of the connector.
- Returns:
- The unique identifier of the connector.
-
connectorStatus
The connectivity status of the connector.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnCspmConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The connectivity status of the connector.
- See Also:
-
connectorStatusAsString
The connectivity status of the connector.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnCspmConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The connectivity status of the connector.
- See Also:
-
enablementStatus
The enablement status of the connector.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnCspmEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector.
- See Also:
-
enablementStatusAsString
The enablement status of the connector.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnCspmEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateConnectorResponse.Builder,CreateConnectorResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-