Class CreateConnectorV2Request

    • Method Detail

      • name

        public final String name()

        The unique name of the connectorV2.

        Returns:
        The unique name of the connectorV2.
      • description

        public final String description()

        The description of the connectorV2.

        Returns:
        The description of the connectorV2.
      • provider

        public final ProviderConfiguration provider()

        The third-party provider’s service configuration.

        Returns:
        The third-party provider’s service configuration.
      • kmsKeyArn

        public final String kmsKeyArn()

        The Amazon Resource Name (ARN) of KMS key used to encrypt secrets for the connectorV2.

        Returns:
        The Amazon Resource Name (ARN) of KMS key used to encrypt secrets for the connectorV2.
      • hasTags

        public final boolean hasTags()
        For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • tags

        public final Map<String,​String> tags()

        The tags to add to the connectorV2 when you create.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasTags() method.

        Returns:
        The tags to add to the connectorV2 when you create.
      • clientToken

        public final String clientToken()

        A unique identifier used to ensure idempotency.

        Returns:
        A unique identifier used to ensure idempotency.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object