Interface CreateConnectorV2Request.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<CreateConnectorV2Request.Builder,,CreateConnectorV2Request> SdkBuilder<CreateConnectorV2Request.Builder,,CreateConnectorV2Request> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- CreateConnectorV2Request
@Mutable
@NotThreadSafe
public static interface CreateConnectorV2Request.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<CreateConnectorV2Request.Builder,CreateConnectorV2Request>
-
Method Summary
Modifier and TypeMethodDescriptionclientToken(String clientToken) A unique identifier used to ensure idempotency.description(String description) The description of the connectorV2.The Amazon Resource Name (ARN) of KMS key used to encrypt secrets for the connectorV2.The unique name of the connectorV2.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) default CreateConnectorV2Request.Builderprovider(Consumer<ProviderConfiguration.Builder> provider) The third-party provider’s service configuration.provider(ProviderConfiguration provider) The third-party provider’s service configuration.The tags to add to the connectorV2 when you create.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
name
The unique name of the connectorV2.
- Parameters:
name- The unique name of the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
description
The description of the connectorV2.
- Parameters:
description- The description of the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
provider
The third-party provider’s service configuration.
- Parameters:
provider- The third-party provider’s service configuration.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
provider
The third-party provider’s service configuration.
This is a convenience method that creates an instance of theProviderConfiguration.Builderavoiding the need to create one manually viaProviderConfiguration.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toprovider(ProviderConfiguration).- Parameters:
provider- a consumer that will call methods onProviderConfiguration.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
kmsKeyArn
The Amazon Resource Name (ARN) of KMS key used to encrypt secrets for the connectorV2.
- Parameters:
kmsKeyArn- The Amazon Resource Name (ARN) of KMS key used to encrypt secrets for the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
tags
The tags to add to the connectorV2 when you create.
- Parameters:
tags- The tags to add to the connectorV2 when you create.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
clientToken
A unique identifier used to ensure idempotency.
- Parameters:
clientToken- A unique identifier used to ensure idempotency.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
CreateConnectorV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreateConnectorV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-