Class CreateConnectorV2Response
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.CreateConnectorV2Response
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateConnectorV2Response.Builder,CreateConnectorV2Response>
@Generated("software.amazon.awssdk:codegen")
public final class CreateConnectorV2Response
extends SecurityHubResponse
implements ToCopyableBuilder<CreateConnectorV2Response.Builder,CreateConnectorV2Response>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringauthUrl()The Url provide to customers for OAuth auth code flow.builder()final StringThe Amazon Resource Name (ARN) of the connectorV2.final StringThe UUID of the connectorV2 to identify connectorV2 resource.final ConnectorStatusThe current status of the connectorV2.final StringThe current status of the connectorV2.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CreateConnectorV2Response.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorArn
The Amazon Resource Name (ARN) of the connectorV2.
- Returns:
- The Amazon Resource Name (ARN) of the connectorV2.
-
connectorId
The UUID of the connectorV2 to identify connectorV2 resource.
- Returns:
- The UUID of the connectorV2 to identify connectorV2 resource.
-
authUrl
The Url provide to customers for OAuth auth code flow.
- Returns:
- The Url provide to customers for OAuth auth code flow.
-
connectorStatus
The current status of the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The current status of the connectorV2.
- See Also:
-
connectorStatusAsString
The current status of the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The current status of the connectorV2.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateConnectorV2Response.Builder,CreateConnectorV2Response> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-