Interface CreateConnectorV2Response.Builder

    • Method Detail

      • connectorArn

        CreateConnectorV2Response.Builder connectorArn​(String connectorArn)

        The Amazon Resource Name (ARN) of the connectorV2.

        Parameters:
        connectorArn - The Amazon Resource Name (ARN) of the connectorV2.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • connectorId

        CreateConnectorV2Response.Builder connectorId​(String connectorId)

        The UUID of the connectorV2 to identify connectorV2 resource.

        Parameters:
        connectorId - The UUID of the connectorV2 to identify connectorV2 resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • authUrl

        CreateConnectorV2Response.Builder authUrl​(String authUrl)

        The Url provide to customers for OAuth auth code flow.

        Parameters:
        authUrl - The Url provide to customers for OAuth auth code flow.
        Returns:
        Returns a reference to this object so that method calls can be chained together.