Class CreateInsightRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.CreateInsightRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateInsightRequest.Builder,CreateInsightRequest>
@Generated("software.amazon.awssdk:codegen")
public final class CreateInsightRequest
extends SecurityHubRequest
implements ToCopyableBuilder<CreateInsightRequest.Builder,CreateInsightRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CreateInsightRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) filters()One or more attributes used to filter the findings included in the insight.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe attribute used to group the findings for the insight.final inthashCode()final Stringname()The name of the custom insight to create.static Class<? extends CreateInsightRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the custom insight to create.
- Returns:
- The name of the custom insight to create.
-
filters
One or more attributes used to filter the findings included in the insight. The insight only includes findings that match the criteria defined in the filters.
- Returns:
- One or more attributes used to filter the findings included in the insight. The insight only includes findings that match the criteria defined in the filters.
-
groupByAttribute
The attribute used to group the findings for the insight. The grouping attribute identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.
- Returns:
- The attribute used to group the findings for the insight. The grouping attribute identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateInsightRequest.Builder,CreateInsightRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-