Interface CreateMembersRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<CreateMembersRequest.Builder,,CreateMembersRequest> SdkBuilder<CreateMembersRequest.Builder,,CreateMembersRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- CreateMembersRequest
@Mutable
@NotThreadSafe
public static interface CreateMembersRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<CreateMembersRequest.Builder,CreateMembersRequest>
-
Method Summary
Modifier and TypeMethodDescriptionaccountDetails(Collection<AccountDetails> accountDetails) The list of accounts to associate with the Security Hub CSPM administrator account.accountDetails(Consumer<AccountDetails.Builder>... accountDetails) The list of accounts to associate with the Security Hub CSPM administrator account.accountDetails(AccountDetails... accountDetails) The list of accounts to associate with the Security Hub CSPM administrator account.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
accountDetails
The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.
- Parameters:
accountDetails- The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
accountDetails
The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.
- Parameters:
accountDetails- The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
accountDetails
The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.
This is a convenience method that creates an instance of theAccountDetails.Builderavoiding the need to create one manually viaAccountDetails.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toaccountDetails(List<AccountDetails>).- Parameters:
accountDetails- a consumer that will call methods onAccountDetails.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
CreateMembersRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreateMembersRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-