Class CreateTicketV2Request
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateTicketV2Request.Builder,CreateTicketV2Request>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe client idempotency token.final StringThe UUID of the connectorV2 to identify connectorV2 resource.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe the unique ID for the finding.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final TicketCreationModemode()The mode for ticket creation.final StringThe mode for ticket creation.static Class<? extends CreateTicketV2Request.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorId
The UUID of the connectorV2 to identify connectorV2 resource.
- Returns:
- The UUID of the connectorV2 to identify connectorV2 resource.
-
findingMetadataUid
The the unique ID for the finding.
- Returns:
- The the unique ID for the finding.
-
clientToken
The client idempotency token.
- Returns:
- The client idempotency token.
-
mode
The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
If the service returns an enum value that is not available in the current SDK version,
modewill returnTicketCreationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommodeAsString().- Returns:
- The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
- See Also:
-
modeAsString
The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
If the service returns an enum value that is not available in the current SDK version,
modewill returnTicketCreationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommodeAsString().- Returns:
- The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateTicketV2Request.Builder,CreateTicketV2Request> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-