Interface CreateTicketV2Request.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<CreateTicketV2Request.Builder,CreateTicketV2Request>, SdkBuilder<CreateTicketV2Request.Builder,CreateTicketV2Request>, SdkPojo, SdkRequest.Builder, SecurityHubRequest.Builder
Enclosing class:
CreateTicketV2Request

  • Method Details

    • connectorId

      CreateTicketV2Request.Builder connectorId(String connectorId)

      The UUID of the connectorV2 to identify connectorV2 resource.

      Parameters:
      connectorId - The UUID of the connectorV2 to identify connectorV2 resource.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • findingMetadataUid

      CreateTicketV2Request.Builder findingMetadataUid(String findingMetadataUid)

      The the unique ID for the finding.

      Parameters:
      findingMetadataUid - The the unique ID for the finding.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • clientToken

      CreateTicketV2Request.Builder clientToken(String clientToken)

      The client idempotency token.

      Parameters:
      clientToken - The client idempotency token.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • mode

      The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.

      Parameters:
      mode - The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • mode

      The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.

      Parameters:
      mode - The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • overrideConfiguration

      CreateTicketV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder