Interface CreateTicketV2Response.Builder

    • Method Detail

      • ticketId

        CreateTicketV2Response.Builder ticketId​(String ticketId)

        The ID for the ticketv2.

        Parameters:
        ticketId - The ID for the ticketv2.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ticketSrcUrl

        CreateTicketV2Response.Builder ticketSrcUrl​(String ticketSrcUrl)

        The url to the created ticket.

        Parameters:
        ticketSrcUrl - The url to the created ticket.
        Returns:
        Returns a reference to this object so that method calls can be chained together.