Class CustomDataIdentifiersDetections
java.lang.Object
software.amazon.awssdk.services.securityhub.model.CustomDataIdentifiersDetections
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CustomDataIdentifiersDetections.Builder,CustomDataIdentifiersDetections>
@Generated("software.amazon.awssdk:codegen")
public final class CustomDataIdentifiersDetections
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CustomDataIdentifiersDetections.Builder,CustomDataIdentifiersDetections>
The list of detected instances of sensitive data.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The ARN of the custom identifier that was used to detect the sensitive data.builder()final Longcount()The total number of occurrences of sensitive data that were detected.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()he name of the custom identifier that detected the sensitive data.final OccurrencesDetails about the sensitive data that was detected.static Class<? extends CustomDataIdentifiersDetections.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
count
The total number of occurrences of sensitive data that were detected.
- Returns:
- The total number of occurrences of sensitive data that were detected.
-
arn
The ARN of the custom identifier that was used to detect the sensitive data.
- Returns:
- The ARN of the custom identifier that was used to detect the sensitive data.
-
name
he name of the custom identifier that detected the sensitive data.
- Returns:
- he name of the custom identifier that detected the sensitive data.
-
occurrences
Details about the sensitive data that was detected.
- Returns:
- Details about the sensitive data that was detected.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CustomDataIdentifiersDetections.Builder,CustomDataIdentifiersDetections>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-