Class DataClassificationDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.DataClassificationDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DataClassificationDetails.Builder,DataClassificationDetails>
@Generated("software.amazon.awssdk:codegen")
public final class DataClassificationDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<DataClassificationDetails.Builder,DataClassificationDetails>
Provides details about sensitive data that was detected on a resource.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe path to the folder or file that contains the sensitive data.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ClassificationResultresult()The details about the sensitive data that was detected on the resource.static Class<? extends DataClassificationDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
detailedResultsLocation
The path to the folder or file that contains the sensitive data.
- Returns:
- The path to the folder or file that contains the sensitive data.
-
result
The details about the sensitive data that was detected on the resource.
- Returns:
- The details about the sensitive data that was detected on the resource.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DataClassificationDetails.Builder,DataClassificationDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-