Class DateRange
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DateRange.Builder,DateRange>
A date range for the date filter.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic DateRange.Builderbuilder()final DateRangeComparisonThe condition to apply to a date range filter.final StringThe condition to apply to a date range filter.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends DateRange.Builder>final StringtoString()Returns a string representation of this object.final DateRangeUnitunit()A date range unit for the date filter.final StringA date range unit for the date filter.final Integervalue()A date range value for the date filter.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
value
A date range value for the date filter.
- Returns:
- A date range value for the date filter.
-
unit
A date range unit for the date filter.
If the service returns an enum value that is not available in the current SDK version,
unitwill returnDateRangeUnit.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromunitAsString().- Returns:
- A date range unit for the date filter.
- See Also:
-
unitAsString
A date range unit for the date filter.
If the service returns an enum value that is not available in the current SDK version,
unitwill returnDateRangeUnit.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromunitAsString().- Returns:
- A date range unit for the date filter.
- See Also:
-
comparison
The condition to apply to a date range filter. If you specify
WITHIN, Security Hub filters for dates within the specified date range. If you specifyOLDER_THAN, Security Hub filters for dates before the specified date range. If you don't specify a value, the default isWITHIN.If the service returns an enum value that is not available in the current SDK version,
comparisonwill returnDateRangeComparison.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcomparisonAsString().- Returns:
- The condition to apply to a date range filter. If you specify
WITHIN, Security Hub filters for dates within the specified date range. If you specifyOLDER_THAN, Security Hub filters for dates before the specified date range. If you don't specify a value, the default isWITHIN. - See Also:
-
comparisonAsString
The condition to apply to a date range filter. If you specify
WITHIN, Security Hub filters for dates within the specified date range. If you specifyOLDER_THAN, Security Hub filters for dates before the specified date range. If you don't specify a value, the default isWITHIN.If the service returns an enum value that is not available in the current SDK version,
comparisonwill returnDateRangeComparison.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcomparisonAsString().- Returns:
- The condition to apply to a date range filter. If you specify
WITHIN, Security Hub filters for dates within the specified date range. If you specifyOLDER_THAN, Security Hub filters for dates before the specified date range. If you don't specify a value, the default isWITHIN. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DateRange.Builder,DateRange>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-