Interface DeleteInvitationsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DeleteInvitationsRequest.Builder,,DeleteInvitationsRequest> SdkBuilder<DeleteInvitationsRequest.Builder,,DeleteInvitationsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- DeleteInvitationsRequest
@Mutable
@NotThreadSafe
public static interface DeleteInvitationsRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<DeleteInvitationsRequest.Builder,DeleteInvitationsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionaccountIds(String... accountIds) The list of member account IDs that received the invitations you want to delete.accountIds(Collection<String> accountIds) The list of member account IDs that received the invitations you want to delete.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
accountIds
The list of member account IDs that received the invitations you want to delete.
- Parameters:
accountIds- The list of member account IDs that received the invitations you want to delete.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
accountIds
The list of member account IDs that received the invitations you want to delete.
- Parameters:
accountIds- The list of member account IDs that received the invitations you want to delete.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DeleteInvitationsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DeleteInvitationsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-