Class DescribeActionTargetsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeActionTargetsRequest.Builder,DescribeActionTargetsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionA list of custom action target ARNs for the custom action targets to retrieve.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the ActionTargetArns property.final inthashCode()final IntegerThe maximum number of results to return.final StringThe token that is required for pagination.static Class<? extends DescribeActionTargetsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasActionTargetArns
public final boolean hasActionTargetArns()For responses, this returns true if the service returned a value for the ActionTargetArns property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
actionTargetArns
A list of custom action target ARNs for the custom action targets to retrieve.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasActionTargetArns()method.- Returns:
- A list of custom action target ARNs for the custom action targets to retrieve.
-
nextToken
The token that is required for pagination. On your first call to the
DescribeActionTargetsoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
- Returns:
- The token that is required for pagination. On your first call to the
DescribeActionTargetsoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
-
maxResults
The maximum number of results to return.
- Returns:
- The maximum number of results to return.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeActionTargetsRequest.Builder,DescribeActionTargetsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-