Class DescribeHubResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DescribeHubResponse.Builder,DescribeHubResponse>

@Generated("software.amazon.awssdk:codegen") public final class DescribeHubResponse extends SecurityHubResponse implements ToCopyableBuilder<DescribeHubResponse.Builder,DescribeHubResponse>
  • Method Details

    • hubArn

      public final String hubArn()

      The ARN of the Hub resource that was retrieved.

      Returns:
      The ARN of the Hub resource that was retrieved.
    • subscribedAt

      public final String subscribedAt()

      The date and time when Security Hub CSPM was enabled in the account.

      Returns:
      The date and time when Security Hub CSPM was enabled in the account.
    • autoEnableControls

      public final Boolean autoEnableControls()

      Whether to automatically enable new controls when they are added to standards that are enabled.

      If set to true, then new controls for enabled standards are enabled automatically. If set to false, then new controls are not enabled.

      When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control as ENABLED in your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you have AutoEnableControls set to true.

      Returns:
      Whether to automatically enable new controls when they are added to standards that are enabled.

      If set to true, then new controls for enabled standards are enabled automatically. If set to false, then new controls are not enabled.

      When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control as ENABLED in your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you have AutoEnableControls set to true.

    • controlFindingGenerator

      public final ControlFindingGenerator controlFindingGenerator()

      Specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is SECURITY_CONTROL if you enabled Security Hub CSPM on or after February 23, 2023.

      If the service returns an enum value that is not available in the current SDK version, controlFindingGenerator will return ControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from controlFindingGeneratorAsString().

      Returns:
      Specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is SECURITY_CONTROL if you enabled Security Hub CSPM on or after February 23, 2023.

      See Also:
    • controlFindingGeneratorAsString

      public final String controlFindingGeneratorAsString()

      Specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is SECURITY_CONTROL if you enabled Security Hub CSPM on or after February 23, 2023.

      If the service returns an enum value that is not available in the current SDK version, controlFindingGenerator will return ControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from controlFindingGeneratorAsString().

      Returns:
      Specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is SECURITY_CONTROL if you enabled Security Hub CSPM on or after February 23, 2023.

      See Also:
    • toBuilder

      public DescribeHubResponse.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<DescribeHubResponse.Builder,DescribeHubResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static DescribeHubResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends DescribeHubResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo