Class DescribeStandardsControlsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest>

@Generated("software.amazon.awssdk:codegen") public final class DescribeStandardsControlsRequest extends SecurityHubRequest implements ToCopyableBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest>
  • Method Details

    • standardsSubscriptionArn

      public final String standardsSubscriptionArn()

      The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.

      Returns:
      The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.
    • nextToken

      public final String nextToken()

      The token that is required for pagination. On your first call to the DescribeStandardsControls operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Returns:
      The token that is required for pagination. On your first call to the DescribeStandardsControls operation, set the value of this parameter to NULL .

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

    • maxResults

      public final Integer maxResults()

      The maximum number of security standard controls to return.

      Returns:
      The maximum number of security standard controls to return.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends DescribeStandardsControlsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo