Interface DescribeStandardsControlsRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest>, SdkBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest>, SdkPojo, SdkRequest.Builder, SecurityHubRequest.Builder
Enclosing class:
DescribeStandardsControlsRequest

  • Method Details

    • standardsSubscriptionArn

      DescribeStandardsControlsRequest.Builder standardsSubscriptionArn(String standardsSubscriptionArn)

      The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.

      Parameters:
      standardsSubscriptionArn - The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • nextToken

      The token that is required for pagination. On your first call to the DescribeStandardsControls operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Parameters:
      nextToken - The token that is required for pagination. On your first call to the DescribeStandardsControls operation, set the value of this parameter to NULL .

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • maxResults

      The maximum number of security standard controls to return.

      Parameters:
      maxResults - The maximum number of security standard controls to return.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      DescribeStandardsControlsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder