Class DescribeStandardsControlsResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.DescribeStandardsControlsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeStandardsControlsResponse.Builder,DescribeStandardsControlsResponse>
@Generated("software.amazon.awssdk:codegen")
public final class DescribeStandardsControlsResponse
extends SecurityHubResponse
implements ToCopyableBuilder<DescribeStandardsControlsResponse.Builder,DescribeStandardsControlsResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final List<StandardsControl>controls()A list of security standards controls.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Controls property.final inthashCode()final StringThe pagination token to use to request the next page of results.static Class<? extends DescribeStandardsControlsResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasControls
public final boolean hasControls()For responses, this returns true if the service returned a value for the Controls property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
controls
A list of security standards controls.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasControls()method.- Returns:
- A list of security standards controls.
-
nextToken
The pagination token to use to request the next page of results.
- Returns:
- The pagination token to use to request the next page of results.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeStandardsControlsResponse.Builder,DescribeStandardsControlsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-