java.lang.Object
software.amazon.awssdk.services.securityhub.model.Detection
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<Detection.Builder,Detection>

@Generated("software.amazon.awssdk:codegen") public final class Detection extends Object implements SdkPojo, Serializable, ToCopyableBuilder<Detection.Builder,Detection>

A top-level object field that provides details about an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

See Also: