Class DisableOrganizationAdminAccountRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DisableOrganizationAdminAccountRequest.Builder,DisableOrganizationAdminAccountRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe Amazon Web Services account identifier of the Security Hub CSPM administrator account.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final SecurityHubFeaturefeature()The feature for which the delegated admin account is disabled.final StringThe feature for which the delegated admin account is disabled.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends DisableOrganizationAdminAccountRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
adminAccountId
The Amazon Web Services account identifier of the Security Hub CSPM administrator account.
- Returns:
- The Amazon Web Services account identifier of the Security Hub CSPM administrator account.
-
feature
The feature for which the delegated admin account is disabled. Defaults to Security Hub CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature for which the delegated admin account is disabled. Defaults to Security Hub CSPM if not specified.
- See Also:
-
featureAsString
The feature for which the delegated admin account is disabled. Defaults to Security Hub CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature for which the delegated admin account is disabled. Defaults to Security Hub CSPM if not specified.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DisableOrganizationAdminAccountRequest.Builder,DisableOrganizationAdminAccountRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends DisableOrganizationAdminAccountRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-