Class DisableSecurityHubFeatureV2Request
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.DisableSecurityHubFeatureV2Request
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DisableSecurityHubFeatureV2Request.Builder,DisableSecurityHubFeatureV2Request>
@Generated("software.amazon.awssdk:codegen")
public final class DisableSecurityHubFeatureV2Request
extends SecurityHubRequest
implements ToCopyableBuilder<DisableSecurityHubFeatureV2Request.Builder,DisableSecurityHubFeatureV2Request>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final FeatureNameThe name of the feature to disable.final StringThe name of the feature to disable.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends DisableSecurityHubFeatureV2Request.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
featureName
The name of the feature to disable.
If the service returns an enum value that is not available in the current SDK version,
featureNamewill returnFeatureName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureNameAsString().- Returns:
- The name of the feature to disable.
- See Also:
-
featureNameAsString
The name of the feature to disable.
If the service returns an enum value that is not available in the current SDK version,
featureNamewill returnFeatureName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureNameAsString().- Returns:
- The name of the feature to disable.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DisableSecurityHubFeatureV2Request.Builder,DisableSecurityHubFeatureV2Request> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends DisableSecurityHubFeatureV2Request.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-