Interface DisableSecurityHubFeatureV2Request.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DisableSecurityHubFeatureV2Request.Builder,,DisableSecurityHubFeatureV2Request> SdkBuilder<DisableSecurityHubFeatureV2Request.Builder,,DisableSecurityHubFeatureV2Request> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- DisableSecurityHubFeatureV2Request
@Mutable
@NotThreadSafe
public static interface DisableSecurityHubFeatureV2Request.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<DisableSecurityHubFeatureV2Request.Builder,DisableSecurityHubFeatureV2Request>
-
Method Summary
Modifier and TypeMethodDescriptionfeatureName(String featureName) The name of the feature to disable.featureName(FeatureName featureName) The name of the feature to disable.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
featureName
The name of the feature to disable.
- Parameters:
featureName- The name of the feature to disable.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
featureName
The name of the feature to disable.
- Parameters:
featureName- The name of the feature to disable.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
DisableSecurityHubFeatureV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DisableSecurityHubFeatureV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-