Interface DisassociateMembersRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DisassociateMembersRequest.Builder,,DisassociateMembersRequest> SdkBuilder<DisassociateMembersRequest.Builder,,DisassociateMembersRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- DisassociateMembersRequest
@Mutable
@NotThreadSafe
public static interface DisassociateMembersRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<DisassociateMembersRequest.Builder,DisassociateMembersRequest>
-
Method Summary
Modifier and TypeMethodDescriptionaccountIds(String... accountIds) The account IDs of the member accounts to disassociate from the administrator account.accountIds(Collection<String> accountIds) The account IDs of the member accounts to disassociate from the administrator account.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
accountIds
The account IDs of the member accounts to disassociate from the administrator account.
- Parameters:
accountIds- The account IDs of the member accounts to disassociate from the administrator account.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
accountIds
The account IDs of the member accounts to disassociate from the administrator account.
- Parameters:
accountIds- The account IDs of the member accounts to disassociate from the administrator account.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DisassociateMembersRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DisassociateMembersRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-