Class EnableOrganizationAdminAccountRequest
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.EnableOrganizationAdminAccountRequest
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<EnableOrganizationAdminAccountRequest.Builder,EnableOrganizationAdminAccountRequest>
@Generated("software.amazon.awssdk:codegen") public final class EnableOrganizationAdminAccountRequest extends SecurityHubRequest implements ToCopyableBuilder<EnableOrganizationAdminAccountRequest.Builder,EnableOrganizationAdminAccountRequest>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceEnableOrganizationAdminAccountRequest.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description StringadminAccountId()The Amazon Web Services account identifier of the account to designate as the Security Hub CSPM administrator account.static EnableOrganizationAdminAccountRequest.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)SecurityHubFeaturefeature()The feature for which the delegated admin account is enabled.StringfeatureAsString()The feature for which the delegated admin account is enabled.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends EnableOrganizationAdminAccountRequest.Builder>serializableBuilderClass()EnableOrganizationAdminAccountRequest.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
adminAccountId
public final String adminAccountId()
The Amazon Web Services account identifier of the account to designate as the Security Hub CSPM administrator account.
- Returns:
- The Amazon Web Services account identifier of the account to designate as the Security Hub CSPM administrator account.
-
feature
public final SecurityHubFeature feature()
The feature for which the delegated admin account is enabled. Defaults to Security Hub CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature for which the delegated admin account is enabled. Defaults to Security Hub CSPM if not specified.
- See Also:
SecurityHubFeature
-
featureAsString
public final String featureAsString()
The feature for which the delegated admin account is enabled. Defaults to Security Hub CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature for which the delegated admin account is enabled. Defaults to Security Hub CSPM if not specified.
- See Also:
SecurityHubFeature
-
toBuilder
public EnableOrganizationAdminAccountRequest.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<EnableOrganizationAdminAccountRequest.Builder,EnableOrganizationAdminAccountRequest>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static EnableOrganizationAdminAccountRequest.Builder builder()
-
serializableBuilderClass
public static Class<? extends EnableOrganizationAdminAccountRequest.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-