Interface EnableOrganizationAdminAccountResponse.Builder

    • Method Detail

      • adminAccountId

        EnableOrganizationAdminAccountResponse.Builder adminAccountId​(String adminAccountId)

        The Amazon Web Services account identifier of the account to designate as the Security Hub administrator account.

        Parameters:
        adminAccountId - The Amazon Web Services account identifier of the account to designate as the Security Hub administrator account.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • feature

        EnableOrganizationAdminAccountResponse.Builder feature​(String feature)

        The feature where the delegated administrator is enabled. The default is Security Hub CSPM if no delegated administrator is specified in the request.

        Parameters:
        feature - The feature where the delegated administrator is enabled. The default is Security Hub CSPM if no delegated administrator is specified in the request.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        SecurityHubFeature, SecurityHubFeature
      • feature

        EnableOrganizationAdminAccountResponse.Builder feature​(SecurityHubFeature feature)

        The feature where the delegated administrator is enabled. The default is Security Hub CSPM if no delegated administrator is specified in the request.

        Parameters:
        feature - The feature where the delegated administrator is enabled. The default is Security Hub CSPM if no delegated administrator is specified in the request.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        SecurityHubFeature, SecurityHubFeature