Interface ExternalIntegrationConfiguration.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ExternalIntegrationConfiguration.Builder,ExternalIntegrationConfiguration>,SdkBuilder<ExternalIntegrationConfiguration.Builder,ExternalIntegrationConfiguration>,SdkPojo
- Enclosing class:
- ExternalIntegrationConfiguration
@Mutable @NotThreadSafe public static interface ExternalIntegrationConfiguration.Builder extends SdkPojo, CopyableBuilder<ExternalIntegrationConfiguration.Builder,ExternalIntegrationConfiguration>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ExternalIntegrationConfiguration.BuilderconnectorArn(String connectorArn)The ARN of the connector that establishes the integration.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
connectorArn
ExternalIntegrationConfiguration.Builder connectorArn(String connectorArn)
The ARN of the connector that establishes the integration.
- Parameters:
connectorArn- The ARN of the connector that establishes the integration.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-