Class FilePaths
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FilePaths.Builder,FilePaths>
Provides information about the file paths that were affected by the threat.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic FilePaths.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringfileName()The name of the infected or suspicious file corresponding to the hash.final StringfilePath()Path to the infected or suspicious file on the resource it was detected on.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final Stringhash()The hash value for the infected or suspicious file.final inthashCode()final StringThe Amazon Resource Name (ARN) of the resource on which the threat was detected.static Class<? extends FilePaths.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
filePath
Path to the infected or suspicious file on the resource it was detected on.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
- Returns:
- Path to the infected or suspicious file on the resource it was detected on.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
-
fileName
The name of the infected or suspicious file corresponding to the hash.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
- Returns:
- The name of the infected or suspicious file corresponding to the hash.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
-
resourceId
The Amazon Resource Name (ARN) of the resource on which the threat was detected.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
- Returns:
- The Amazon Resource Name (ARN) of the resource on which the threat was detected.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
-
hash
The hash value for the infected or suspicious file.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
- Returns:
- The hash value for the infected or suspicious file.
Length Constraints: Minimum of 1 length. Maximum of 128 length.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FilePaths.Builder,FilePaths>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-