Class FindingHistoryUpdate
java.lang.Object
software.amazon.awssdk.services.securityhub.model.FindingHistoryUpdate
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FindingHistoryUpdate.Builder,FindingHistoryUpdate>
@Generated("software.amazon.awssdk:codegen")
public final class FindingHistoryUpdate
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<FindingHistoryUpdate.Builder,FindingHistoryUpdate>
An array of objects that provides details about a change to a finding, including the Amazon Web Services Security Finding Format (ASFF) field that changed, the value of the field before the change, and the value of the field after the change.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic FindingHistoryUpdate.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringnewValue()The value of the ASFF field after the finding change event.final StringoldValue()The value of the ASFF field before the finding change event.static Class<? extends FindingHistoryUpdate.Builder>final StringtoString()Returns a string representation of this object.final StringThe ASFF field that changed during the finding change event.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
updatedField
The ASFF field that changed during the finding change event.
- Returns:
- The ASFF field that changed during the finding change event.
-
oldValue
The value of the ASFF field before the finding change event.
- Returns:
- The value of the ASFF field before the finding change event.
-
newValue
The value of the ASFF field after the finding change event. To preserve storage and readability, Security Hub CSPM omits this value if
FindingHistoryRecordexceeds database limits.- Returns:
- The value of the ASFF field after the finding change event. To preserve storage and readability, Security
Hub CSPM omits this value if
FindingHistoryRecordexceeds database limits.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FindingHistoryUpdate.Builder,FindingHistoryUpdate>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-