Class FindingHistoryUpdateSource
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FindingHistoryUpdateSource.Builder,FindingHistoryUpdateSource>
Identifies the source of the finding change event.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringidentity()The identity of the source that initiated the finding change event.static Class<? extends FindingHistoryUpdateSource.Builder>final StringtoString()Returns a string representation of this object.type()Describes the type of finding change event, such as a call toBatchImportFindings(by an integrated Amazon Web Services service or third party partner integration) orBatchUpdateFindings(by a Security Hub CSPM customer).final StringDescribes the type of finding change event, such as a call toBatchImportFindings(by an integrated Amazon Web Services service or third party partner integration) orBatchUpdateFindings(by a Security Hub CSPM customer).Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
Describes the type of finding change event, such as a call to
BatchImportFindings(by an integrated Amazon Web Services service or third party partner integration) orBatchUpdateFindings(by a Security Hub CSPM customer).If the service returns an enum value that is not available in the current SDK version,
typewill returnFindingHistoryUpdateSourceType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- Describes the type of finding change event, such as a call to
BatchImportFindings(by an integrated Amazon Web Services service or third party partner integration) orBatchUpdateFindings(by a Security Hub CSPM customer). - See Also:
-
typeAsString
Describes the type of finding change event, such as a call to
BatchImportFindings(by an integrated Amazon Web Services service or third party partner integration) orBatchUpdateFindings(by a Security Hub CSPM customer).If the service returns an enum value that is not available in the current SDK version,
typewill returnFindingHistoryUpdateSourceType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- Describes the type of finding change event, such as a call to
BatchImportFindings(by an integrated Amazon Web Services service or third party partner integration) orBatchUpdateFindings(by a Security Hub CSPM customer). - See Also:
-
identity
The identity of the source that initiated the finding change event. For example, the Amazon Resource Name (ARN) of a partner that calls BatchImportFindings or of a customer that calls BatchUpdateFindings.
- Returns:
- The identity of the source that initiated the finding change event. For example, the Amazon Resource Name (ARN) of a partner that calls BatchImportFindings or of a customer that calls BatchUpdateFindings.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FindingHistoryUpdateSource.Builder,FindingHistoryUpdateSource>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-