Class FindingProviderSeverity
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FindingProviderSeverity.Builder,FindingProviderSeverity>
The severity assigned to a finding by the finding provider. This object may include one or more of the following attributes:
-
Label -
Normalized -
Original -
Product
If a
BatchImportFindings request for a new finding only provides Label or only provides
Normalized, Security Hub CSPM automatically populates the value of the other field.
The Normalized and Product attributes are included in the
FindingProviderSeverity structure to preserve the historical information associated with the finding,
even if the top-level Severity object is later modified using the
BatchUpdateFindings operation.
If the top-level Finding.Severity object is present, but Finding.FindingProviderFields
isn't present, Security Hub CSPM creates the FindingProviderFields.Severity object and copies the entire
Finding.Severity object into it. This ensures that the original, provider-supplied details are retained
within the FindingProviderFields.Severity object, even if the top-level Severity object is
overwritten.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final SeverityLabellabel()The severity label assigned to the finding by the finding provider.final StringThe severity label assigned to the finding by the finding provider.final Stringoriginal()The finding provider's original value for the severity.static Class<? extends FindingProviderSeverity.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
label
The severity label assigned to the finding by the finding provider.
If the service returns an enum value that is not available in the current SDK version,
labelwill returnSeverityLabel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlabelAsString().- Returns:
- The severity label assigned to the finding by the finding provider.
- See Also:
-
labelAsString
The severity label assigned to the finding by the finding provider.
If the service returns an enum value that is not available in the current SDK version,
labelwill returnSeverityLabel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlabelAsString().- Returns:
- The severity label assigned to the finding by the finding provider.
- See Also:
-
original
The finding provider's original value for the severity.
Length Constraints: Minimum length of 1. Maximum length of 64.
- Returns:
- The finding provider's original value for the severity.
Length Constraints: Minimum length of 1. Maximum length of 64.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FindingProviderSeverity.Builder,FindingProviderSeverity>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-