Class FindingScopes
java.lang.Object
software.amazon.awssdk.services.securityhub.model.FindingScopes
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FindingScopes.Builder,FindingScopes>
@Generated("software.amazon.awssdk:codegen")
public final class FindingScopes
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<FindingScopes.Builder,FindingScopes>
Defines the data boundary for a findings query. Scopes determine which organizational units or organizations to retrieve data from.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal List<AwsOrganizationScope>A list of Organizations scopes to include in the query results.static FindingScopes.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the AwsOrganizations property.final inthashCode()static Class<? extends FindingScopes.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasAwsOrganizations
public final boolean hasAwsOrganizations()For responses, this returns true if the service returned a value for the AwsOrganizations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
awsOrganizations
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAwsOrganizations()method.- Returns:
- A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FindingScopes.Builder,FindingScopes>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-