Enum FindingsTrendsStringField
- java.lang.Object
-
- java.lang.Enum<FindingsTrendsStringField>
-
- software.amazon.awssdk.services.securityhub.model.FindingsTrendsStringField
-
- All Implemented Interfaces:
Serializable,Comparable<FindingsTrendsStringField>
@Generated("software.amazon.awssdk:codegen") public enum FindingsTrendsStringField extends Enum<FindingsTrendsStringField>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_IDFINDING_ACTIVITY_NAMEFINDING_CLASS_NAMEFINDING_COMPLIANCE_STATUSFINDING_CONTROL_IDFINDING_CVE_IDSFINDING_PROVIDERFINDING_STATUSFINDING_TYPESREGIONUNKNOWN_TO_SDK_VERSION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static FindingsTrendsStringFieldfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<FindingsTrendsStringField>knownValues()StringtoString()static FindingsTrendsStringFieldvalueOf(String name)Returns the enum constant of this type with the specified name.static FindingsTrendsStringField[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
ACCOUNT_ID
public static final FindingsTrendsStringField ACCOUNT_ID
-
REGION
public static final FindingsTrendsStringField REGION
-
FINDING_TYPES
public static final FindingsTrendsStringField FINDING_TYPES
-
FINDING_STATUS
public static final FindingsTrendsStringField FINDING_STATUS
-
FINDING_CVE_IDS
public static final FindingsTrendsStringField FINDING_CVE_IDS
-
FINDING_COMPLIANCE_STATUS
public static final FindingsTrendsStringField FINDING_COMPLIANCE_STATUS
-
FINDING_CONTROL_ID
public static final FindingsTrendsStringField FINDING_CONTROL_ID
-
FINDING_CLASS_NAME
public static final FindingsTrendsStringField FINDING_CLASS_NAME
-
FINDING_PROVIDER
public static final FindingsTrendsStringField FINDING_PROVIDER
-
FINDING_ACTIVITY_NAME
public static final FindingsTrendsStringField FINDING_ACTIVITY_NAME
-
UNKNOWN_TO_SDK_VERSION
public static final FindingsTrendsStringField UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static FindingsTrendsStringField[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (FindingsTrendsStringField c : FindingsTrendsStringField.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static FindingsTrendsStringField valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<FindingsTrendsStringField>
-
fromValue
public static FindingsTrendsStringField fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- FindingsTrendsStringField corresponding to the value
-
knownValues
public static Set<FindingsTrendsStringField> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownFindingsTrendsStringFields
-
-