Class FirewallPolicyStatelessRuleGroupReferencesDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.FirewallPolicyStatelessRuleGroupReferencesDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FirewallPolicyStatelessRuleGroupReferencesDetails.Builder,FirewallPolicyStatelessRuleGroupReferencesDetails>
@Generated("software.amazon.awssdk:codegen")
public final class FirewallPolicyStatelessRuleGroupReferencesDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<FirewallPolicyStatelessRuleGroupReferencesDetails.Builder,FirewallPolicyStatelessRuleGroupReferencesDetails>
A stateless rule group that is used by the firewall policy.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Integerpriority()The order in which to run the stateless rule group.final StringThe ARN of the stateless rule group.static Class<? extends FirewallPolicyStatelessRuleGroupReferencesDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
priority
The order in which to run the stateless rule group.
- Returns:
- The order in which to run the stateless rule group.
-
resourceArn
The ARN of the stateless rule group.
- Returns:
- The ARN of the stateless rule group.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends FirewallPolicyStatelessRuleGroupReferencesDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-