Class GeoLocation
java.lang.Object
software.amazon.awssdk.services.securityhub.model.GeoLocation
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<GeoLocation.Builder,GeoLocation>
@Generated("software.amazon.awssdk:codegen")
public final class GeoLocation
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<GeoLocation.Builder,GeoLocation>
Provides the latitude and longitude coordinates of a location.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic GeoLocation.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Doublelat()The latitude of the location.final Doublelon()The longitude of the location.static Class<? extends GeoLocation.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
lon
The longitude of the location.
- Returns:
- The longitude of the location.
-
lat
The latitude of the location.
- Returns:
- The latitude of the location.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GeoLocation.Builder,GeoLocation>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-