Interface GetAutomationRuleV2Request.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<GetAutomationRuleV2Request.Builder,GetAutomationRuleV2Request>,SdkBuilder<GetAutomationRuleV2Request.Builder,GetAutomationRuleV2Request>,SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- GetAutomationRuleV2Request
@Mutable @NotThreadSafe public static interface GetAutomationRuleV2Request.Builder extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<GetAutomationRuleV2Request.Builder,GetAutomationRuleV2Request>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description GetAutomationRuleV2Request.Builderidentifier(String identifier)The ARN of the V2 automation rule.GetAutomationRuleV2Request.BuilderoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)GetAutomationRuleV2Request.BuilderoverrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
-
-
-
Method Detail
-
identifier
GetAutomationRuleV2Request.Builder identifier(String identifier)
The ARN of the V2 automation rule.
- Parameters:
identifier- The ARN of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetAutomationRuleV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetAutomationRuleV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-