Interface GetAutomationRuleV2Response.Builder

    • Method Detail

      • ruleArn

        GetAutomationRuleV2Response.Builder ruleArn​(String ruleArn)

        The ARN of the V2 automation rule.

        Parameters:
        ruleArn - The ARN of the V2 automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleId

        GetAutomationRuleV2Response.Builder ruleId​(String ruleId)

        The ID of the V2 automation rule.

        Parameters:
        ruleId - The ID of the V2 automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleOrder

        GetAutomationRuleV2Response.Builder ruleOrder​(Float ruleOrder)

        The value for the rule priority.

        Parameters:
        ruleOrder - The value for the rule priority.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleName

        GetAutomationRuleV2Response.Builder ruleName​(String ruleName)

        The name of the V2 automation rule.

        Parameters:
        ruleName - The name of the V2 automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleStatus

        GetAutomationRuleV2Response.Builder ruleStatus​(String ruleStatus)

        The status of the V2 automation automation rule.

        Parameters:
        ruleStatus - The status of the V2 automation automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        RuleStatusV2, RuleStatusV2
      • description

        GetAutomationRuleV2Response.Builder description​(String description)

        A description of the automation rule.

        Parameters:
        description - A description of the automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • criteria

        GetAutomationRuleV2Response.Builder criteria​(Criteria criteria)

        The filtering type and configuration of the V2 automation rule.

        Parameters:
        criteria - The filtering type and configuration of the V2 automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • actions

        GetAutomationRuleV2Response.Builder actions​(AutomationRulesActionV2... actions)

        A list of actions performed when the rule criteria is met.

        Parameters:
        actions - A list of actions performed when the rule criteria is met.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • createdAt

        GetAutomationRuleV2Response.Builder createdAt​(Instant createdAt)

        The timestamp when the V2 automation rule was created.

        Parameters:
        createdAt - The timestamp when the V2 automation rule was created.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • updatedAt

        GetAutomationRuleV2Response.Builder updatedAt​(Instant updatedAt)

        The timestamp when the V2 automation rule was updated.

        Parameters:
        updatedAt - The timestamp when the V2 automation rule was updated.
        Returns:
        Returns a reference to this object so that method calls can be chained together.