Class GetConfigurationPolicyResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetConfigurationPolicyResponse.Builder,GetConfigurationPolicyResponse>

@Generated("software.amazon.awssdk:codegen") public final class GetConfigurationPolicyResponse extends SecurityHubResponse implements ToCopyableBuilder<GetConfigurationPolicyResponse.Builder,GetConfigurationPolicyResponse>
  • Method Details

    • arn

      public final String arn()

      The ARN of the configuration policy.

      Returns:
      The ARN of the configuration policy.
    • id

      public final String id()

      The UUID of the configuration policy.

      Returns:
      The UUID of the configuration policy.
    • name

      public final String name()

      The name of the configuration policy.

      Returns:
      The name of the configuration policy.
    • description

      public final String description()

      The description of the configuration policy.

      Returns:
      The description of the configuration policy.
    • updatedAt

      public final Instant updatedAt()

      The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.

      Returns:
      The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
    • createdAt

      public final Instant createdAt()

      The date and time, in UTC and ISO 8601 format, that the configuration policy was created.

      Returns:
      The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
    • configurationPolicy

      public final Policy configurationPolicy()

      An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the policy includes a list of security controls that are enabled, Security Hub CSPM disables all other controls (including newly released controls). If the policy includes a list of security controls that are disabled, Security Hub CSPM enables all other controls (including newly released controls).

      Returns:
      An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the policy includes a list of security controls that are enabled, Security Hub CSPM disables all other controls (including newly released controls). If the policy includes a list of security controls that are disabled, Security Hub CSPM enables all other controls (including newly released controls).
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetConfigurationPolicyResponse.Builder,GetConfigurationPolicyResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static GetConfigurationPolicyResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetConfigurationPolicyResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo