Class GetConnectorResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetConnectorResponse.Builder,GetConnectorResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic GetConnectorResponse.Builderbuilder()final StringThe Amazon Resource Name (ARN) of the connector.final StringThe unique identifier of the connector.final InstantThe ISO 8601 UTC timestamp indicating when the connector was created.final StringThe service principal that created the connector.final StringThe description of the connector.final CspmEnablementStatusThe enablement status of the connector.final StringThe enablement status of the connector.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final CspmHealthCheckhealth()The health status of the connector, including connectivity status and last check time.final InstantThe ISO 8601 UTC timestamp indicating when the connector was last updated.final Stringname()The name of the connector.final CspmProviderDetailThe cloud provider configuration details for the connector.static Class<? extends GetConnectorResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorArn
The Amazon Resource Name (ARN) of the connector.
- Returns:
- The Amazon Resource Name (ARN) of the connector.
-
connectorId
The unique identifier of the connector.
- Returns:
- The unique identifier of the connector.
-
name
The name of the connector.
- Returns:
- The name of the connector.
-
description
The description of the connector.
- Returns:
- The description of the connector.
-
createdAt
The ISO 8601 UTC timestamp indicating when the connector was created.
- Returns:
- The ISO 8601 UTC timestamp indicating when the connector was created.
-
lastUpdatedAt
The ISO 8601 UTC timestamp indicating when the connector was last updated.
- Returns:
- The ISO 8601 UTC timestamp indicating when the connector was last updated.
-
health
The health status of the connector, including connectivity status and last check time.
- Returns:
- The health status of the connector, including connectivity status and last check time.
-
providerDetail
The cloud provider configuration details for the connector.
- Returns:
- The cloud provider configuration details for the connector.
-
createdBy
The service principal that created the connector.
- Returns:
- The service principal that created the connector.
-
enablementStatus
The enablement status of the connector.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnCspmEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector.
- See Also:
-
enablementStatusAsString
The enablement status of the connector.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnCspmEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetConnectorResponse.Builder,GetConnectorResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-