Class GetConnectorV2Response

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response>

@Generated("software.amazon.awssdk:codegen") public final class GetConnectorV2Response extends SecurityHubResponse implements ToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response>
  • Method Details

    • connectorArn

      public final String connectorArn()

      The Amazon Resource Name (ARN) of the connectorV2.

      Returns:
      The Amazon Resource Name (ARN) of the connectorV2.
    • connectorId

      public final String connectorId()

      The UUID of the connectorV2 to identify connectorV2 resource.

      Returns:
      The UUID of the connectorV2 to identify connectorV2 resource.
    • name

      public final String name()

      The name of the connectorV2.

      Returns:
      The name of the connectorV2.
    • description

      public final String description()

      The description of the connectorV2.

      Returns:
      The description of the connectorV2.
    • kmsKeyArn

      public final String kmsKeyArn()

      The Amazon Resource Name (ARN) of KMS key used for the connectorV2.

      Returns:
      The Amazon Resource Name (ARN) of KMS key used for the connectorV2.
    • createdAt

      public final Instant createdAt()

      ISO 8601 UTC timestamp for the time create the connectorV2.

      Returns:
      ISO 8601 UTC timestamp for the time create the connectorV2.
    • lastUpdatedAt

      public final Instant lastUpdatedAt()

      ISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.

      Returns:
      ISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.
    • health

      public final HealthCheck health()

      The current health status for connectorV2

      Returns:
      The current health status for connectorV2
    • providerDetail

      public final ProviderDetail providerDetail()

      The third-party provider detail for a service configuration.

      Returns:
      The third-party provider detail for a service configuration.
    • enablementStatus

      public final EnablementStatus enablementStatus()

      The enablement status of the connector.

      If the service returns an enum value that is not available in the current SDK version, enablementStatus will return EnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from enablementStatusAsString().

      Returns:
      The enablement status of the connector.
      See Also:
    • enablementStatusAsString

      public final String enablementStatusAsString()

      The enablement status of the connector.

      If the service returns an enum value that is not available in the current SDK version, enablementStatus will return EnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from enablementStatusAsString().

      Returns:
      The enablement status of the connector.
      See Also:
    • enablementStatusReason

      public final String enablementStatusReason()

      The reason for the current enablement status. Provides additional context when the connector is in a failed state.

      Returns:
      The reason for the current enablement status. Provides additional context when the connector is in a failed state.
    • toBuilder

      public GetConnectorV2Response.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static GetConnectorV2Response.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetConnectorV2Response.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo