Interface GetEnabledStandardsRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<GetEnabledStandardsRequest.Builder,GetEnabledStandardsRequest>, SdkBuilder<GetEnabledStandardsRequest.Builder,GetEnabledStandardsRequest>, SdkPojo, SdkRequest.Builder, SecurityHubRequest.Builder
Enclosing class:
GetEnabledStandardsRequest

  • Method Details

    • standardsSubscriptionArns

      GetEnabledStandardsRequest.Builder standardsSubscriptionArns(Collection<String> standardsSubscriptionArns)

      The list of the standards subscription ARNs for the standards to retrieve.

      Parameters:
      standardsSubscriptionArns - The list of the standards subscription ARNs for the standards to retrieve.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • standardsSubscriptionArns

      GetEnabledStandardsRequest.Builder standardsSubscriptionArns(String... standardsSubscriptionArns)

      The list of the standards subscription ARNs for the standards to retrieve.

      Parameters:
      standardsSubscriptionArns - The list of the standards subscription ARNs for the standards to retrieve.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • nextToken

      The token that is required for pagination. On your first call to the GetEnabledStandards operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Parameters:
      nextToken - The token that is required for pagination. On your first call to the GetEnabledStandards operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • maxResults

      The maximum number of results to return in the response.

      Parameters:
      maxResults - The maximum number of results to return in the response.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      GetEnabledStandardsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder