Interface GetFindingAggregatorRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<GetFindingAggregatorRequest.Builder,,GetFindingAggregatorRequest> SdkBuilder<GetFindingAggregatorRequest.Builder,,GetFindingAggregatorRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- GetFindingAggregatorRequest
@Mutable
@NotThreadSafe
public static interface GetFindingAggregatorRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<GetFindingAggregatorRequest.Builder,GetFindingAggregatorRequest>
-
Method Summary
Modifier and TypeMethodDescriptionfindingAggregatorArn(String findingAggregatorArn) The ARN of the finding aggregator to return details for.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
findingAggregatorArn
The ARN of the finding aggregator to return details for. To obtain the ARN, use
ListFindingAggregators.- Parameters:
findingAggregatorArn- The ARN of the finding aggregator to return details for. To obtain the ARN, useListFindingAggregators.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetFindingAggregatorRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetFindingAggregatorRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-