Class GetFindingAggregatorResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetFindingAggregatorResponse.Builder,GetFindingAggregatorResponse>

@Generated("software.amazon.awssdk:codegen") public final class GetFindingAggregatorResponse extends SecurityHubResponse implements ToCopyableBuilder<GetFindingAggregatorResponse.Builder,GetFindingAggregatorResponse>
  • Method Details

    • findingAggregatorArn

      public final String findingAggregatorArn()

      The ARN of the finding aggregator.

      Returns:
      The ARN of the finding aggregator.
    • findingAggregationRegion

      public final String findingAggregationRegion()

      The home Region. Findings generated in linked Regions are replicated and sent to the home Region.

      Returns:
      The home Region. Findings generated in linked Regions are replicated and sent to the home Region.
    • regionLinkingMode

      public final String regionLinkingMode()

      Indicates whether to link all Regions, all Regions except for a list of excluded Regions, or a list of included Regions.

      Returns:
      Indicates whether to link all Regions, all Regions except for a list of excluded Regions, or a list of included Regions.
    • hasRegions

      public final boolean hasRegions()
      For responses, this returns true if the service returned a value for the Regions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • regions

      public final List<String> regions()

      The list of excluded Regions or included Regions.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasRegions() method.

      Returns:
      The list of excluded Regions or included Regions.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetFindingAggregatorResponse.Builder,GetFindingAggregatorResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static GetFindingAggregatorResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetFindingAggregatorResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo