Class GetFindingHistoryRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetFindingHistoryRequest.Builder,GetFindingHistoryRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetFindingHistoryRequest extends SecurityHubRequest implements ToCopyableBuilder<GetFindingHistoryRequest.Builder,GetFindingHistoryRequest>
  • Method Details

    • findingIdentifier

      public final AwsSecurityFindingIdentifier findingIdentifier()
      Returns the value of the FindingIdentifier property for this object.
      Returns:
      The value of the FindingIdentifier property for this object.
    • startTime

      public final Instant startTime()

      A timestamp that indicates the start time of the requested finding history.

      If you provide values for both StartTime and EndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value for StartTime but not for EndTime, Security Hub CSPM returns finding history from the StartTime to the time at which the API is called. If you provide a value for EndTime but not for StartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the EndTime. If you provide neither StartTime nor EndTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      Returns:
      A timestamp that indicates the start time of the requested finding history.

      If you provide values for both StartTime and EndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value for StartTime but not for EndTime, Security Hub CSPM returns finding history from the StartTime to the time at which the API is called. If you provide a value for EndTime but not for StartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the EndTime. If you provide neither StartTime nor EndTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

    • endTime

      public final Instant endTime()

      An ISO 8601-formatted timestamp that indicates the end time of the requested finding history.

      If you provide values for both StartTime and EndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value for StartTime but not for EndTime, Security Hub CSPM returns finding history from the StartTime to the time at which the API is called. If you provide a value for EndTime but not for StartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the EndTime. If you provide neither StartTime nor EndTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      Returns:
      An ISO 8601-formatted timestamp that indicates the end time of the requested finding history.

      If you provide values for both StartTime and EndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value for StartTime but not for EndTime, Security Hub CSPM returns finding history from the StartTime to the time at which the API is called. If you provide a value for EndTime but not for StartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the EndTime. If you provide neither StartTime nor EndTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

    • nextToken

      public final String nextToken()

      A token for pagination purposes. Provide NULL as the initial value. In subsequent requests, provide the token included in the response to get up to an additional 100 results of finding history. If you don’t provide NextToken, Security Hub CSPM returns up to 100 results of finding history for each request.

      Returns:
      A token for pagination purposes. Provide NULL as the initial value. In subsequent requests, provide the token included in the response to get up to an additional 100 results of finding history. If you don’t provide NextToken, Security Hub CSPM returns up to 100 results of finding history for each request.
    • maxResults

      public final Integer maxResults()

      The maximum number of results to be returned. If you don’t provide it, Security Hub CSPM returns up to 100 results of finding history.

      Returns:
      The maximum number of results to be returned. If you don’t provide it, Security Hub CSPM returns up to 100 results of finding history.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetFindingHistoryRequest.Builder,GetFindingHistoryRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

      public static GetFindingHistoryRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetFindingHistoryRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo