Class GetFindingHistoryResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetFindingHistoryResponse.Builder,GetFindingHistoryResponse>

@Generated("software.amazon.awssdk:codegen") public final class GetFindingHistoryResponse extends SecurityHubResponse implements ToCopyableBuilder<GetFindingHistoryResponse.Builder,GetFindingHistoryResponse>
  • Method Details

    • hasRecords

      public final boolean hasRecords()
      For responses, this returns true if the service returned a value for the Records property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • records

      public final List<FindingHistoryRecord> records()

      A list of events that altered the specified finding during the specified time period.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasRecords() method.

      Returns:
      A list of events that altered the specified finding during the specified time period.
    • nextToken

      public final String nextToken()

      A token for pagination purposes. Provide this token in the subsequent request to GetFindingsHistory to get up to an additional 100 results of history for the same finding that you specified in your initial request.

      Returns:
      A token for pagination purposes. Provide this token in the subsequent request to GetFindingsHistory to get up to an additional 100 results of history for the same finding that you specified in your initial request.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetFindingHistoryResponse.Builder,GetFindingHistoryResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static GetFindingHistoryResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetFindingHistoryResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo