Class GetFindingStatisticsV2Request

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>

@Generated("software.amazon.awssdk:codegen") public final class GetFindingStatisticsV2Request extends SecurityHubRequest implements ToCopyableBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>
  • Method Details

    • hasGroupByRules

      public final boolean hasGroupByRules()
      For responses, this returns true if the service returned a value for the GroupByRules property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • groupByRules

      public final List<GroupByRule> groupByRules()

      Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasGroupByRules() method.

      Returns:
      Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
    • scopes

      public final FindingScopes scopes()

      Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

      This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.

      You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

      Returns:
      Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

      This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.

      You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

    • sortOrder

      public final SortOrder sortOrder()

      Orders the aggregation count in descending or ascending order. Descending order is the default.

      If the service returns an enum value that is not available in the current SDK version, sortOrder will return SortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from sortOrderAsString().

      Returns:
      Orders the aggregation count in descending or ascending order. Descending order is the default.
      See Also:
    • sortOrderAsString

      public final String sortOrderAsString()

      Orders the aggregation count in descending or ascending order. Descending order is the default.

      If the service returns an enum value that is not available in the current SDK version, sortOrder will return SortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from sortOrderAsString().

      Returns:
      Orders the aggregation count in descending or ascending order. Descending order is the default.
      See Also:
    • maxStatisticResults

      public final Integer maxStatisticResults()

      The maximum number of results to be returned.

      Returns:
      The maximum number of results to be returned.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

      public static GetFindingStatisticsV2Request.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetFindingStatisticsV2Request.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo