Interface GetFindingStatisticsV2Request.Builder

    • Method Detail

      • groupByRules

        GetFindingStatisticsV2Request.Builder groupByRules​(Collection<GroupByRule> groupByRules)

        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

        Parameters:
        groupByRules - Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • groupByRules

        GetFindingStatisticsV2Request.Builder groupByRules​(GroupByRule... groupByRules)

        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

        Parameters:
        groupByRules - Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • groupByRules

        GetFindingStatisticsV2Request.Builder groupByRules​(Consumer<GroupByRule.Builder>... groupByRules)

        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

        This is a convenience method that creates an instance of the GroupByRule.Builder avoiding the need to create one manually via GroupByRule.builder().

        When the Consumer completes, SdkBuilder.build() is called immediately and its result is passed to #groupByRules(List).

        Parameters:
        groupByRules - a consumer that will call methods on GroupByRule.Builder
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        #groupByRules(java.util.Collection)
      • scopes

        GetFindingStatisticsV2Request.Builder scopes​(FindingScopes scopes)

        Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

        This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.

        You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

        Parameters:
        scopes - Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

        This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.

        You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • scopes

        default GetFindingStatisticsV2Request.Builder scopes​(Consumer<FindingScopes.Builder> scopes)

        Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

        This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.

        You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

        This is a convenience method that creates an instance of the FindingScopes.Builder avoiding the need to create one manually via FindingScopes.builder().

        When the Consumer completes, SdkBuilder.build() is called immediately and its result is passed to scopes(FindingScopes).

        Parameters:
        scopes - a consumer that will call methods on FindingScopes.Builder
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        scopes(FindingScopes)
      • sortOrder

        GetFindingStatisticsV2Request.Builder sortOrder​(String sortOrder)

        Orders the aggregation count in descending or ascending order. Descending order is the default.

        Parameters:
        sortOrder - Orders the aggregation count in descending or ascending order. Descending order is the default.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        SortOrder, SortOrder
      • sortOrder

        GetFindingStatisticsV2Request.Builder sortOrder​(SortOrder sortOrder)

        Orders the aggregation count in descending or ascending order. Descending order is the default.

        Parameters:
        sortOrder - Orders the aggregation count in descending or ascending order. Descending order is the default.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        SortOrder, SortOrder
      • maxStatisticResults

        GetFindingStatisticsV2Request.Builder maxStatisticResults​(Integer maxStatisticResults)

        The maximum number of results to be returned.

        Parameters:
        maxStatisticResults - The maximum number of results to be returned.
        Returns:
        Returns a reference to this object so that method calls can be chained together.