Interface GetFindingStatisticsV2Response.Builder
-
- All Superinterfaces:
AwsResponse.Builder,Buildable,CopyableBuilder<GetFindingStatisticsV2Response.Builder,GetFindingStatisticsV2Response>,SdkBuilder<GetFindingStatisticsV2Response.Builder,GetFindingStatisticsV2Response>,SdkPojo,SdkResponse.Builder,SecurityHubResponse.Builder
- Enclosing class:
- GetFindingStatisticsV2Response
@Mutable @NotThreadSafe public static interface GetFindingStatisticsV2Response.Builder extends SecurityHubResponse.Builder, SdkPojo, CopyableBuilder<GetFindingStatisticsV2Response.Builder,GetFindingStatisticsV2Response>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description GetFindingStatisticsV2Response.BuildergroupByResults(Collection<GroupByResult> groupByResults)Aggregated statistics about security findings based on specified grouping criteria.GetFindingStatisticsV2Response.BuildergroupByResults(Consumer<GroupByResult.Builder>... groupByResults)Aggregated statistics about security findings based on specified grouping criteria.GetFindingStatisticsV2Response.BuildergroupByResults(GroupByResult... groupByResults)Aggregated statistics about security findings based on specified grouping criteria.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.core.SdkResponse.Builder
sdkHttpResponse, sdkHttpResponse
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubResponse.Builder
build, responseMetadata, responseMetadata
-
-
-
-
Method Detail
-
groupByResults
GetFindingStatisticsV2Response.Builder groupByResults(Collection<GroupByResult> groupByResults)
Aggregated statistics about security findings based on specified grouping criteria.
- Parameters:
groupByResults- Aggregated statistics about security findings based on specified grouping criteria.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
groupByResults
GetFindingStatisticsV2Response.Builder groupByResults(GroupByResult... groupByResults)
Aggregated statistics about security findings based on specified grouping criteria.
- Parameters:
groupByResults- Aggregated statistics about security findings based on specified grouping criteria.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
groupByResults
GetFindingStatisticsV2Response.Builder groupByResults(Consumer<GroupByResult.Builder>... groupByResults)
Aggregated statistics about security findings based on specified grouping criteria.
This is a convenience method that creates an instance of theGroupByResult.Builderavoiding the need to create one manually viaGroupByResult.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#groupByResults(List.) - Parameters:
groupByResults- a consumer that will call methods onGroupByResult.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#groupByResults(java.util.Collection)
-
-