Class GetFindingsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetFindingsRequest.Builder,GetFindingsRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetFindingsRequest extends SecurityHubRequest implements ToCopyableBuilder<GetFindingsRequest.Builder,GetFindingsRequest>
  • Method Details

    • filters

      public final AwsSecurityFindingFilters filters()

      The finding attributes used to define a condition to filter the returned findings.

      You can filter by up to 10 finding attributes. For each attribute, you can provide up to 20 filter values.

      Note that in the available filter fields, WorkflowState is deprecated. To search for a finding based on its workflow status, use WorkflowStatus.

      Returns:
      The finding attributes used to define a condition to filter the returned findings.

      You can filter by up to 10 finding attributes. For each attribute, you can provide up to 20 filter values.

      Note that in the available filter fields, WorkflowState is deprecated. To search for a finding based on its workflow status, use WorkflowStatus.

    • hasSortCriteria

      public final boolean hasSortCriteria()
      For responses, this returns true if the service returned a value for the SortCriteria property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • sortCriteria

      public final List<SortCriterion> sortCriteria()

      The finding attributes used to sort the list of returned findings.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasSortCriteria() method.

      Returns:
      The finding attributes used to sort the list of returned findings.
    • nextToken

      public final String nextToken()

      The token that is required for pagination. On your first call to the GetFindings operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Returns:
      The token that is required for pagination. On your first call to the GetFindings operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

    • maxResults

      public final Integer maxResults()

      The maximum number of findings to return.

      Returns:
      The maximum number of findings to return.
    • toBuilder

      public GetFindingsRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<GetFindingsRequest.Builder,GetFindingsRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

      public static GetFindingsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetFindingsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo