Interface GetFindingsV2Request.Builder

    • Method Detail

      • filters

        GetFindingsV2Request.Builder filters​(OcsfFindingFilters filters)

        The finding attributes used to define a condition to filter the returned OCSF findings. You can filter up to 10 composite filters. For each filter type inside of a composite filter, you can provide up to 20 filters.

        Parameters:
        filters - The finding attributes used to define a condition to filter the returned OCSF findings. You can filter up to 10 composite filters. For each filter type inside of a composite filter, you can provide up to 20 filters.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • sortCriteria

        GetFindingsV2Request.Builder sortCriteria​(Collection<SortCriterion> sortCriteria)

        The finding attributes used to sort the list of returned findings.

        Parameters:
        sortCriteria - The finding attributes used to sort the list of returned findings.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • sortCriteria

        GetFindingsV2Request.Builder sortCriteria​(SortCriterion... sortCriteria)

        The finding attributes used to sort the list of returned findings.

        Parameters:
        sortCriteria - The finding attributes used to sort the list of returned findings.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • nextToken

        GetFindingsV2Request.Builder nextToken​(String nextToken)

        The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

        Parameters:
        nextToken - The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • maxResults

        GetFindingsV2Request.Builder maxResults​(Integer maxResults)

        The maximum number of results to return.

        Parameters:
        maxResults - The maximum number of results to return.
        Returns:
        Returns a reference to this object so that method calls can be chained together.