Class GetInvitationsCountResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.GetInvitationsCountResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetInvitationsCountResponse.Builder,GetInvitationsCountResponse>
@Generated("software.amazon.awssdk:codegen")
public final class GetInvitationsCountResponse
extends SecurityHubResponse
implements ToCopyableBuilder<GetInvitationsCountResponse.Builder,GetInvitationsCountResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe number of all membership invitations sent to this Security Hub CSPM member account, not including the currently accepted invitation.static Class<? extends GetInvitationsCountResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
invitationsCount
The number of all membership invitations sent to this Security Hub CSPM member account, not including the currently accepted invitation.
- Returns:
- The number of all membership invitations sent to this Security Hub CSPM member account, not including the currently accepted invitation.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetInvitationsCountResponse.Builder,GetInvitationsCountResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-