Class GetRecommendedPolicyV2Request
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.GetRecommendedPolicyV2Request
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetRecommendedPolicyV2Request.Builder,GetRecommendedPolicyV2Request>
@Generated("software.amazon.awssdk:codegen")
public final class GetRecommendedPolicyV2Request
extends SecurityHubRequest
implements ToCopyableBuilder<GetRecommendedPolicyV2Request.Builder,GetRecommendedPolicyV2Request>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of recommendation steps to return.final StringThe unique identifier (ID) of Security Hub OCSF findings found under themetadata.uidfield of the finding.final StringThe token used to paginate theRecommendationStepslist returned.static Class<? extends GetRecommendedPolicyV2Request.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
metadataUid
The unique identifier (ID) of Security Hub OCSF findings found under the
metadata.uidfield of the finding.- Returns:
- The unique identifier (ID) of Security Hub OCSF findings found under the
metadata.uidfield of the finding.
-
nextToken
The token used to paginate the
RecommendationStepslist returned. On your first call toGetRecommendedPolicyV2, omit this parameter or set it toNULL. For subsequent calls, use theNextTokenvalue returned in the previous response to retrieve the next page of results.- Returns:
- The token used to paginate the
RecommendationStepslist returned. On your first call toGetRecommendedPolicyV2, omit this parameter or set it toNULL. For subsequent calls, use theNextTokenvalue returned in the previous response to retrieve the next page of results.
-
maxResults
The maximum number of recommendation steps to return.
- Returns:
- The maximum number of recommendation steps to return.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetRecommendedPolicyV2Request.Builder,GetRecommendedPolicyV2Request> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-