Interface GetRecommendedPolicyV2Request.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<GetRecommendedPolicyV2Request.Builder,GetRecommendedPolicyV2Request>, SdkBuilder<GetRecommendedPolicyV2Request.Builder,GetRecommendedPolicyV2Request>, SdkPojo, SdkRequest.Builder, SecurityHubRequest.Builder
Enclosing class:
GetRecommendedPolicyV2Request

  • Method Details

    • metadataUid

      The unique identifier (ID) of Security Hub OCSF findings found under the metadata.uid field of the finding.

      Parameters:
      metadataUid - The unique identifier (ID) of Security Hub OCSF findings found under the metadata.uid field of the finding.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • nextToken

      The token used to paginate the RecommendationSteps list returned. On your first call to GetRecommendedPolicyV2, omit this parameter or set it to NULL. For subsequent calls, use the NextToken value returned in the previous response to retrieve the next page of results.

      Parameters:
      nextToken - The token used to paginate the RecommendationSteps list returned. On your first call to GetRecommendedPolicyV2, omit this parameter or set it to NULL. For subsequent calls, use the NextToken value returned in the previous response to retrieve the next page of results.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • maxResults

      The maximum number of recommendation steps to return.

      Parameters:
      maxResults - The maximum number of recommendation steps to return.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      GetRecommendedPolicyV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder