Class GetRecommendedPolicyV2Response

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetRecommendedPolicyV2Response.Builder,GetRecommendedPolicyV2Response>

@Generated("software.amazon.awssdk:codegen") public final class GetRecommendedPolicyV2Response extends SecurityHubResponse implements ToCopyableBuilder<GetRecommendedPolicyV2Response.Builder,GetRecommendedPolicyV2Response>
  • Method Details

    • nextToken

      public final String nextToken()

      The pagination token to use to request the next page of results.

      Returns:
      The pagination token to use to request the next page of results.
    • recommendationType

      public final RecommendationType recommendationType()

      The type of recommendation for the finding.

      If the service returns an enum value that is not available in the current SDK version, recommendationType will return RecommendationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from recommendationTypeAsString().

      Returns:
      The type of recommendation for the finding.
      See Also:
    • recommendationTypeAsString

      public final String recommendationTypeAsString()

      The type of recommendation for the finding.

      If the service returns an enum value that is not available in the current SDK version, recommendationType will return RecommendationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from recommendationTypeAsString().

      Returns:
      The type of recommendation for the finding.
      See Also:
    • hasRecommendationSteps

      public final boolean hasRecommendationSteps()
      For responses, this returns true if the service returned a value for the RecommendationSteps property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • recommendationSteps

      public final List<RecommendationStep> recommendationSteps()

      The recommended steps to take to resolve the finding.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasRecommendationSteps() method.

      Returns:
      The recommended steps to take to resolve the finding.
    • error

      public final RecommendationError error()

      Detailed information for a FAILED retrieval status.

      Returns:
      Detailed information for a FAILED retrieval status.
    • status

      public final RecommendationStatus status()

      The current status of the recommended policy retrieval.

      If the service returns an enum value that is not available in the current SDK version, status will return RecommendationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the recommended policy retrieval.
      See Also:
    • statusAsString

      public final String statusAsString()

      The current status of the recommended policy retrieval.

      If the service returns an enum value that is not available in the current SDK version, status will return RecommendationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the recommended policy retrieval.
      See Also:
    • resourceArn

      public final String resourceArn()

      The ARN of the resource of the finding.

      Returns:
      The ARN of the resource of the finding.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetRecommendedPolicyV2Response.Builder,GetRecommendedPolicyV2Response>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static GetRecommendedPolicyV2Response.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetRecommendedPolicyV2Response.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo