Class GetResourcesStatisticsV2Request
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetResourcesStatisticsV2Request.Builder,GetResourcesStatisticsV2Request>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final List<ResourceGroupByRule>How resource statistics should be aggregated and organized in the response.final booleanFor responses, this returns true if the service returned a value for the GroupByRules property.final inthashCode()final IntegerThe maximum number of results to be returned.final ResourceScopesscopes()Limits the results to resources from specific organizational units or from the delegated administrator's organization.static Class<? extends GetResourcesStatisticsV2Request.Builder>final SortOrderSorts aggregated statistics.final StringSorts aggregated statistics.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasGroupByRules
public final boolean hasGroupByRules()For responses, this returns true if the service returned a value for the GroupByRules property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
groupByRules
How resource statistics should be aggregated and organized in the response.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasGroupByRules()method.- Returns:
- How resource statistics should be aggregated and organized in the response.
-
scopes
Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an
AccessDeniedException.This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own resources.
You can specify up to 10 entries in
Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.- Returns:
- Limits the results to resources from specific organizational units or from the delegated administrator's
organization. Only the delegated administrator account can use this parameter. Other accounts receive an
AccessDeniedException.This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own resources.
You can specify up to 10 entries in
Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
-
sortOrder
Sorts aggregated statistics.
If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- Sorts aggregated statistics.
- See Also:
-
sortOrderAsString
Sorts aggregated statistics.
If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- Sorts aggregated statistics.
- See Also:
-
maxStatisticResults
The maximum number of results to be returned.
- Returns:
- The maximum number of results to be returned.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetResourcesStatisticsV2Request.Builder,GetResourcesStatisticsV2Request> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-