Class GetResourcesTrendsV2Request

    • Method Detail

      • filters

        public final ResourcesTrendsFilters filters()

        The filters to apply to the resources trend data.

        Returns:
        The filters to apply to the resources trend data.
      • startTime

        public final Instant startTime()

        The starting timestamp for the time period to analyze resources trends, in ISO 8601 format.

        Returns:
        The starting timestamp for the time period to analyze resources trends, in ISO 8601 format.
      • endTime

        public final Instant endTime()

        The ending timestamp for the time period to analyze resources trends, in ISO 8601 format.

        Returns:
        The ending timestamp for the time period to analyze resources trends, in ISO 8601 format.
      • nextToken

        public final String nextToken()

        The token to use for paginating results. This value is returned in the response if more results are available.

        Returns:
        The token to use for paginating results. This value is returned in the response if more results are available.
      • maxResults

        public final Integer maxResults()

        The maximum number of trend data points to return in a single response.

        Returns:
        The maximum number of trend data points to return in a single response.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object