Class GetResourcesV2Request

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request>

@Generated("software.amazon.awssdk:codegen") public final class GetResourcesV2Request extends SecurityHubRequest implements ToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request>
  • Method Details

    • filters

      public final ResourcesFilters filters()

      Filters resources based on a set of criteria.

      Returns:
      Filters resources based on a set of criteria.
    • scopes

      public final ResourceScopes scopes()

      Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

      This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.

      You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

      Returns:
      Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

      This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.

      You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

    • hasSortCriteria

      public final boolean hasSortCriteria()
      For responses, this returns true if the service returned a value for the SortCriteria property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • sortCriteria

      public final List<SortCriterion> sortCriteria()

      The resource attributes used to sort the list of returned resources.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasSortCriteria() method.

      Returns:
      The resource attributes used to sort the list of returned resources.
    • nextToken

      public final String nextToken()

      The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

      Returns:
      The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
    • maxResults

      public final Integer maxResults()

      The maximum number of results to return.

      Returns:
      The maximum number of results to return.
    • toBuilder

      public GetResourcesV2Request.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

      public static GetResourcesV2Request.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetResourcesV2Request.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo