Class GetResourcesV2Response
- java.lang.Object
-
- software.amazon.awssdk.core.SdkResponse
-
- software.amazon.awssdk.awscore.AwsResponse
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
-
- software.amazon.awssdk.services.securityhub.model.GetResourcesV2Response
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetResourcesV2Response.Builder,GetResourcesV2Response>
@Generated("software.amazon.awssdk:codegen") public final class GetResourcesV2Response extends SecurityHubResponse implements ToCopyableBuilder<GetResourcesV2Response.Builder,GetResourcesV2Response>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGetResourcesV2Response.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static GetResourcesV2Response.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()booleanhasResources()For responses, this returns true if the service returned a value for the Resources property.StringnextToken()The pagination token to use to request the next page of results.List<ResourceResult>resources()Filters resources based on a set of criteria.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GetResourcesV2Response.Builder>serializableBuilderClass()GetResourcesV2Response.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadata
-
Methods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponse
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
hasResources
public final boolean hasResources()
For responses, this returns true if the service returned a value for the Resources property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
resources
public final List<ResourceResult> resources()
Filters resources based on a set of criteria.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasResources()method.- Returns:
- Filters resources based on a set of criteria.
-
nextToken
public final String nextToken()
The pagination token to use to request the next page of results. Otherwise, this parameter is null.
- Returns:
- The pagination token to use to request the next page of results. Otherwise, this parameter is null.
-
toBuilder
public GetResourcesV2Response.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetResourcesV2Response.Builder,GetResourcesV2Response>- Specified by:
toBuilderin classAwsResponse
-
builder
public static GetResourcesV2Response.Builder builder()
-
serializableBuilderClass
public static Class<? extends GetResourcesV2Response.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsResponse
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-