Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
Use this in place of valueOf to convert the raw string returned by the service into the enum value.
Use this in place of
values() to return a
Set of all values known to the SDK.
Returns the enum constant of this type with the specified name.
Returns an array containing the constants of this enum type, in
the order they are declared.
Enum Constant Details
COMPLIANCE_ASSESSMENTS_NAME
public static final GroupByField COMPLIANCE_ASSESSMENTS_NAME
VULNERABILITIES_FIX_COVERAGE
public static final GroupByField VULNERABILITIES_FIX_COVERAGE
VULNERABILITIES_AFFECTED_PACKAGES_NAME
public static final GroupByField VULNERABILITIES_AFFECTED_PACKAGES_NAME
FINDING_INFO_ANALYTIC_NAME
VENDOR_ATTRIBUTES_SEVERITY
Method Details
values
Returns an array containing the constants of this enum type, in
the order they are declared.
Returns:
an array containing the constants of this enum type, in the order they are declared
valueOf
Returns the enum constant of this type with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this type. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum type has no constant with the specified name
NullPointerException - if the argument is null
fromValue
Use this in place of valueOf to convert the raw string returned by the service into the enum value.
Parameters:
value - real value
Returns:
GroupByField corresponding to the value