Class GroupByResult
java.lang.Object
software.amazon.awssdk.services.securityhub.model.GroupByResult
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<GroupByResult.Builder,GroupByResult>
@Generated("software.amazon.awssdk:codegen")
public final class GroupByResult
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<GroupByResult.Builder,GroupByResult>
Represents finding statistics grouped by GroupedByField.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic GroupByResult.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe attribute by which filtered security findings should be grouped.final List<GroupByValue>An array of grouped values and their respective counts for eachGroupByField.final booleanFor responses, this returns true if the service returned a value for the GroupByValues property.final inthashCode()static Class<? extends GroupByResult.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
groupByField
The attribute by which filtered security findings should be grouped.
- Returns:
- The attribute by which filtered security findings should be grouped.
-
hasGroupByValues
public final boolean hasGroupByValues()For responses, this returns true if the service returned a value for the GroupByValues property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
groupByValues
An array of grouped values and their respective counts for each
GroupByField.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasGroupByValues()method.- Returns:
- An array of grouped values and their respective counts for each
GroupByField.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GroupByResult.Builder,GroupByResult>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-