Class GroupByRule
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<GroupByRule.Builder,GroupByRule>
Defines the how the finding attribute should be grouped.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic GroupByRule.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final OcsfFindingFiltersfilters()The criteria used to select which security findings should be included in the grouping operation.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final GroupByFieldThe attribute by which filtered findings should be grouped.final StringThe attribute by which filtered findings should be grouped.final inthashCode()static Class<? extends GroupByRule.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
filters
The criteria used to select which security findings should be included in the grouping operation.
- Returns:
- The criteria used to select which security findings should be included in the grouping operation.
-
groupByField
The attribute by which filtered findings should be grouped.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- The attribute by which filtered findings should be grouped.
- See Also:
-
groupByFieldAsString
The attribute by which filtered findings should be grouped.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- The attribute by which filtered findings should be grouped.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GroupByRule.Builder,GroupByRule>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-