Interface GroupByRule.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<GroupByRule.Builder,GroupByRule>,SdkBuilder<GroupByRule.Builder,GroupByRule>,SdkPojo
- Enclosing class:
- GroupByRule
@Mutable @NotThreadSafe public static interface GroupByRule.Builder extends SdkPojo, CopyableBuilder<GroupByRule.Builder,GroupByRule>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default GroupByRule.Builderfilters(Consumer<OcsfFindingFilters.Builder> filters)The criteria used to select which security findings should be included in the grouping operation.GroupByRule.Builderfilters(OcsfFindingFilters filters)The criteria used to select which security findings should be included in the grouping operation.GroupByRule.BuildergroupByField(String groupByField)The attribute by which filtered findings should be grouped.GroupByRule.BuildergroupByField(GroupByField groupByField)The attribute by which filtered findings should be grouped.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
filters
GroupByRule.Builder filters(OcsfFindingFilters filters)
The criteria used to select which security findings should be included in the grouping operation.
- Parameters:
filters- The criteria used to select which security findings should be included in the grouping operation.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
filters
default GroupByRule.Builder filters(Consumer<OcsfFindingFilters.Builder> filters)
The criteria used to select which security findings should be included in the grouping operation.
This is a convenience method that creates an instance of theOcsfFindingFilters.Builderavoiding the need to create one manually viaOcsfFindingFilters.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tofilters(OcsfFindingFilters).- Parameters:
filters- a consumer that will call methods onOcsfFindingFilters.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
filters(OcsfFindingFilters)
-
groupByField
GroupByRule.Builder groupByField(String groupByField)
The attribute by which filtered findings should be grouped.
- Parameters:
groupByField- The attribute by which filtered findings should be grouped.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
GroupByField,GroupByField
-
groupByField
GroupByRule.Builder groupByField(GroupByField groupByField)
The attribute by which filtered findings should be grouped.
- Parameters:
groupByField- The attribute by which filtered findings should be grouped.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
GroupByField,GroupByField
-
-