Class GroupByValue
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.GroupByValue
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<GroupByValue.Builder,GroupByValue>
@Generated("software.amazon.awssdk:codegen") public final class GroupByValue extends Object implements SdkPojo, Serializable, ToCopyableBuilder<GroupByValue.Builder,GroupByValue>
Represents individual aggregated results when grouping security findings for each
GroupByField.- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGroupByValue.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static GroupByValue.Builderbuilder()Integercount()The number of findings for a specificFieldValueandGroupByField.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)StringfieldValue()The value of the field by which findings are grouped.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GroupByValue.Builder>serializableBuilderClass()GroupByValue.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
fieldValue
public final String fieldValue()
The value of the field by which findings are grouped.
- Returns:
- The value of the field by which findings are grouped.
-
count
public final Integer count()
The number of findings for a specific
FieldValueandGroupByField.- Returns:
- The number of findings for a specific
FieldValueandGroupByField.
-
toBuilder
public GroupByValue.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GroupByValue.Builder,GroupByValue>
-
builder
public static GroupByValue.Builder builder()
-
serializableBuilderClass
public static Class<? extends GroupByValue.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-