Interface GroupByValue.Builder

    • Method Detail

      • fieldValue

        GroupByValue.Builder fieldValue​(String fieldValue)

        The value of the field by which findings are grouped.

        Parameters:
        fieldValue - The value of the field by which findings are grouped.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • count

        GroupByValue.Builder count​(Integer count)

        The number of findings for a specific FieldValue and GroupByField.

        Parameters:
        count - The number of findings for a specific FieldValue and GroupByField.
        Returns:
        Returns a reference to this object so that method calls can be chained together.