Class HealthCheck
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<HealthCheck.Builder,HealthCheck>
Information about the operational status and health of a connectorV2.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic HealthCheck.Builderbuilder()final ConnectorStatusThe status of the connectorV2.final StringThe status of the connectorV2.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InstantISO 8601 UTC timestamp for the time check the health status of the connectorV2.final Stringmessage()The message for the reason of connectorStatus change.static Class<? extends HealthCheck.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorStatus
The status of the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status of the connectorV2.
- See Also:
-
connectorStatusAsString
The status of the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status of the connectorV2.
- See Also:
-
message
The message for the reason of connectorStatus change.
- Returns:
- The message for the reason of connectorStatus change.
-
lastCheckedAt
ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
- Returns:
- ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<HealthCheck.Builder,HealthCheck>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-