Interface HealthCheck.Builder

All Superinterfaces:
Buildable, CopyableBuilder<HealthCheck.Builder,HealthCheck>, SdkBuilder<HealthCheck.Builder,HealthCheck>, SdkPojo
Enclosing class:
HealthCheck

@Mutable @NotThreadSafe public static interface HealthCheck.Builder extends SdkPojo, CopyableBuilder<HealthCheck.Builder,HealthCheck>
  • Method Details

    • connectorStatus

      HealthCheck.Builder connectorStatus(String connectorStatus)

      The status of the connectorV2.

      Parameters:
      connectorStatus - The status of the connectorV2.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • connectorStatus

      HealthCheck.Builder connectorStatus(ConnectorStatus connectorStatus)

      The status of the connectorV2.

      Parameters:
      connectorStatus - The status of the connectorV2.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • message

      HealthCheck.Builder message(String message)

      The message for the reason of connectorStatus change.

      Parameters:
      message - The message for the reason of connectorStatus change.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • lastCheckedAt

      HealthCheck.Builder lastCheckedAt(Instant lastCheckedAt)

      ISO 8601 UTC timestamp for the time check the health status of the connectorV2.

      Parameters:
      lastCheckedAt - ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
      Returns:
      Returns a reference to this object so that method calls can be chained together.