Class HealthIssue
java.lang.Object
software.amazon.awssdk.services.securityhub.model.HealthIssue
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<HealthIssue.Builder,HealthIssue>
@Generated("software.amazon.awssdk:codegen")
public final class HealthIssue
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<HealthIssue.Builder,HealthIssue>
Represents a specific health issue detected for a connector.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic HealthIssue.Builderbuilder()final HealthIssueCodecode()The error code that identifies the type of health issue.final StringThe error code that identifies the type of health issue.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringmessage()A human-readable message that describes the health issue.static Class<? extends HealthIssue.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
code
The error code that identifies the type of health issue.
If the service returns an enum value that is not available in the current SDK version,
codewill returnHealthIssueCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcodeAsString().- Returns:
- The error code that identifies the type of health issue.
- See Also:
-
codeAsString
The error code that identifies the type of health issue.
If the service returns an enum value that is not available in the current SDK version,
codewill returnHealthIssueCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcodeAsString().- Returns:
- The error code that identifies the type of health issue.
- See Also:
-
message
A human-readable message that describes the health issue.
- Returns:
- A human-readable message that describes the health issue.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<HealthIssue.Builder,HealthIssue>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-