Class ImportFindingsError
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ImportFindingsError
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ImportFindingsError.Builder,ImportFindingsError>
@Generated("software.amazon.awssdk:codegen")
public final class ImportFindingsError
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ImportFindingsError.Builder,ImportFindingsError>
The list of the findings that cannot be imported. For each finding, the list provides the error.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ImportFindingsError.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe code of the error returned by theBatchImportFindingsoperation.final StringThe message of the error returned by theBatchImportFindingsoperation.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The identifier of the finding that could not be updated.static Class<? extends ImportFindingsError.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The identifier of the finding that could not be updated.
- Returns:
- The identifier of the finding that could not be updated.
-
errorCode
The code of the error returned by the
BatchImportFindingsoperation.- Returns:
- The code of the error returned by the
BatchImportFindingsoperation.
-
errorMessage
The message of the error returned by the
BatchImportFindingsoperation.- Returns:
- The message of the error returned by the
BatchImportFindingsoperation.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ImportFindingsError.Builder,ImportFindingsError>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-