java.lang.Object
software.amazon.awssdk.services.securityhub.model.Insight
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<Insight.Builder,Insight>

@Generated("software.amazon.awssdk:codegen") public final class Insight extends Object implements SdkPojo, Serializable, ToCopyableBuilder<Insight.Builder,Insight>

Contains information about a Security Hub CSPM insight.

See Also:
  • Method Details

    • insightArn

      public final String insightArn()

      The ARN of a Security Hub CSPM insight.

      Returns:
      The ARN of a Security Hub CSPM insight.
    • name

      public final String name()

      The name of a Security Hub CSPM insight.

      Returns:
      The name of a Security Hub CSPM insight.
    • filters

      public final AwsSecurityFindingFilters filters()

      One or more attributes used to filter the findings included in the insight. You can filter by up to ten finding attributes. For each attribute, you can provide up to 20 filter values. The insight only includes findings that match the criteria defined in the filters.

      Returns:
      One or more attributes used to filter the findings included in the insight. You can filter by up to ten finding attributes. For each attribute, you can provide up to 20 filter values. The insight only includes findings that match the criteria defined in the filters.
    • groupByAttribute

      public final String groupByAttribute()

      The grouping attribute for the insight's findings. Indicates how to group the matching findings, and identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.

      Returns:
      The grouping attribute for the insight's findings. Indicates how to group the matching findings, and identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.
    • toBuilder

      public Insight.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<Insight.Builder,Insight>
    • builder

      public static Insight.Builder builder()
    • serializableBuilderClass

      public static Class<? extends Insight.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo