Class InsightResultValue
java.lang.Object
software.amazon.awssdk.services.securityhub.model.InsightResultValue
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<InsightResultValue.Builder,InsightResultValue>
@Generated("software.amazon.awssdk:codegen")
public final class InsightResultValue
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<InsightResultValue.Builder,InsightResultValue>
The insight result values returned by the GetInsightResults operation.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic InsightResultValue.Builderbuilder()final Integercount()The number of findings returned for eachGroupByAttributeValue.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe value of the attribute that the findings are grouped by for the insight whose results are returned by theGetInsightResultsoperation.final inthashCode()static Class<? extends InsightResultValue.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
groupByAttributeValue
The value of the attribute that the findings are grouped by for the insight whose results are returned by the
GetInsightResultsoperation.- Returns:
- The value of the attribute that the findings are grouped by for the insight whose results are returned by
the
GetInsightResultsoperation.
-
count
The number of findings returned for each
GroupByAttributeValue.- Returns:
- The number of findings returned for each
GroupByAttributeValue.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<InsightResultValue.Builder,InsightResultValue>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-