Class InsightResults
java.lang.Object
software.amazon.awssdk.services.securityhub.model.InsightResults
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<InsightResults.Builder,InsightResults>
@Generated("software.amazon.awssdk:codegen")
public final class InsightResults
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<InsightResults.Builder,InsightResults>
The insight results returned by the GetInsightResults operation.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic InsightResults.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe attribute that the findings are grouped by for the insight whose results are returned by theGetInsightResultsoperation.final inthashCode()final booleanFor responses, this returns true if the service returned a value for the ResultValues property.final StringThe ARN of the insight whose results are returned by theGetInsightResultsoperation.final List<InsightResultValue>The list of insight result values returned by theGetInsightResultsoperation.static Class<? extends InsightResults.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
insightArn
The ARN of the insight whose results are returned by the
GetInsightResultsoperation.- Returns:
- The ARN of the insight whose results are returned by the
GetInsightResultsoperation.
-
groupByAttribute
The attribute that the findings are grouped by for the insight whose results are returned by the
GetInsightResultsoperation.- Returns:
- The attribute that the findings are grouped by for the insight whose results are returned by the
GetInsightResultsoperation.
-
hasResultValues
public final boolean hasResultValues()For responses, this returns true if the service returned a value for the ResultValues property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
resultValues
The list of insight result values returned by the
GetInsightResultsoperation.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasResultValues()method.- Returns:
- The list of insight result values returned by the
GetInsightResultsoperation.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<InsightResults.Builder,InsightResults>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-