Class IntegerConfigurationOptions
java.lang.Object
software.amazon.awssdk.services.securityhub.model.IntegerConfigurationOptions
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<IntegerConfigurationOptions.Builder,IntegerConfigurationOptions>
@Generated("software.amazon.awssdk:codegen")
public final class IntegerConfigurationOptions
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<IntegerConfigurationOptions.Builder,IntegerConfigurationOptions>
The options for customizing a security control parameter that is an integer.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final IntegerThe Security Hub CSPM default value for a control parameter that is an integer.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Integermax()The maximum valid value for a control parameter that is an integer.final Integermin()The minimum valid value for a control parameter that is an integer.static Class<? extends IntegerConfigurationOptions.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
defaultValue
The Security Hub CSPM default value for a control parameter that is an integer.
- Returns:
- The Security Hub CSPM default value for a control parameter that is an integer.
-
min
The minimum valid value for a control parameter that is an integer.
- Returns:
- The minimum valid value for a control parameter that is an integer.
-
max
The maximum valid value for a control parameter that is an integer.
- Returns:
- The maximum valid value for a control parameter that is an integer.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<IntegerConfigurationOptions.Builder,IntegerConfigurationOptions>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-