Class Invitation
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Invitation
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Invitation.Builder,Invitation>
@Generated("software.amazon.awssdk:codegen")
public final class Invitation
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Invitation.Builder,Invitation>
Details about an invitation.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe account ID of the Security Hub CSPM administrator account that the invitation was sent from.static Invitation.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ID of the invitation sent to the member account.final InstantThe timestamp of when the invitation was sent.final StringThe current status of the association between the member and administrator accounts.static Class<? extends Invitation.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
accountId
The account ID of the Security Hub CSPM administrator account that the invitation was sent from.
- Returns:
- The account ID of the Security Hub CSPM administrator account that the invitation was sent from.
-
invitationId
The ID of the invitation sent to the member account.
- Returns:
- The ID of the invitation sent to the member account.
-
invitedAt
The timestamp of when the invitation was sent.
- Returns:
- The timestamp of when the invitation was sent.
-
memberStatus
The current status of the association between the member and administrator accounts.
- Returns:
- The current status of the association between the member and administrator accounts.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Invitation.Builder,Invitation>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-