Interface LimitExceededException.Builder
- All Superinterfaces:
AwsServiceException.Builder,Buildable,CopyableBuilder<LimitExceededException.Builder,,LimitExceededException> SdkBuilder<LimitExceededException.Builder,,LimitExceededException> SdkException.Builder,SdkPojo,SdkServiceException.Builder,SecurityHubException.Builder
- Enclosing class:
- LimitExceededException
@Mutable
@NotThreadSafe
public static interface LimitExceededException.Builder
extends SdkPojo, CopyableBuilder<LimitExceededException.Builder,LimitExceededException>, SecurityHubException.Builder
-
Method Summary
Modifier and TypeMethodDescriptionawsErrorDetails(AwsErrorDetails awsErrorDetails) Sets the value of the Code property for this object.numAttempts(Integer numAttempts) statusCode(int statusCode) writableStackTrace(Boolean writableStackTrace) Methods inherited from interface software.amazon.awssdk.awscore.exception.AwsServiceException.Builder
awsErrorDetails, build, clockSkew, clockSkew, extendedRequestIdMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.exception.SdkException.Builder
cause, message, numAttempts, writableStackTraceMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.core.exception.SdkServiceException.Builder
extendedRequestId, requestId, statusCode
-
Method Details
-
code
Sets the value of the Code property for this object.- Parameters:
code- The new value for the Code property for this object.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
awsErrorDetails
- Specified by:
awsErrorDetailsin interfaceAwsServiceException.Builder- Specified by:
awsErrorDetailsin interfaceSecurityHubException.Builder
-
message
- Specified by:
messagein interfaceAwsServiceException.Builder- Specified by:
messagein interfaceSdkException.Builder- Specified by:
messagein interfaceSdkServiceException.Builder- Specified by:
messagein interfaceSecurityHubException.Builder
-
requestId
- Specified by:
requestIdin interfaceAwsServiceException.Builder- Specified by:
requestIdin interfaceSdkServiceException.Builder- Specified by:
requestIdin interfaceSecurityHubException.Builder
-
statusCode
- Specified by:
statusCodein interfaceAwsServiceException.Builder- Specified by:
statusCodein interfaceSdkServiceException.Builder- Specified by:
statusCodein interfaceSecurityHubException.Builder
-
cause
- Specified by:
causein interfaceAwsServiceException.Builder- Specified by:
causein interfaceSdkException.Builder- Specified by:
causein interfaceSdkServiceException.Builder- Specified by:
causein interfaceSecurityHubException.Builder
-
writableStackTrace
- Specified by:
writableStackTracein interfaceSdkException.Builder- Specified by:
writableStackTracein interfaceSdkServiceException.Builder- Specified by:
writableStackTracein interfaceSecurityHubException.Builder
-
numAttempts
- Specified by:
numAttemptsin interfaceAwsServiceException.Builder- Specified by:
numAttemptsin interfaceSdkException.Builder- Specified by:
numAttemptsin interfaceSdkServiceException.Builder- Specified by:
numAttemptsin interfaceSecurityHubException.Builder
-