Class ListConfigurationPolicyAssociationsResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListConfigurationPolicyAssociationsResponse.Builder,ListConfigurationPolicyAssociationsResponse>

@Generated("software.amazon.awssdk:codegen") public final class ListConfigurationPolicyAssociationsResponse extends SecurityHubResponse implements ToCopyableBuilder<ListConfigurationPolicyAssociationsResponse.Builder,ListConfigurationPolicyAssociationsResponse>
  • Method Details

    • hasConfigurationPolicyAssociationSummaries

      public final boolean hasConfigurationPolicyAssociationSummaries()
      For responses, this returns true if the service returned a value for the ConfigurationPolicyAssociationSummaries property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • configurationPolicyAssociationSummaries

      public final List<ConfigurationPolicyAssociationSummary> configurationPolicyAssociationSummaries()

      An object that contains the details of each configuration policy association that’s returned in a ListConfigurationPolicyAssociations request.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasConfigurationPolicyAssociationSummaries() method.

      Returns:
      An object that contains the details of each configuration policy association that’s returned in a ListConfigurationPolicyAssociations request.
    • nextToken

      public final String nextToken()

      The NextToken value to include in the next ListConfigurationPolicyAssociations request. When the results of a ListConfigurationPolicyAssociations request exceed MaxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.

      Returns:
      The NextToken value to include in the next ListConfigurationPolicyAssociations request. When the results of a ListConfigurationPolicyAssociations request exceed MaxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListConfigurationPolicyAssociationsResponse.Builder,ListConfigurationPolicyAssociationsResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

    • serializableBuilderClass

      public static Class<? extends ListConfigurationPolicyAssociationsResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo