Class ListConnectorsV2Request
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.ListConnectorsV2Request
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListConnectorsV2Request.Builder,ListConnectorsV2Request>
@Generated("software.amazon.awssdk:codegen") public final class ListConnectorsV2Request extends SecurityHubRequest implements ToCopyableBuilder<ListConnectorsV2Request.Builder,ListConnectorsV2Request>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceListConnectorsV2Request.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ListConnectorsV2Request.Builderbuilder()ConnectorStatusconnectorStatus()The status for the connectorV2.StringconnectorStatusAsString()The status for the connectorV2.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()IntegermaxResults()The maximum number of results to be returned.StringnextToken()The pagination token per the Amazon Web Services Pagination standardConnectorProviderNameproviderName()The name of the third-party provider.StringproviderNameAsString()The name of the third-party provider.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ListConnectorsV2Request.Builder>serializableBuilderClass()ListConnectorsV2Request.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
nextToken
public final String nextToken()
The pagination token per the Amazon Web Services Pagination standard
- Returns:
- The pagination token per the Amazon Web Services Pagination standard
-
maxResults
public final Integer maxResults()
The maximum number of results to be returned.
- Returns:
- The maximum number of results to be returned.
-
providerName
public final ConnectorProviderName providerName()
The name of the third-party provider.
If the service returns an enum value that is not available in the current SDK version,
providerNamewill returnConnectorProviderName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromproviderNameAsString().- Returns:
- The name of the third-party provider.
- See Also:
ConnectorProviderName
-
providerNameAsString
public final String providerNameAsString()
The name of the third-party provider.
If the service returns an enum value that is not available in the current SDK version,
providerNamewill returnConnectorProviderName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromproviderNameAsString().- Returns:
- The name of the third-party provider.
- See Also:
ConnectorProviderName
-
connectorStatus
public final ConnectorStatus connectorStatus()
The status for the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status for the connectorV2.
- See Also:
ConnectorStatus
-
connectorStatusAsString
public final String connectorStatusAsString()
The status for the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status for the connectorV2.
- See Also:
ConnectorStatus
-
toBuilder
public ListConnectorsV2Request.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListConnectorsV2Request.Builder,ListConnectorsV2Request>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static ListConnectorsV2Request.Builder builder()
-
serializableBuilderClass
public static Class<? extends ListConnectorsV2Request.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-