Interface ListFindingAggregatorsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<ListFindingAggregatorsRequest.Builder,,ListFindingAggregatorsRequest> SdkBuilder<ListFindingAggregatorsRequest.Builder,,ListFindingAggregatorsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- ListFindingAggregatorsRequest
@Mutable
@NotThreadSafe
public static interface ListFindingAggregatorsRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<ListFindingAggregatorsRequest.Builder,ListFindingAggregatorsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionmaxResults(Integer maxResults) The maximum number of results to return.The token returned with the previous set of results.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
nextToken
The token returned with the previous set of results. Identifies the next set of results to return.
- Parameters:
nextToken- The token returned with the previous set of results. Identifies the next set of results to return.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
maxResults
The maximum number of results to return. This operation currently only returns a single result.
- Parameters:
maxResults- The maximum number of results to return. This operation currently only returns a single result.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
ListFindingAggregatorsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
ListFindingAggregatorsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-