Class ListInvitationsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListInvitationsRequest.Builder,ListInvitationsRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListInvitationsRequest extends SecurityHubRequest implements ToCopyableBuilder<ListInvitationsRequest.Builder,ListInvitationsRequest>
  • Method Details

    • maxResults

      public final Integer maxResults()

      The maximum number of items to return in the response.

      Returns:
      The maximum number of items to return in the response.
    • nextToken

      public final String nextToken()

      The token that is required for pagination. On your first call to the ListInvitations operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Returns:
      The token that is required for pagination. On your first call to the ListInvitations operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

    • toBuilder

      public ListInvitationsRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<ListInvitationsRequest.Builder,ListInvitationsRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

      public static ListInvitationsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListInvitationsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo