Class ListMembersRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListMembersRequest.Builder,ListMembersRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListMembersRequest extends SecurityHubRequest implements ToCopyableBuilder<ListMembersRequest.Builder,ListMembersRequest>
  • Method Details

    • onlyAssociated

      public final Boolean onlyAssociated()

      Specifies which member accounts to include in the response based on their relationship status with the administrator account. The default value is TRUE.

      If OnlyAssociated is set to TRUE, the response includes member accounts whose relationship status with the administrator account is set to ENABLED.

      If OnlyAssociated is set to FALSE, the response includes all existing member accounts.

      Returns:
      Specifies which member accounts to include in the response based on their relationship status with the administrator account. The default value is TRUE.

      If OnlyAssociated is set to TRUE, the response includes member accounts whose relationship status with the administrator account is set to ENABLED.

      If OnlyAssociated is set to FALSE, the response includes all existing member accounts.

    • maxResults

      public final Integer maxResults()

      The maximum number of items to return in the response.

      Returns:
      The maximum number of items to return in the response.
    • nextToken

      public final String nextToken()

      The token that is required for pagination. On your first call to the ListMembers operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

      Returns:
      The token that is required for pagination. On your first call to the ListMembers operation, set the value of this parameter to NULL.

      For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

    • toBuilder

      public ListMembersRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<ListMembersRequest.Builder,ListMembersRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

      public static ListMembersRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListMembersRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo