Class ListOrganizationAdminAccountsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListOrganizationAdminAccountsRequest.Builder,ListOrganizationAdminAccountsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final SecurityHubFeaturefeature()The feature where the delegated administrator account is listed.final StringThe feature where the delegated administrator account is listed.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of items to return in the response.final StringThe token that is required for pagination.static Class<? extends ListOrganizationAdminAccountsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
maxResults
The maximum number of items to return in the response.
- Returns:
- The maximum number of items to return in the response.
-
nextToken
The token that is required for pagination. On your first call to the
ListOrganizationAdminAccountsoperation, set the value of this parameter toNULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.- Returns:
- The token that is required for pagination. On your first call to the
ListOrganizationAdminAccountsoperation, set the value of this parameter toNULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
-
feature
The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM if not specified.
- See Also:
-
featureAsString
The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM if not specified.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListOrganizationAdminAccountsRequest.Builder,ListOrganizationAdminAccountsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends ListOrganizationAdminAccountsRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-