Class ListOrganizationAdminAccountsResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListOrganizationAdminAccountsResponse.Builder,ListOrganizationAdminAccountsResponse>

@Generated("software.amazon.awssdk:codegen") public final class ListOrganizationAdminAccountsResponse extends SecurityHubResponse implements ToCopyableBuilder<ListOrganizationAdminAccountsResponse.Builder,ListOrganizationAdminAccountsResponse>
  • Method Details

    • hasAdminAccounts

      public final boolean hasAdminAccounts()
      For responses, this returns true if the service returned a value for the AdminAccounts property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • adminAccounts

      public final List<AdminAccount> adminAccounts()

      The list of Security Hub CSPM administrator accounts.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasAdminAccounts() method.

      Returns:
      The list of Security Hub CSPM administrator accounts.
    • nextToken

      public final String nextToken()

      The pagination token to use to request the next page of results.

      Returns:
      The pagination token to use to request the next page of results.
    • feature

      public final SecurityHubFeature feature()

      The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.

      If the service returns an enum value that is not available in the current SDK version, feature will return SecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from featureAsString().

      Returns:
      The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.
      See Also:
    • featureAsString

      public final String featureAsString()

      The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.

      If the service returns an enum value that is not available in the current SDK version, feature will return SecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from featureAsString().

      Returns:
      The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.
      See Also:
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListOrganizationAdminAccountsResponse.Builder,ListOrganizationAdminAccountsResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

    • serializableBuilderClass

      public static Class<? extends ListOrganizationAdminAccountsResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo