Class ListSecurityControlDefinitionsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListSecurityControlDefinitionsRequest extends SecurityHubRequest implements ToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>
  • Method Details

    • standardsArn

      public final String standardsArn()

      The Amazon Resource Name (ARN) of the standard that you want to view controls for.

      Returns:
      The Amazon Resource Name (ARN) of the standard that you want to view controls for.
    • nextToken

      public final String nextToken()

      Optional pagination parameter.

      Returns:
      Optional pagination parameter.
    • maxResults

      public final Integer maxResults()

      An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.

      Returns:
      An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.
    • providers

      public final List<SecurityControlsProvider> providers()

      A list of cloud providers to filter the security control definitions by. For example, specify Azure to return only controls that evaluate Azure resources.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasProviders() method.

      Returns:
      A list of cloud providers to filter the security control definitions by. For example, specify Azure to return only controls that evaluate Azure resources.
    • hasProviders

      public final boolean hasProviders()
      For responses, this returns true if the service returned a value for the Providers property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • providersAsStrings

      public final List<String> providersAsStrings()

      A list of cloud providers to filter the security control definitions by. For example, specify Azure to return only controls that evaluate Azure resources.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasProviders() method.

      Returns:
      A list of cloud providers to filter the security control definitions by. For example, specify Azure to return only controls that evaluate Azure resources.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends ListSecurityControlDefinitionsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo