Interface ListSecurityControlDefinitionsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,,ListSecurityControlDefinitionsRequest> SdkBuilder<ListSecurityControlDefinitionsRequest.Builder,,ListSecurityControlDefinitionsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- ListSecurityControlDefinitionsRequest
@Mutable
@NotThreadSafe
public static interface ListSecurityControlDefinitionsRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionmaxResults(Integer maxResults) An optional parameter that limits the total results of the API response to the specified number.Optional pagination parameter.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) standardsArn(String standardsArn) The Amazon Resource Name (ARN) of the standard that you want to view controls for.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
standardsArn
The Amazon Resource Name (ARN) of the standard that you want to view controls for.
- Parameters:
standardsArn- The Amazon Resource Name (ARN) of the standard that you want to view controls for.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
nextToken
Optional pagination parameter.
- Parameters:
nextToken- Optional pagination parameter.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
maxResults
An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a
NextTokenparameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.- Parameters:
maxResults- An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include aNextTokenparameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
ListSecurityControlDefinitionsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
ListSecurityControlDefinitionsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-