Class ListSecurityControlDefinitionsResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.ListSecurityControlDefinitionsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListSecurityControlDefinitionsResponse.Builder,ListSecurityControlDefinitionsResponse>
@Generated("software.amazon.awssdk:codegen")
public final class ListSecurityControlDefinitionsResponse
extends SecurityHubResponse
implements ToCopyableBuilder<ListSecurityControlDefinitionsResponse.Builder,ListSecurityControlDefinitionsResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the SecurityControlDefinitions property.final StringA pagination parameter that's included in the response only if it was included in the request.final List<SecurityControlDefinition>An array of controls that apply to the specified standard.static Class<? extends ListSecurityControlDefinitionsResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasSecurityControlDefinitions
public final boolean hasSecurityControlDefinitions()For responses, this returns true if the service returned a value for the SecurityControlDefinitions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
securityControlDefinitions
An array of controls that apply to the specified standard.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSecurityControlDefinitions()method.- Returns:
- An array of controls that apply to the specified standard.
-
nextToken
A pagination parameter that's included in the response only if it was included in the request.
- Returns:
- A pagination parameter that's included in the response only if it was included in the request.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListSecurityControlDefinitionsResponse.Builder,ListSecurityControlDefinitionsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends ListSecurityControlDefinitionsResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-