Class ListStandardsControlAssociationsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListStandardsControlAssociationsRequest.Builder,ListStandardsControlAssociationsRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerAn optional parameter that limits the total results of the API response to the specified number.final StringOptional pagination parameter.final StringThe identifier of the control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.static Class<? extends ListStandardsControlAssociationsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
securityControlId
The identifier of the control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.- Returns:
- The identifier of the control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.
-
nextToken
Optional pagination parameter.
- Returns:
- Optional pagination parameter.
-
maxResults
An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 standard and control associations. The results also include a
NextTokenparameter that you can use in a subsequent API call to get the next 25 associations. This repeats until all associations for the specified control are returned. The number of results is limited by the number of supported Security Hub CSPM standards that you've enabled in the calling account.- Returns:
- An optional parameter that limits the total results of the API response to the specified number. If this
parameter isn't provided in the request, the results include the first 25 standard and control
associations. The results also include a
NextTokenparameter that you can use in a subsequent API call to get the next 25 associations. This repeats until all associations for the specified control are returned. The number of results is limited by the number of supported Security Hub CSPM standards that you've enabled in the calling account.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListStandardsControlAssociationsRequest.Builder,ListStandardsControlAssociationsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends ListStandardsControlAssociationsRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-