Interface ListStandardsControlAssociationsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<ListStandardsControlAssociationsRequest.Builder,,ListStandardsControlAssociationsRequest> SdkBuilder<ListStandardsControlAssociationsRequest.Builder,,ListStandardsControlAssociationsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- ListStandardsControlAssociationsRequest
-
Method Summary
Modifier and TypeMethodDescriptionmaxResults(Integer maxResults) An optional parameter that limits the total results of the API response to the specified number.Optional pagination parameter.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) securityControlId(String securityControlId) The identifier of the control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
securityControlId
The identifier of the control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.- Parameters:
securityControlId- The identifier of the control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
nextToken
Optional pagination parameter.
- Parameters:
nextToken- Optional pagination parameter.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
maxResults
An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 standard and control associations. The results also include a
NextTokenparameter that you can use in a subsequent API call to get the next 25 associations. This repeats until all associations for the specified control are returned. The number of results is limited by the number of supported Security Hub CSPM standards that you've enabled in the calling account.- Parameters:
maxResults- An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 standard and control associations. The results also include aNextTokenparameter that you can use in a subsequent API call to get the next 25 associations. This repeats until all associations for the specified control are returned. The number of results is limited by the number of supported Security Hub CSPM standards that you've enabled in the calling account.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
ListStandardsControlAssociationsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
ListStandardsControlAssociationsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-