Class ListStandardsControlAssociationsResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.ListStandardsControlAssociationsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListStandardsControlAssociationsResponse.Builder,ListStandardsControlAssociationsResponse>
@Generated("software.amazon.awssdk:codegen")
public final class ListStandardsControlAssociationsResponse
extends SecurityHubResponse
implements ToCopyableBuilder<ListStandardsControlAssociationsResponse.Builder,ListStandardsControlAssociationsResponse>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the StandardsControlAssociationSummaries property.final StringA pagination parameter that's included in the response only if it was included in the request.static Class<? extends ListStandardsControlAssociationsResponse.Builder>An array that provides the enablement status and other details for each security control that applies to each enabled standard.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasStandardsControlAssociationSummaries
public final boolean hasStandardsControlAssociationSummaries()For responses, this returns true if the service returned a value for the StandardsControlAssociationSummaries property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
standardsControlAssociationSummaries
An array that provides the enablement status and other details for each security control that applies to each enabled standard.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStandardsControlAssociationSummaries()method.- Returns:
- An array that provides the enablement status and other details for each security control that applies to each enabled standard.
-
nextToken
A pagination parameter that's included in the response only if it was included in the request.
- Returns:
- A pagination parameter that's included in the response only if it was included in the request.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListStandardsControlAssociationsResponse.Builder,ListStandardsControlAssociationsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends ListStandardsControlAssociationsResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-