Class LoadBalancerState
java.lang.Object
software.amazon.awssdk.services.securityhub.model.LoadBalancerState
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<LoadBalancerState.Builder,LoadBalancerState>
@Generated("software.amazon.awssdk:codegen")
public final class LoadBalancerState
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<LoadBalancerState.Builder,LoadBalancerState>
Information about the state of the load balancer.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic LoadBalancerState.Builderbuilder()final Stringcode()The state code.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringreason()A description of the state.static Class<? extends LoadBalancerState.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
code
The state code. The initial state of the load balancer is provisioning.
After the load balancer is fully set up and ready to route traffic, its state is active.
If the load balancer could not be set up, its state is failed.
- Returns:
- The state code. The initial state of the load balancer is provisioning.
After the load balancer is fully set up and ready to route traffic, its state is active.
If the load balancer could not be set up, its state is failed.
-
reason
A description of the state.
- Returns:
- A description of the state.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<LoadBalancerState.Builder,LoadBalancerState>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-