Class Malware
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Malware.Builder,Malware>
A list of malware related to a finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Malware.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the malware that was observed.final Stringpath()The file system path of the malware that was observed.static Class<? extends Malware.Builder>final MalwareStatestate()The state of the malware that was observed.final StringThe state of the malware that was observed.final StringtoString()Returns a string representation of this object.final MalwareTypetype()The type of the malware that was observed.final StringThe type of the malware that was observed.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the malware that was observed.
Length Constraints: Minimum of 1. Maximum of 64.
- Returns:
- The name of the malware that was observed.
Length Constraints: Minimum of 1. Maximum of 64.
-
type
The type of the malware that was observed.
If the service returns an enum value that is not available in the current SDK version,
typewill returnMalwareType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The type of the malware that was observed.
- See Also:
-
typeAsString
The type of the malware that was observed.
If the service returns an enum value that is not available in the current SDK version,
typewill returnMalwareType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The type of the malware that was observed.
- See Also:
-
path
The file system path of the malware that was observed.
Length Constraints: Minimum of 1. Maximum of 512.
- Returns:
- The file system path of the malware that was observed.
Length Constraints: Minimum of 1. Maximum of 512.
-
state
The state of the malware that was observed.
If the service returns an enum value that is not available in the current SDK version,
statewill returnMalwareState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstateAsString().- Returns:
- The state of the malware that was observed.
- See Also:
-
stateAsString
The state of the malware that was observed.
If the service returns an enum value that is not available in the current SDK version,
statewill returnMalwareState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstateAsString().- Returns:
- The state of the malware that was observed.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Malware.Builder,Malware>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-