Class Member
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Member.Builder,Member>
The details about a member account.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe Amazon Web Services account ID of the member account.final StringThe Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.static Member.Builderbuilder()final Stringemail()The email address of the member account.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InstantA timestamp for the date and time when the invitation was sent to the member account.final StringmasterId()Deprecated.This field is deprecated, use AdministratorId instead.final StringThe status of the relationship between the member account and its administrator account.static Class<? extends Member.Builder>final StringtoString()Returns a string representation of this object.final InstantThe timestamp for the date and time when the member account was updated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
accountId
The Amazon Web Services account ID of the member account.
- Returns:
- The Amazon Web Services account ID of the member account.
-
email
The email address of the member account.
- Returns:
- The email address of the member account.
-
masterId
Deprecated.This field is deprecated, use AdministratorId instead.This is replaced by
AdministratorID.The Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.
- Returns:
- This is replaced by
AdministratorID.The Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.
-
administratorId
The Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.
- Returns:
- The Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.
-
memberStatus
The status of the relationship between the member account and its administrator account.
The status can have one of the following values:
-
Created- Indicates that the administrator account added the member account, but has not yet invited the member account. -
Invited- Indicates that the administrator account invited the member account. The member account has not yet responded to the invitation. -
Enabled- Indicates that the member account is currently active. For manually invited member accounts, indicates that the member account accepted the invitation. -
Removed- Indicates that the administrator account disassociated the member account. -
Resigned- Indicates that the member account disassociated themselves from the administrator account. -
Deleted- Indicates that the administrator account deleted the member account. -
AccountSuspended- Indicates that an organization account was suspended from Amazon Web Services at the same time that the administrator account tried to enable the organization account as a member account.
- Returns:
- The status of the relationship between the member account and its administrator account.
The status can have one of the following values:
-
Created- Indicates that the administrator account added the member account, but has not yet invited the member account. -
Invited- Indicates that the administrator account invited the member account. The member account has not yet responded to the invitation. -
Enabled- Indicates that the member account is currently active. For manually invited member accounts, indicates that the member account accepted the invitation. -
Removed- Indicates that the administrator account disassociated the member account. -
Resigned- Indicates that the member account disassociated themselves from the administrator account. -
Deleted- Indicates that the administrator account deleted the member account. -
AccountSuspended- Indicates that an organization account was suspended from Amazon Web Services at the same time that the administrator account tried to enable the organization account as a member account.
-
-
-
invitedAt
A timestamp for the date and time when the invitation was sent to the member account.
- Returns:
- A timestamp for the date and time when the invitation was sent to the member account.
-
updatedAt
The timestamp for the date and time when the member account was updated.
- Returns:
- The timestamp for the date and time when the member account was updated.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Member.Builder,Member>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-