Class Network
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Network.Builder,Network>
The details of network-related information about a finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Network.Builderbuilder()final StringThe destination domain of network-related information about a finding.final StringThe destination IPv4 address of network-related information about a finding.final StringThe destination IPv6 address of network-related information about a finding.final IntegerThe destination port of network-related information about a finding.final NetworkDirectionThe direction of network traffic associated with a finding.final StringThe direction of network traffic associated with a finding.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final PortRangeThe range of open ports that is present on the network.final Stringprotocol()The protocol of network-related information about a finding.static Class<? extends Network.Builder>final StringThe source domain of network-related information about a finding.final StringThe source IPv4 address of network-related information about a finding.final StringThe source IPv6 address of network-related information about a finding.final StringThe source media access control (MAC) address of network-related information about a finding.final IntegerThe source port of network-related information about a finding.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
direction
The direction of network traffic associated with a finding.
If the service returns an enum value that is not available in the current SDK version,
directionwill returnNetworkDirection.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromdirectionAsString().- Returns:
- The direction of network traffic associated with a finding.
- See Also:
-
directionAsString
The direction of network traffic associated with a finding.
If the service returns an enum value that is not available in the current SDK version,
directionwill returnNetworkDirection.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromdirectionAsString().- Returns:
- The direction of network traffic associated with a finding.
- See Also:
-
protocol
The protocol of network-related information about a finding.
Length Constraints: Minimum of 1. Maximum of 16.
- Returns:
- The protocol of network-related information about a finding.
Length Constraints: Minimum of 1. Maximum of 16.
-
openPortRange
The range of open ports that is present on the network.
- Returns:
- The range of open ports that is present on the network.
-
sourceIpV4
The source IPv4 address of network-related information about a finding.
- Returns:
- The source IPv4 address of network-related information about a finding.
-
sourceIpV6
The source IPv6 address of network-related information about a finding.
- Returns:
- The source IPv6 address of network-related information about a finding.
-
sourcePort
The source port of network-related information about a finding.
- Returns:
- The source port of network-related information about a finding.
-
sourceDomain
The source domain of network-related information about a finding.
Length Constraints: Minimum of 1. Maximum of 128.
- Returns:
- The source domain of network-related information about a finding.
Length Constraints: Minimum of 1. Maximum of 128.
-
sourceMac
The source media access control (MAC) address of network-related information about a finding.
- Returns:
- The source media access control (MAC) address of network-related information about a finding.
-
destinationIpV4
The destination IPv4 address of network-related information about a finding.
- Returns:
- The destination IPv4 address of network-related information about a finding.
-
destinationIpV6
The destination IPv6 address of network-related information about a finding.
- Returns:
- The destination IPv6 address of network-related information about a finding.
-
destinationPort
The destination port of network-related information about a finding.
- Returns:
- The destination port of network-related information about a finding.
-
destinationDomain
The destination domain of network-related information about a finding.
Length Constraints: Minimum of 1. Maximum of 128.
- Returns:
- The destination domain of network-related information about a finding.
Length Constraints: Minimum of 1. Maximum of 128.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Network.Builder,Network>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-