Class NetworkAutonomousSystem

java.lang.Object
software.amazon.awssdk.services.securityhub.model.NetworkAutonomousSystem
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>

@Generated("software.amazon.awssdk:codegen") public final class NetworkAutonomousSystem extends Object implements SdkPojo, Serializable, ToCopyableBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>

Contains information about the Autonomous System (AS) of the network endpoints involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

See Also: