Interface NetworkAutonomousSystem.Builder

All Superinterfaces:
Buildable, CopyableBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>, SdkBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>, SdkPojo
Enclosing class:
NetworkAutonomousSystem

@Mutable @NotThreadSafe public static interface NetworkAutonomousSystem.Builder extends SdkPojo, CopyableBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>
  • Method Details

    • name

      The name associated with the AS.

      Parameters:
      name - The name associated with the AS.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • number

      The unique number that identifies the AS.

      Parameters:
      number - The unique number that identifies the AS.
      Returns:
      Returns a reference to this object so that method calls can be chained together.