Class NetworkConnection
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<NetworkConnection.Builder,NetworkConnection>
Contains information about the network connection involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic NetworkConnection.Builderbuilder()final ConnectionDirectionThe direction in which the network traffic is flowing.final StringThe direction in which the network traffic is flowing.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends NetworkConnection.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
direction
The direction in which the network traffic is flowing.
If the service returns an enum value that is not available in the current SDK version,
directionwill returnConnectionDirection.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromdirectionAsString().- Returns:
- The direction in which the network traffic is flowing.
- See Also:
-
directionAsString
The direction in which the network traffic is flowing.
If the service returns an enum value that is not available in the current SDK version,
directionwill returnConnectionDirection.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromdirectionAsString().- Returns:
- The direction in which the network traffic is flowing.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<NetworkConnection.Builder,NetworkConnection>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-