Class NetworkConnectionAction
java.lang.Object
software.amazon.awssdk.services.securityhub.model.NetworkConnectionAction
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<NetworkConnectionAction.Builder,NetworkConnectionAction>
@Generated("software.amazon.awssdk:codegen")
public final class NetworkConnectionAction
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<NetworkConnectionAction.Builder,NetworkConnectionAction>
Provided if ActionType is NETWORK_CONNECTION. It provides details about the attempted
network connection that was detected.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Booleanblocked()Indicates whether the network connection attempt was blocked.builder()final StringThe direction of the network connection request (INorOUT).final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ActionLocalPortDetailsInformation about the port on the EC2 instance.final Stringprotocol()The protocol used to make the network connection request.final ActionRemoteIpDetailsInformation about the remote IP address that issued the network connection request.final ActionRemotePortDetailsInformation about the port on the remote IP address.static Class<? extends NetworkConnectionAction.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectionDirection
The direction of the network connection request (
INorOUT).- Returns:
- The direction of the network connection request (
INorOUT).
-
remoteIpDetails
Information about the remote IP address that issued the network connection request.
- Returns:
- Information about the remote IP address that issued the network connection request.
-
remotePortDetails
Information about the port on the remote IP address.
- Returns:
- Information about the port on the remote IP address.
-
localPortDetails
Information about the port on the EC2 instance.
- Returns:
- Information about the port on the EC2 instance.
-
protocol
The protocol used to make the network connection request.
Length Constraints: Minimum length of 1. Maximum length of 64.
- Returns:
- The protocol used to make the network connection request.
Length Constraints: Minimum length of 1. Maximum length of 64.
-
blocked
Indicates whether the network connection attempt was blocked.
- Returns:
- Indicates whether the network connection attempt was blocked.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<NetworkConnectionAction.Builder,NetworkConnectionAction>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-