Class NetworkGeoLocation

java.lang.Object
software.amazon.awssdk.services.securityhub.model.NetworkGeoLocation
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>

@Generated("software.amazon.awssdk:codegen") public final class NetworkGeoLocation extends Object implements SdkPojo, Serializable, ToCopyableBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>

Contains information about the location of a network endpoint involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

See Also: