Interface NetworkGeoLocation.Builder

All Superinterfaces:
Buildable, CopyableBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>, SdkBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>, SdkPojo
Enclosing class:
NetworkGeoLocation

@Mutable @NotThreadSafe public static interface NetworkGeoLocation.Builder extends SdkPojo, CopyableBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>
  • Method Details

    • city

      The name of the city.

      Parameters:
      city - The name of the city.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • country

      The name of the country.

      Parameters:
      country - The name of the country.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • lat

      The latitude information of the endpoint location.

      Parameters:
      lat - The latitude information of the endpoint location.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • lon

      The longitude information of the endpoint location.

      Parameters:
      lon - The longitude information of the endpoint location.
      Returns:
      Returns a reference to this object so that method calls can be chained together.