Class NetworkHeader
java.lang.Object
software.amazon.awssdk.services.securityhub.model.NetworkHeader
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<NetworkHeader.Builder,NetworkHeader>
@Generated("software.amazon.awssdk:codegen")
public final class NetworkHeader
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<NetworkHeader.Builder,NetworkHeader>
Details about a network path component that occurs before or after the current component.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic NetworkHeader.Builderbuilder()Information about the destination of the component.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringprotocol()The protocol used for the component.static Class<? extends NetworkHeader.Builder>source()Information about the origin of the component.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
protocol
The protocol used for the component.
Length Constraints: Minimum of 1. Maximum of 16.
- Returns:
- The protocol used for the component.
Length Constraints: Minimum of 1. Maximum of 16.
-
destination
Information about the destination of the component.
- Returns:
- Information about the destination of the component.
-
source
Information about the origin of the component.
- Returns:
- Information about the origin of the component.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<NetworkHeader.Builder,NetworkHeader>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-