Class NetworkPathComponent
java.lang.Object
software.amazon.awssdk.services.securityhub.model.NetworkPathComponent
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<NetworkPathComponent.Builder,NetworkPathComponent>
@Generated("software.amazon.awssdk:codegen")
public final class NetworkPathComponent
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<NetworkPathComponent.Builder,NetworkPathComponent>
Information about a network path component.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic NetworkPathComponent.Builderbuilder()final StringThe identifier of a component in the network path.final StringThe type of component.final NetworkHeaderegress()Information about the component that comes after the current component in the network path.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final NetworkHeaderingress()Information about the component that comes before the current node in the network path.static Class<? extends NetworkPathComponent.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
componentId
The identifier of a component in the network path.
Length Constraints: Minimum of 1. Maximum of 32.
- Returns:
- The identifier of a component in the network path.
Length Constraints: Minimum of 1. Maximum of 32.
-
componentType
The type of component.
Length Constraints: Minimum of 1. Maximum of 32.
- Returns:
- The type of component.
Length Constraints: Minimum of 1. Maximum of 32.
-
egress
Information about the component that comes after the current component in the network path.
- Returns:
- Information about the component that comes after the current component in the network path.
-
ingress
Information about the component that comes before the current node in the network path.
- Returns:
- Information about the component that comes before the current node in the network path.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<NetworkPathComponent.Builder,NetworkPathComponent>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-