Class Note
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Note
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Note.Builder,Note>
@Generated("software.amazon.awssdk:codegen")
public final class Note
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Note.Builder,Note>
A user-defined note added to a finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Note.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends Note.Builder>final Stringtext()The text of a note.final StringtoString()Returns a string representation of this object.final StringA timestamp that indicates when the note was updated.final StringThe principal that created a note.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
text
The text of a note.
Length Constraints: Minimum of 1. Maximum of 512.
- Returns:
- The text of a note.
Length Constraints: Minimum of 1. Maximum of 512.
-
updatedBy
The principal that created a note.
- Returns:
- The principal that created a note.
-
updatedAt
A timestamp that indicates when the note was updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- A timestamp that indicates when the note was updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Note.Builder,Note>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-