Enum OcsfBooleanField

    • Enum Constant Detail

      • COMPLIANCE_ASSESSMENTS_MEETS_CRITERIA

        public static final OcsfBooleanField COMPLIANCE_ASSESSMENTS_MEETS_CRITERIA
      • VULNERABILITIES_IS_EXPLOIT_AVAILABLE

        public static final OcsfBooleanField VULNERABILITIES_IS_EXPLOIT_AVAILABLE
      • VULNERABILITIES_IS_FIX_AVAILABLE

        public static final OcsfBooleanField VULNERABILITIES_IS_FIX_AVAILABLE
      • UNKNOWN_TO_SDK_VERSION

        public static final OcsfBooleanField UNKNOWN_TO_SDK_VERSION
    • Method Detail

      • values

        public static OcsfBooleanField[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (OcsfBooleanField c : OcsfBooleanField.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static OcsfBooleanField valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • fromValue

        public static OcsfBooleanField fromValue​(String value)
        Use this in place of valueOf to convert the raw string returned by the service into the enum value.
        Parameters:
        value - real value
        Returns:
        OcsfBooleanField corresponding to the value