Enum OcsfDateField

    • Enum Constant Detail

      • FINDING_INFO_CREATED_TIME_DT

        public static final OcsfDateField FINDING_INFO_CREATED_TIME_DT
      • FINDING_INFO_FIRST_SEEN_TIME_DT

        public static final OcsfDateField FINDING_INFO_FIRST_SEEN_TIME_DT
      • FINDING_INFO_LAST_SEEN_TIME_DT

        public static final OcsfDateField FINDING_INFO_LAST_SEEN_TIME_DT
      • FINDING_INFO_MODIFIED_TIME_DT

        public static final OcsfDateField FINDING_INFO_MODIFIED_TIME_DT
      • RESOURCES_IMAGE_CREATED_TIME_DT

        public static final OcsfDateField RESOURCES_IMAGE_CREATED_TIME_DT
      • RESOURCES_IMAGE_LAST_USED_TIME_DT

        public static final OcsfDateField RESOURCES_IMAGE_LAST_USED_TIME_DT
      • RESOURCES_MODIFIED_TIME_DT

        public static final OcsfDateField RESOURCES_MODIFIED_TIME_DT
      • UNKNOWN_TO_SDK_VERSION

        public static final OcsfDateField UNKNOWN_TO_SDK_VERSION
    • Method Detail

      • values

        public static OcsfDateField[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (OcsfDateField c : OcsfDateField.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static OcsfDateField valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • fromValue

        public static OcsfDateField fromValue​(String value)
        Use this in place of valueOf to convert the raw string returned by the service into the enum value.
        Parameters:
        value - real value
        Returns:
        OcsfDateField corresponding to the value