Enum OcsfMapField

    • Enum Constant Detail

      • RESOURCES_TAGS

        public static final OcsfMapField RESOURCES_TAGS
      • COMPLIANCE_CONTROL_PARAMETERS

        public static final OcsfMapField COMPLIANCE_CONTROL_PARAMETERS
      • DATABUCKET_TAGS

        public static final OcsfMapField DATABUCKET_TAGS
      • FINDING_INFO_TAGS

        public static final OcsfMapField FINDING_INFO_TAGS
      • UNKNOWN_TO_SDK_VERSION

        public static final OcsfMapField UNKNOWN_TO_SDK_VERSION
    • Method Detail

      • values

        public static OcsfMapField[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (OcsfMapField c : OcsfMapField.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static OcsfMapField valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • fromValue

        public static OcsfMapField fromValue​(String value)
        Use this in place of valueOf to convert the raw string returned by the service into the enum value.
        Parameters:
        value - real value
        Returns:
        OcsfMapField corresponding to the value