Enum OcsfNumberField

    • Enum Constant Detail

      • COMPLIANCE_STATUS_ID

        public static final OcsfNumberField COMPLIANCE_STATUS_ID
      • FINDING_INFO_RELATED_EVENTS_COUNT

        public static final OcsfNumberField FINDING_INFO_RELATED_EVENTS_COUNT
      • EVIDENCES_API_RESPONSE_CODE

        public static final OcsfNumberField EVIDENCES_API_RESPONSE_CODE
      • EVIDENCES_DST_ENDPOINT_AUTONOMOUS_SYSTEM_NUMBER

        public static final OcsfNumberField EVIDENCES_DST_ENDPOINT_AUTONOMOUS_SYSTEM_NUMBER
      • EVIDENCES_DST_ENDPOINT_PORT

        public static final OcsfNumberField EVIDENCES_DST_ENDPOINT_PORT
      • EVIDENCES_SRC_ENDPOINT_AUTONOMOUS_SYSTEM_NUMBER

        public static final OcsfNumberField EVIDENCES_SRC_ENDPOINT_AUTONOMOUS_SYSTEM_NUMBER
      • EVIDENCES_SRC_ENDPOINT_PORT

        public static final OcsfNumberField EVIDENCES_SRC_ENDPOINT_PORT
      • RESOURCES_IMAGE_IN_USE_COUNT

        public static final OcsfNumberField RESOURCES_IMAGE_IN_USE_COUNT
      • VULNERABILITIES_CVE_CVSS_BASE_SCORE

        public static final OcsfNumberField VULNERABILITIES_CVE_CVSS_BASE_SCORE
      • VENDOR_ATTRIBUTES_SEVERITY_ID

        public static final OcsfNumberField VENDOR_ATTRIBUTES_SEVERITY_ID
      • UNKNOWN_TO_SDK_VERSION

        public static final OcsfNumberField UNKNOWN_TO_SDK_VERSION
    • Method Detail

      • values

        public static OcsfNumberField[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (OcsfNumberField c : OcsfNumberField.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static OcsfNumberField valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • fromValue

        public static OcsfNumberField fromValue​(String value)
        Use this in place of valueOf to convert the raw string returned by the service into the enum value.
        Parameters:
        value - real value
        Returns:
        OcsfNumberField corresponding to the value