Class OrganizationConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<OrganizationConfiguration.Builder,OrganizationConfiguration>
Provides information about the way an organization is configured in Security Hub CSPM.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Indicates whether the organization uses local or central configuration.final StringIndicates whether the organization uses local or central configuration.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends OrganizationConfiguration.Builder>status()Describes whether central configuration could be enabled as theConfigurationTypefor the organization.final StringDescribes whether central configuration could be enabled as theConfigurationTypefor the organization.final StringProvides an explanation if the value ofStatusis equal toFAILEDwhenConfigurationTypeis equal toCENTRAL.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
configurationType
Indicates whether the organization uses local or central configuration.
If you use local configuration, the Security Hub CSPM delegated administrator can set
AutoEnabletotrueandAutoEnableStandardstoDEFAULT. This automatically enables Security Hub CSPM and default security standards in new organization accounts. These new account settings must be set separately in each Amazon Web Services Region, and settings may be different in each Region.If you use central configuration, the delegated administrator can create configuration policies. Configuration policies can be used to configure Security Hub CSPM, security standards, and security controls in multiple accounts and Regions. If you want new organization accounts to use a specific configuration, you can create a configuration policy and associate it with the root or specific organizational units (OUs). New accounts will inherit the policy from the root or their assigned OU.
If the service returns an enum value that is not available in the current SDK version,
configurationTypewill returnOrganizationConfigurationConfigurationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconfigurationTypeAsString().- Returns:
- Indicates whether the organization uses local or central configuration.
If you use local configuration, the Security Hub CSPM delegated administrator can set
AutoEnabletotrueandAutoEnableStandardstoDEFAULT. This automatically enables Security Hub CSPM and default security standards in new organization accounts. These new account settings must be set separately in each Amazon Web Services Region, and settings may be different in each Region.If you use central configuration, the delegated administrator can create configuration policies. Configuration policies can be used to configure Security Hub CSPM, security standards, and security controls in multiple accounts and Regions. If you want new organization accounts to use a specific configuration, you can create a configuration policy and associate it with the root or specific organizational units (OUs). New accounts will inherit the policy from the root or their assigned OU.
- See Also:
-
configurationTypeAsString
Indicates whether the organization uses local or central configuration.
If you use local configuration, the Security Hub CSPM delegated administrator can set
AutoEnabletotrueandAutoEnableStandardstoDEFAULT. This automatically enables Security Hub CSPM and default security standards in new organization accounts. These new account settings must be set separately in each Amazon Web Services Region, and settings may be different in each Region.If you use central configuration, the delegated administrator can create configuration policies. Configuration policies can be used to configure Security Hub CSPM, security standards, and security controls in multiple accounts and Regions. If you want new organization accounts to use a specific configuration, you can create a configuration policy and associate it with the root or specific organizational units (OUs). New accounts will inherit the policy from the root or their assigned OU.
If the service returns an enum value that is not available in the current SDK version,
configurationTypewill returnOrganizationConfigurationConfigurationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconfigurationTypeAsString().- Returns:
- Indicates whether the organization uses local or central configuration.
If you use local configuration, the Security Hub CSPM delegated administrator can set
AutoEnabletotrueandAutoEnableStandardstoDEFAULT. This automatically enables Security Hub CSPM and default security standards in new organization accounts. These new account settings must be set separately in each Amazon Web Services Region, and settings may be different in each Region.If you use central configuration, the delegated administrator can create configuration policies. Configuration policies can be used to configure Security Hub CSPM, security standards, and security controls in multiple accounts and Regions. If you want new organization accounts to use a specific configuration, you can create a configuration policy and associate it with the root or specific organizational units (OUs). New accounts will inherit the policy from the root or their assigned OU.
- See Also:
-
status
Describes whether central configuration could be enabled as the
ConfigurationTypefor the organization. If yourConfigurationTypeis local configuration, then the value ofStatusis alwaysENABLED.If the service returns an enum value that is not available in the current SDK version,
statuswill returnOrganizationConfigurationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- Describes whether central configuration could be enabled as the
ConfigurationTypefor the organization. If yourConfigurationTypeis local configuration, then the value ofStatusis alwaysENABLED. - See Also:
-
statusAsString
Describes whether central configuration could be enabled as the
ConfigurationTypefor the organization. If yourConfigurationTypeis local configuration, then the value ofStatusis alwaysENABLED.If the service returns an enum value that is not available in the current SDK version,
statuswill returnOrganizationConfigurationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- Describes whether central configuration could be enabled as the
ConfigurationTypefor the organization. If yourConfigurationTypeis local configuration, then the value ofStatusis alwaysENABLED. - See Also:
-
statusMessage
Provides an explanation if the value of
Statusis equal toFAILEDwhenConfigurationTypeis equal toCENTRAL.- Returns:
- Provides an explanation if the value of
Statusis equal toFAILEDwhenConfigurationTypeis equal toCENTRAL.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<OrganizationConfiguration.Builder,OrganizationConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-