Class OrganizationNotFoundException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
software.amazon.awssdk.core.exception.SdkException
software.amazon.awssdk.core.exception.SdkServiceException
software.amazon.awssdk.awscore.exception.AwsServiceException
software.amazon.awssdk.services.securityhub.model.SecurityHubException
software.amazon.awssdk.services.securityhub.model.OrganizationNotFoundException
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<OrganizationNotFoundException.Builder,OrganizationNotFoundException>
@Generated("software.amazon.awssdk:codegen")
public final class OrganizationNotFoundException
extends SecurityHubException
implements ToCopyableBuilder<OrganizationNotFoundException.Builder,OrganizationNotFoundException>
The request failed because one or more organizations specified in the request don't exist or don't belong to the caller's organization.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()code()Returns the value of the Code property for this object.static Class<? extends OrganizationNotFoundException.Builder>Methods inherited from class software.amazon.awssdk.awscore.exception.AwsServiceException
awsErrorDetails, getMessage, isClockSkewException, isThrottlingExceptionMethods inherited from class software.amazon.awssdk.core.exception.SdkServiceException
extendedRequestId, isRetryableException, requestId, statusCodeMethods inherited from class software.amazon.awssdk.core.exception.SdkException
create, numAttempts, rawMessage, retryableMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFieldsMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<OrganizationNotFoundException.Builder,OrganizationNotFoundException> - Overrides:
toBuilderin classSecurityHubException
-
builder
-
serializableBuilderClass
-
code
Returns the value of the Code property for this object.- Returns:
- The value of the Code property for this object.
-
sdkFields
- Specified by:
sdkFieldsin interfaceSdkPojo- Overrides:
sdkFieldsin classSdkServiceException
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-