Class ParameterConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ParameterConfiguration.Builder,ParameterConfiguration>
An object that provides the current value of a security control parameter and identifies whether it has been customized.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends ParameterConfiguration.Builder>final StringtoString()Returns a string representation of this object.final ParameterValuevalue()The current value of a control parameter.final ParameterValueTypeIdentifies whether a control parameter uses a custom user-defined value or subscribes to the default Security Hub CSPM behavior.final StringIdentifies whether a control parameter uses a custom user-defined value or subscribes to the default Security Hub CSPM behavior.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
valueType
Identifies whether a control parameter uses a custom user-defined value or subscribes to the default Security Hub CSPM behavior.
When
ValueTypeis set equal toDEFAULT, the default behavior can be a specific Security Hub CSPM default value, or the default behavior can be to ignore a specific parameter. WhenValueTypeis set equal toDEFAULT, Security Hub CSPM ignores user-provided input for theValuefield.When
ValueTypeis set equal toCUSTOM, theValuefield can't be empty.If the service returns an enum value that is not available in the current SDK version,
valueTypewill returnParameterValueType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromvalueTypeAsString().- Returns:
- Identifies whether a control parameter uses a custom user-defined value or subscribes to the default
Security Hub CSPM behavior.
When
ValueTypeis set equal toDEFAULT, the default behavior can be a specific Security Hub CSPM default value, or the default behavior can be to ignore a specific parameter. WhenValueTypeis set equal toDEFAULT, Security Hub CSPM ignores user-provided input for theValuefield.When
ValueTypeis set equal toCUSTOM, theValuefield can't be empty. - See Also:
-
valueTypeAsString
Identifies whether a control parameter uses a custom user-defined value or subscribes to the default Security Hub CSPM behavior.
When
ValueTypeis set equal toDEFAULT, the default behavior can be a specific Security Hub CSPM default value, or the default behavior can be to ignore a specific parameter. WhenValueTypeis set equal toDEFAULT, Security Hub CSPM ignores user-provided input for theValuefield.When
ValueTypeis set equal toCUSTOM, theValuefield can't be empty.If the service returns an enum value that is not available in the current SDK version,
valueTypewill returnParameterValueType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromvalueTypeAsString().- Returns:
- Identifies whether a control parameter uses a custom user-defined value or subscribes to the default
Security Hub CSPM behavior.
When
ValueTypeis set equal toDEFAULT, the default behavior can be a specific Security Hub CSPM default value, or the default behavior can be to ignore a specific parameter. WhenValueTypeis set equal toDEFAULT, Security Hub CSPM ignores user-provided input for theValuefield.When
ValueTypeis set equal toCUSTOM, theValuefield can't be empty. - See Also:
-
value
The current value of a control parameter.
- Returns:
- The current value of a control parameter.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ParameterConfiguration.Builder,ParameterConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-