Class ParameterDefinition
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ParameterDefinition
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ParameterDefinition.Builder,ParameterDefinition>
@Generated("software.amazon.awssdk:codegen")
public final class ParameterDefinition
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ParameterDefinition.Builder,ParameterDefinition>
An object that describes a security control parameter and the options for customizing it.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ParameterDefinition.Builderbuilder()final ConfigurationOptionsThe options for customizing a control parameter.final StringDescription of a control parameter.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends ParameterDefinition.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
description
Description of a control parameter.
- Returns:
- Description of a control parameter.
-
configurationOptions
The options for customizing a control parameter. Customization options vary based on the data type of the parameter.
- Returns:
- The options for customizing a control parameter. Customization options vary based on the data type of the parameter.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ParameterDefinition.Builder,ParameterDefinition>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-