Class Policy
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Policy.Builder,Policy>
An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Policy.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) static PolicyfromSecurityHub(Consumer<SecurityHubPolicy.Builder> securityHub) Create an instance of this class withsecurityHub()initialized to the given value.static PolicyfromSecurityHub(SecurityHubPolicy securityHub) Create an instance of this class withsecurityHub()initialized to the given value.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final SecurityHubPolicyThe Amazon Web Services service that the configuration policy applies to.static Class<? extends Policy.Builder>final StringtoString()Returns a string representation of this object.type()Retrieve an enum value representing which member of this object is populated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
securityHub
The Amazon Web Services service that the configuration policy applies to.
- Returns:
- The Amazon Web Services service that the configuration policy applies to.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Policy.Builder,Policy>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
fromSecurityHub
Create an instance of this class withsecurityHub()initialized to the given value.The Amazon Web Services service that the configuration policy applies to.
- Parameters:
securityHub- The Amazon Web Services service that the configuration policy applies to.
-
fromSecurityHub
Create an instance of this class withsecurityHub()initialized to the given value.The Amazon Web Services service that the configuration policy applies to.
- Parameters:
securityHub- The Amazon Web Services service that the configuration policy applies to.
-
type
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will bePolicy.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will bePolicy.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set. -
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-