Class PortProbeAction

java.lang.Object
software.amazon.awssdk.services.securityhub.model.PortProbeAction
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<PortProbeAction.Builder,PortProbeAction>

@Generated("software.amazon.awssdk:codegen") public final class PortProbeAction extends Object implements SdkPojo, Serializable, ToCopyableBuilder<PortProbeAction.Builder,PortProbeAction>

Provided if ActionType is PORT_PROBE. It provides details about the attempted port probe that was detected.

See Also:
  • Method Details

    • hasPortProbeDetails

      public final boolean hasPortProbeDetails()
      For responses, this returns true if the service returned a value for the PortProbeDetails property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • portProbeDetails

      public final List<PortProbeDetail> portProbeDetails()

      Information about the ports affected by the port probe.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasPortProbeDetails() method.

      Returns:
      Information about the ports affected by the port probe.
    • blocked

      public final Boolean blocked()

      Indicates whether the port probe was blocked.

      Returns:
      Indicates whether the port probe was blocked.
    • toBuilder

      public PortProbeAction.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<PortProbeAction.Builder,PortProbeAction>
    • builder

      public static PortProbeAction.Builder builder()
    • serializableBuilderClass

      public static Class<? extends PortProbeAction.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo