Class PortProbeDetail
java.lang.Object
software.amazon.awssdk.services.securityhub.model.PortProbeDetail
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PortProbeDetail.Builder,PortProbeDetail>
@Generated("software.amazon.awssdk:codegen")
public final class PortProbeDetail
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<PortProbeDetail.Builder,PortProbeDetail>
A port scan that was part of the port probe. For each scan, PortProbeDetails provides information about the local IP address and port that were scanned, and the remote IP address that the scan originated from.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic PortProbeDetail.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ActionLocalIpDetailsProvides information about the IP address where the scanned port is located.final ActionLocalPortDetailsProvides information about the port that was scanned.final ActionRemoteIpDetailsProvides information about the remote IP address that performed the scan.static Class<? extends PortProbeDetail.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
localPortDetails
Provides information about the port that was scanned.
- Returns:
- Provides information about the port that was scanned.
-
localIpDetails
Provides information about the IP address where the scanned port is located.
- Returns:
- Provides information about the IP address where the scanned port is located.
-
remoteIpDetails
Provides information about the remote IP address that performed the scan.
- Returns:
- Provides information about the remote IP address that performed the scan.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PortProbeDetail.Builder,PortProbeDetail>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-