Class ProcessDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProcessDetails.Builder,ProcessDetails>
The details of process-related information about a finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ProcessDetails.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringIndicates when the process was launched.final Stringname()The name of the process.final IntegerThe parent process ID.final Stringpath()The path to the process executable.final Integerpid()The process ID.static Class<? extends ProcessDetails.Builder>final StringIndicates when the process was terminated.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the process.
Length Constraints: Minimum of 1. Maximum of 64.
- Returns:
- The name of the process.
Length Constraints: Minimum of 1. Maximum of 64.
-
path
The path to the process executable.
Length Constraints: Minimum of 1. Maximum of 512.
- Returns:
- The path to the process executable.
Length Constraints: Minimum of 1. Maximum of 512.
-
pid
The process ID.
- Returns:
- The process ID.
-
parentPid
The parent process ID. This field accepts positive integers between
Oand2147483647.- Returns:
- The parent process ID. This field accepts positive integers between
Oand2147483647.
-
launchedAt
Indicates when the process was launched.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the process was launched.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
terminatedAt
Indicates when the process was terminated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the process was terminated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProcessDetails.Builder,ProcessDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-