Interface ProcessDetails.Builder

All Superinterfaces:
Buildable, CopyableBuilder<ProcessDetails.Builder,ProcessDetails>, SdkBuilder<ProcessDetails.Builder,ProcessDetails>, SdkPojo
Enclosing class:
ProcessDetails

@Mutable @NotThreadSafe public static interface ProcessDetails.Builder extends SdkPojo, CopyableBuilder<ProcessDetails.Builder,ProcessDetails>
  • Method Details

    • name

      The name of the process.

      Length Constraints: Minimum of 1. Maximum of 64.

      Parameters:
      name - The name of the process.

      Length Constraints: Minimum of 1. Maximum of 64.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • path

      The path to the process executable.

      Length Constraints: Minimum of 1. Maximum of 512.

      Parameters:
      path - The path to the process executable.

      Length Constraints: Minimum of 1. Maximum of 512.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • pid

      The process ID.

      Parameters:
      pid - The process ID.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • parentPid

      ProcessDetails.Builder parentPid(Integer parentPid)

      The parent process ID. This field accepts positive integers between O and 2147483647.

      Parameters:
      parentPid - The parent process ID. This field accepts positive integers between O and 2147483647.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • launchedAt

      ProcessDetails.Builder launchedAt(String launchedAt)

      Indicates when the process was launched.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      Parameters:
      launchedAt - Indicates when the process was launched.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps</ a>.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • terminatedAt

      ProcessDetails.Builder terminatedAt(String terminatedAt)

      Indicates when the process was terminated.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      Parameters:
      terminatedAt - Indicates when the process was terminated.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps</ a>.

      Returns:
      Returns a reference to this object so that method calls can be chained together.