Class ProviderConfiguration
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ProviderConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>
@Generated("software.amazon.awssdk:codegen")
public final class ProviderConfiguration
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>
The initial configuration settings required to establish an integration between Security Hub and third-party provider.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfacestatic enum -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) static ProviderConfigurationCreate an instance of this class withjiraCloud()initialized to the given value.static ProviderConfigurationfromJiraCloud(JiraCloudProviderConfiguration jiraCloud) Create an instance of this class withjiraCloud()initialized to the given value.static ProviderConfigurationCreate an instance of this class withserviceNow()initialized to the given value.static ProviderConfigurationfromServiceNow(ServiceNowProviderConfiguration serviceNow) Create an instance of this class withserviceNow()initialized to the given value.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()The configuration settings required to establish an integration with Jira Cloud.static Class<? extends ProviderConfiguration.Builder>The configuration settings required to establish an integration with ServiceNow ITSM.final StringtoString()Returns a string representation of this object.type()Retrieve an enum value representing which member of this object is populated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
jiraCloud
The configuration settings required to establish an integration with Jira Cloud.
- Returns:
- The configuration settings required to establish an integration with Jira Cloud.
-
serviceNow
The configuration settings required to establish an integration with ServiceNow ITSM.
- Returns:
- The configuration settings required to establish an integration with ServiceNow ITSM.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
fromJiraCloud
Create an instance of this class withjiraCloud()initialized to the given value.The configuration settings required to establish an integration with Jira Cloud.
- Parameters:
jiraCloud- The configuration settings required to establish an integration with Jira Cloud.
-
fromJiraCloud
public static ProviderConfiguration fromJiraCloud(Consumer<JiraCloudProviderConfiguration.Builder> jiraCloud) Create an instance of this class withjiraCloud()initialized to the given value.The configuration settings required to establish an integration with Jira Cloud.
- Parameters:
jiraCloud- The configuration settings required to establish an integration with Jira Cloud.
-
fromServiceNow
Create an instance of this class withserviceNow()initialized to the given value.The configuration settings required to establish an integration with ServiceNow ITSM.
- Parameters:
serviceNow- The configuration settings required to establish an integration with ServiceNow ITSM.
-
fromServiceNow
public static ProviderConfiguration fromServiceNow(Consumer<ServiceNowProviderConfiguration.Builder> serviceNow) Create an instance of this class withserviceNow()initialized to the given value.The configuration settings required to establish an integration with ServiceNow ITSM.
- Parameters:
serviceNow- The configuration settings required to establish an integration with ServiceNow ITSM.
-
type
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beProviderConfiguration.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beProviderConfiguration.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set. -
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-