Interface ProviderConfiguration.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>,SdkBuilder<ProviderConfiguration.Builder,ProviderConfiguration>,SdkPojo
- Enclosing class:
- ProviderConfiguration
@Mutable @NotThreadSafe public static interface ProviderConfiguration.Builder extends SdkPojo, CopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default ProviderConfiguration.BuilderjiraCloud(Consumer<JiraCloudProviderConfiguration.Builder> jiraCloud)The configuration settings required to establish an integration with Jira Cloud.ProviderConfiguration.BuilderjiraCloud(JiraCloudProviderConfiguration jiraCloud)The configuration settings required to establish an integration with Jira Cloud.default ProviderConfiguration.BuilderserviceNow(Consumer<ServiceNowProviderConfiguration.Builder> serviceNow)The configuration settings required to establish an integration with ServiceNow ITSM.ProviderConfiguration.BuilderserviceNow(ServiceNowProviderConfiguration serviceNow)The configuration settings required to establish an integration with ServiceNow ITSM.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
jiraCloud
ProviderConfiguration.Builder jiraCloud(JiraCloudProviderConfiguration jiraCloud)
The configuration settings required to establish an integration with Jira Cloud.
- Parameters:
jiraCloud- The configuration settings required to establish an integration with Jira Cloud.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
jiraCloud
default ProviderConfiguration.Builder jiraCloud(Consumer<JiraCloudProviderConfiguration.Builder> jiraCloud)
The configuration settings required to establish an integration with Jira Cloud.
This is a convenience method that creates an instance of theJiraCloudProviderConfiguration.Builderavoiding the need to create one manually viaJiraCloudProviderConfiguration.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tojiraCloud(JiraCloudProviderConfiguration).- Parameters:
jiraCloud- a consumer that will call methods onJiraCloudProviderConfiguration.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
jiraCloud(JiraCloudProviderConfiguration)
-
serviceNow
ProviderConfiguration.Builder serviceNow(ServiceNowProviderConfiguration serviceNow)
The configuration settings required to establish an integration with ServiceNow ITSM.
- Parameters:
serviceNow- The configuration settings required to establish an integration with ServiceNow ITSM.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
serviceNow
default ProviderConfiguration.Builder serviceNow(Consumer<ServiceNowProviderConfiguration.Builder> serviceNow)
The configuration settings required to establish an integration with ServiceNow ITSM.
This is a convenience method that creates an instance of theServiceNowProviderConfiguration.Builderavoiding the need to create one manually viaServiceNowProviderConfiguration.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toserviceNow(ServiceNowProviderConfiguration).- Parameters:
serviceNow- a consumer that will call methods onServiceNowProviderConfiguration.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
serviceNow(ServiceNowProviderConfiguration)
-
-