Class ProviderDetail
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ProviderDetail
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProviderDetail.Builder,ProviderDetail>
@Generated("software.amazon.awssdk:codegen")
public final class ProviderDetail
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ProviderDetail.Builder,ProviderDetail>
The third-party provider detail for a service configuration.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfacestatic enum -
Method Summary
Modifier and TypeMethodDescriptionstatic ProviderDetail.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) static ProviderDetailfromJiraCloud(Consumer<JiraCloudDetail.Builder> jiraCloud) Create an instance of this class withjiraCloud()initialized to the given value.static ProviderDetailfromJiraCloud(JiraCloudDetail jiraCloud) Create an instance of this class withjiraCloud()initialized to the given value.static ProviderDetailfromServiceNow(Consumer<ServiceNowDetail.Builder> serviceNow) Create an instance of this class withserviceNow()initialized to the given value.static ProviderDetailfromServiceNow(ServiceNowDetail serviceNow) Create an instance of this class withserviceNow()initialized to the given value.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final JiraCloudDetailDetails about a Jira Cloud integration.static Class<? extends ProviderDetail.Builder>final ServiceNowDetailDetails about a ServiceNow ITSM integration.final StringtoString()Returns a string representation of this object.type()Retrieve an enum value representing which member of this object is populated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
jiraCloud
Details about a Jira Cloud integration.
- Returns:
- Details about a Jira Cloud integration.
-
serviceNow
Details about a ServiceNow ITSM integration.
- Returns:
- Details about a ServiceNow ITSM integration.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProviderDetail.Builder,ProviderDetail>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
fromJiraCloud
Create an instance of this class withjiraCloud()initialized to the given value.Details about a Jira Cloud integration.
- Parameters:
jiraCloud- Details about a Jira Cloud integration.
-
fromJiraCloud
Create an instance of this class withjiraCloud()initialized to the given value.Details about a Jira Cloud integration.
- Parameters:
jiraCloud- Details about a Jira Cloud integration.
-
fromServiceNow
Create an instance of this class withserviceNow()initialized to the given value.Details about a ServiceNow ITSM integration.
- Parameters:
serviceNow- Details about a ServiceNow ITSM integration.
-
fromServiceNow
Create an instance of this class withserviceNow()initialized to the given value.Details about a ServiceNow ITSM integration.
- Parameters:
serviceNow- Details about a ServiceNow ITSM integration.
-
type
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beProviderDetail.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beProviderDetail.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set. -
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-