Class ProviderSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProviderSummary.Builder,ProviderSummary>
The connectorV2 third-party provider configuration summary.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ProviderSummary.Builderbuilder()final ConnectorStatusThe status for the connectorV2.final StringThe status for the connectorV2.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ConnectorProviderNameThe name of the provider.final StringThe name of the provider.static Class<? extends ProviderSummary.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
providerName
The name of the provider.
If the service returns an enum value that is not available in the current SDK version,
providerNamewill returnConnectorProviderName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromproviderNameAsString().- Returns:
- The name of the provider.
- See Also:
-
providerNameAsString
The name of the provider.
If the service returns an enum value that is not available in the current SDK version,
providerNamewill returnConnectorProviderName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromproviderNameAsString().- Returns:
- The name of the provider.
- See Also:
-
connectorStatus
The status for the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status for the connectorV2.
- See Also:
-
connectorStatusAsString
The status for the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status for the connectorV2.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProviderSummary.Builder,ProviderSummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-