Interface ProviderUpdateConfiguration.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ProviderUpdateConfiguration.Builder,ProviderUpdateConfiguration>,SdkBuilder<ProviderUpdateConfiguration.Builder,ProviderUpdateConfiguration>,SdkPojo
- Enclosing class:
- ProviderUpdateConfiguration
@Mutable @NotThreadSafe public static interface ProviderUpdateConfiguration.Builder extends SdkPojo, CopyableBuilder<ProviderUpdateConfiguration.Builder,ProviderUpdateConfiguration>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default ProviderUpdateConfiguration.BuilderjiraCloud(Consumer<JiraCloudUpdateConfiguration.Builder> jiraCloud)The parameters required to update the configuration for a Jira Cloud integration.ProviderUpdateConfiguration.BuilderjiraCloud(JiraCloudUpdateConfiguration jiraCloud)The parameters required to update the configuration for a Jira Cloud integration.default ProviderUpdateConfiguration.BuilderserviceNow(Consumer<ServiceNowUpdateConfiguration.Builder> serviceNow)The parameters required to update the configuration for a ServiceNow integration.ProviderUpdateConfiguration.BuilderserviceNow(ServiceNowUpdateConfiguration serviceNow)The parameters required to update the configuration for a ServiceNow integration.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
jiraCloud
ProviderUpdateConfiguration.Builder jiraCloud(JiraCloudUpdateConfiguration jiraCloud)
The parameters required to update the configuration for a Jira Cloud integration.
- Parameters:
jiraCloud- The parameters required to update the configuration for a Jira Cloud integration.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
jiraCloud
default ProviderUpdateConfiguration.Builder jiraCloud(Consumer<JiraCloudUpdateConfiguration.Builder> jiraCloud)
The parameters required to update the configuration for a Jira Cloud integration.
This is a convenience method that creates an instance of theJiraCloudUpdateConfiguration.Builderavoiding the need to create one manually viaJiraCloudUpdateConfiguration.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tojiraCloud(JiraCloudUpdateConfiguration).- Parameters:
jiraCloud- a consumer that will call methods onJiraCloudUpdateConfiguration.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
jiraCloud(JiraCloudUpdateConfiguration)
-
serviceNow
ProviderUpdateConfiguration.Builder serviceNow(ServiceNowUpdateConfiguration serviceNow)
The parameters required to update the configuration for a ServiceNow integration.
- Parameters:
serviceNow- The parameters required to update the configuration for a ServiceNow integration.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
serviceNow
default ProviderUpdateConfiguration.Builder serviceNow(Consumer<ServiceNowUpdateConfiguration.Builder> serviceNow)
The parameters required to update the configuration for a ServiceNow integration.
This is a convenience method that creates an instance of theServiceNowUpdateConfiguration.Builderavoiding the need to create one manually viaServiceNowUpdateConfiguration.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toserviceNow(ServiceNowUpdateConfiguration).- Parameters:
serviceNow- a consumer that will call methods onServiceNowUpdateConfiguration.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
serviceNow(ServiceNowUpdateConfiguration)
-
-