Class Range
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Range
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Range.Builder,Range>
@Generated("software.amazon.awssdk:codegen")
public final class Range
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Range.Builder,Range>
Identifies where the sensitive data begins and ends.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Range.Builderbuilder()final Longend()The number of lines (for a line range) or characters (for an offset range) from the beginning of the file to the end of the sensitive data.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends Range.Builder>final Longstart()The number of lines (for a line range) or characters (for an offset range) from the beginning of the file to the end of the sensitive data.final LongIn the line where the sensitive data starts, the column within the line where the sensitive data starts.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
start
The number of lines (for a line range) or characters (for an offset range) from the beginning of the file to the end of the sensitive data.
- Returns:
- The number of lines (for a line range) or characters (for an offset range) from the beginning of the file to the end of the sensitive data.
-
end
The number of lines (for a line range) or characters (for an offset range) from the beginning of the file to the end of the sensitive data.
- Returns:
- The number of lines (for a line range) or characters (for an offset range) from the beginning of the file to the end of the sensitive data.
-
startColumn
In the line where the sensitive data starts, the column within the line where the sensitive data starts.
- Returns:
- In the line where the sensitive data starts, the column within the line where the sensitive data starts.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Range.Builder,Range>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-