Class Recommendation
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Recommendation
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Recommendation.Builder,Recommendation>
@Generated("software.amazon.awssdk:codegen")
public final class Recommendation
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Recommendation.Builder,Recommendation>
A recommendation on how to remediate the issue identified in a finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Recommendation.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends Recommendation.Builder>final Stringtext()Describes the recommended steps to take to remediate an issue identified in a finding.final StringtoString()Returns a string representation of this object.final Stringurl()A URL to a page or site that contains information about how to remediate a finding.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
text
Describes the recommended steps to take to remediate an issue identified in a finding.
Length Constraints: Minimum of 1 length. Maximum of 512 length.
- Returns:
- Describes the recommended steps to take to remediate an issue identified in a finding.
Length Constraints: Minimum of 1 length. Maximum of 512 length.
-
url
A URL to a page or site that contains information about how to remediate a finding.
- Returns:
- A URL to a page or site that contains information about how to remediate a finding.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Recommendation.Builder,Recommendation>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-