Class RecommendationError
java.lang.Object
software.amazon.awssdk.services.securityhub.model.RecommendationError
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RecommendationError.Builder,RecommendationError>
@Generated("software.amazon.awssdk:codegen")
public final class RecommendationError
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<RecommendationError.Builder,RecommendationError>
Contains information about the reason that the retrieval of a recommended policy for a finding failed.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic RecommendationError.Builderbuilder()final Stringcode()The error code for a failed retrieval of a recommended policy for a finding.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringmessage()The error message for a failed retrieval of a recommended policy for a finding.static Class<? extends RecommendationError.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
code
The error code for a failed retrieval of a recommended policy for a finding.
- Returns:
- The error code for a failed retrieval of a recommended policy for a finding.
-
message
The error message for a failed retrieval of a recommended policy for a finding.
- Returns:
- The error message for a failed retrieval of a recommended policy for a finding.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RecommendationError.Builder,RecommendationError>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-