java.lang.Object
software.amazon.awssdk.services.securityhub.model.Record
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<Record.Builder,Record>

@Generated("software.amazon.awssdk:codegen") public final class Record extends Object implements SdkPojo, Serializable, ToCopyableBuilder<Record.Builder,Record>

An occurrence of sensitive data in an Apache Avro object container or an Apache Parquet file.

See Also:
  • Method Details

    • jsonPath

      public final String jsonPath()

      The path, as a JSONPath expression, to the field in the record that contains the data. If the field name is longer than 20 characters, it is truncated. If the path is longer than 250 characters, it is truncated.

      Returns:
      The path, as a JSONPath expression, to the field in the record that contains the data. If the field name is longer than 20 characters, it is truncated. If the path is longer than 250 characters, it is truncated.
    • recordIndex

      public final Long recordIndex()

      The record index, starting from 0, for the record that contains the data.

      Returns:
      The record index, starting from 0, for the record that contains the data.
    • toBuilder

      public Record.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<Record.Builder,Record>
    • builder

      public static Record.Builder builder()
    • serializableBuilderClass

      public static Class<? extends Record.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo