Enum ResourceCategory
- java.lang.Object
-
- java.lang.Enum<ResourceCategory>
-
- software.amazon.awssdk.services.securityhub.model.ResourceCategory
-
- All Implemented Interfaces:
Serializable,Comparable<ResourceCategory>
@Generated("software.amazon.awssdk:codegen") public enum ResourceCategory extends Enum<ResourceCategory>
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ResourceCategoryfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<ResourceCategory>knownValues()StringtoString()static ResourceCategoryvalueOf(String name)Returns the enum constant of this type with the specified name.static ResourceCategory[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
COMPUTE
public static final ResourceCategory COMPUTE
-
DATABASE
public static final ResourceCategory DATABASE
-
STORAGE
public static final ResourceCategory STORAGE
-
CODE
public static final ResourceCategory CODE
-
AI_ML
public static final ResourceCategory AI_ML
-
IDENTITY
public static final ResourceCategory IDENTITY
-
NETWORK
public static final ResourceCategory NETWORK
-
OTHER
public static final ResourceCategory OTHER
-
UNKNOWN_TO_SDK_VERSION
public static final ResourceCategory UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static ResourceCategory[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ResourceCategory c : ResourceCategory.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ResourceCategory valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<ResourceCategory>
-
fromValue
public static ResourceCategory fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- ResourceCategory corresponding to the value
-
knownValues
public static Set<ResourceCategory> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownResourceCategorys
-
-