Class ResourceFindingsSummary
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ResourceFindingsSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>
@Generated("software.amazon.awssdk:codegen")
public final class ResourceFindingsSummary
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>
A list of summaries for all finding types on a resource.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe category or classification of the security finding.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the product associated with the security finding.static Class<? extends ResourceFindingsSummary.Builder>A breakdown of security findings by their severity levels.final StringtoString()Returns a string representation of this object.final IntegerThe total count of security findings.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
findingType
The category or classification of the security finding.
- Returns:
- The category or classification of the security finding.
-
productName
The name of the product associated with the security finding.
- Returns:
- The name of the product associated with the security finding.
-
totalFindings
The total count of security findings.
- Returns:
- The total count of security findings.
-
severities
A breakdown of security findings by their severity levels.
- Returns:
- A breakdown of security findings by their severity levels.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-