Interface ResourceFindingsSummary.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>,SdkBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>,SdkPojo
- Enclosing class:
- ResourceFindingsSummary
@Mutable @NotThreadSafe public static interface ResourceFindingsSummary.Builder extends SdkPojo, CopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description ResourceFindingsSummary.BuilderfindingType(String findingType)The category or classification of the security finding.ResourceFindingsSummary.BuilderproductName(String productName)The name of the product associated with the security finding.default ResourceFindingsSummary.Builderseverities(Consumer<ResourceSeverityBreakdown.Builder> severities)A breakdown of security findings by their severity levels.ResourceFindingsSummary.Builderseverities(ResourceSeverityBreakdown severities)A breakdown of security findings by their severity levels.ResourceFindingsSummary.BuildertotalFindings(Integer totalFindings)The total count of security findings.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
findingType
ResourceFindingsSummary.Builder findingType(String findingType)
The category or classification of the security finding.
- Parameters:
findingType- The category or classification of the security finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
productName
ResourceFindingsSummary.Builder productName(String productName)
The name of the product associated with the security finding.
- Parameters:
productName- The name of the product associated with the security finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
totalFindings
ResourceFindingsSummary.Builder totalFindings(Integer totalFindings)
The total count of security findings.
- Parameters:
totalFindings- The total count of security findings.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
severities
ResourceFindingsSummary.Builder severities(ResourceSeverityBreakdown severities)
A breakdown of security findings by their severity levels.
- Parameters:
severities- A breakdown of security findings by their severity levels.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
severities
default ResourceFindingsSummary.Builder severities(Consumer<ResourceSeverityBreakdown.Builder> severities)
A breakdown of security findings by their severity levels.
This is a convenience method that creates an instance of theResourceSeverityBreakdown.Builderavoiding the need to create one manually viaResourceSeverityBreakdown.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toseverities(ResourceSeverityBreakdown).- Parameters:
severities- a consumer that will call methods onResourceSeverityBreakdown.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
severities(ResourceSeverityBreakdown)
-
-