Enum ResourceGroupByField
- java.lang.Object
-
- java.lang.Enum<ResourceGroupByField>
-
- software.amazon.awssdk.services.securityhub.model.ResourceGroupByField
-
- All Implemented Interfaces:
Serializable,Comparable<ResourceGroupByField>
@Generated("software.amazon.awssdk:codegen") public enum ResourceGroupByField extends Enum<ResourceGroupByField>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_IDFINDINGS_SUMMARY_FINDING_TYPEREGIONRESOURCE_CATEGORYRESOURCE_NAMERESOURCE_TYPEUNKNOWN_TO_SDK_VERSION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ResourceGroupByFieldfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<ResourceGroupByField>knownValues()StringtoString()static ResourceGroupByFieldvalueOf(String name)Returns the enum constant of this type with the specified name.static ResourceGroupByField[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
ACCOUNT_ID
public static final ResourceGroupByField ACCOUNT_ID
-
REGION
public static final ResourceGroupByField REGION
-
RESOURCE_CATEGORY
public static final ResourceGroupByField RESOURCE_CATEGORY
-
RESOURCE_TYPE
public static final ResourceGroupByField RESOURCE_TYPE
-
RESOURCE_NAME
public static final ResourceGroupByField RESOURCE_NAME
-
FINDINGS_SUMMARY_FINDING_TYPE
public static final ResourceGroupByField FINDINGS_SUMMARY_FINDING_TYPE
-
UNKNOWN_TO_SDK_VERSION
public static final ResourceGroupByField UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static ResourceGroupByField[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ResourceGroupByField c : ResourceGroupByField.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ResourceGroupByField valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<ResourceGroupByField>
-
fromValue
public static ResourceGroupByField fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- ResourceGroupByField corresponding to the value
-
knownValues
public static Set<ResourceGroupByField> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownResourceGroupByFields
-
-