Class ResourceGroupByRule
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>
Defines the configuration for organizing and categorizing Amazon Web Services resources based on associated security findings.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ResourceGroupByRule.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final ResourcesFiltersfilters()The criteria used to select resources and associated security findings.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final ResourceGroupByFieldSpecifies the attribute that resources should be grouped by.final StringSpecifies the attribute that resources should be grouped by.final inthashCode()static Class<? extends ResourceGroupByRule.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
groupByField
Specifies the attribute that resources should be grouped by.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnResourceGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- Specifies the attribute that resources should be grouped by.
- See Also:
-
groupByFieldAsString
Specifies the attribute that resources should be grouped by.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnResourceGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- Specifies the attribute that resources should be grouped by.
- See Also:
-
filters
The criteria used to select resources and associated security findings.
- Returns:
- The criteria used to select resources and associated security findings.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-