Interface ResourceGroupByRule.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>,SdkBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>,SdkPojo
- Enclosing class:
- ResourceGroupByRule
@Mutable @NotThreadSafe public static interface ResourceGroupByRule.Builder extends SdkPojo, CopyableBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default ResourceGroupByRule.Builderfilters(Consumer<ResourcesFilters.Builder> filters)The criteria used to select resources and associated security findings.ResourceGroupByRule.Builderfilters(ResourcesFilters filters)The criteria used to select resources and associated security findings.ResourceGroupByRule.BuildergroupByField(String groupByField)Specifies the attribute that resources should be grouped by.ResourceGroupByRule.BuildergroupByField(ResourceGroupByField groupByField)Specifies the attribute that resources should be grouped by.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
groupByField
ResourceGroupByRule.Builder groupByField(String groupByField)
Specifies the attribute that resources should be grouped by.
- Parameters:
groupByField- Specifies the attribute that resources should be grouped by.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ResourceGroupByField,ResourceGroupByField
-
groupByField
ResourceGroupByRule.Builder groupByField(ResourceGroupByField groupByField)
Specifies the attribute that resources should be grouped by.
- Parameters:
groupByField- Specifies the attribute that resources should be grouped by.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ResourceGroupByField,ResourceGroupByField
-
filters
ResourceGroupByRule.Builder filters(ResourcesFilters filters)
The criteria used to select resources and associated security findings.
- Parameters:
filters- The criteria used to select resources and associated security findings.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
filters
default ResourceGroupByRule.Builder filters(Consumer<ResourcesFilters.Builder> filters)
The criteria used to select resources and associated security findings.
This is a convenience method that creates an instance of theResourcesFilters.Builderavoiding the need to create one manually viaResourcesFilters.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tofilters(ResourcesFilters).- Parameters:
filters- a consumer that will call methods onResourcesFilters.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
filters(ResourcesFilters)
-
-