java.lang.Object
software.amazon.awssdk.services.securityhub.model.ResourceOwner
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<ResourceOwner.Builder,ResourceOwner>

@Generated("software.amazon.awssdk:codegen") public final class ResourceOwner extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ResourceOwner.Builder,ResourceOwner>

Information about the owner of a resource, including the account and organization that the resource belongs to.

See Also:
  • Method Details

    • account

      public final ResourceOwnerAccount account()

      Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.

      Returns:
      Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.
    • org

      public final ResourceOwnerOrg org()

      Information about the organization that owns the resource, for example, an Azure Tenant.

      Returns:
      Information about the organization that owns the resource, for example, an Azure Tenant.
    • toBuilder

      public ResourceOwner.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<ResourceOwner.Builder,ResourceOwner>
    • builder

      public static ResourceOwner.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ResourceOwner.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo