Class ResourceOwnerAccount

java.lang.Object
software.amazon.awssdk.services.securityhub.model.ResourceOwnerAccount
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<ResourceOwnerAccount.Builder,ResourceOwnerAccount>

@Generated("software.amazon.awssdk:codegen") public final class ResourceOwnerAccount extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ResourceOwnerAccount.Builder,ResourceOwnerAccount>

Information about the account that owns a resource, for example, an Azure Subscription or Amazon Web Services Account.

See Also: