Class ResourceResult

    • Method Detail

      • resourceGuid

        public final String resourceGuid()

        The global identifier used to identify a resource.

        Returns:
        The global identifier used to identify a resource.
      • resourceId

        public final String resourceId()

        The unique identifier for a resource.

        Returns:
        The unique identifier for a resource.
      • accountId

        public final String accountId()

        The Amazon Web Services account that owns the resource.

        Returns:
        The Amazon Web Services account that owns the resource.
      • region

        public final String region()

        The Amazon Web Services Region where the resource is located.

        Returns:
        The Amazon Web Services Region where the resource is located.
      • resourceType

        public final String resourceType()

        The type of resource.

        Returns:
        The type of resource.
      • resourceName

        public final String resourceName()

        The name of the resource.

        Returns:
        The name of the resource.
      • resourceCreationTimeDt

        public final String resourceCreationTimeDt()

        The time when the resource was created.

        Returns:
        The time when the resource was created.
      • resourceDetailCaptureTimeDt

        public final String resourceDetailCaptureTimeDt()

        The timestamp when information about the resource was captured.

        Returns:
        The timestamp when information about the resource was captured.
      • hasFindingsSummary

        public final boolean hasFindingsSummary()
        For responses, this returns true if the service returned a value for the FindingsSummary property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • findingsSummary

        public final List<ResourceFindingsSummary> findingsSummary()

        An aggregated view of security findings associated with a resource.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasFindingsSummary() method.

        Returns:
        An aggregated view of security findings associated with a resource.
      • hasResourceTags

        public final boolean hasResourceTags()
        For responses, this returns true if the service returned a value for the ResourceTags property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • resourceTags

        public final List<ResourceTag> resourceTags()

        The key-value pairs associated with a resource.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasResourceTags() method.

        Returns:
        The key-value pairs associated with a resource.
      • resourceConfig

        public final Document resourceConfig()

        The configuration details of a resource.

        Returns:
        The configuration details of a resource.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)