Interface ResourceResult.Builder

    • Method Detail

      • resourceArn

        ResourceResult.Builder resourceArn​(String resourceArn)

        Specifies the ARN that uniquely identifies a resource.

        Parameters:
        resourceArn - Specifies the ARN that uniquely identifies a resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceId

        ResourceResult.Builder resourceId​(String resourceId)

        The unique identifier for a resource.

        Parameters:
        resourceId - The unique identifier for a resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • accountId

        ResourceResult.Builder accountId​(String accountId)

        The Amazon Web Services account that owns the resource.

        Parameters:
        accountId - The Amazon Web Services account that owns the resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • region

        ResourceResult.Builder region​(String region)

        The Amazon Web Services Region where the resource is located.

        Parameters:
        region - The Amazon Web Services Region where the resource is located.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceCategory

        ResourceResult.Builder resourceCategory​(String resourceCategory)

        The grouping where the resource belongs.

        Parameters:
        resourceCategory - The grouping where the resource belongs.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        ResourceCategory, ResourceCategory
      • resourceType

        ResourceResult.Builder resourceType​(String resourceType)

        The type of resource.

        Parameters:
        resourceType - The type of resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceName

        ResourceResult.Builder resourceName​(String resourceName)

        The name of the resource.

        Parameters:
        resourceName - The name of the resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceCreationTimeDt

        ResourceResult.Builder resourceCreationTimeDt​(String resourceCreationTimeDt)

        The time when the resource was created.

        Parameters:
        resourceCreationTimeDt - The time when the resource was created.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceDetailCaptureTimeDt

        ResourceResult.Builder resourceDetailCaptureTimeDt​(String resourceDetailCaptureTimeDt)

        The timestamp when information about the resource was captured.

        Parameters:
        resourceDetailCaptureTimeDt - The timestamp when information about the resource was captured.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • findingsSummary

        ResourceResult.Builder findingsSummary​(Collection<ResourceFindingsSummary> findingsSummary)

        An aggregated view of security findings associated with a resource.

        Parameters:
        findingsSummary - An aggregated view of security findings associated with a resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • findingsSummary

        ResourceResult.Builder findingsSummary​(ResourceFindingsSummary... findingsSummary)

        An aggregated view of security findings associated with a resource.

        Parameters:
        findingsSummary - An aggregated view of security findings associated with a resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceTags

        ResourceResult.Builder resourceTags​(Collection<ResourceTag> resourceTags)

        The key-value pairs associated with a resource.

        Parameters:
        resourceTags - The key-value pairs associated with a resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceTags

        ResourceResult.Builder resourceTags​(ResourceTag... resourceTags)

        The key-value pairs associated with a resource.

        Parameters:
        resourceTags - The key-value pairs associated with a resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • resourceConfig

        ResourceResult.Builder resourceConfig​(Document resourceConfig)

        The configuration details of a resource.

        Parameters:
        resourceConfig - The configuration details of a resource.
        Returns:
        Returns a reference to this object so that method calls can be chained together.