Interface ResourceScopes.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ResourceScopes.Builder,ResourceScopes>,SdkBuilder<ResourceScopes.Builder,ResourceScopes>,SdkPojo
- Enclosing class:
- ResourceScopes
@Mutable @NotThreadSafe public static interface ResourceScopes.Builder extends SdkPojo, CopyableBuilder<ResourceScopes.Builder,ResourceScopes>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ResourceScopes.BuilderawsOrganizations(Collection<AwsOrganizationScope> awsOrganizations)A list of Organizations scopes to include in the query results.ResourceScopes.BuilderawsOrganizations(Consumer<AwsOrganizationScope.Builder>... awsOrganizations)A list of Organizations scopes to include in the query results.ResourceScopes.BuilderawsOrganizations(AwsOrganizationScope... awsOrganizations)A list of Organizations scopes to include in the query results.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
awsOrganizations
ResourceScopes.Builder awsOrganizations(Collection<AwsOrganizationScope> awsOrganizations)
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
- Parameters:
awsOrganizations- A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
awsOrganizations
ResourceScopes.Builder awsOrganizations(AwsOrganizationScope... awsOrganizations)
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
- Parameters:
awsOrganizations- A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
awsOrganizations
ResourceScopes.Builder awsOrganizations(Consumer<AwsOrganizationScope.Builder>... awsOrganizations)
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
This is a convenience method that creates an instance of theAwsOrganizationScope.Builderavoiding the need to create one manually viaAwsOrganizationScope.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#awsOrganizations(List.) - Parameters:
awsOrganizations- a consumer that will call methods onAwsOrganizationScope.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#awsOrganizations(java.util.Collection)
-
-