Class ResourceSeverityBreakdown
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ResourceSeverityBreakdown
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceSeverityBreakdown.Builder,ResourceSeverityBreakdown>
@Generated("software.amazon.awssdk:codegen")
public final class ResourceSeverityBreakdown
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ResourceSeverityBreakdown.Builder,ResourceSeverityBreakdown>
A comprehensive distribution of security findings by severity level for Amazon Web Services resources.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Integercritical()The number of findings with a severity level of critical.final booleanfinal booleanequalsBySdkFields(Object obj) final Integerfatal()The number of findings with a severity level of fatal.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Integerhigh()The number of findings with a severity level of high.final IntegerThe number of findings that provide security-related information.final Integerlow()The number of findings with a severity level of low.final Integermedium()The number of findings with a severity level of medium.final Integerother()The number of findings not in any of the severity categories.static Class<? extends ResourceSeverityBreakdown.Builder>final StringtoString()Returns a string representation of this object.final Integerunknown()The number of findings with a severity level cannot be determined.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
other
The number of findings not in any of the severity categories.
- Returns:
- The number of findings not in any of the severity categories.
-
fatal
The number of findings with a severity level of fatal.
- Returns:
- The number of findings with a severity level of fatal.
-
critical
The number of findings with a severity level of critical.
- Returns:
- The number of findings with a severity level of critical.
-
high
The number of findings with a severity level of high.
- Returns:
- The number of findings with a severity level of high.
-
medium
The number of findings with a severity level of medium.
- Returns:
- The number of findings with a severity level of medium.
-
low
The number of findings with a severity level of low.
- Returns:
- The number of findings with a severity level of low.
-
informational
The number of findings that provide security-related information.
- Returns:
- The number of findings that provide security-related information.
-
unknown
The number of findings with a severity level cannot be determined.
- Returns:
- The number of findings with a severity level cannot be determined.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceSeverityBreakdown.Builder,ResourceSeverityBreakdown>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-