Enum ResourcesNumberField

    • Enum Constant Detail

      • FINDINGS_SUMMARY_TOTAL_FINDINGS

        public static final ResourcesNumberField FINDINGS_SUMMARY_TOTAL_FINDINGS
      • FINDINGS_SUMMARY_SEVERITIES_OTHER

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_OTHER
      • FINDINGS_SUMMARY_SEVERITIES_FATAL

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_FATAL
      • FINDINGS_SUMMARY_SEVERITIES_CRITICAL

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_CRITICAL
      • FINDINGS_SUMMARY_SEVERITIES_HIGH

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_HIGH
      • FINDINGS_SUMMARY_SEVERITIES_MEDIUM

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_MEDIUM
      • FINDINGS_SUMMARY_SEVERITIES_LOW

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_LOW
      • FINDINGS_SUMMARY_SEVERITIES_INFORMATIONAL

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_INFORMATIONAL
      • FINDINGS_SUMMARY_SEVERITIES_UNKNOWN

        public static final ResourcesNumberField FINDINGS_SUMMARY_SEVERITIES_UNKNOWN
    • Method Detail

      • values

        public static ResourcesNumberField[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (ResourcesNumberField c : ResourcesNumberField.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static ResourcesNumberField valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • fromValue

        public static ResourcesNumberField fromValue​(String value)
        Use this in place of valueOf to convert the raw string returned by the service into the enum value.
        Parameters:
        value - real value
        Returns:
        ResourcesNumberField corresponding to the value