Enum ResourcesStringField
- java.lang.Object
-
- java.lang.Enum<ResourcesStringField>
-
- software.amazon.awssdk.services.securityhub.model.ResourcesStringField
-
- All Implemented Interfaces:
Serializable,Comparable<ResourcesStringField>
@Generated("software.amazon.awssdk:codegen") public enum ResourcesStringField extends Enum<ResourcesStringField>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_IDFINDINGS_SUMMARY_FINDING_TYPEFINDINGS_SUMMARY_PRODUCT_NAMEREGIONRESOURCE_ARNRESOURCE_CATEGORYRESOURCE_IDRESOURCE_NAMERESOURCE_TYPEUNKNOWN_TO_SDK_VERSION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ResourcesStringFieldfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<ResourcesStringField>knownValues()StringtoString()static ResourcesStringFieldvalueOf(String name)Returns the enum constant of this type with the specified name.static ResourcesStringField[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
RESOURCE_ARN
public static final ResourcesStringField RESOURCE_ARN
-
RESOURCE_ID
public static final ResourcesStringField RESOURCE_ID
-
ACCOUNT_ID
public static final ResourcesStringField ACCOUNT_ID
-
REGION
public static final ResourcesStringField REGION
-
RESOURCE_CATEGORY
public static final ResourcesStringField RESOURCE_CATEGORY
-
RESOURCE_TYPE
public static final ResourcesStringField RESOURCE_TYPE
-
RESOURCE_NAME
public static final ResourcesStringField RESOURCE_NAME
-
FINDINGS_SUMMARY_FINDING_TYPE
public static final ResourcesStringField FINDINGS_SUMMARY_FINDING_TYPE
-
FINDINGS_SUMMARY_PRODUCT_NAME
public static final ResourcesStringField FINDINGS_SUMMARY_PRODUCT_NAME
-
UNKNOWN_TO_SDK_VERSION
public static final ResourcesStringField UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static ResourcesStringField[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ResourcesStringField c : ResourcesStringField.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ResourcesStringField valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<ResourcesStringField>
-
fromValue
public static ResourcesStringField fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- ResourcesStringField corresponding to the value
-
knownValues
public static Set<ResourcesStringField> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownResourcesStringFields
-
-