Enum ResourcesTrendsStringField
- java.lang.Object
-
- java.lang.Enum<ResourcesTrendsStringField>
-
- software.amazon.awssdk.services.securityhub.model.ResourcesTrendsStringField
-
- All Implemented Interfaces:
Serializable,Comparable<ResourcesTrendsStringField>
@Generated("software.amazon.awssdk:codegen") public enum ResourcesTrendsStringField extends Enum<ResourcesTrendsStringField>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_IDREGIONRESOURCE_CATEGORYRESOURCE_TYPEUNKNOWN_TO_SDK_VERSION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ResourcesTrendsStringFieldfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<ResourcesTrendsStringField>knownValues()StringtoString()static ResourcesTrendsStringFieldvalueOf(String name)Returns the enum constant of this type with the specified name.static ResourcesTrendsStringField[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
ACCOUNT_ID
public static final ResourcesTrendsStringField ACCOUNT_ID
-
REGION
public static final ResourcesTrendsStringField REGION
-
RESOURCE_TYPE
public static final ResourcesTrendsStringField RESOURCE_TYPE
-
RESOURCE_CATEGORY
public static final ResourcesTrendsStringField RESOURCE_CATEGORY
-
UNKNOWN_TO_SDK_VERSION
public static final ResourcesTrendsStringField UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static ResourcesTrendsStringField[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ResourcesTrendsStringField c : ResourcesTrendsStringField.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ResourcesTrendsStringField valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<ResourcesTrendsStringField>
-
fromValue
public static ResourcesTrendsStringField fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- ResourcesTrendsStringField corresponding to the value
-
knownValues
public static Set<ResourcesTrendsStringField> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownResourcesTrendsStringFields
-
-