Class ResourcesTrendsValues
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ResourcesTrendsValues
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourcesTrendsValues.Builder,ResourcesTrendsValues>
@Generated("software.amazon.awssdk:codegen")
public final class ResourcesTrendsValues
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ResourcesTrendsValues.Builder,ResourcesTrendsValues>
Contains the aggregated resource count values for a specific point in the resources trend timeline.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ResourcesCountThe resource count statistics for this data point in the trend timeline.static Class<? extends ResourcesTrendsValues.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
resourcesCount
The resource count statistics for this data point in the trend timeline.
- Returns:
- The resource count statistics for this data point in the trend timeline.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourcesTrendsValues.Builder,ResourcesTrendsValues>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-