Class RouteSetDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RouteSetDetails.Builder,RouteSetDetails>
Provides details about the routes in the route table.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic RouteSetDetails.Builderbuilder()final StringThe ID of the carrier gateway.final StringThe Amazon Resource Name (ARN) of the core network.final StringThe IPv4 CIDR block used for the destination match.final StringThe IPv6 CIDR block used for the destination match.final StringThe prefix of the destination Amazon Web Services service.final StringThe ID of the egress-only internet gateway.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe ID of a gateway attached to your VPC.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ID of a NAT instance in your VPC.final StringThe ID of the Amazon Web Services account that owns the instance.final StringThe ID of the local gateway.final StringThe ID of a NAT gateway.final StringThe ID of the network interface.final Stringorigin()Describes how the route was created.static Class<? extends RouteSetDetails.Builder>final Stringstate()The state of the route.final StringtoString()Returns a string representation of this object.final StringThe ID of a transit gateway.final StringThe ID of a VPC peering connection.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
carrierGatewayId
The ID of the carrier gateway.
- Returns:
- The ID of the carrier gateway.
-
coreNetworkArn
The Amazon Resource Name (ARN) of the core network.
- Returns:
- The Amazon Resource Name (ARN) of the core network.
-
destinationCidrBlock
The IPv4 CIDR block used for the destination match.
- Returns:
- The IPv4 CIDR block used for the destination match.
-
destinationIpv6CidrBlock
The IPv6 CIDR block used for the destination match.
- Returns:
- The IPv6 CIDR block used for the destination match.
-
destinationPrefixListId
The prefix of the destination Amazon Web Services service.
- Returns:
- The prefix of the destination Amazon Web Services service.
-
egressOnlyInternetGatewayId
The ID of the egress-only internet gateway.
- Returns:
- The ID of the egress-only internet gateway.
-
gatewayId
The ID of a gateway attached to your VPC.
- Returns:
- The ID of a gateway attached to your VPC.
-
instanceId
The ID of a NAT instance in your VPC.
- Returns:
- The ID of a NAT instance in your VPC.
-
instanceOwnerId
The ID of the Amazon Web Services account that owns the instance.
- Returns:
- The ID of the Amazon Web Services account that owns the instance.
-
localGatewayId
The ID of the local gateway.
- Returns:
- The ID of the local gateway.
-
natGatewayId
The ID of a NAT gateway.
- Returns:
- The ID of a NAT gateway.
-
networkInterfaceId
The ID of the network interface.
- Returns:
- The ID of the network interface.
-
origin
Describes how the route was created.
- Returns:
- Describes how the route was created.
-
state
The state of the route.
- Returns:
- The state of the route.
-
transitGatewayId
The ID of a transit gateway.
- Returns:
- The ID of a transit gateway.
-
vpcPeeringConnectionId
The ID of a VPC peering connection.
- Returns:
- The ID of a VPC peering connection.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RouteSetDetails.Builder,RouteSetDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-