Class RuleGroupSourceListDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RuleGroupSourceListDetails.Builder,RuleGroupSourceListDetails>
Stateful inspection criteria for a domain list rule group.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringIndicates whether to allow or deny access to the domains listed inTargets.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Targets property.final booleanFor responses, this returns true if the service returned a value for the TargetTypes property.static Class<? extends RuleGroupSourceListDetails.Builder>targets()The domains that you want to inspect for in your traffic flows.The protocols that you want to inspect.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
generatedRulesType
Indicates whether to allow or deny access to the domains listed in
Targets.- Returns:
- Indicates whether to allow or deny access to the domains listed in
Targets.
-
hasTargetTypes
public final boolean hasTargetTypes()For responses, this returns true if the service returned a value for the TargetTypes property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
targetTypes
The protocols that you want to inspect. Specify
LS_SNIfor HTTPS. SpecifyHTTP_HOSTfor HTTP. You can specify either or both.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTargetTypes()method.- Returns:
- The protocols that you want to inspect. Specify
LS_SNIfor HTTPS. SpecifyHTTP_HOSTfor HTTP. You can specify either or both.
-
hasTargets
public final boolean hasTargets()For responses, this returns true if the service returned a value for the Targets property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
targets
The domains that you want to inspect for in your traffic flows. You can provide full domain names, or use the '.' prefix as a wildcard. For example,
.example.commatches all domains that end withexample.com.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTargets()method.- Returns:
- The domains that you want to inspect for in your traffic flows. You can provide full domain names, or use
the '.' prefix as a wildcard. For example,
.example.commatches all domains that end withexample.com.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RuleGroupSourceListDetails.Builder,RuleGroupSourceListDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-