Class RuleGroupSourceStatefulRulesHeaderDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RuleGroupSourceStatefulRulesHeaderDetails.Builder,RuleGroupSourceStatefulRulesHeaderDetails>
The inspection criteria for a stateful rule.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe destination IP address or address range to inspect for, in CIDR notation.final StringThe destination port to inspect for.final StringThe direction of traffic flow to inspect.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringprotocol()The protocol to inspect for.static Class<? extends RuleGroupSourceStatefulRulesHeaderDetails.Builder>final Stringsource()The source IP address or address range to inspect for, in CIDR notation.final StringThe source port to inspect for.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
destination
The destination IP address or address range to inspect for, in CIDR notation. To match with any address, specify
ANY.- Returns:
- The destination IP address or address range to inspect for, in CIDR notation. To match with any address,
specify
ANY.
-
destinationPort
The destination port to inspect for. You can specify an individual port, such as
1994. You also can specify a port range, such as1990:1994. To match with any port, specifyANY.- Returns:
- The destination port to inspect for. You can specify an individual port, such as
1994. You also can specify a port range, such as1990:1994. To match with any port, specifyANY.
-
direction
The direction of traffic flow to inspect. If set to
ANY, the inspection matches bidirectional traffic, both from the source to the destination and from the destination to the source. If set toFORWARD, the inspection only matches traffic going from the source to the destination.- Returns:
- The direction of traffic flow to inspect. If set to
ANY, the inspection matches bidirectional traffic, both from the source to the destination and from the destination to the source. If set toFORWARD, the inspection only matches traffic going from the source to the destination.
-
protocol
The protocol to inspect for. To inspector for all protocols, use
IP.- Returns:
- The protocol to inspect for. To inspector for all protocols, use
IP.
-
source
The source IP address or address range to inspect for, in CIDR notation. To match with any address, specify
ANY.- Returns:
- The source IP address or address range to inspect for, in CIDR notation. To match with any address,
specify
ANY.
-
sourcePort
The source port to inspect for. You can specify an individual port, such as
1994. You also can specify a port range, such as1990:1994. To match with any port, specifyANY.- Returns:
- The source port to inspect for. You can specify an individual port, such as
1994. You also can specify a port range, such as1990:1994. To match with any port, specifyANY.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RuleGroupSourceStatefulRulesHeaderDetails.Builder,RuleGroupSourceStatefulRulesHeaderDetails>
-
builder
-
serializableBuilderClass
public static Class<? extends RuleGroupSourceStatefulRulesHeaderDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-