Class RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
java.lang.Object
software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.Builder,RuleGroupSourceStatelessRuleMatchAttributesSourcePorts>
@Generated("software.amazon.awssdk:codegen")
public final class RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.Builder,RuleGroupSourceStatelessRuleMatchAttributesSourcePorts>
A port range to specify the source ports to inspect for.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final IntegerfromPort()The starting port value for the port range.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.Builder>final IntegertoPort()The ending port value for the port range.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
fromPort
The starting port value for the port range.
- Returns:
- The starting port value for the port range.
-
toPort
The ending port value for the port range.
- Returns:
- The ending port value for the port range.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-