Class RuleGroupSourceStatelessRuleMatchAttributesTcpFlags
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RuleGroupSourceStatelessRuleMatchAttributesTcpFlags.Builder,RuleGroupSourceStatelessRuleMatchAttributesTcpFlags>
A set of TCP flags and masks to inspect for.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) flags()Defines the flags from theMaskssetting that must be set in order for the packet to match.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanhasFlags()For responses, this returns true if the service returned a value for the Flags property.final inthashCode()final booleanhasMasks()For responses, this returns true if the service returned a value for the Masks property.masks()The set of flags to consider in the inspection.static Class<? extends RuleGroupSourceStatelessRuleMatchAttributesTcpFlags.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasFlags
public final boolean hasFlags()For responses, this returns true if the service returned a value for the Flags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
flags
Defines the flags from the
Maskssetting that must be set in order for the packet to match. Flags that are listed must be set. Flags that are not listed must not be set.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasFlags()method.- Returns:
- Defines the flags from the
Maskssetting that must be set in order for the packet to match. Flags that are listed must be set. Flags that are not listed must not be set.
-
hasMasks
public final boolean hasMasks()For responses, this returns true if the service returned a value for the Masks property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
masks
The set of flags to consider in the inspection. If not specified, then all flags are inspected.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasMasks()method.- Returns:
- The set of flags to consider in the inspection. If not specified, then all flags are inspected.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends RuleGroupSourceStatelessRuleMatchAttributesTcpFlags.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-