Class RuleGroupSourceStatelessRulesAndCustomActionsDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RuleGroupSourceStatelessRulesAndCustomActionsDetails.Builder,RuleGroupSourceStatelessRulesAndCustomActionsDetails>
Stateless rules and custom actions for a stateless rule group.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Custom actions for the rule group.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the CustomActions property.final inthashCode()final booleanFor responses, this returns true if the service returned a value for the StatelessRules property.static Class<? extends RuleGroupSourceStatelessRulesAndCustomActionsDetails.Builder>Stateless rules for the rule group.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasCustomActions
public final boolean hasCustomActions()For responses, this returns true if the service returned a value for the CustomActions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
customActions
Custom actions for the rule group.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCustomActions()method.- Returns:
- Custom actions for the rule group.
-
hasStatelessRules
public final boolean hasStatelessRules()For responses, this returns true if the service returned a value for the StatelessRules property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
statelessRules
Stateless rules for the rule group.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStatelessRules()method.- Returns:
- Stateless rules for the rule group.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends RuleGroupSourceStatelessRulesAndCustomActionsDetails.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-