Interface SecurityControl.Builder

    • Method Detail

      • securityControlId

        SecurityControl.Builder securityControlId​(String securityControlId)

        The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number, such as APIGateway.3.

        Parameters:
        securityControlId - The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number, such as APIGateway.3.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • securityControlArn

        SecurityControl.Builder securityControlArn​(String securityControlArn)

        The Amazon Resource Name (ARN) for a security control across standards, such as arn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1. This parameter doesn't mention a specific standard.

        Parameters:
        securityControlArn - The Amazon Resource Name (ARN) for a security control across standards, such as arn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1. This parameter doesn't mention a specific standard.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • title

        SecurityControl.Builder title​(String title)

        The title of a security control.

        Parameters:
        title - The title of a security control.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • description

        SecurityControl.Builder description​(String description)

        The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.

        Parameters:
        description - The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • remediationUrl

        SecurityControl.Builder remediationUrl​(String remediationUrl)

        A link to Security Hub documentation that explains how to remediate a failed finding for a security control.

        Parameters:
        remediationUrl - A link to Security Hub documentation that explains how to remediate a failed finding for a security control.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • securityControlStatus

        SecurityControl.Builder securityControlStatus​(String securityControlStatus)

        The enablement status of a security control in a specific standard.

        Parameters:
        securityControlStatus - The enablement status of a security control in a specific standard.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        ControlStatus, ControlStatus
      • securityControlStatus

        SecurityControl.Builder securityControlStatus​(ControlStatus securityControlStatus)

        The enablement status of a security control in a specific standard.

        Parameters:
        securityControlStatus - The enablement status of a security control in a specific standard.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        ControlStatus, ControlStatus