Class SecurityControlCustomParameter
java.lang.Object
software.amazon.awssdk.services.securityhub.model.SecurityControlCustomParameter
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SecurityControlCustomParameter.Builder,SecurityControlCustomParameter>
@Generated("software.amazon.awssdk:codegen")
public final class SecurityControlCustomParameter
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<SecurityControlCustomParameter.Builder,SecurityControlCustomParameter>
A list of security controls and control parameter values that are included in a configuration policy.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Parameters property.final Map<String,ParameterConfiguration> An object that specifies parameter values for a control in a configuration policy.final StringThe ID of the security control.static Class<? extends SecurityControlCustomParameter.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
securityControlId
The ID of the security control.
- Returns:
- The ID of the security control.
-
hasParameters
public final boolean hasParameters()For responses, this returns true if the service returned a value for the Parameters property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
parameters
An object that specifies parameter values for a control in a configuration policy.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasParameters()method.- Returns:
- An object that specifies parameter values for a control in a configuration policy.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SecurityControlCustomParameter.Builder,SecurityControlCustomParameter>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-