Interface SecurityControlDefinition.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<SecurityControlDefinition.Builder,SecurityControlDefinition>,SdkBuilder<SecurityControlDefinition.Builder,SecurityControlDefinition>,SdkPojo
- Enclosing class:
- SecurityControlDefinition
public static interface SecurityControlDefinition.Builder extends SdkPojo, CopyableBuilder<SecurityControlDefinition.Builder,SecurityControlDefinition>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description SecurityControlDefinition.BuildercurrentRegionAvailability(String currentRegionAvailability)Specifies whether a security control is available in the current Amazon Web Services Region.SecurityControlDefinition.BuildercurrentRegionAvailability(RegionAvailabilityStatus currentRegionAvailability)Specifies whether a security control is available in the current Amazon Web Services Region.SecurityControlDefinition.Builderdescription(String description)The description of a security control across standards.SecurityControlDefinition.BuilderremediationUrl(String remediationUrl)A link to Security Hub documentation that explains how to remediate a failed finding for a security control.SecurityControlDefinition.BuildersecurityControlId(String securityControlId)The unique identifier of a security control across standards.SecurityControlDefinition.BuilderseverityRating(String severityRating)The severity of a security control.SecurityControlDefinition.BuilderseverityRating(SeverityRating severityRating)The severity of a security control.SecurityControlDefinition.Buildertitle(String title)The title of a security control.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFields
-
-
-
-
Method Detail
-
securityControlId
SecurityControlDefinition.Builder securityControlId(String securityControlId)
The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number (for example, APIGateway.3). This parameter differs from
SecurityControlArn, which is a unique Amazon Resource Name (ARN) assigned to a control. The ARN references the security control ID (for example, arn:aws:securityhub:eu-central-1:123456789012:security-control/APIGateway.3).- Parameters:
securityControlId- The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number (for example, APIGateway.3). This parameter differs fromSecurityControlArn, which is a unique Amazon Resource Name (ARN) assigned to a control. The ARN references the security control ID (for example, arn:aws:securityhub:eu-central-1:123456789012:security-control/APIGateway.3).- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
title
SecurityControlDefinition.Builder title(String title)
The title of a security control.
- Parameters:
title- The title of a security control.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
description
SecurityControlDefinition.Builder description(String description)
The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.
- Parameters:
description- The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
remediationUrl
SecurityControlDefinition.Builder remediationUrl(String remediationUrl)
A link to Security Hub documentation that explains how to remediate a failed finding for a security control.
- Parameters:
remediationUrl- A link to Security Hub documentation that explains how to remediate a failed finding for a security control.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
severityRating
SecurityControlDefinition.Builder severityRating(String severityRating)
The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
- Parameters:
severityRating- The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
SeverityRating,SeverityRating
-
severityRating
SecurityControlDefinition.Builder severityRating(SeverityRating severityRating)
The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
- Parameters:
severityRating- The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
SeverityRating,SeverityRating
-
currentRegionAvailability
SecurityControlDefinition.Builder currentRegionAvailability(String currentRegionAvailability)
Specifies whether a security control is available in the current Amazon Web Services Region.
- Parameters:
currentRegionAvailability- Specifies whether a security control is available in the current Amazon Web Services Region.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RegionAvailabilityStatus,RegionAvailabilityStatus
-
currentRegionAvailability
SecurityControlDefinition.Builder currentRegionAvailability(RegionAvailabilityStatus currentRegionAvailability)
Specifies whether a security control is available in the current Amazon Web Services Region.
- Parameters:
currentRegionAvailability- Specifies whether a security control is available in the current Amazon Web Services Region.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RegionAvailabilityStatus,RegionAvailabilityStatus
-
-