Class SecurityControlParameter
java.lang.Object
software.amazon.awssdk.services.securityhub.model.SecurityControlParameter
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SecurityControlParameter.Builder,SecurityControlParameter>
@Generated("software.amazon.awssdk:codegen")
public final class SecurityControlParameter
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<SecurityControlParameter.Builder,SecurityControlParameter>
A parameter that a security control accepts.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasValue()For responses, this returns true if the service returned a value for the Value property.final Stringname()The name of astatic Class<? extends SecurityControlParameter.Builder>final StringtoString()Returns a string representation of this object.value()The current value of a control parameter.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of a
- Returns:
- The name of a
-
hasValue
public final boolean hasValue()For responses, this returns true if the service returned a value for the Value property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
value
The current value of a control parameter.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasValue()method.- Returns:
- The current value of a control parameter.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SecurityControlParameter.Builder,SecurityControlParameter>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-