Class SecurityHubPolicy
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SecurityHubPolicy.Builder,SecurityHubPolicy>
An object that defines how Security Hub CSPM is configured. The configuration policy includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic SecurityHubPolicy.Builderbuilder()A list that defines which security standards are enabled in the configuration policy.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the EnabledStandardIdentifiers property.final inthashCode()An object that defines which security controls are enabled in the configuration policy.static Class<? extends SecurityHubPolicy.Builder>final BooleanIndicates whether Security Hub CSPM is enabled in the policy.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
serviceEnabled
Indicates whether Security Hub CSPM is enabled in the policy.
- Returns:
- Indicates whether Security Hub CSPM is enabled in the policy.
-
hasEnabledStandardIdentifiers
public final boolean hasEnabledStandardIdentifiers()For responses, this returns true if the service returned a value for the EnabledStandardIdentifiers property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
enabledStandardIdentifiers
A list that defines which security standards are enabled in the configuration policy.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasEnabledStandardIdentifiers()method.- Returns:
- A list that defines which security standards are enabled in the configuration policy.
-
securityControlsConfiguration
An object that defines which security controls are enabled in the configuration policy. The enablement status of a control is aligned across all of the enabled standards in an account.
- Returns:
- An object that defines which security controls are enabled in the configuration policy. The enablement status of a control is aligned across all of the enabled standards in an account.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SecurityHubPolicy.Builder,SecurityHubPolicy>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-