Class SensitiveDataDetections

java.lang.Object
software.amazon.awssdk.services.securityhub.model.SensitiveDataDetections
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<SensitiveDataDetections.Builder,SensitiveDataDetections>

@Generated("software.amazon.awssdk:codegen") public final class SensitiveDataDetections extends Object implements SdkPojo, Serializable, ToCopyableBuilder<SensitiveDataDetections.Builder,SensitiveDataDetections>

The list of detected instances of sensitive data.

See Also:
  • Method Details

    • count

      public final Long count()

      The total number of occurrences of sensitive data that were detected.

      Returns:
      The total number of occurrences of sensitive data that were detected.
    • type

      public final String type()

      The type of sensitive data that was detected. For example, the type might indicate that the data is an email address.

      Returns:
      The type of sensitive data that was detected. For example, the type might indicate that the data is an email address.
    • occurrences

      public final Occurrences occurrences()

      Details about the sensitive data that was detected.

      Returns:
      Details about the sensitive data that was detected.
    • toBuilder

      public SensitiveDataDetections.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<SensitiveDataDetections.Builder,SensitiveDataDetections>
    • builder

      public static SensitiveDataDetections.Builder builder()
    • serializableBuilderClass

      public static Class<? extends SensitiveDataDetections.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo