Class SensitiveDataResult
java.lang.Object
software.amazon.awssdk.services.securityhub.model.SensitiveDataResult
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SensitiveDataResult.Builder,SensitiveDataResult>
@Generated("software.amazon.awssdk:codegen")
public final class SensitiveDataResult
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<SensitiveDataResult.Builder,SensitiveDataResult>
Contains a detected instance of sensitive data that are based on built-in identifiers.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic SensitiveDataResult.Builderbuilder()final Stringcategory()The category of sensitive data that was detected.final List<SensitiveDataDetections>The list of detected instances of sensitive data.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Detections property.final inthashCode()static Class<? extends SensitiveDataResult.Builder>final StringtoString()Returns a string representation of this object.final LongThe total number of occurrences of sensitive data.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
category
The category of sensitive data that was detected. For example, the category can indicate that the sensitive data involved credentials, financial information, or personal information.
- Returns:
- The category of sensitive data that was detected. For example, the category can indicate that the sensitive data involved credentials, financial information, or personal information.
-
hasDetections
public final boolean hasDetections()For responses, this returns true if the service returned a value for the Detections property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
detections
The list of detected instances of sensitive data.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasDetections()method.- Returns:
- The list of detected instances of sensitive data.
-
totalCount
The total number of occurrences of sensitive data.
- Returns:
- The total number of occurrences of sensitive data.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SensitiveDataResult.Builder,SensitiveDataResult>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-