Class ServiceNowDetail
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>
Information about a ServiceNow ITSM integration.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal ConnectorAuthStatusThe status of the authorization between ServiceNow and the service.final StringThe status of the authorization between ServiceNow and the service.static ServiceNowDetail.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe instanceName of ServiceNow ITSM.final StringThe Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.static Class<? extends ServiceNowDetail.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
instanceName
The instanceName of ServiceNow ITSM.
- Returns:
- The instanceName of ServiceNow ITSM.
-
secretArn
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
- Returns:
- The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
-
authStatus
The status of the authorization between ServiceNow and the service.
If the service returns an enum value that is not available in the current SDK version,
authStatuswill returnConnectorAuthStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromauthStatusAsString().- Returns:
- The status of the authorization between ServiceNow and the service.
- See Also:
-
authStatusAsString
The status of the authorization between ServiceNow and the service.
If the service returns an enum value that is not available in the current SDK version,
authStatuswill returnConnectorAuthStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromauthStatusAsString().- Returns:
- The status of the authorization between ServiceNow and the service.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-