Interface ServiceNowDetail.Builder

All Superinterfaces:
Buildable, CopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>, SdkBuilder<ServiceNowDetail.Builder,ServiceNowDetail>, SdkPojo
Enclosing class:
ServiceNowDetail

@Mutable @NotThreadSafe public static interface ServiceNowDetail.Builder extends SdkPojo, CopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>
  • Method Details

    • instanceName

      ServiceNowDetail.Builder instanceName(String instanceName)

      The instanceName of ServiceNow ITSM.

      Parameters:
      instanceName - The instanceName of ServiceNow ITSM.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • secretArn

      ServiceNowDetail.Builder secretArn(String secretArn)

      The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.

      Parameters:
      secretArn - The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • authStatus

      ServiceNowDetail.Builder authStatus(String authStatus)

      The status of the authorization between ServiceNow and the service.

      Parameters:
      authStatus - The status of the authorization between ServiceNow and the service.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • authStatus

      The status of the authorization between ServiceNow and the service.

      Parameters:
      authStatus - The status of the authorization between ServiceNow and the service.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also: