Interface ServiceNowProviderConfiguration.Builder

    • Method Detail

      • instanceName

        ServiceNowProviderConfiguration.Builder instanceName​(String instanceName)

        The instance name of ServiceNow ITSM.

        Parameters:
        instanceName - The instance name of ServiceNow ITSM.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • secretArn

        ServiceNowProviderConfiguration.Builder secretArn​(String secretArn)

        The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.

        Parameters:
        secretArn - The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
        Returns:
        Returns a reference to this object so that method calls can be chained together.