Class ServiceNowUpdateConfiguration
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ServiceNowUpdateConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>
@Generated("software.amazon.awssdk:codegen")
public final class ServiceNowUpdateConfiguration
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>
The parameters used to modify an existing ServiceNow integration.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.static Class<? extends ServiceNowUpdateConfiguration.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
secretArn
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
- Returns:
- The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-