Interface ServiceNowUpdateConfiguration.Builder

All Superinterfaces:
Buildable, CopyableBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>, SdkBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>, SdkPojo
Enclosing class:
ServiceNowUpdateConfiguration

@Mutable @NotThreadSafe public static interface ServiceNowUpdateConfiguration.Builder extends SdkPojo, CopyableBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>
  • Method Details

    • secretArn

      The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.

      Parameters:
      secretArn - The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
      Returns:
      Returns a reference to this object so that method calls can be chained together.