Class SeverityUpdate
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SeverityUpdate.Builder,SeverityUpdate>
Updates to the severity information for a finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic SeverityUpdate.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final SeverityLabellabel()The severity value of the finding.final StringThe severity value of the finding.final IntegerThe normalized severity for the finding.final Doubleproduct()The native severity as defined by the Amazon Web Services service or integrated partner product that generated the finding.static Class<? extends SeverityUpdate.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
normalized
The normalized severity for the finding. This attribute is to be deprecated in favor of
Label.If you provide
Normalizedand don't provideLabel,Labelis set automatically as follows.-
0 -
INFORMATIONAL -
1–39 -
LOW -
40–69 -
MEDIUM -
70–89 -
HIGH -
90–100 -
CRITICAL
- Returns:
- The normalized severity for the finding. This attribute is to be deprecated in favor of
Label.If you provide
Normalizedand don't provideLabel,Labelis set automatically as follows.-
0 -
INFORMATIONAL -
1–39 -
LOW -
40–69 -
MEDIUM -
70–89 -
HIGH -
90–100 -
CRITICAL
-
-
-
product
The native severity as defined by the Amazon Web Services service or integrated partner product that generated the finding.
- Returns:
- The native severity as defined by the Amazon Web Services service or integrated partner product that generated the finding.
-
label
The severity value of the finding. The allowed values are the following.
-
INFORMATIONAL- No issue was found. -
LOW- The issue does not require action on its own. -
MEDIUM- The issue must be addressed but not urgently. -
HIGH- The issue must be addressed as a priority. -
CRITICAL- The issue must be remediated immediately to avoid it escalating.
If the service returns an enum value that is not available in the current SDK version,
labelwill returnSeverityLabel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlabelAsString().- Returns:
- The severity value of the finding. The allowed values are the following.
-
INFORMATIONAL- No issue was found. -
LOW- The issue does not require action on its own. -
MEDIUM- The issue must be addressed but not urgently. -
HIGH- The issue must be addressed as a priority. -
CRITICAL- The issue must be remediated immediately to avoid it escalating.
-
- See Also:
-
-
labelAsString
The severity value of the finding. The allowed values are the following.
-
INFORMATIONAL- No issue was found. -
LOW- The issue does not require action on its own. -
MEDIUM- The issue must be addressed but not urgently. -
HIGH- The issue must be addressed as a priority. -
CRITICAL- The issue must be remediated immediately to avoid it escalating.
If the service returns an enum value that is not available in the current SDK version,
labelwill returnSeverityLabel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlabelAsString().- Returns:
- The severity value of the finding. The allowed values are the following.
-
INFORMATIONAL- No issue was found. -
LOW- The issue does not require action on its own. -
MEDIUM- The issue must be addressed but not urgently. -
HIGH- The issue must be addressed as a priority. -
CRITICAL- The issue must be remediated immediately to avoid it escalating.
-
- See Also:
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SeverityUpdate.Builder,SeverityUpdate>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-