Class SortCriterion
java.lang.Object
software.amazon.awssdk.services.securityhub.model.SortCriterion
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SortCriterion.Builder,SortCriterion>
@Generated("software.amazon.awssdk:codegen")
public final class SortCriterion
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<SortCriterion.Builder,SortCriterion>
A collection of finding attributes used to sort findings.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic SortCriterion.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final Stringfield()The finding attribute used to sort findings.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends SortCriterion.Builder>final SortOrderThe order used to sort findings.final StringThe order used to sort findings.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
field
The finding attribute used to sort findings.
- Returns:
- The finding attribute used to sort findings.
-
sortOrder
The order used to sort findings.
If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- The order used to sort findings.
- See Also:
-
sortOrderAsString
The order used to sort findings.
If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- The order used to sort findings.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SortCriterion.Builder,SortCriterion>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-