Class Standard
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Standard
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Standard.Builder,Standard>
@Generated("software.amazon.awssdk:codegen")
public final class Standard
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Standard.Builder,Standard>
Provides information about a specific security standard.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Standard.Builderbuilder()final StringA description of the standard.final BooleanWhether the standard is enabled by default.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the standard.static Class<? extends Standard.Builder>final StringThe ARN of the standard.final StandardsManagedByProvides details about the management of a standard.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsArn
The ARN of the standard.
- Returns:
- The ARN of the standard.
-
name
The name of the standard.
- Returns:
- The name of the standard.
-
description
A description of the standard.
- Returns:
- A description of the standard.
-
enabledByDefault
Whether the standard is enabled by default. When Security Hub CSPM is enabled from the console, if a standard is enabled by default, the check box for that standard is selected by default.
When Security Hub CSPM is enabled using the
EnableSecurityHubAPI operation, the standard is enabled by default unlessEnableDefaultStandardsis set tofalse.- Returns:
- Whether the standard is enabled by default. When Security Hub CSPM is enabled from the console, if a
standard is enabled by default, the check box for that standard is selected by default.
When Security Hub CSPM is enabled using the
EnableSecurityHubAPI operation, the standard is enabled by default unlessEnableDefaultStandardsis set tofalse.
-
standardsManagedBy
Provides details about the management of a standard.
- Returns:
- Provides details about the management of a standard.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Standard.Builder,Standard>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-