Class StandardsControlAssociationId
java.lang.Object
software.amazon.awssdk.services.securityhub.model.StandardsControlAssociationId
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<StandardsControlAssociationId.Builder,StandardsControlAssociationId>
@Generated("software.amazon.awssdk:codegen")
public final class StandardsControlAssociationId
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<StandardsControlAssociationId.Builder,StandardsControlAssociationId>
An array with one or more objects that includes a security control (identified with SecurityControlId,
SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard. The
security control ID or ARN is the same across standards.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe unique identifier (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) of a security control across standards.static Class<? extends StandardsControlAssociationId.Builder>final StringThe ARN of a standard.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
securityControlId
The unique identifier (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) of a security control across standards.- Returns:
- The unique identifier (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) of a security control across standards.
-
standardsArn
The ARN of a standard.
- Returns:
- The ARN of a standard.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<StandardsControlAssociationId.Builder,StandardsControlAssociationId>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-