Class StandardsControlAssociationUpdate

java.lang.Object
software.amazon.awssdk.services.securityhub.model.StandardsControlAssociationUpdate
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<StandardsControlAssociationUpdate.Builder,StandardsControlAssociationUpdate>

@Generated("software.amazon.awssdk:codegen") public final class StandardsControlAssociationUpdate extends Object implements SdkPojo, Serializable, ToCopyableBuilder<StandardsControlAssociationUpdate.Builder,StandardsControlAssociationUpdate>

An array of requested updates to the enablement status of controls in specified standards. The objects in the array include a security control ID, the Amazon Resource Name (ARN) of the standard, the requested enablement status, and the reason for updating the enablement status.

See Also: