Class StandardsSubscription
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<StandardsSubscription.Builder,StandardsSubscription>
A resource that represents your subscription to a supported standard.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the StandardsInput property.static Class<? extends StandardsSubscription.Builder>final StringThe ARN of the standard.Specifies whether you can retrieve information about and configure individual controls that apply to the standard.final StringSpecifies whether you can retrieve information about and configure individual controls that apply to the standard.A key-value pair of input for the standard.final StandardsStatusThe status of your subscription to the standard.final StringThe status of your subscription to the standard.final StandardsStatusReasonThe reason for the current status.final StringThe ARN of the resource that represents your subscription to the standard.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsSubscriptionArn
The ARN of the resource that represents your subscription to the standard.
- Returns:
- The ARN of the resource that represents your subscription to the standard.
-
standardsArn
The ARN of the standard.
- Returns:
- The ARN of the standard.
-
hasStandardsInput
public final boolean hasStandardsInput()For responses, this returns true if the service returned a value for the StandardsInput property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
standardsInput
A key-value pair of input for the standard.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStandardsInput()method.- Returns:
- A key-value pair of input for the standard.
-
standardsStatus
The status of your subscription to the standard. Possible values are:
-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub CSPM is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to disable the standard.
If the service returns an enum value that is not available in the current SDK version,
standardsStatuswill returnStandardsStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstandardsStatusAsString().- Returns:
- The status of your subscription to the standard. Possible values are:
-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub CSPM is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to disable the standard.
-
- See Also:
-
-
standardsStatusAsString
The status of your subscription to the standard. Possible values are:
-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub CSPM is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to disable the standard.
If the service returns an enum value that is not available in the current SDK version,
standardsStatuswill returnStandardsStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstandardsStatusAsString().- Returns:
- The status of your subscription to the standard. Possible values are:
-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub CSPM is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to disable the standard.
-
- See Also:
-
-
standardsControlsUpdatable
Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:
-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
If the service returns an enum value that is not available in the current SDK version,
standardsControlsUpdatablewill returnStandardsControlsUpdatable.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstandardsControlsUpdatableAsString().- Returns:
- Specifies whether you can retrieve information about and configure individual controls that apply to the
standard. Possible values are:
-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
-
- See Also:
-
-
standardsControlsUpdatableAsString
Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:
-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
If the service returns an enum value that is not available in the current SDK version,
standardsControlsUpdatablewill returnStandardsControlsUpdatable.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstandardsControlsUpdatableAsString().- Returns:
- Specifies whether you can retrieve information about and configure individual controls that apply to the
standard. Possible values are:
-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
-
- See Also:
-
-
standardsStatusReason
The reason for the current status.
- Returns:
- The reason for the current status.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<StandardsSubscription.Builder,StandardsSubscription>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-