Interface StandardsSubscription.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<StandardsSubscription.Builder,StandardsSubscription>,SdkBuilder<StandardsSubscription.Builder,StandardsSubscription>,SdkPojo
- Enclosing class:
- StandardsSubscription
public static interface StandardsSubscription.Builder extends SdkPojo, CopyableBuilder<StandardsSubscription.Builder,StandardsSubscription>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description StandardsSubscription.BuilderstandardsArn(String standardsArn)The ARN of the standard.StandardsSubscription.BuilderstandardsControlsUpdatable(String standardsControlsUpdatable)Specifies whether you can retrieve information about and configure individual controls that apply to the standard.StandardsSubscription.BuilderstandardsControlsUpdatable(StandardsControlsUpdatable standardsControlsUpdatable)Specifies whether you can retrieve information about and configure individual controls that apply to the standard.StandardsSubscription.BuilderstandardsInput(Map<String,String> standardsInput)A key-value pair of input for the standard.StandardsSubscription.BuilderstandardsStatus(String standardsStatus)The status of your subscription to the standard.StandardsSubscription.BuilderstandardsStatus(StandardsStatus standardsStatus)The status of your subscription to the standard.default StandardsSubscription.BuilderstandardsStatusReason(Consumer<StandardsStatusReason.Builder> standardsStatusReason)The reason for the current status.StandardsSubscription.BuilderstandardsStatusReason(StandardsStatusReason standardsStatusReason)The reason for the current status.StandardsSubscription.BuilderstandardsSubscriptionArn(String standardsSubscriptionArn)The ARN of the resource that represents your subscription to the standard.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
standardsSubscriptionArn
StandardsSubscription.Builder standardsSubscriptionArn(String standardsSubscriptionArn)
The ARN of the resource that represents your subscription to the standard.
- Parameters:
standardsSubscriptionArn- The ARN of the resource that represents your subscription to the standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
standardsArn
StandardsSubscription.Builder standardsArn(String standardsArn)
The ARN of the standard.
- Parameters:
standardsArn- The ARN of the standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
standardsInput
StandardsSubscription.Builder standardsInput(Map<String,String> standardsInput)
A key-value pair of input for the standard.
- Parameters:
standardsInput- A key-value pair of input for the standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
standardsStatus
StandardsSubscription.Builder standardsStatus(String standardsStatus)
The status of your subscription to the standard. Possible values are:
-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to disable the standard.
- Parameters:
standardsStatus- The status of your subscription to the standard. Possible values are:-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to disable the standard.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
StandardsStatus,StandardsStatus
-
-
standardsStatus
StandardsSubscription.Builder standardsStatus(StandardsStatus standardsStatus)
The status of your subscription to the standard. Possible values are:
-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to disable the standard.
- Parameters:
standardsStatus- The status of your subscription to the standard. Possible values are:-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to disable the standard.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
StandardsStatus,StandardsStatus
-
-
standardsControlsUpdatable
StandardsSubscription.Builder standardsControlsUpdatable(String standardsControlsUpdatable)
Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:
-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
- Parameters:
standardsControlsUpdatable- Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
StandardsControlsUpdatable,StandardsControlsUpdatable
-
-
standardsControlsUpdatable
StandardsSubscription.Builder standardsControlsUpdatable(StandardsControlsUpdatable standardsControlsUpdatable)
Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:
-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
- Parameters:
standardsControlsUpdatable- Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
StandardsControlsUpdatable,StandardsControlsUpdatable
-
-
standardsStatusReason
StandardsSubscription.Builder standardsStatusReason(StandardsStatusReason standardsStatusReason)
The reason for the current status.
- Parameters:
standardsStatusReason- The reason for the current status.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
standardsStatusReason
default StandardsSubscription.Builder standardsStatusReason(Consumer<StandardsStatusReason.Builder> standardsStatusReason)
The reason for the current status.
This is a convenience method that creates an instance of theStandardsStatusReason.Builderavoiding the need to create one manually viaStandardsStatusReason.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tostandardsStatusReason(StandardsStatusReason).- Parameters:
standardsStatusReason- a consumer that will call methods onStandardsStatusReason.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
standardsStatusReason(StandardsStatusReason)
-
-