Class StandardsSubscriptionRequest
java.lang.Object
software.amazon.awssdk.services.securityhub.model.StandardsSubscriptionRequest
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<StandardsSubscriptionRequest.Builder,StandardsSubscriptionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class StandardsSubscriptionRequest
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<StandardsSubscriptionRequest.Builder,StandardsSubscriptionRequest>
The standard that you want to enable.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the StandardsInput property.static Class<? extends StandardsSubscriptionRequest.Builder>final StringThe ARN of the standard that you want to enable.A key-value pair of input for the standard.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsArn
The ARN of the standard that you want to enable. To view the list of available standards and their ARNs, use the
DescribeStandardsoperation.- Returns:
- The ARN of the standard that you want to enable. To view the list of available standards and their ARNs,
use the
DescribeStandardsoperation.
-
hasStandardsInput
public final boolean hasStandardsInput()For responses, this returns true if the service returned a value for the StandardsInput property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
standardsInput
A key-value pair of input for the standard.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStandardsInput()method.- Returns:
- A key-value pair of input for the standard.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<StandardsSubscriptionRequest.Builder,StandardsSubscriptionRequest>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-