Class StartConfigurationPolicyAssociationResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<StartConfigurationPolicyAssociationResponse.Builder,StartConfigurationPolicyAssociationResponse>

@Generated("software.amazon.awssdk:codegen") public final class StartConfigurationPolicyAssociationResponse extends SecurityHubResponse implements ToCopyableBuilder<StartConfigurationPolicyAssociationResponse.Builder,StartConfigurationPolicyAssociationResponse>
  • Method Details

    • configurationPolicyId

      public final String configurationPolicyId()

      The UUID of the configuration policy.

      Returns:
      The UUID of the configuration policy.
    • targetId

      public final String targetId()

      The identifier of the target account, organizational unit, or the organization root with which the configuration is associated.

      Returns:
      The identifier of the target account, organizational unit, or the organization root with which the configuration is associated.
    • targetType

      public final TargetType targetType()

      Indicates whether the target is an Amazon Web Services account, organizational unit, or the organization root.

      If the service returns an enum value that is not available in the current SDK version, targetType will return TargetType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from targetTypeAsString().

      Returns:
      Indicates whether the target is an Amazon Web Services account, organizational unit, or the organization root.
      See Also:
    • targetTypeAsString

      public final String targetTypeAsString()

      Indicates whether the target is an Amazon Web Services account, organizational unit, or the organization root.

      If the service returns an enum value that is not available in the current SDK version, targetType will return TargetType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from targetTypeAsString().

      Returns:
      Indicates whether the target is an Amazon Web Services account, organizational unit, or the organization root.
      See Also:
    • associationType

      public final AssociationType associationType()

      Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.

      If the service returns an enum value that is not available in the current SDK version, associationType will return AssociationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from associationTypeAsString().

      Returns:
      Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
      See Also:
    • associationTypeAsString

      public final String associationTypeAsString()

      Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.

      If the service returns an enum value that is not available in the current SDK version, associationType will return AssociationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from associationTypeAsString().

      Returns:
      Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
      See Also:
    • updatedAt

      public final Instant updatedAt()

      The date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.

      Returns:
      The date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.
    • associationStatus

      public final ConfigurationPolicyAssociationStatus associationStatus()

      The current status of the association between the specified target and the configuration.

      If the service returns an enum value that is not available in the current SDK version, associationStatus will return ConfigurationPolicyAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from associationStatusAsString().

      Returns:
      The current status of the association between the specified target and the configuration.
      See Also:
    • associationStatusAsString

      public final String associationStatusAsString()

      The current status of the association between the specified target and the configuration.

      If the service returns an enum value that is not available in the current SDK version, associationStatus will return ConfigurationPolicyAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from associationStatusAsString().

      Returns:
      The current status of the association between the specified target and the configuration.
      See Also:
    • associationStatusMessage

      public final String associationStatusMessage()

      An explanation for a FAILED value for AssociationStatus.

      Returns:
      An explanation for a FAILED value for AssociationStatus.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<StartConfigurationPolicyAssociationResponse.Builder,StartConfigurationPolicyAssociationResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

    • serializableBuilderClass

      public static Class<? extends StartConfigurationPolicyAssociationResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo