Class TrendsValues
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.TrendsValues
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<TrendsValues.Builder,TrendsValues>
@Generated("software.amazon.awssdk:codegen") public final class TrendsValues extends Object implements SdkPojo, Serializable, ToCopyableBuilder<TrendsValues.Builder,TrendsValues>
Contains the aggregated finding values for a specific point in the findings trend timeline.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceTrendsValues.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static TrendsValues.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends TrendsValues.Builder>serializableBuilderClass()SeverityTrendsCountseverityTrends()The count of findings organized by severity level for this data point in the trend timeline.TrendsValues.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
severityTrends
public final SeverityTrendsCount severityTrends()
The count of findings organized by severity level for this data point in the trend timeline.
- Returns:
- The count of findings organized by severity level for this data point in the trend timeline.
-
toBuilder
public TrendsValues.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<TrendsValues.Builder,TrendsValues>
-
builder
public static TrendsValues.Builder builder()
-
serializableBuilderClass
public static Class<? extends TrendsValues.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-