Interface TrendsValues.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<TrendsValues.Builder,TrendsValues>,SdkBuilder<TrendsValues.Builder,TrendsValues>,SdkPojo
- Enclosing class:
- TrendsValues
@Mutable @NotThreadSafe public static interface TrendsValues.Builder extends SdkPojo, CopyableBuilder<TrendsValues.Builder,TrendsValues>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default TrendsValues.BuilderseverityTrends(Consumer<SeverityTrendsCount.Builder> severityTrends)The count of findings organized by severity level for this data point in the trend timeline.TrendsValues.BuilderseverityTrends(SeverityTrendsCount severityTrends)The count of findings organized by severity level for this data point in the trend timeline.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
severityTrends
TrendsValues.Builder severityTrends(SeverityTrendsCount severityTrends)
The count of findings organized by severity level for this data point in the trend timeline.
- Parameters:
severityTrends- The count of findings organized by severity level for this data point in the trend timeline.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
severityTrends
default TrendsValues.Builder severityTrends(Consumer<SeverityTrendsCount.Builder> severityTrends)
The count of findings organized by severity level for this data point in the trend timeline.
This is a convenience method that creates an instance of theSeverityTrendsCount.Builderavoiding the need to create one manually viaSeverityTrendsCount.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toseverityTrends(SeverityTrendsCount).- Parameters:
severityTrends- a consumer that will call methods onSeverityTrendsCount.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
severityTrends(SeverityTrendsCount)
-
-