Class UnprocessedAutomationRule
java.lang.Object
software.amazon.awssdk.services.securityhub.model.UnprocessedAutomationRule
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UnprocessedAutomationRule.Builder,UnprocessedAutomationRule>
@Generated("software.amazon.awssdk:codegen")
public final class UnprocessedAutomationRule
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<UnprocessedAutomationRule.Builder,UnprocessedAutomationRule>
A list of objects containing RuleArn, ErrorCode, and ErrorMessage. This
parameter tells you which automation rules the request didn't process and why.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final IntegerThe error code associated with the unprocessed automation rule.final StringAn error message describing why a request didn't process a specific rule.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringruleArn()The Amazon Resource Name (ARN) for the unprocessed automation rule.static Class<? extends UnprocessedAutomationRule.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
ruleArn
The Amazon Resource Name (ARN) for the unprocessed automation rule.
- Returns:
- The Amazon Resource Name (ARN) for the unprocessed automation rule.
-
errorCode
The error code associated with the unprocessed automation rule.
- Returns:
- The error code associated with the unprocessed automation rule.
-
errorMessage
An error message describing why a request didn't process a specific rule.
- Returns:
- An error message describing why a request didn't process a specific rule.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UnprocessedAutomationRule.Builder,UnprocessedAutomationRule>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-