Class UnprocessedConfigurationPolicyAssociation
java.lang.Object
software.amazon.awssdk.services.securityhub.model.UnprocessedConfigurationPolicyAssociation
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UnprocessedConfigurationPolicyAssociation.Builder,UnprocessedConfigurationPolicyAssociation>
@Generated("software.amazon.awssdk:codegen")
public final class UnprocessedConfigurationPolicyAssociation
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<UnprocessedConfigurationPolicyAssociation.Builder,UnprocessedConfigurationPolicyAssociation>
An array of configuration policy associations, one for each configuration policy association identifier, that was
specified in a BatchGetConfigurationPolicyAssociations request but couldn’t be processed due to an
error.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Configuration policy association identifiers that were specified in aBatchGetConfigurationPolicyAssociationsrequest but couldn’t be processed due to an error.final booleanfinal booleanequalsBySdkFields(Object obj) final StringAn HTTP status code that identifies why the configuration policy association failed.final StringA string that identifies why the configuration policy association failed.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UnprocessedConfigurationPolicyAssociation.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
configurationPolicyAssociationIdentifiers
Configuration policy association identifiers that were specified in a
BatchGetConfigurationPolicyAssociationsrequest but couldn’t be processed due to an error.- Returns:
- Configuration policy association identifiers that were specified in a
BatchGetConfigurationPolicyAssociationsrequest but couldn’t be processed due to an error.
-
errorCode
An HTTP status code that identifies why the configuration policy association failed.
- Returns:
- An HTTP status code that identifies why the configuration policy association failed.
-
errorReason
A string that identifies why the configuration policy association failed.
- Returns:
- A string that identifies why the configuration policy association failed.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UnprocessedConfigurationPolicyAssociation.Builder,UnprocessedConfigurationPolicyAssociation>
-
builder
-
serializableBuilderClass
public static Class<? extends UnprocessedConfigurationPolicyAssociation.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-