Class UnprocessedSecurityControl
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UnprocessedSecurityControl.Builder,UnprocessedSecurityControl>
Provides details about a security control for which a response couldn't be returned.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final UnprocessedErrorCodeThe error code for the unprocessed security control.final StringThe error code for the unprocessed security control.final StringThe reason why the security control was unprocessed.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.static Class<? extends UnprocessedSecurityControl.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
securityControlId
The control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.- Returns:
- The control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.
-
errorCode
The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
-
errorCodeAsString
The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
-
errorReason
The reason why the security control was unprocessed.
- Returns:
- The reason why the security control was unprocessed.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UnprocessedSecurityControl.Builder,UnprocessedSecurityControl>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-