Interface UnprocessedSecurityControl.Builder

    • Method Detail

      • securityControlId

        UnprocessedSecurityControl.Builder securityControlId​(String securityControlId)

        The control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.

        Parameters:
        securityControlId - The control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • errorCode

        UnprocessedSecurityControl.Builder errorCode​(String errorCode)

        The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.

        Parameters:
        errorCode - The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        UnprocessedErrorCode, UnprocessedErrorCode
      • errorCode

        UnprocessedSecurityControl.Builder errorCode​(UnprocessedErrorCode errorCode)

        The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.

        Parameters:
        errorCode - The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        UnprocessedErrorCode, UnprocessedErrorCode
      • errorReason

        UnprocessedSecurityControl.Builder errorReason​(String errorReason)

        The reason why the security control was unprocessed.

        Parameters:
        errorReason - The reason why the security control was unprocessed.
        Returns:
        Returns a reference to this object so that method calls can be chained together.