Class UnprocessedStandardsControlAssociation
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UnprocessedStandardsControlAssociation.Builder,UnprocessedStandardsControlAssociation>
Provides details about which control's enablement status couldn't be retrieved in a specified standard when calling BatchUpdateStandardsControlAssociations. This parameter also provides details about why the request was unprocessed.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final UnprocessedErrorCodeThe error code for the unprocessed standard and control association.final StringThe error code for the unprocessed standard and control association.final StringThe reason why the standard and control association was unprocessed.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UnprocessedStandardsControlAssociation.Builder>An array with one or more objects that includes a security control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsControlAssociationId
An array with one or more objects that includes a security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard. This parameter shows the specific controls for which the enablement status couldn't be retrieved in specified standards when calling BatchUpdateStandardsControlAssociations.- Returns:
- An array with one or more objects that includes a security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard. This parameter shows the specific controls for which the enablement status couldn't be retrieved in specified standards when calling BatchUpdateStandardsControlAssociations.
-
errorCode
The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
-
errorCodeAsString
The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
-
errorReason
The reason why the standard and control association was unprocessed.
- Returns:
- The reason why the standard and control association was unprocessed.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UnprocessedStandardsControlAssociation.Builder,UnprocessedStandardsControlAssociation>
-
builder
-
serializableBuilderClass
public static Class<? extends UnprocessedStandardsControlAssociation.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-