Class UnprocessedStandardsControlAssociationUpdate
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UnprocessedStandardsControlAssociationUpdate.Builder,UnprocessedStandardsControlAssociationUpdate>
Provides details about which control's enablement status could not be updated in a specified standard when calling the BatchUpdateStandardsControlAssociations API. This parameter also provides details about why the request was unprocessed.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final UnprocessedErrorCodeThe error code for the unprocessed update of the control's enablement status in the specified standard.final StringThe error code for the unprocessed update of the control's enablement status in the specified standard.final StringThe reason why a control's enablement status in the specified standard couldn't be updated.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UnprocessedStandardsControlAssociationUpdate.Builder>An array of control and standard associations for which an update failed when calling BatchUpdateStandardsControlAssociations.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsControlAssociationUpdate
An array of control and standard associations for which an update failed when calling BatchUpdateStandardsControlAssociations.
- Returns:
- An array of control and standard associations for which an update failed when calling BatchUpdateStandardsControlAssociations.
-
errorCode
The error code for the unprocessed update of the control's enablement status in the specified standard. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed update of the control's enablement status in the specified standard.
The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
-
errorCodeAsString
The error code for the unprocessed update of the control's enablement status in the specified standard. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed update of the control's enablement status in the specified standard.
The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
-
errorReason
The reason why a control's enablement status in the specified standard couldn't be updated.
- Returns:
- The reason why a control's enablement status in the specified standard couldn't be updated.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UnprocessedStandardsControlAssociationUpdate.Builder,UnprocessedStandardsControlAssociationUpdate>
-
builder
-
serializableBuilderClass
public static Class<? extends UnprocessedStandardsControlAssociationUpdate.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-