Interface UpdateActionTargetRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<UpdateActionTargetRequest.Builder,,UpdateActionTargetRequest> SdkBuilder<UpdateActionTargetRequest.Builder,,UpdateActionTargetRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- UpdateActionTargetRequest
@Mutable
@NotThreadSafe
public static interface UpdateActionTargetRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<UpdateActionTargetRequest.Builder,UpdateActionTargetRequest>
-
Method Summary
Modifier and TypeMethodDescriptionactionTargetArn(String actionTargetArn) The ARN of the custom action target to update.description(String description) The updated description for the custom action target.The updated name of the custom action target.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
actionTargetArn
The ARN of the custom action target to update.
- Parameters:
actionTargetArn- The ARN of the custom action target to update.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
name
The updated name of the custom action target.
- Parameters:
name- The updated name of the custom action target.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
description
The updated description for the custom action target.
- Parameters:
description- The updated description for the custom action target.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
UpdateActionTargetRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
UpdateActionTargetRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-