Interface UpdateAggregatorV2Request.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<UpdateAggregatorV2Request.Builder,UpdateAggregatorV2Request>,SdkBuilder<UpdateAggregatorV2Request.Builder,UpdateAggregatorV2Request>,SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- UpdateAggregatorV2Request
@Mutable @NotThreadSafe public static interface UpdateAggregatorV2Request.Builder extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<UpdateAggregatorV2Request.Builder,UpdateAggregatorV2Request>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description UpdateAggregatorV2Request.BuilderaggregatorV2Arn(String aggregatorV2Arn)The ARN of the Aggregator V2.UpdateAggregatorV2Request.BuilderlinkedRegions(String... linkedRegions)A list of Amazon Web Services Regions linked to the aggegation Region.UpdateAggregatorV2Request.BuilderlinkedRegions(Collection<String> linkedRegions)A list of Amazon Web Services Regions linked to the aggegation Region.UpdateAggregatorV2Request.BuilderoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)UpdateAggregatorV2Request.BuilderoverrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)UpdateAggregatorV2Request.BuilderregionLinkingMode(String regionLinkingMode)Determines how Amazon Web Services Regions should be linked to the Aggregator V2.-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
-
-
-
Method Detail
-
aggregatorV2Arn
UpdateAggregatorV2Request.Builder aggregatorV2Arn(String aggregatorV2Arn)
The ARN of the Aggregator V2.
- Parameters:
aggregatorV2Arn- The ARN of the Aggregator V2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
regionLinkingMode
UpdateAggregatorV2Request.Builder regionLinkingMode(String regionLinkingMode)
Determines how Amazon Web Services Regions should be linked to the Aggregator V2.
- Parameters:
regionLinkingMode- Determines how Amazon Web Services Regions should be linked to the Aggregator V2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
linkedRegions
UpdateAggregatorV2Request.Builder linkedRegions(Collection<String> linkedRegions)
A list of Amazon Web Services Regions linked to the aggegation Region.
- Parameters:
linkedRegions- A list of Amazon Web Services Regions linked to the aggegation Region.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
linkedRegions
UpdateAggregatorV2Request.Builder linkedRegions(String... linkedRegions)
A list of Amazon Web Services Regions linked to the aggegation Region.
- Parameters:
linkedRegions- A list of Amazon Web Services Regions linked to the aggegation Region.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
UpdateAggregatorV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
UpdateAggregatorV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-