Interface UpdateAggregatorV2Response.Builder

    • Method Detail

      • aggregatorV2Arn

        UpdateAggregatorV2Response.Builder aggregatorV2Arn​(String aggregatorV2Arn)

        The ARN of the Aggregator V2.

        Parameters:
        aggregatorV2Arn - The ARN of the Aggregator V2.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • aggregationRegion

        UpdateAggregatorV2Response.Builder aggregationRegion​(String aggregationRegion)

        The Amazon Web Services Region where data is aggregated.

        Parameters:
        aggregationRegion - The Amazon Web Services Region where data is aggregated.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • regionLinkingMode

        UpdateAggregatorV2Response.Builder regionLinkingMode​(String regionLinkingMode)

        Determines how Amazon Web Services Regions should be linked to the Aggregator V2.

        Parameters:
        regionLinkingMode - Determines how Amazon Web Services Regions should be linked to the Aggregator V2.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • linkedRegions

        UpdateAggregatorV2Response.Builder linkedRegions​(Collection<String> linkedRegions)

        A list of Amazon Web Services Regions linked to the aggegation Region.

        Parameters:
        linkedRegions - A list of Amazon Web Services Regions linked to the aggegation Region.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • linkedRegions

        UpdateAggregatorV2Response.Builder linkedRegions​(String... linkedRegions)

        A list of Amazon Web Services Regions linked to the aggegation Region.

        Parameters:
        linkedRegions - A list of Amazon Web Services Regions linked to the aggegation Region.
        Returns:
        Returns a reference to this object so that method calls can be chained together.