Interface UpdateAutomationRuleV2Request.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request>,SdkBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request>,SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- UpdateAutomationRuleV2Request
@Mutable @NotThreadSafe public static interface UpdateAutomationRuleV2Request.Builder extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request>
-
-
Method Summary
-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
-
-
-
Method Detail
-
identifier
UpdateAutomationRuleV2Request.Builder identifier(String identifier)
The ARN of the automation rule.
- Parameters:
identifier- The ARN of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleStatus
UpdateAutomationRuleV2Request.Builder ruleStatus(String ruleStatus)
The status of the automation rule.
- Parameters:
ruleStatus- The status of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
ruleStatus
UpdateAutomationRuleV2Request.Builder ruleStatus(RuleStatusV2 ruleStatus)
The status of the automation rule.
- Parameters:
ruleStatus- The status of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
ruleOrder
UpdateAutomationRuleV2Request.Builder ruleOrder(Float ruleOrder)
Represents a value for the rule priority.
- Parameters:
ruleOrder- Represents a value for the rule priority.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
description
UpdateAutomationRuleV2Request.Builder description(String description)
A description of the automation rule.
- Parameters:
description- A description of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleName
UpdateAutomationRuleV2Request.Builder ruleName(String ruleName)
The name of the automation rule.
- Parameters:
ruleName- The name of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
criteria
UpdateAutomationRuleV2Request.Builder criteria(Criteria criteria)
The filtering type and configuration of the automation rule.
- Parameters:
criteria- The filtering type and configuration of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
criteria
default UpdateAutomationRuleV2Request.Builder criteria(Consumer<Criteria.Builder> criteria)
The filtering type and configuration of the automation rule.
This is a convenience method that creates an instance of theCriteria.Builderavoiding the need to create one manually viaCriteria.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tocriteria(Criteria).- Parameters:
criteria- a consumer that will call methods onCriteria.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
criteria(Criteria)
-
actions
UpdateAutomationRuleV2Request.Builder actions(Collection<AutomationRulesActionV2> actions)
A list of actions to be performed when the rule criteria is met.
- Parameters:
actions- A list of actions to be performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
UpdateAutomationRuleV2Request.Builder actions(AutomationRulesActionV2... actions)
A list of actions to be performed when the rule criteria is met.
- Parameters:
actions- A list of actions to be performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
UpdateAutomationRuleV2Request.Builder actions(Consumer<AutomationRulesActionV2.Builder>... actions)
A list of actions to be performed when the rule criteria is met.
This is a convenience method that creates an instance of theAutomationRulesActionV2.Builderavoiding the need to create one manually viaAutomationRulesActionV2.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#actions(List.) - Parameters:
actions- a consumer that will call methods onAutomationRulesActionV2.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#actions(java.util.Collection)
-
overrideConfiguration
UpdateAutomationRuleV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
UpdateAutomationRuleV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-