Class UpdateConfigurationPolicyRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdateConfigurationPolicyRequest.Builder,UpdateConfigurationPolicyRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdateConfigurationPolicyRequest extends SecurityHubRequest implements ToCopyableBuilder<UpdateConfigurationPolicyRequest.Builder,UpdateConfigurationPolicyRequest>
  • Method Details

    • identifier

      public final String identifier()

      The Amazon Resource Name (ARN) or universally unique identifier (UUID) of the configuration policy.

      Returns:
      The Amazon Resource Name (ARN) or universally unique identifier (UUID) of the configuration policy.
    • name

      public final String name()

      The name of the configuration policy. Alphanumeric characters and the following ASCII characters are permitted: -, ., !, *, /.

      Returns:
      The name of the configuration policy. Alphanumeric characters and the following ASCII characters are permitted: -, ., !, *, /.
    • description

      public final String description()

      The description of the configuration policy.

      Returns:
      The description of the configuration policy.
    • updatedReason

      public final String updatedReason()

      The reason for updating the configuration policy.

      Returns:
      The reason for updating the configuration policy.
    • configurationPolicy

      public final Policy configurationPolicy()

      An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).

      When updating a configuration policy, provide a complete list of standards that you want to enable and a complete list of controls that you want to enable or disable. The updated configuration replaces the current configuration.

      Returns:
      An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).

      When updating a configuration policy, provide a complete list of standards that you want to enable and a complete list of controls that you want to enable or disable. The updated configuration replaces the current configuration.

    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdateConfigurationPolicyRequest.Builder,UpdateConfigurationPolicyRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends UpdateConfigurationPolicyRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo