Class UpdateConfigurationPolicyResponse
- java.lang.Object
-
- software.amazon.awssdk.core.SdkResponse
-
- software.amazon.awssdk.awscore.AwsResponse
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
-
- software.amazon.awssdk.services.securityhub.model.UpdateConfigurationPolicyResponse
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateConfigurationPolicyResponse.Builder,UpdateConfigurationPolicyResponse>
@Generated("software.amazon.awssdk:codegen") public final class UpdateConfigurationPolicyResponse extends SecurityHubResponse implements ToCopyableBuilder<UpdateConfigurationPolicyResponse.Builder,UpdateConfigurationPolicyResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceUpdateConfigurationPolicyResponse.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description Stringarn()The ARN of the configuration policy.static UpdateConfigurationPolicyResponse.Builderbuilder()PolicyconfigurationPolicy()An object that defines how Security Hub CSPM is configured.InstantcreatedAt()The date and time, in UTC and ISO 8601 format, that the configuration policy was created.Stringdescription()The description of the configuration policy.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Stringid()The UUID of the configuration policy.Stringname()The name of the configuration policy.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends UpdateConfigurationPolicyResponse.Builder>serializableBuilderClass()UpdateConfigurationPolicyResponse.BuildertoBuilder()StringtoString()Returns a string representation of this object.InstantupdatedAt()The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.-
Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadata
-
Methods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponse
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
arn
public final String arn()
The ARN of the configuration policy.
- Returns:
- The ARN of the configuration policy.
-
id
public final String id()
The UUID of the configuration policy.
- Returns:
- The UUID of the configuration policy.
-
name
public final String name()
The name of the configuration policy.
- Returns:
- The name of the configuration policy.
-
description
public final String description()
The description of the configuration policy.
- Returns:
- The description of the configuration policy.
-
updatedAt
public final Instant updatedAt()
The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
- Returns:
- The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
-
createdAt
public final Instant createdAt()
The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
- Returns:
- The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
-
configurationPolicy
public final Policy configurationPolicy()
An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the request included a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If the request included a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
- Returns:
- An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the request included a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If the request included a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
-
toBuilder
public UpdateConfigurationPolicyResponse.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateConfigurationPolicyResponse.Builder,UpdateConfigurationPolicyResponse>- Specified by:
toBuilderin classAwsResponse
-
builder
public static UpdateConfigurationPolicyResponse.Builder builder()
-
serializableBuilderClass
public static Class<? extends UpdateConfigurationPolicyResponse.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsResponse
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-