Class UpdateConnectorV2Response
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateConnectorV2Response.Builder,UpdateConnectorV2Response>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final ConnectorStatusThe status of the connector after the update.final StringThe status of the connector after the update.final EnablementStatusThe enablement status of the connector after the update.final StringThe enablement status of the connector after the update.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UpdateConnectorV2Response.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorStatus
The status of the connector after the update.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status of the connector after the update.
- See Also:
-
connectorStatusAsString
The status of the connector after the update.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status of the connector after the update.
- See Also:
-
enablementStatus
The enablement status of the connector after the update.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector after the update.
- See Also:
-
enablementStatusAsString
The enablement status of the connector after the update.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector after the update.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateConnectorV2Response.Builder,UpdateConnectorV2Response> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-