Class UpdateFindingAggregatorRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateFindingAggregatorRequest.Builder,UpdateFindingAggregatorRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe ARN of the finding aggregator.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Regions property.final StringIndicates whether to aggregate findings from all of the available Regions in the current partition.regions()IfRegionLinkingModeisALL_REGIONS_EXCEPT_SPECIFIED, then this is a space-separated list of Regions that don't replicate and send findings to the home Region.static Class<? extends UpdateFindingAggregatorRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
findingAggregatorArn
The ARN of the finding aggregator. To obtain the ARN, use
ListFindingAggregators.- Returns:
- The ARN of the finding aggregator. To obtain the ARN, use
ListFindingAggregators.
-
regionLinkingMode
Indicates whether to aggregate findings from all of the available Regions in the current partition. Also determines whether to automatically aggregate findings from new Regions as Security Hub CSPM supports them and you opt into them.
The selected option also determines how to use the Regions provided in the Regions list.
The options are as follows:
-
ALL_REGIONS- Aggregates findings from all of the Regions where Security Hub CSPM is enabled. When you choose this option, Security Hub CSPM also automatically aggregates findings from new Regions as Security Hub CSPM supports them and you opt into them. -
ALL_REGIONS_EXCEPT_SPECIFIED- Aggregates findings from all of the Regions where Security Hub CSPM is enabled, except for the Regions listed in theRegionsparameter. When you choose this option, Security Hub CSPM also automatically aggregates findings from new Regions as Security Hub CSPM supports them and you opt into them. -
SPECIFIED_REGIONS- Aggregates findings only from the Regions listed in theRegionsparameter. Security Hub CSPM does not automatically aggregate findings from new Regions. -
NO_REGIONS- Aggregates no data because no Regions are selected as linked Regions.
- Returns:
- Indicates whether to aggregate findings from all of the available Regions in the current partition. Also
determines whether to automatically aggregate findings from new Regions as Security Hub CSPM supports
them and you opt into them.
The selected option also determines how to use the Regions provided in the Regions list.
The options are as follows:
-
ALL_REGIONS- Aggregates findings from all of the Regions where Security Hub CSPM is enabled. When you choose this option, Security Hub CSPM also automatically aggregates findings from new Regions as Security Hub CSPM supports them and you opt into them. -
ALL_REGIONS_EXCEPT_SPECIFIED- Aggregates findings from all of the Regions where Security Hub CSPM is enabled, except for the Regions listed in theRegionsparameter. When you choose this option, Security Hub CSPM also automatically aggregates findings from new Regions as Security Hub CSPM supports them and you opt into them. -
SPECIFIED_REGIONS- Aggregates findings only from the Regions listed in theRegionsparameter. Security Hub CSPM does not automatically aggregate findings from new Regions. -
NO_REGIONS- Aggregates no data because no Regions are selected as linked Regions.
-
-
-
hasRegions
public final boolean hasRegions()For responses, this returns true if the service returned a value for the Regions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
regions
If
RegionLinkingModeisALL_REGIONS_EXCEPT_SPECIFIED, then this is a space-separated list of Regions that don't replicate and send findings to the home Region.If
RegionLinkingModeisSPECIFIED_REGIONS, then this is a space-separated list of Regions that do replicate and send findings to the home Region.An
InvalidInputExceptionerror results if you populate this field whileRegionLinkingModeisNO_REGIONS.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasRegions()method.- Returns:
- If
RegionLinkingModeisALL_REGIONS_EXCEPT_SPECIFIED, then this is a space-separated list of Regions that don't replicate and send findings to the home Region.If
RegionLinkingModeisSPECIFIED_REGIONS, then this is a space-separated list of Regions that do replicate and send findings to the home Region.An
InvalidInputExceptionerror results if you populate this field whileRegionLinkingModeisNO_REGIONS.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateFindingAggregatorRequest.Builder,UpdateFindingAggregatorRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-