Class UpdateFindingsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.UpdateFindingsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateFindingsRequest.Builder,UpdateFindingsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdateFindingsRequest
extends SecurityHubRequest
implements ToCopyableBuilder<UpdateFindingsRequest.Builder,UpdateFindingsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) filters()A collection of attributes that specify which findings you want to update.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final NoteUpdatenote()The updated note for the finding.final RecordStateThe updated record state for the finding.final StringThe updated record state for the finding.static Class<? extends UpdateFindingsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
filters
A collection of attributes that specify which findings you want to update.
- Returns:
- A collection of attributes that specify which findings you want to update.
-
note
The updated note for the finding.
- Returns:
- The updated note for the finding.
-
recordState
The updated record state for the finding.
If the service returns an enum value that is not available in the current SDK version,
recordStatewill returnRecordState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecordStateAsString().- Returns:
- The updated record state for the finding.
- See Also:
-
recordStateAsString
The updated record state for the finding.
If the service returns an enum value that is not available in the current SDK version,
recordStatewill returnRecordState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecordStateAsString().- Returns:
- The updated record state for the finding.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateFindingsRequest.Builder,UpdateFindingsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-