Interface UpdateFindingsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<UpdateFindingsRequest.Builder,,UpdateFindingsRequest> SdkBuilder<UpdateFindingsRequest.Builder,,UpdateFindingsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- UpdateFindingsRequest
@Mutable
@NotThreadSafe
public static interface UpdateFindingsRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<UpdateFindingsRequest.Builder,UpdateFindingsRequest>
-
Method Summary
Modifier and TypeMethodDescriptiondefault UpdateFindingsRequest.Builderfilters(Consumer<AwsSecurityFindingFilters.Builder> filters) A collection of attributes that specify which findings you want to update.filters(AwsSecurityFindingFilters filters) A collection of attributes that specify which findings you want to update.default UpdateFindingsRequest.Buildernote(Consumer<NoteUpdate.Builder> note) The updated note for the finding.note(NoteUpdate note) The updated note for the finding.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) recordState(String recordState) The updated record state for the finding.recordState(RecordState recordState) The updated record state for the finding.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
filters
A collection of attributes that specify which findings you want to update.
- Parameters:
filters- A collection of attributes that specify which findings you want to update.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
filters
A collection of attributes that specify which findings you want to update.
This is a convenience method that creates an instance of theAwsSecurityFindingFilters.Builderavoiding the need to create one manually viaAwsSecurityFindingFilters.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tofilters(AwsSecurityFindingFilters).- Parameters:
filters- a consumer that will call methods onAwsSecurityFindingFilters.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
note
The updated note for the finding.
- Parameters:
note- The updated note for the finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
note
The updated note for the finding.
This is a convenience method that creates an instance of theNoteUpdate.Builderavoiding the need to create one manually viaNoteUpdate.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tonote(NoteUpdate).- Parameters:
note- a consumer that will call methods onNoteUpdate.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
recordState
The updated record state for the finding.
- Parameters:
recordState- The updated record state for the finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
recordState
The updated record state for the finding.
- Parameters:
recordState- The updated record state for the finding.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
UpdateFindingsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
UpdateFindingsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-