Class UpdateInsightRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.UpdateInsightRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateInsightRequest.Builder,UpdateInsightRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdateInsightRequest
extends SecurityHubRequest
implements ToCopyableBuilder<UpdateInsightRequest.Builder,UpdateInsightRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic UpdateInsightRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) filters()The updated filters that define this insight.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe updatedGroupByattribute that defines this insight.final inthashCode()final StringThe ARN of the insight that you want to update.final Stringname()The updated name for the insight.static Class<? extends UpdateInsightRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
insightArn
The ARN of the insight that you want to update.
- Returns:
- The ARN of the insight that you want to update.
-
name
The updated name for the insight.
- Returns:
- The updated name for the insight.
-
filters
The updated filters that define this insight.
- Returns:
- The updated filters that define this insight.
-
groupByAttribute
The updated
GroupByattribute that defines this insight.- Returns:
- The updated
GroupByattribute that defines this insight.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateInsightRequest.Builder,UpdateInsightRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-