Interface UpdateInsightRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<UpdateInsightRequest.Builder,,UpdateInsightRequest> SdkBuilder<UpdateInsightRequest.Builder,,UpdateInsightRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- UpdateInsightRequest
@Mutable
@NotThreadSafe
public static interface UpdateInsightRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<UpdateInsightRequest.Builder,UpdateInsightRequest>
-
Method Summary
Modifier and TypeMethodDescriptiondefault UpdateInsightRequest.Builderfilters(Consumer<AwsSecurityFindingFilters.Builder> filters) The updated filters that define this insight.filters(AwsSecurityFindingFilters filters) The updated filters that define this insight.groupByAttribute(String groupByAttribute) The updatedGroupByattribute that defines this insight.insightArn(String insightArn) The ARN of the insight that you want to update.The updated name for the insight.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
insightArn
The ARN of the insight that you want to update.
- Parameters:
insightArn- The ARN of the insight that you want to update.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
name
The updated name for the insight.
- Parameters:
name- The updated name for the insight.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
filters
The updated filters that define this insight.
- Parameters:
filters- The updated filters that define this insight.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
filters
The updated filters that define this insight.
This is a convenience method that creates an instance of theAwsSecurityFindingFilters.Builderavoiding the need to create one manually viaAwsSecurityFindingFilters.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tofilters(AwsSecurityFindingFilters).- Parameters:
filters- a consumer that will call methods onAwsSecurityFindingFilters.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
groupByAttribute
The updated
GroupByattribute that defines this insight.- Parameters:
groupByAttribute- The updatedGroupByattribute that defines this insight.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
UpdateInsightRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
UpdateInsightRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-