Class UpdateOrganizationConfigurationRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateOrganizationConfigurationRequest.Builder,UpdateOrganizationConfigurationRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal BooleanWhether to automatically enable Security Hub CSPM in new member accounts when they join the organization.final AutoEnableStandardsWhether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.final StringWhether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()Returns the value of the OrganizationConfiguration property for this object.static Class<? extends UpdateOrganizationConfigurationRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
autoEnable
Whether to automatically enable Security Hub CSPM in new member accounts when they join the organization.
If set to
true, then Security Hub CSPM is automatically enabled in new accounts. If set tofalse, then Security Hub CSPM isn't enabled in new accounts automatically. The default value isfalse.If the
ConfigurationTypeof your organization is set toCENTRAL, then this field is set tofalseand can't be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which Security Hub CSPM is enabled and associate the policy with new organization accounts.- Returns:
- Whether to automatically enable Security Hub CSPM in new member accounts when they join the
organization.
If set to
true, then Security Hub CSPM is automatically enabled in new accounts. If set tofalse, then Security Hub CSPM isn't enabled in new accounts automatically. The default value isfalse.If the
ConfigurationTypeof your organization is set toCENTRAL, then this field is set tofalseand can't be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which Security Hub CSPM is enabled and associate the policy with new organization accounts.
-
autoEnableStandards
Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.
The default value of this parameter is equal to
DEFAULT.If equal to
DEFAULT, then Security Hub CSPM default standards are automatically enabled for new member accounts. If equal toNONE, then default standards are not automatically enabled for new member accounts.If the
ConfigurationTypeof your organization is set toCENTRAL, then this field is set toNONEand can't be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which specific security standards are enabled and associate the policy with new organization accounts.If the service returns an enum value that is not available in the current SDK version,
autoEnableStandardswill returnAutoEnableStandards.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromautoEnableStandardsAsString().- Returns:
- Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.
The default value of this parameter is equal to
DEFAULT.If equal to
DEFAULT, then Security Hub CSPM default standards are automatically enabled for new member accounts. If equal toNONE, then default standards are not automatically enabled for new member accounts.If the
ConfigurationTypeof your organization is set toCENTRAL, then this field is set toNONEand can't be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which specific security standards are enabled and associate the policy with new organization accounts. - See Also:
-
autoEnableStandardsAsString
Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.
The default value of this parameter is equal to
DEFAULT.If equal to
DEFAULT, then Security Hub CSPM default standards are automatically enabled for new member accounts. If equal toNONE, then default standards are not automatically enabled for new member accounts.If the
ConfigurationTypeof your organization is set toCENTRAL, then this field is set toNONEand can't be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which specific security standards are enabled and associate the policy with new organization accounts.If the service returns an enum value that is not available in the current SDK version,
autoEnableStandardswill returnAutoEnableStandards.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromautoEnableStandardsAsString().- Returns:
- Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.
The default value of this parameter is equal to
DEFAULT.If equal to
DEFAULT, then Security Hub CSPM default standards are automatically enabled for new member accounts. If equal toNONE, then default standards are not automatically enabled for new member accounts.If the
ConfigurationTypeof your organization is set toCENTRAL, then this field is set toNONEand can't be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which specific security standards are enabled and associate the policy with new organization accounts. - See Also:
-
organizationConfiguration
Returns the value of the OrganizationConfiguration property for this object.- Returns:
- The value of the OrganizationConfiguration property for this object.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateOrganizationConfigurationRequest.Builder,UpdateOrganizationConfigurationRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends UpdateOrganizationConfigurationRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-