Class UpdateSecurityHubConfigurationRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdateSecurityHubConfigurationRequest.Builder,UpdateSecurityHubConfigurationRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdateSecurityHubConfigurationRequest extends SecurityHubRequest implements ToCopyableBuilder<UpdateSecurityHubConfigurationRequest.Builder,UpdateSecurityHubConfigurationRequest>
  • Method Details

    • autoEnableControls

      public final Boolean autoEnableControls()

      Whether to automatically enable new controls when they are added to standards that are enabled.

      By default, this is set to true, and new controls are enabled automatically. To not automatically enable new controls, set this to false.

      When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control as ENABLED in your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you have AutoEnableControls set to true.

      Returns:
      Whether to automatically enable new controls when they are added to standards that are enabled.

      By default, this is set to true, and new controls are enabled automatically. To not automatically enable new controls, set this to false.

      When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control as ENABLED in your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you have AutoEnableControls set to true.

    • controlFindingGenerator

      public final ControlFindingGenerator controlFindingGenerator()

      Updates whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      For accounts that are part of an organization, this value can only be updated in the administrator account.

      If the service returns an enum value that is not available in the current SDK version, controlFindingGenerator will return ControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from controlFindingGeneratorAsString().

      Returns:
      Updates whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      For accounts that are part of an organization, this value can only be updated in the administrator account.

      See Also:
    • controlFindingGeneratorAsString

      public final String controlFindingGeneratorAsString()

      Updates whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      For accounts that are part of an organization, this value can only be updated in the administrator account.

      If the service returns an enum value that is not available in the current SDK version, controlFindingGenerator will return ControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from controlFindingGeneratorAsString().

      Returns:
      Updates whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.

      If the value for this field is set to STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.

      For accounts that are part of an organization, this value can only be updated in the administrator account.

      See Also:
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdateSecurityHubConfigurationRequest.Builder,UpdateSecurityHubConfigurationRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends UpdateSecurityHubConfigurationRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo