Class UpdateStandardsControlRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateStandardsControlRequest.Builder,UpdateStandardsControlRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final ControlStatusThe updated status of the security standard control.final StringThe updated status of the security standard control.final StringA description of the reason why you are disabling a security standard control.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UpdateStandardsControlRequest.Builder>final StringThe ARN of the security standard control to enable or disable.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsControlArn
The ARN of the security standard control to enable or disable.
- Returns:
- The ARN of the security standard control to enable or disable.
-
controlStatus
The updated status of the security standard control.
If the service returns an enum value that is not available in the current SDK version,
controlStatuswill returnControlStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolStatusAsString().- Returns:
- The updated status of the security standard control.
- See Also:
-
controlStatusAsString
The updated status of the security standard control.
If the service returns an enum value that is not available in the current SDK version,
controlStatuswill returnControlStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolStatusAsString().- Returns:
- The updated status of the security standard control.
- See Also:
-
disabledReason
A description of the reason why you are disabling a security standard control. If you are disabling a control, then this is required.
- Returns:
- A description of the reason why you are disabling a security standard control. If you are disabling a control, then this is required.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateStandardsControlRequest.Builder,UpdateStandardsControlRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-