Class UserAccount
java.lang.Object
software.amazon.awssdk.services.securityhub.model.UserAccount
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UserAccount.Builder,UserAccount>
@Generated("software.amazon.awssdk:codegen")
public final class UserAccount
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<UserAccount.Builder,UserAccount>
Provides Amazon Web Services account information of the user involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic UserAccount.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the user account involved in the attack sequence.static Class<? extends UserAccount.Builder>final StringtoString()Returns a string representation of this object.final Stringuid()The unique identifier of the user account involved in the attack sequence.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
uid
The unique identifier of the user account involved in the attack sequence.
- Returns:
- The unique identifier of the user account involved in the attack sequence.
-
name
The name of the user account involved in the attack sequence.
- Returns:
- The name of the user account involved in the attack sequence.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UserAccount.Builder,UserAccount>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-