Class VolumeMount
java.lang.Object
software.amazon.awssdk.services.securityhub.model.VolumeMount
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<VolumeMount.Builder,VolumeMount>
@Generated("software.amazon.awssdk:codegen")
public final class VolumeMount
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<VolumeMount.Builder,VolumeMount>
Describes the mounting of a volume in a container.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic VolumeMount.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe path in the container at which the volume should be mounted.final Stringname()The name of the volume.static Class<? extends VolumeMount.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the volume.
- Returns:
- The name of the volume.
-
mountPath
The path in the container at which the volume should be mounted.
- Returns:
- The path in the container at which the volume should be mounted.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<VolumeMount.Builder,VolumeMount>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-