Class VulnerabilityVendor

java.lang.Object
software.amazon.awssdk.services.securityhub.model.VulnerabilityVendor
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<VulnerabilityVendor.Builder,VulnerabilityVendor>

@Generated("software.amazon.awssdk:codegen") public final class VulnerabilityVendor extends Object implements SdkPojo, Serializable, ToCopyableBuilder<VulnerabilityVendor.Builder,VulnerabilityVendor>

A vendor that generates a vulnerability report.

See Also:
  • Method Details

    • name

      public final String name()

      The name of the vendor.

      Returns:
      The name of the vendor.
    • url

      public final String url()

      The URL of the vulnerability advisory.

      Returns:
      The URL of the vulnerability advisory.
    • vendorSeverity

      public final String vendorSeverity()

      The severity that the vendor assigned to the vulnerability.

      Returns:
      The severity that the vendor assigned to the vulnerability.
    • vendorCreatedAt

      public final String vendorCreatedAt()

      Indicates when the vulnerability advisory was created.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      Returns:
      Indicates when the vulnerability advisory was created.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

    • vendorUpdatedAt

      public final String vendorUpdatedAt()

      Indicates when the vulnerability advisory was last updated.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      Returns:
      Indicates when the vulnerability advisory was last updated.

      For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

    • toBuilder

      public VulnerabilityVendor.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<VulnerabilityVendor.Builder,VulnerabilityVendor>
    • builder

      public static VulnerabilityVendor.Builder builder()
    • serializableBuilderClass

      public static Class<? extends VulnerabilityVendor.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo