java.lang.Object
software.amazon.awssdk.services.securityhub.model.WafAction
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<WafAction.Builder,WafAction>

@Generated("software.amazon.awssdk:codegen") public final class WafAction extends Object implements SdkPojo, Serializable, ToCopyableBuilder<WafAction.Builder,WafAction>

Details about the action that CloudFront or WAF takes when a web request matches the conditions in the rule.

See Also:
  • Method Details

    • type

      public final String type()

      Specifies how you want WAF to respond to requests that match the settings in a rule.

      Valid settings include the following:

      • ALLOW - WAF allows requests

      • BLOCK - WAF blocks requests

      • COUNT - WAF increments a counter of the requests that match all of the conditions in the rule. WAF then continues to inspect the web request based on the remaining rules in the web ACL. You can't specify COUNT for the default action for a web ACL.

      Returns:
      Specifies how you want WAF to respond to requests that match the settings in a rule.

      Valid settings include the following:

      • ALLOW - WAF allows requests

      • BLOCK - WAF blocks requests

      • COUNT - WAF increments a counter of the requests that match all of the conditions in the rule. WAF then continues to inspect the web request based on the remaining rules in the web ACL. You can't specify COUNT for the default action for a web ACL.

    • toBuilder

      public WafAction.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<WafAction.Builder,WafAction>
    • builder

      public static WafAction.Builder builder()
    • serializableBuilderClass

      public static Class<? extends WafAction.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo