Class Workflow
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Workflow.Builder,Workflow>
Provides details about the status of the investigation into a finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Workflow.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends Workflow.Builder>final WorkflowStatusstatus()The status of the investigation into the finding.final StringThe status of the investigation into the finding.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
status
The status of the investigation into the finding. The workflow status is specific to an individual finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets the workflow status from
NOTIFIEDorRESOLVEDtoNEWin the following cases:-
RecordStatechanges fromARCHIVEDtoACTIVE. -
ComplianceStatuschanges fromPASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnWorkflowStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the investigation into the finding. The workflow status is specific to an individual
finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets the workflow status from
NOTIFIEDorRESOLVEDtoNEWin the following cases:-
RecordStatechanges fromARCHIVEDtoACTIVE. -
ComplianceStatuschanges fromPASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved.
-
- See Also:
-
-
statusAsString
The status of the investigation into the finding. The workflow status is specific to an individual finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets the workflow status from
NOTIFIEDorRESOLVEDtoNEWin the following cases:-
RecordStatechanges fromARCHIVEDtoACTIVE. -
ComplianceStatuschanges fromPASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnWorkflowStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the investigation into the finding. The workflow status is specific to an individual
finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets the workflow status from
NOTIFIEDorRESOLVEDtoNEWin the following cases:-
RecordStatechanges fromARCHIVEDtoACTIVE. -
ComplianceStatuschanges fromPASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved.
-
- See Also:
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Workflow.Builder,Workflow>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-