Class WorkflowUpdate
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<WorkflowUpdate.Builder,WorkflowUpdate>
Used to update information about the investigation into the finding.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic WorkflowUpdate.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends WorkflowUpdate.Builder>final WorkflowStatusstatus()The status of the investigation into the finding.final StringThe status of the investigation into the finding.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
status
The status of the investigation into the finding. The workflow status is specific to an individual finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets
WorkFlowStatusfromNOTIFIEDorRESOLVEDtoNEWin the following cases:-
The record state changes from
ARCHIVEDtoACTIVE. -
The compliance status changes from
PASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnWorkflowStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the investigation into the finding. The workflow status is specific to an individual
finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets
WorkFlowStatusfromNOTIFIEDorRESOLVEDtoNEWin the following cases:-
The record state changes from
ARCHIVEDtoACTIVE. -
The compliance status changes from
PASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated.
-
- See Also:
-
-
statusAsString
The status of the investigation into the finding. The workflow status is specific to an individual finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets
WorkFlowStatusfromNOTIFIEDorRESOLVEDtoNEWin the following cases:-
The record state changes from
ARCHIVEDtoACTIVE. -
The compliance status changes from
PASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnWorkflowStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the investigation into the finding. The workflow status is specific to an individual
finding. It does not affect the generation of new findings. For example, setting the workflow status to
SUPPRESSEDorRESOLVEDdoes not prevent a new finding for the same issue.The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets
WorkFlowStatusfromNOTIFIEDorRESOLVEDtoNEWin the following cases:-
The record state changes from
ARCHIVEDtoACTIVE. -
The compliance status changes from
PASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE.
-
-
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated.
-
- See Also:
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<WorkflowUpdate.Builder,WorkflowUpdate>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-