Uses of Class
software.amazon.awssdk.services.securityhub.model.ActorSession
Packages that use ActorSession
-
Uses of ActorSession in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ActorSessionModifier and TypeMethodDescriptionfinal ActorSessionActor.session()Contains information about the user session where the activity initiated.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ActorSessionModifier and TypeMethodDescriptionActor.Builder.session(ActorSession session) Contains information about the user session where the activity initiated.