Uses of Class
software.amazon.awssdk.services.securityhub.model.AllowedOperators
-
Packages that use AllowedOperators Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of AllowedOperators in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AllowedOperators Modifier and Type Method Description AllowedOperatorsOcsfFindingFilters. compositeOperator()The logical operators used to combine the filtering on multipleCompositeFilters.AllowedOperatorsResourcesFilters. compositeOperator()The logical operator used to combine multiple filter conditions in the structure.static AllowedOperatorsAllowedOperators. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.AllowedOperatorsCompositeFilter. operator()The logical operator used to combine multiple filter conditions.AllowedOperatorsResourcesCompositeFilter. operator()The logical operator used to combine multiple filter conditions.static AllowedOperatorsAllowedOperators. valueOf(String name)Returns the enum constant of this type with the specified name.static AllowedOperators[]AllowedOperators. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AllowedOperators Modifier and Type Method Description static Set<AllowedOperators>AllowedOperators. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type AllowedOperators Modifier and Type Method Description OcsfFindingFilters.BuilderOcsfFindingFilters.Builder. compositeOperator(AllowedOperators compositeOperator)The logical operators used to combine the filtering on multipleCompositeFilters.ResourcesFilters.BuilderResourcesFilters.Builder. compositeOperator(AllowedOperators compositeOperator)The logical operator used to combine multiple filter conditions in the structure.CompositeFilter.BuilderCompositeFilter.Builder. operator(AllowedOperators operator)The logical operator used to combine multiple filter conditions.ResourcesCompositeFilter.BuilderResourcesCompositeFilter.Builder. operator(AllowedOperators operator)The logical operator used to combine multiple filter conditions.
-