Uses of Enum
software.amazon.awssdk.services.securityhub.model.AutoEnableStandards
Packages that use AutoEnableStandards
-
Uses of AutoEnableStandards in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AutoEnableStandardsModifier and TypeMethodDescriptionfinal AutoEnableStandardsDescribeOrganizationConfigurationResponse.autoEnableStandards()Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.final AutoEnableStandardsUpdateOrganizationConfigurationRequest.autoEnableStandards()Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.static AutoEnableStandardsUse this in place of valueOf to convert the raw string returned by the service into the enum value.static AutoEnableStandardsReturns the enum constant of this type with the specified name.static AutoEnableStandards[]AutoEnableStandards.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AutoEnableStandardsModifier and TypeMethodDescriptionstatic Set<AutoEnableStandards>AutoEnableStandards.knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type AutoEnableStandardsModifier and TypeMethodDescriptionDescribeOrganizationConfigurationResponse.Builder.autoEnableStandards(AutoEnableStandards autoEnableStandards) Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.UpdateOrganizationConfigurationRequest.Builder.autoEnableStandards(AutoEnableStandards autoEnableStandards) Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization.