Uses of Class
software.amazon.awssdk.services.securityhub.model.AutomationRulesAction
Packages that use AutomationRulesAction
-
Uses of AutomationRulesAction in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AutomationRulesActionModifier and TypeMethodDescriptionfinal List<AutomationRulesAction>AutomationRulesConfig.actions()One or more actions to update finding fields if a finding matches the defined criteria of the rule.final List<AutomationRulesAction>CreateAutomationRuleRequest.actions()One or more actions to update finding fields if a finding matches the conditions specified inCriteria.final List<AutomationRulesAction>UpdateAutomationRulesRequestItem.actions()One or more actions to update finding fields if a finding matches the conditions specified inCriteria.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type AutomationRulesActionModifier and TypeMethodDescriptionAutomationRulesConfig.Builder.actions(AutomationRulesAction... actions) One or more actions to update finding fields if a finding matches the defined criteria of the rule.CreateAutomationRuleRequest.Builder.actions(AutomationRulesAction... actions) One or more actions to update finding fields if a finding matches the conditions specified inCriteria.UpdateAutomationRulesRequestItem.Builder.actions(AutomationRulesAction... actions) One or more actions to update finding fields if a finding matches the conditions specified inCriteria.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type AutomationRulesActionModifier and TypeMethodDescriptionAutomationRulesConfig.Builder.actions(Collection<AutomationRulesAction> actions) One or more actions to update finding fields if a finding matches the defined criteria of the rule.CreateAutomationRuleRequest.Builder.actions(Collection<AutomationRulesAction> actions) One or more actions to update finding fields if a finding matches the conditions specified inCriteria.UpdateAutomationRulesRequestItem.Builder.actions(Collection<AutomationRulesAction> actions) One or more actions to update finding fields if a finding matches the conditions specified inCriteria.