Uses of Interface
software.amazon.awssdk.services.securityhub.model.AutomationRulesConfig.Builder
Packages that use AutomationRulesConfig.Builder
-
Uses of AutomationRulesConfig.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AutomationRulesConfig.BuilderModifier and TypeMethodDescriptionAutomationRulesConfig.Builder.actions(Collection<AutomationRulesAction> actions) One or more actions to update finding fields if a finding matches the defined criteria of the rule.AutomationRulesConfig.Builder.actions(Consumer<AutomationRulesAction.Builder>... actions) One or more actions to update finding fields if a finding matches the defined criteria of the rule.AutomationRulesConfig.Builder.actions(AutomationRulesAction... actions) One or more actions to update finding fields if a finding matches the defined criteria of the rule.AutomationRulesConfig.builder()A timestamp that indicates when the rule was created.The principal that created a rule.default AutomationRulesConfig.BuilderAutomationRulesConfig.Builder.criteria(Consumer<AutomationRulesFindingFilters.Builder> criteria) A set of Amazon Web Services Security Finding Format finding field attributes and corresponding expected values that Security Hub CSPM uses to filter findings.AutomationRulesConfig.Builder.criteria(AutomationRulesFindingFilters criteria) A set of Amazon Web Services Security Finding Format finding field attributes and corresponding expected values that Security Hub CSPM uses to filter findings.AutomationRulesConfig.Builder.description(String description) A description of the rule.AutomationRulesConfig.Builder.isTerminal(Boolean isTerminal) Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria.The Amazon Resource Name (ARN) of a rule.The name of the rule.An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings.AutomationRulesConfig.Builder.ruleStatus(String ruleStatus) Whether the rule is active after it is created.AutomationRulesConfig.Builder.ruleStatus(RuleStatus ruleStatus) Whether the rule is active after it is created.AutomationRulesConfig.toBuilder()A timestamp that indicates when the rule was most recently updated.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AutomationRulesConfig.BuilderModifier and TypeMethodDescriptionstatic Class<? extends AutomationRulesConfig.Builder>AutomationRulesConfig.serializableBuilderClass()