Uses of Interface
software.amazon.awssdk.services.securityhub.model.AutomationRulesMetadata.Builder
Packages that use AutomationRulesMetadata.Builder
-
Uses of AutomationRulesMetadata.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AutomationRulesMetadata.BuilderModifier and TypeMethodDescriptionAutomationRulesMetadata.builder()A timestamp that indicates when the rule was created.The principal that created a rule.AutomationRulesMetadata.Builder.description(String description) A description of the rule.AutomationRulesMetadata.Builder.isTerminal(Boolean isTerminal) Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria.The Amazon Resource Name (ARN) for the rule.The name of the rule.An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings.AutomationRulesMetadata.Builder.ruleStatus(String ruleStatus) Whether the rule is active after it is created.AutomationRulesMetadata.Builder.ruleStatus(RuleStatus ruleStatus) Whether the rule is active after it is created.AutomationRulesMetadata.toBuilder()A timestamp that indicates when the rule was most recently updated.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AutomationRulesMetadata.BuilderModifier and TypeMethodDescriptionstatic Class<? extends AutomationRulesMetadata.Builder>AutomationRulesMetadata.serializableBuilderClass()