Uses of Interface
software.amazon.awssdk.services.securityhub.model.AwsCloudFrontDistributionOriginCustomOriginConfig.Builder
Packages that use AwsCloudFrontDistributionOriginCustomOriginConfig.Builder
-
Uses of AwsCloudFrontDistributionOriginCustomOriginConfig.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AwsCloudFrontDistributionOriginCustomOriginConfig.BuilderModifier and TypeMethodDescriptionAwsCloudFrontDistributionOriginCustomOriginConfig.builder()The HTTP port that CloudFront uses to connect to the origin.The HTTPS port that CloudFront uses to connect to the origin.AwsCloudFrontDistributionOriginCustomOriginConfig.Builder.originKeepaliveTimeout(Integer originKeepaliveTimeout) Specifies how long, in seconds, CloudFront persists its connection to the origin.AwsCloudFrontDistributionOriginCustomOriginConfig.Builder.originProtocolPolicy(String originProtocolPolicy) Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.AwsCloudFrontDistributionOriginCustomOriginConfig.Builder.originReadTimeout(Integer originReadTimeout) Specifies how long, in seconds, CloudFront waits for a response from the origin.AwsCloudFrontDistributionOriginCustomOriginConfig.Builder.originSslProtocols(Consumer<AwsCloudFrontDistributionOriginSslProtocols.Builder> originSslProtocols) Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.AwsCloudFrontDistributionOriginCustomOriginConfig.Builder.originSslProtocols(AwsCloudFrontDistributionOriginSslProtocols originSslProtocols) Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.AwsCloudFrontDistributionOriginCustomOriginConfig.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AwsCloudFrontDistributionOriginCustomOriginConfig.BuilderModifier and TypeMethodDescriptionstatic Class<? extends AwsCloudFrontDistributionOriginCustomOriginConfig.Builder>AwsCloudFrontDistributionOriginCustomOriginConfig.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type AwsCloudFrontDistributionOriginCustomOriginConfig.BuilderModifier and TypeMethodDescriptionAwsCloudFrontDistributionOriginItem.Builder.customOriginConfig(Consumer<AwsCloudFrontDistributionOriginCustomOriginConfig.Builder> customOriginConfig) An origin that is not an Amazon S3 bucket, with one exception.