Uses of Interface
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableStreamSpecification.Builder
Packages that use AwsDynamoDbTableStreamSpecification.Builder
-
Uses of AwsDynamoDbTableStreamSpecification.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AwsDynamoDbTableStreamSpecification.BuilderModifier and TypeMethodDescriptionAwsDynamoDbTableStreamSpecification.builder()AwsDynamoDbTableStreamSpecification.Builder.streamEnabled(Boolean streamEnabled) Indicates whether DynamoDB Streams is enabled on the table.AwsDynamoDbTableStreamSpecification.Builder.streamViewType(String streamViewType) Determines the information that is written to the table.AwsDynamoDbTableStreamSpecification.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AwsDynamoDbTableStreamSpecification.BuilderModifier and TypeMethodDescriptionstatic Class<? extends AwsDynamoDbTableStreamSpecification.Builder>AwsDynamoDbTableStreamSpecification.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type AwsDynamoDbTableStreamSpecification.BuilderModifier and TypeMethodDescriptiondefault AwsDynamoDbTableDetails.BuilderAwsDynamoDbTableDetails.Builder.streamSpecification(Consumer<AwsDynamoDbTableStreamSpecification.Builder> streamSpecification) The current DynamoDB Streams configuration for the table.