Uses of Class
software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainMasterUserOptionsDetails
Packages that use AwsOpenSearchServiceDomainMasterUserOptionsDetails
-
Uses of AwsOpenSearchServiceDomainMasterUserOptionsDetails in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AwsOpenSearchServiceDomainMasterUserOptionsDetailsModifier and TypeMethodDescriptionAwsOpenSearchServiceDomainAdvancedSecurityOptionsDetails.masterUserOptions()Specifies information about the master user of the domain.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type AwsOpenSearchServiceDomainMasterUserOptionsDetailsModifier and TypeMethodDescriptionAwsOpenSearchServiceDomainAdvancedSecurityOptionsDetails.Builder.masterUserOptions(AwsOpenSearchServiceDomainMasterUserOptionsDetails masterUserOptions) Specifies information about the master user of the domain.