Uses of Interface
software.amazon.awssdk.services.securityhub.model.AwsRedshiftClusterPendingModifiedValues.Builder
Packages that use AwsRedshiftClusterPendingModifiedValues.Builder
-
Uses of AwsRedshiftClusterPendingModifiedValues.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AwsRedshiftClusterPendingModifiedValues.BuilderModifier and TypeMethodDescriptionAwsRedshiftClusterPendingModifiedValues.Builder.automatedSnapshotRetentionPeriod(Integer automatedSnapshotRetentionPeriod) The pending or in-progress change to the automated snapshot retention period.AwsRedshiftClusterPendingModifiedValues.builder()AwsRedshiftClusterPendingModifiedValues.Builder.clusterIdentifier(String clusterIdentifier) The pending or in-progress change to the identifier for the cluster.AwsRedshiftClusterPendingModifiedValues.Builder.clusterType(String clusterType) The pending or in-progress change to the cluster type.AwsRedshiftClusterPendingModifiedValues.Builder.clusterVersion(String clusterVersion) The pending or in-progress change to the service version.AwsRedshiftClusterPendingModifiedValues.Builder.encryptionType(String encryptionType) The encryption type for a cluster.AwsRedshiftClusterPendingModifiedValues.Builder.enhancedVpcRouting(Boolean enhancedVpcRouting) Indicates whether to create the cluster with enhanced VPC routing enabled.AwsRedshiftClusterPendingModifiedValues.Builder.maintenanceTrackName(String maintenanceTrackName) The name of the maintenance track that the cluster changes to during the next maintenance window.AwsRedshiftClusterPendingModifiedValues.Builder.masterUserPassword(String masterUserPassword) The pending or in-progress change to the master user password for the cluster.The pending or in-progress change to the cluster's node type.AwsRedshiftClusterPendingModifiedValues.Builder.numberOfNodes(Integer numberOfNodes) The pending or in-progress change to the number of nodes in the cluster.AwsRedshiftClusterPendingModifiedValues.Builder.publiclyAccessible(Boolean publiclyAccessible) The pending or in-progress change to whether the cluster can be connected to from the public network.AwsRedshiftClusterPendingModifiedValues.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AwsRedshiftClusterPendingModifiedValues.BuilderModifier and TypeMethodDescriptionstatic Class<? extends AwsRedshiftClusterPendingModifiedValues.Builder>AwsRedshiftClusterPendingModifiedValues.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type AwsRedshiftClusterPendingModifiedValues.BuilderModifier and TypeMethodDescriptionAwsRedshiftClusterDetails.Builder.pendingModifiedValues(Consumer<AwsRedshiftClusterPendingModifiedValues.Builder> pendingModifiedValues) A list of changes to the cluster that are currently pending.