Uses of Class
software.amazon.awssdk.services.securityhub.model.AwsS3BucketServerSideEncryptionRule
Packages that use AwsS3BucketServerSideEncryptionRule
-
Uses of AwsS3BucketServerSideEncryptionRule in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type AwsS3BucketServerSideEncryptionRuleModifier and TypeMethodDescriptionAwsS3BucketServerSideEncryptionConfiguration.rules()The encryption rules that are applied to the S3 bucket.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type AwsS3BucketServerSideEncryptionRuleModifier and TypeMethodDescriptionAwsS3BucketServerSideEncryptionConfiguration.Builder.rules(AwsS3BucketServerSideEncryptionRule... rules) The encryption rules that are applied to the S3 bucket.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type AwsS3BucketServerSideEncryptionRuleModifier and TypeMethodDescriptionAwsS3BucketServerSideEncryptionConfiguration.Builder.rules(Collection<AwsS3BucketServerSideEncryptionRule> rules) The encryption rules that are applied to the S3 bucket.