Uses of Class
software.amazon.awssdk.services.securityhub.model.AwsStepFunctionStateMachineDetails
Packages that use AwsStepFunctionStateMachineDetails
-
Uses of AwsStepFunctionStateMachineDetails in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return AwsStepFunctionStateMachineDetailsModifier and TypeMethodDescriptionResourceDetails.awsStepFunctionStateMachine()Provides details about an Step Functions state machine, which is a workflow consisting of a series of event-driven steps.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type AwsStepFunctionStateMachineDetailsModifier and TypeMethodDescriptionResourceDetails.Builder.awsStepFunctionStateMachine(AwsStepFunctionStateMachineDetails awsStepFunctionStateMachine) Provides details about an Step Functions state machine, which is a workflow consisting of a series of event-driven steps.