Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchDisableStandardsRequest
Packages that use BatchDisableStandardsRequest
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchDisableStandardsRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type BatchDisableStandardsRequestModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchDisableStandards(BatchDisableStandardsRequest batchDisableStandardsRequest) Disables the standards specified by the providedStandardsSubscriptionArns.default BatchDisableStandardsResponseSecurityHubClient.batchDisableStandards(BatchDisableStandardsRequest batchDisableStandardsRequest) Disables the standards specified by the providedStandardsSubscriptionArns. -
Uses of BatchDisableStandardsRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type BatchDisableStandardsRequestModifier and TypeMethodDescriptionBatchDisableStandardsRequestMarshaller.marshall(BatchDisableStandardsRequest batchDisableStandardsRequest)