Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchGetAutomationRulesRequest
Packages that use BatchGetAutomationRulesRequest
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchGetAutomationRulesRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type BatchGetAutomationRulesRequestModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchGetAutomationRules(BatchGetAutomationRulesRequest batchGetAutomationRulesRequest) Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).default BatchGetAutomationRulesResponseSecurityHubClient.batchGetAutomationRules(BatchGetAutomationRulesRequest batchGetAutomationRulesRequest) Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs). -
Uses of BatchGetAutomationRulesRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type BatchGetAutomationRulesRequestModifier and TypeMethodDescriptionBatchGetAutomationRulesRequestMarshaller.marshall(BatchGetAutomationRulesRequest batchGetAutomationRulesRequest)