Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchGetAutomationRulesResponse
Packages that use BatchGetAutomationRulesResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchGetAutomationRulesResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return BatchGetAutomationRulesResponseModifier and TypeMethodDescriptiondefault BatchGetAutomationRulesResponseSecurityHubClient.batchGetAutomationRules(Consumer<BatchGetAutomationRulesRequest.Builder> batchGetAutomationRulesRequest) Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).default BatchGetAutomationRulesResponseSecurityHubClient.batchGetAutomationRules(BatchGetAutomationRulesRequest batchGetAutomationRulesRequest) Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type BatchGetAutomationRulesResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchGetAutomationRules(Consumer<BatchGetAutomationRulesRequest.Builder> batchGetAutomationRulesRequest) Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).SecurityHubAsyncClient.batchGetAutomationRules(BatchGetAutomationRulesRequest batchGetAutomationRulesRequest) Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).