Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchGetSecurityControlsRequest
Packages that use BatchGetSecurityControlsRequest
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchGetSecurityControlsRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type BatchGetSecurityControlsRequestModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchGetSecurityControls(BatchGetSecurityControlsRequest batchGetSecurityControlsRequest) Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web Services Region.default BatchGetSecurityControlsResponseSecurityHubClient.batchGetSecurityControls(BatchGetSecurityControlsRequest batchGetSecurityControlsRequest) Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web Services Region. -
Uses of BatchGetSecurityControlsRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type BatchGetSecurityControlsRequestModifier and TypeMethodDescriptionBatchGetSecurityControlsRequestMarshaller.marshall(BatchGetSecurityControlsRequest batchGetSecurityControlsRequest)