Uses of Interface
software.amazon.awssdk.services.securityhub.model.BatchGetSecurityControlsResponse.Builder
Packages that use BatchGetSecurityControlsResponse.Builder
-
Uses of BatchGetSecurityControlsResponse.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return BatchGetSecurityControlsResponse.BuilderModifier and TypeMethodDescriptionBatchGetSecurityControlsResponse.builder()BatchGetSecurityControlsResponse.Builder.securityControls(Collection<SecurityControl> securityControls) An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control.BatchGetSecurityControlsResponse.Builder.securityControls(Consumer<SecurityControl.Builder>... securityControls) An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control.BatchGetSecurityControlsResponse.Builder.securityControls(SecurityControl... securityControls) An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control.BatchGetSecurityControlsResponse.toBuilder()BatchGetSecurityControlsResponse.Builder.unprocessedIds(Collection<UnprocessedSecurityControl> unprocessedIds) A security control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) for which details cannot be returned.BatchGetSecurityControlsResponse.Builder.unprocessedIds(Consumer<UnprocessedSecurityControl.Builder>... unprocessedIds) A security control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) for which details cannot be returned.BatchGetSecurityControlsResponse.Builder.unprocessedIds(UnprocessedSecurityControl... unprocessedIds) A security control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) for which details cannot be returned.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type BatchGetSecurityControlsResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends BatchGetSecurityControlsResponse.Builder>BatchGetSecurityControlsResponse.serializableBuilderClass()