Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchUpdateAutomationRulesResponse
Packages that use BatchUpdateAutomationRulesResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchUpdateAutomationRulesResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return BatchUpdateAutomationRulesResponseModifier and TypeMethodDescriptionSecurityHubClient.batchUpdateAutomationRules(Consumer<BatchUpdateAutomationRulesRequest.Builder> batchUpdateAutomationRulesRequest) Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.SecurityHubClient.batchUpdateAutomationRules(BatchUpdateAutomationRulesRequest batchUpdateAutomationRulesRequest) Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type BatchUpdateAutomationRulesResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchUpdateAutomationRules(Consumer<BatchUpdateAutomationRulesRequest.Builder> batchUpdateAutomationRulesRequest) Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.SecurityHubAsyncClient.batchUpdateAutomationRules(BatchUpdateAutomationRulesRequest batchUpdateAutomationRulesRequest) Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.