Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchUpdateFindingsRequest
-
Packages that use BatchUpdateFindingsRequest Package Description software.amazon.awssdk.services.securityhub Security Hub provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.software.amazon.awssdk.services.securityhub.transform -
-
Uses of BatchUpdateFindingsRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type BatchUpdateFindingsRequest Modifier and Type Method Description default CompletableFuture<BatchUpdateFindingsResponse>SecurityHubAsyncClient. batchUpdateFindings(BatchUpdateFindingsRequest batchUpdateFindingsRequest)Used by Security Hub customers to update information about their investigation into one or more findings.default BatchUpdateFindingsResponseSecurityHubClient. batchUpdateFindings(BatchUpdateFindingsRequest batchUpdateFindingsRequest)Used by Security Hub customers to update information about their investigation into one or more findings. -
Uses of BatchUpdateFindingsRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type BatchUpdateFindingsRequest Modifier and Type Method Description SdkHttpFullRequestBatchUpdateFindingsRequestMarshaller. marshall(BatchUpdateFindingsRequest batchUpdateFindingsRequest)
-