Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchUpdateFindingsResponse
Packages that use BatchUpdateFindingsResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchUpdateFindingsResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return BatchUpdateFindingsResponseModifier and TypeMethodDescriptiondefault BatchUpdateFindingsResponseSecurityHubClient.batchUpdateFindings(Consumer<BatchUpdateFindingsRequest.Builder> batchUpdateFindingsRequest) Used by Security Hub CSPM customers to update information about their investigation into one or more findings.default BatchUpdateFindingsResponseSecurityHubClient.batchUpdateFindings(BatchUpdateFindingsRequest batchUpdateFindingsRequest) Used by Security Hub CSPM customers to update information about their investigation into one or more findings.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type BatchUpdateFindingsResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchUpdateFindings(Consumer<BatchUpdateFindingsRequest.Builder> batchUpdateFindingsRequest) Used by Security Hub CSPM customers to update information about their investigation into one or more findings.SecurityHubAsyncClient.batchUpdateFindings(BatchUpdateFindingsRequest batchUpdateFindingsRequest) Used by Security Hub CSPM customers to update information about their investigation into one or more findings.