Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchUpdateFindingsV2UnprocessedFindingErrorCode
-
Packages that use BatchUpdateFindingsV2UnprocessedFindingErrorCode Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of BatchUpdateFindingsV2UnprocessedFindingErrorCode in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return BatchUpdateFindingsV2UnprocessedFindingErrorCode Modifier and Type Method Description BatchUpdateFindingsV2UnprocessedFindingErrorCodeBatchUpdateFindingsV2UnprocessedFinding. errorCode()Indicates the specific type of error preventing successful processing of a finding during a batch update operation.static BatchUpdateFindingsV2UnprocessedFindingErrorCodeBatchUpdateFindingsV2UnprocessedFindingErrorCode. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static BatchUpdateFindingsV2UnprocessedFindingErrorCodeBatchUpdateFindingsV2UnprocessedFindingErrorCode. valueOf(String name)Returns the enum constant of this type with the specified name.static BatchUpdateFindingsV2UnprocessedFindingErrorCode[]BatchUpdateFindingsV2UnprocessedFindingErrorCode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type BatchUpdateFindingsV2UnprocessedFindingErrorCode Modifier and Type Method Description static Set<BatchUpdateFindingsV2UnprocessedFindingErrorCode>BatchUpdateFindingsV2UnprocessedFindingErrorCode. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type BatchUpdateFindingsV2UnprocessedFindingErrorCode Modifier and Type Method Description BatchUpdateFindingsV2UnprocessedFinding.BuilderBatchUpdateFindingsV2UnprocessedFinding.Builder. errorCode(BatchUpdateFindingsV2UnprocessedFindingErrorCode errorCode)Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
-