Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchUpdateStandardsControlAssociationsRequest
Packages that use BatchUpdateStandardsControlAssociationsRequest
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchUpdateStandardsControlAssociationsRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type BatchUpdateStandardsControlAssociationsRequestModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchUpdateStandardsControlAssociations(BatchUpdateStandardsControlAssociationsRequest batchUpdateStandardsControlAssociationsRequest) For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.SecurityHubClient.batchUpdateStandardsControlAssociations(BatchUpdateStandardsControlAssociationsRequest batchUpdateStandardsControlAssociationsRequest) For a batch of security controls and standards, this operation updates the enablement status of a control in a standard. -
Uses of BatchUpdateStandardsControlAssociationsRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type BatchUpdateStandardsControlAssociationsRequestModifier and TypeMethodDescriptionBatchUpdateStandardsControlAssociationsRequestMarshaller.marshall(BatchUpdateStandardsControlAssociationsRequest batchUpdateStandardsControlAssociationsRequest)