Uses of Class
software.amazon.awssdk.services.securityhub.model.BatchUpdateStandardsControlAssociationsResponse
Packages that use BatchUpdateStandardsControlAssociationsResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of BatchUpdateStandardsControlAssociationsResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return BatchUpdateStandardsControlAssociationsResponseModifier and TypeMethodDescriptionSecurityHubClient.batchUpdateStandardsControlAssociations(Consumer<BatchUpdateStandardsControlAssociationsRequest.Builder> batchUpdateStandardsControlAssociationsRequest) For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.SecurityHubClient.batchUpdateStandardsControlAssociations(BatchUpdateStandardsControlAssociationsRequest batchUpdateStandardsControlAssociationsRequest) For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type BatchUpdateStandardsControlAssociationsResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.batchUpdateStandardsControlAssociations(Consumer<BatchUpdateStandardsControlAssociationsRequest.Builder> batchUpdateStandardsControlAssociationsRequest) For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.SecurityHubAsyncClient.batchUpdateStandardsControlAssociations(BatchUpdateStandardsControlAssociationsRequest batchUpdateStandardsControlAssociationsRequest) For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.