Uses of Enum
software.amazon.awssdk.services.securityhub.model.ConnectorStatus
Packages that use ConnectorStatus
-
Uses of ConnectorStatus in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ConnectorStatusModifier and TypeMethodDescriptionfinal ConnectorStatusCreateConnectorV2Response.connectorStatus()The current status of the connectorV2.final ConnectorStatusHealthCheck.connectorStatus()The status of the connectorV2.final ConnectorStatusListConnectorsV2Request.connectorStatus()The status for the connectorV2.final ConnectorStatusProviderSummary.connectorStatus()The status for the connectorV2.static ConnectorStatusUse this in place of valueOf to convert the raw string returned by the service into the enum value.static ConnectorStatusReturns the enum constant of this type with the specified name.static ConnectorStatus[]ConnectorStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type ConnectorStatusMethods in software.amazon.awssdk.services.securityhub.model with parameters of type ConnectorStatusModifier and TypeMethodDescriptionCreateConnectorV2Response.Builder.connectorStatus(ConnectorStatus connectorStatus) The current status of the connectorV2.HealthCheck.Builder.connectorStatus(ConnectorStatus connectorStatus) The status of the connectorV2.ListConnectorsV2Request.Builder.connectorStatus(ConnectorStatus connectorStatus) The status for the connectorV2.ProviderSummary.Builder.connectorStatus(ConnectorStatus connectorStatus) The status for the connectorV2.