Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateAggregatorV2Request
Packages that use CreateAggregatorV2Request
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of CreateAggregatorV2Request in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type CreateAggregatorV2RequestModifier and TypeMethodDescriptionSecurityHubAsyncClient.createAggregatorV2(CreateAggregatorV2Request createAggregatorV2Request) Enables aggregation across Amazon Web Services Regions.default CreateAggregatorV2ResponseSecurityHubClient.createAggregatorV2(CreateAggregatorV2Request createAggregatorV2Request) Enables aggregation across Amazon Web Services Regions. -
Uses of CreateAggregatorV2Request in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type CreateAggregatorV2RequestModifier and TypeMethodDescriptionCreateAggregatorV2RequestMarshaller.marshall(CreateAggregatorV2Request createAggregatorV2Request)