Uses of Interface
software.amazon.awssdk.services.securityhub.model.CreateAutomationRuleRequest.Builder
Packages that use CreateAutomationRuleRequest.Builder
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of CreateAutomationRuleRequest.Builder in software.amazon.awssdk.services.securityhub
Method parameters in software.amazon.awssdk.services.securityhub with type arguments of type CreateAutomationRuleRequest.BuilderModifier and TypeMethodDescriptionSecurityHubAsyncClient.createAutomationRule(Consumer<CreateAutomationRuleRequest.Builder> createAutomationRuleRequest) Creates an automation rule based on input parameters.default CreateAutomationRuleResponseSecurityHubClient.createAutomationRule(Consumer<CreateAutomationRuleRequest.Builder> createAutomationRuleRequest) Creates an automation rule based on input parameters. -
Uses of CreateAutomationRuleRequest.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return CreateAutomationRuleRequest.BuilderModifier and TypeMethodDescriptionCreateAutomationRuleRequest.Builder.actions(Collection<AutomationRulesAction> actions) One or more actions to update finding fields if a finding matches the conditions specified inCriteria.CreateAutomationRuleRequest.Builder.actions(Consumer<AutomationRulesAction.Builder>... actions) One or more actions to update finding fields if a finding matches the conditions specified inCriteria.CreateAutomationRuleRequest.Builder.actions(AutomationRulesAction... actions) One or more actions to update finding fields if a finding matches the conditions specified inCriteria.CreateAutomationRuleRequest.builder()CreateAutomationRuleRequest.Builder.criteria(Consumer<AutomationRulesFindingFilters.Builder> criteria) A set of ASFF finding field attributes and corresponding expected values that Security Hub CSPM uses to filter findings.CreateAutomationRuleRequest.Builder.criteria(AutomationRulesFindingFilters criteria) A set of ASFF finding field attributes and corresponding expected values that Security Hub CSPM uses to filter findings.CreateAutomationRuleRequest.Builder.description(String description) A description of the rule.CreateAutomationRuleRequest.Builder.isTerminal(Boolean isTerminal) Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria.CreateAutomationRuleRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) CreateAutomationRuleRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The name of the rule.An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings.CreateAutomationRuleRequest.Builder.ruleStatus(String ruleStatus) Whether the rule is active after it is created.CreateAutomationRuleRequest.Builder.ruleStatus(RuleStatus ruleStatus) Whether the rule is active after it is created.User-defined tags associated with an automation rule.CreateAutomationRuleRequest.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type CreateAutomationRuleRequest.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CreateAutomationRuleRequest.Builder>CreateAutomationRuleRequest.serializableBuilderClass()