Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateAutomationRuleV2Request
-
Packages that use CreateAutomationRuleV2Request Package Description software.amazon.awssdk.services.securityhub Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.software.amazon.awssdk.services.securityhub.transform -
-
Uses of CreateAutomationRuleV2Request in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type CreateAutomationRuleV2Request Modifier and Type Method Description default CompletableFuture<CreateAutomationRuleV2Response>SecurityHubAsyncClient. createAutomationRuleV2(CreateAutomationRuleV2Request createAutomationRuleV2Request)Creates a V2 automation rule.default CreateAutomationRuleV2ResponseSecurityHubClient. createAutomationRuleV2(CreateAutomationRuleV2Request createAutomationRuleV2Request)Creates a V2 automation rule. -
Uses of CreateAutomationRuleV2Request in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type CreateAutomationRuleV2Request Modifier and Type Method Description SdkHttpFullRequestCreateAutomationRuleV2RequestMarshaller. marshall(CreateAutomationRuleV2Request createAutomationRuleV2Request)
-