Uses of Interface
software.amazon.awssdk.services.securityhub.model.CreateAutomationRuleV2Request.Builder
Packages that use CreateAutomationRuleV2Request.Builder
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of CreateAutomationRuleV2Request.Builder in software.amazon.awssdk.services.securityhub
Method parameters in software.amazon.awssdk.services.securityhub with type arguments of type CreateAutomationRuleV2Request.BuilderModifier and TypeMethodDescriptionSecurityHubAsyncClient.createAutomationRuleV2(Consumer<CreateAutomationRuleV2Request.Builder> createAutomationRuleV2Request) Creates a V2 automation rule.default CreateAutomationRuleV2ResponseSecurityHubClient.createAutomationRuleV2(Consumer<CreateAutomationRuleV2Request.Builder> createAutomationRuleV2Request) Creates a V2 automation rule. -
Uses of CreateAutomationRuleV2Request.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return CreateAutomationRuleV2Request.BuilderModifier and TypeMethodDescriptionCreateAutomationRuleV2Request.Builder.actions(Collection<AutomationRulesActionV2> actions) A list of actions to be performed when the rule criteria is met.CreateAutomationRuleV2Request.Builder.actions(Consumer<AutomationRulesActionV2.Builder>... actions) A list of actions to be performed when the rule criteria is met.CreateAutomationRuleV2Request.Builder.actions(AutomationRulesActionV2... actions) A list of actions to be performed when the rule criteria is met.CreateAutomationRuleV2Request.builder()CreateAutomationRuleV2Request.Builder.clientToken(String clientToken) A unique identifier used to ensure idempotency.CreateAutomationRuleV2Request.Builder.criteria(Consumer<Criteria.Builder> criteria) The filtering type and configuration of the automation rule.The filtering type and configuration of the automation rule.CreateAutomationRuleV2Request.Builder.description(String description) A description of the V2 automation rule.CreateAutomationRuleV2Request.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) CreateAutomationRuleV2Request.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The name of the V2 automation rule.The value for the rule priority.CreateAutomationRuleV2Request.Builder.ruleStatus(String ruleStatus) The status of the V2 automation rule.CreateAutomationRuleV2Request.Builder.ruleStatus(RuleStatusV2 ruleStatus) The status of the V2 automation rule.A list of key-value pairs associated with the V2 automation rule.CreateAutomationRuleV2Request.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type CreateAutomationRuleV2Request.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CreateAutomationRuleV2Request.Builder>CreateAutomationRuleV2Request.serializableBuilderClass()