Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
Packages that use CreateFindingAggregatorResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of CreateFindingAggregatorResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return CreateFindingAggregatorResponseModifier and TypeMethodDescriptiondefault CreateFindingAggregatorResponseSecurityHubClient.createFindingAggregator(Consumer<CreateFindingAggregatorRequest.Builder> createFindingAggregatorRequest) default CreateFindingAggregatorResponseSecurityHubClient.createFindingAggregator(CreateFindingAggregatorRequest createFindingAggregatorRequest) Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type CreateFindingAggregatorResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.createFindingAggregator(Consumer<CreateFindingAggregatorRequest.Builder> createFindingAggregatorRequest) SecurityHubAsyncClient.createFindingAggregator(CreateFindingAggregatorRequest createFindingAggregatorRequest)