Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateInsightResponse
Packages that use CreateInsightResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of CreateInsightResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return CreateInsightResponseModifier and TypeMethodDescriptiondefault CreateInsightResponseSecurityHubClient.createInsight(Consumer<CreateInsightRequest.Builder> createInsightRequest) Creates a custom insight in Security Hub CSPM.default CreateInsightResponseSecurityHubClient.createInsight(CreateInsightRequest createInsightRequest) Creates a custom insight in Security Hub CSPM.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type CreateInsightResponseModifier and TypeMethodDescriptiondefault CompletableFuture<CreateInsightResponse>SecurityHubAsyncClient.createInsight(Consumer<CreateInsightRequest.Builder> createInsightRequest) Creates a custom insight in Security Hub CSPM.default CompletableFuture<CreateInsightResponse>SecurityHubAsyncClient.createInsight(CreateInsightRequest createInsightRequest) Creates a custom insight in Security Hub CSPM.