Uses of Interface
software.amazon.awssdk.services.securityhub.model.CreateMembersRequest.Builder
Packages that use CreateMembersRequest.Builder
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of CreateMembersRequest.Builder in software.amazon.awssdk.services.securityhub
Method parameters in software.amazon.awssdk.services.securityhub with type arguments of type CreateMembersRequest.BuilderModifier and TypeMethodDescriptiondefault CompletableFuture<CreateMembersResponse>SecurityHubAsyncClient.createMembers(Consumer<CreateMembersRequest.Builder> createMembersRequest) Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account.default CreateMembersResponseSecurityHubClient.createMembers(Consumer<CreateMembersRequest.Builder> createMembersRequest) Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account. -
Uses of CreateMembersRequest.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return CreateMembersRequest.BuilderModifier and TypeMethodDescriptionCreateMembersRequest.Builder.accountDetails(Collection<AccountDetails> accountDetails) The list of accounts to associate with the Security Hub CSPM administrator account.CreateMembersRequest.Builder.accountDetails(Consumer<AccountDetails.Builder>... accountDetails) The list of accounts to associate with the Security Hub CSPM administrator account.CreateMembersRequest.Builder.accountDetails(AccountDetails... accountDetails) The list of accounts to associate with the Security Hub CSPM administrator account.static CreateMembersRequest.BuilderCreateMembersRequest.builder()CreateMembersRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) CreateMembersRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) CreateMembersRequest.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type CreateMembersRequest.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CreateMembersRequest.Builder>CreateMembersRequest.serializableBuilderClass()