Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateMembersResponse
Packages that use CreateMembersResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of CreateMembersResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return CreateMembersResponseModifier and TypeMethodDescriptiondefault CreateMembersResponseSecurityHubClient.createMembers(Consumer<CreateMembersRequest.Builder> createMembersRequest) Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account.default CreateMembersResponseSecurityHubClient.createMembers(CreateMembersRequest createMembersRequest) Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type CreateMembersResponseModifier and TypeMethodDescriptiondefault CompletableFuture<CreateMembersResponse>SecurityHubAsyncClient.createMembers(Consumer<CreateMembersRequest.Builder> createMembersRequest) Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account.default CompletableFuture<CreateMembersResponse>SecurityHubAsyncClient.createMembers(CreateMembersRequest createMembersRequest) Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account.