Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateTicketV2Request
-
Packages that use CreateTicketV2Request Package Description software.amazon.awssdk.services.securityhub Security Hub provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.software.amazon.awssdk.services.securityhub.transform -
-
Uses of CreateTicketV2Request in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type CreateTicketV2Request Modifier and Type Method Description default CompletableFuture<CreateTicketV2Response>SecurityHubAsyncClient. createTicketV2(CreateTicketV2Request createTicketV2Request)Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.default CreateTicketV2ResponseSecurityHubClient. createTicketV2(CreateTicketV2Request createTicketV2Request)Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID. -
Uses of CreateTicketV2Request in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type CreateTicketV2Request Modifier and Type Method Description SdkHttpFullRequestCreateTicketV2RequestMarshaller. marshall(CreateTicketV2Request createTicketV2Request)
-