Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateTicketV2Response
-
Packages that use CreateTicketV2Response Package Description software.amazon.awssdk.services.securityhub Security Hub provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices. -
-
Uses of CreateTicketV2Response in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return CreateTicketV2Response Modifier and Type Method Description default CreateTicketV2ResponseSecurityHubClient. createTicketV2(Consumer<CreateTicketV2Request.Builder> createTicketV2Request)Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.default CreateTicketV2ResponseSecurityHubClient. createTicketV2(CreateTicketV2Request createTicketV2Request)Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type CreateTicketV2Response Modifier and Type Method Description default CompletableFuture<CreateTicketV2Response>SecurityHubAsyncClient. createTicketV2(Consumer<CreateTicketV2Request.Builder> createTicketV2Request)Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.default CompletableFuture<CreateTicketV2Response>SecurityHubAsyncClient. createTicketV2(CreateTicketV2Request createTicketV2Request)Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.
-