Uses of Interface
software.amazon.awssdk.services.securityhub.model.CustomDataIdentifiersDetections.Builder
Packages that use CustomDataIdentifiersDetections.Builder
-
Uses of CustomDataIdentifiersDetections.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return CustomDataIdentifiersDetections.BuilderModifier and TypeMethodDescriptionThe ARN of the custom identifier that was used to detect the sensitive data.CustomDataIdentifiersDetections.builder()The total number of occurrences of sensitive data that were detected.he name of the custom identifier that detected the sensitive data.CustomDataIdentifiersDetections.Builder.occurrences(Consumer<Occurrences.Builder> occurrences) Details about the sensitive data that was detected.CustomDataIdentifiersDetections.Builder.occurrences(Occurrences occurrences) Details about the sensitive data that was detected.CustomDataIdentifiersDetections.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type CustomDataIdentifiersDetections.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CustomDataIdentifiersDetections.Builder>CustomDataIdentifiersDetections.serializableBuilderClass()