Uses of Class
software.amazon.awssdk.services.securityhub.model.DisableSecurityHubV2Response
-
Packages that use DisableSecurityHubV2Response Package Description software.amazon.awssdk.services.securityhub Security Hub provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices. -
-
Uses of DisableSecurityHubV2Response in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return DisableSecurityHubV2Response Modifier and Type Method Description default DisableSecurityHubV2ResponseSecurityHubClient. disableSecurityHubV2(Consumer<DisableSecurityHubV2Request.Builder> disableSecurityHubV2Request)Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.default DisableSecurityHubV2ResponseSecurityHubClient. disableSecurityHubV2(DisableSecurityHubV2Request disableSecurityHubV2Request)Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type DisableSecurityHubV2Response Modifier and Type Method Description default CompletableFuture<DisableSecurityHubV2Response>SecurityHubAsyncClient. disableSecurityHubV2(Consumer<DisableSecurityHubV2Request.Builder> disableSecurityHubV2Request)Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.default CompletableFuture<DisableSecurityHubV2Response>SecurityHubAsyncClient. disableSecurityHubV2(DisableSecurityHubV2Request disableSecurityHubV2Request)Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
-