Uses of Class
software.amazon.awssdk.services.securityhub.model.EnableSecurityHubRequest
Packages that use EnableSecurityHubRequest
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of EnableSecurityHubRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type EnableSecurityHubRequestModifier and TypeMethodDescriptionSecurityHubAsyncClient.enableSecurityHub(EnableSecurityHubRequest enableSecurityHubRequest) Enables Security Hub CSPM for your account in the current Region or the Region you specify in the request.default EnableSecurityHubResponseSecurityHubClient.enableSecurityHub(EnableSecurityHubRequest enableSecurityHubRequest) Enables Security Hub CSPM for your account in the current Region or the Region you specify in the request. -
Uses of EnableSecurityHubRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type EnableSecurityHubRequestModifier and TypeMethodDescriptionEnableSecurityHubRequestMarshaller.marshall(EnableSecurityHubRequest enableSecurityHubRequest)