Uses of Class
software.amazon.awssdk.services.securityhub.model.ExternalIntegrationConfiguration
Packages that use ExternalIntegrationConfiguration
-
Uses of ExternalIntegrationConfiguration in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ExternalIntegrationConfigurationModifier and TypeMethodDescriptionAutomationRulesActionV2.externalIntegrationConfiguration()The settings for integrating automation rule actions with external systems or service.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ExternalIntegrationConfigurationModifier and TypeMethodDescriptionAutomationRulesActionV2.Builder.externalIntegrationConfiguration(ExternalIntegrationConfiguration externalIntegrationConfiguration) The settings for integrating automation rule actions with external systems or service.