Uses of Class
software.amazon.awssdk.services.securityhub.model.FindingHistoryUpdateSource
Packages that use FindingHistoryUpdateSource
-
Uses of FindingHistoryUpdateSource in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return FindingHistoryUpdateSourceModifier and TypeMethodDescriptionFindingHistoryRecord.updateSource()Identifies the source of the event that changed the finding.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type FindingHistoryUpdateSourceModifier and TypeMethodDescriptionFindingHistoryRecord.Builder.updateSource(FindingHistoryUpdateSource updateSource) Identifies the source of the event that changed the finding.