Uses of Enum
software.amazon.awssdk.services.securityhub.model.FindingsTrendsStringField
Packages that use FindingsTrendsStringField
-
Uses of FindingsTrendsStringField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return FindingsTrendsStringFieldModifier and TypeMethodDescriptionFindingsTrendsStringFilter.fieldName()The name of the findings field to filter on.static FindingsTrendsStringFieldUse this in place of valueOf to convert the raw string returned by the service into the enum value.static FindingsTrendsStringFieldReturns the enum constant of this type with the specified name.static FindingsTrendsStringField[]FindingsTrendsStringField.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type FindingsTrendsStringFieldModifier and TypeMethodDescriptionstatic Set<FindingsTrendsStringField>FindingsTrendsStringField.knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type FindingsTrendsStringFieldModifier and TypeMethodDescriptionFindingsTrendsStringFilter.Builder.fieldName(FindingsTrendsStringField fieldName) The name of the findings field to filter on.