Uses of Class
software.amazon.awssdk.services.securityhub.model.GetAutomationRuleV2Request
-
Packages that use GetAutomationRuleV2Request Package Description software.amazon.awssdk.services.securityhub Security Hub provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.software.amazon.awssdk.services.securityhub.transform -
-
Uses of GetAutomationRuleV2Request in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type GetAutomationRuleV2Request Modifier and Type Method Description default CompletableFuture<GetAutomationRuleV2Response>SecurityHubAsyncClient. getAutomationRuleV2(GetAutomationRuleV2Request getAutomationRuleV2Request)Returns an automation rule for the V2 service.default GetAutomationRuleV2ResponseSecurityHubClient. getAutomationRuleV2(GetAutomationRuleV2Request getAutomationRuleV2Request)Returns an automation rule for the V2 service. -
Uses of GetAutomationRuleV2Request in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type GetAutomationRuleV2Request Modifier and Type Method Description SdkHttpFullRequestGetAutomationRuleV2RequestMarshaller. marshall(GetAutomationRuleV2Request getAutomationRuleV2Request)
-