Uses of Class
software.amazon.awssdk.services.securityhub.model.GetAutomationRuleV2Response
-
Packages that use GetAutomationRuleV2Response Package Description software.amazon.awssdk.services.securityhub Security Hub provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices. -
-
Uses of GetAutomationRuleV2Response in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return GetAutomationRuleV2Response Modifier and Type Method Description default GetAutomationRuleV2ResponseSecurityHubClient. getAutomationRuleV2(Consumer<GetAutomationRuleV2Request.Builder> getAutomationRuleV2Request)Returns an automation rule for the V2 service.default GetAutomationRuleV2ResponseSecurityHubClient. getAutomationRuleV2(GetAutomationRuleV2Request getAutomationRuleV2Request)Returns an automation rule for the V2 service.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type GetAutomationRuleV2Response Modifier and Type Method Description default CompletableFuture<GetAutomationRuleV2Response>SecurityHubAsyncClient. getAutomationRuleV2(Consumer<GetAutomationRuleV2Request.Builder> getAutomationRuleV2Request)Returns an automation rule for the V2 service.default CompletableFuture<GetAutomationRuleV2Response>SecurityHubAsyncClient. getAutomationRuleV2(GetAutomationRuleV2Request getAutomationRuleV2Request)Returns an automation rule for the V2 service.
-