Uses of Interface
software.amazon.awssdk.services.securityhub.model.GetEnabledStandardsRequest.Builder
Packages that use GetEnabledStandardsRequest.Builder
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of GetEnabledStandardsRequest.Builder in software.amazon.awssdk.services.securityhub
Method parameters in software.amazon.awssdk.services.securityhub with type arguments of type GetEnabledStandardsRequest.BuilderModifier and TypeMethodDescriptionSecurityHubAsyncClient.getEnabledStandards(Consumer<GetEnabledStandardsRequest.Builder> getEnabledStandardsRequest) Returns a list of the standards that are currently enabled.default GetEnabledStandardsResponseSecurityHubClient.getEnabledStandards(Consumer<GetEnabledStandardsRequest.Builder> getEnabledStandardsRequest) Returns a list of the standards that are currently enabled.default GetEnabledStandardsPublisherSecurityHubAsyncClient.getEnabledStandardsPaginator(Consumer<GetEnabledStandardsRequest.Builder> getEnabledStandardsRequest) This is a variant ofSecurityHubAsyncClient.getEnabledStandards(software.amazon.awssdk.services.securityhub.model.GetEnabledStandardsRequest)operation.default GetEnabledStandardsIterableSecurityHubClient.getEnabledStandardsPaginator(Consumer<GetEnabledStandardsRequest.Builder> getEnabledStandardsRequest) This is a variant ofSecurityHubClient.getEnabledStandards(software.amazon.awssdk.services.securityhub.model.GetEnabledStandardsRequest)operation. -
Uses of GetEnabledStandardsRequest.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return GetEnabledStandardsRequest.BuilderModifier and TypeMethodDescriptionGetEnabledStandardsRequest.builder()GetEnabledStandardsRequest.Builder.maxResults(Integer maxResults) The maximum number of results to return in the response.The token that is required for pagination.GetEnabledStandardsRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) GetEnabledStandardsRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) GetEnabledStandardsRequest.Builder.standardsSubscriptionArns(String... standardsSubscriptionArns) The list of the standards subscription ARNs for the standards to retrieve.GetEnabledStandardsRequest.Builder.standardsSubscriptionArns(Collection<String> standardsSubscriptionArns) The list of the standards subscription ARNs for the standards to retrieve.GetEnabledStandardsRequest.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type GetEnabledStandardsRequest.BuilderModifier and TypeMethodDescriptionstatic Class<? extends GetEnabledStandardsRequest.Builder>GetEnabledStandardsRequest.serializableBuilderClass()