Uses of Interface
software.amazon.awssdk.services.securityhub.model.GetFindingHistoryRequest.Builder
Packages that use GetFindingHistoryRequest.Builder
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of GetFindingHistoryRequest.Builder in software.amazon.awssdk.services.securityhub
Method parameters in software.amazon.awssdk.services.securityhub with type arguments of type GetFindingHistoryRequest.BuilderModifier and TypeMethodDescriptionSecurityHubAsyncClient.getFindingHistory(Consumer<GetFindingHistoryRequest.Builder> getFindingHistoryRequest) Returns the history of a Security Hub CSPM finding.default GetFindingHistoryResponseSecurityHubClient.getFindingHistory(Consumer<GetFindingHistoryRequest.Builder> getFindingHistoryRequest) Returns the history of a Security Hub CSPM finding.default GetFindingHistoryPublisherSecurityHubAsyncClient.getFindingHistoryPaginator(Consumer<GetFindingHistoryRequest.Builder> getFindingHistoryRequest) This is a variant ofSecurityHubAsyncClient.getFindingHistory(software.amazon.awssdk.services.securityhub.model.GetFindingHistoryRequest)operation.default GetFindingHistoryIterableSecurityHubClient.getFindingHistoryPaginator(Consumer<GetFindingHistoryRequest.Builder> getFindingHistoryRequest) This is a variant ofSecurityHubClient.getFindingHistory(software.amazon.awssdk.services.securityhub.model.GetFindingHistoryRequest)operation. -
Uses of GetFindingHistoryRequest.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return GetFindingHistoryRequest.BuilderModifier and TypeMethodDescriptionGetFindingHistoryRequest.builder()An ISO 8601-formatted timestamp that indicates the end time of the requested finding history.default GetFindingHistoryRequest.BuilderGetFindingHistoryRequest.Builder.findingIdentifier(Consumer<AwsSecurityFindingIdentifier.Builder> findingIdentifier) Sets the value of the FindingIdentifier property for this object.GetFindingHistoryRequest.Builder.findingIdentifier(AwsSecurityFindingIdentifier findingIdentifier) Sets the value of the FindingIdentifier property for this object.GetFindingHistoryRequest.Builder.maxResults(Integer maxResults) The maximum number of results to be returned.A token for pagination purposes.GetFindingHistoryRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) GetFindingHistoryRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) A timestamp that indicates the start time of the requested finding history.GetFindingHistoryRequest.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type GetFindingHistoryRequest.BuilderModifier and TypeMethodDescriptionstatic Class<? extends GetFindingHistoryRequest.Builder>GetFindingHistoryRequest.serializableBuilderClass()