Uses of Class
software.amazon.awssdk.services.securityhub.model.GetInsightsRequest
Packages that use GetInsightsRequest
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of GetInsightsRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type GetInsightsRequestModifier and TypeMethodDescriptiondefault CompletableFuture<GetInsightsResponse>SecurityHubAsyncClient.getInsights(GetInsightsRequest getInsightsRequest) Lists and describes insights for the specified insight ARNs.default GetInsightsResponseSecurityHubClient.getInsights(GetInsightsRequest getInsightsRequest) Lists and describes insights for the specified insight ARNs.default GetInsightsPublisherSecurityHubAsyncClient.getInsightsPaginator(GetInsightsRequest getInsightsRequest) This is a variant ofSecurityHubAsyncClient.getInsights(software.amazon.awssdk.services.securityhub.model.GetInsightsRequest)operation.default GetInsightsIterableSecurityHubClient.getInsightsPaginator(GetInsightsRequest getInsightsRequest) This is a variant ofSecurityHubClient.getInsights(software.amazon.awssdk.services.securityhub.model.GetInsightsRequest)operation. -
Uses of GetInsightsRequest in software.amazon.awssdk.services.securityhub.paginators
Constructors in software.amazon.awssdk.services.securityhub.paginators with parameters of type GetInsightsRequestModifierConstructorDescriptionGetInsightsIterable(SecurityHubClient client, GetInsightsRequest firstRequest) GetInsightsPublisher(SecurityHubAsyncClient client, GetInsightsRequest firstRequest) -
Uses of GetInsightsRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type GetInsightsRequestModifier and TypeMethodDescriptionGetInsightsRequestMarshaller.marshall(GetInsightsRequest getInsightsRequest)