Uses of Class
software.amazon.awssdk.services.securityhub.model.GetMasterAccountResponse
Packages that use GetMasterAccountResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of GetMasterAccountResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return GetMasterAccountResponseModifier and TypeMethodDescriptiondefault GetMasterAccountResponseSecurityHubClient.getMasterAccount()Deprecated.This API has been deprecated, use GetAdministratorAccount API instead.default GetMasterAccountResponseSecurityHubClient.getMasterAccount(Consumer<GetMasterAccountRequest.Builder> getMasterAccountRequest) Deprecated.This API has been deprecated, use GetAdministratorAccount API instead.default GetMasterAccountResponseSecurityHubClient.getMasterAccount(GetMasterAccountRequest getMasterAccountRequest) Deprecated.This API has been deprecated, use GetAdministratorAccount API instead.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type GetMasterAccountResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.getMasterAccount()Deprecated.This API has been deprecated, use GetAdministratorAccount API instead.SecurityHubAsyncClient.getMasterAccount(Consumer<GetMasterAccountRequest.Builder> getMasterAccountRequest) Deprecated.This API has been deprecated, use GetAdministratorAccount API instead.SecurityHubAsyncClient.getMasterAccount(GetMasterAccountRequest getMasterAccountRequest) Deprecated.This API has been deprecated, use GetAdministratorAccount API instead.