Uses of Class
software.amazon.awssdk.services.securityhub.model.GranularityField
-
Packages that use GranularityField Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of GranularityField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return GranularityField Modifier and Type Method Description static GranularityFieldGranularityField. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.GranularityFieldGetFindingsTrendsV2Response. granularity()The time interval granularity for the returned trend data.GranularityFieldGetResourcesTrendsV2Response. granularity()The time interval granularity for the returned trend data (such as DAILY or WEEKLY).static GranularityFieldGranularityField. valueOf(String name)Returns the enum constant of this type with the specified name.static GranularityField[]GranularityField. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type GranularityField Modifier and Type Method Description static Set<GranularityField>GranularityField. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type GranularityField Modifier and Type Method Description GetFindingsTrendsV2Response.BuilderGetFindingsTrendsV2Response.Builder. granularity(GranularityField granularity)The time interval granularity for the returned trend data.GetResourcesTrendsV2Response.BuilderGetResourcesTrendsV2Response.Builder. granularity(GranularityField granularity)The time interval granularity for the returned trend data (such as DAILY or WEEKLY).
-