Uses of Class
software.amazon.awssdk.services.securityhub.model.IntegerConfigurationOptions
Packages that use IntegerConfigurationOptions
-
Uses of IntegerConfigurationOptions in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return IntegerConfigurationOptionsModifier and TypeMethodDescriptionConfigurationOptions.integer()The options for customizing a security control parameter that is an integer.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type IntegerConfigurationOptionsModifier and TypeMethodDescriptionstatic ConfigurationOptionsConfigurationOptions.fromInteger(IntegerConfigurationOptions integer) Create an instance of this class withConfigurationOptions.integer()initialized to the given value.ConfigurationOptions.Builder.integer(IntegerConfigurationOptions integer) The options for customizing a security control parameter that is an integer.