Uses of Class
software.amazon.awssdk.services.securityhub.model.IntegerListConfigurationOptions
Packages that use IntegerListConfigurationOptions
-
Uses of IntegerListConfigurationOptions in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return IntegerListConfigurationOptionsModifier and TypeMethodDescriptionConfigurationOptions.integerList()The options for customizing a security control parameter that is a list of integers.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type IntegerListConfigurationOptionsModifier and TypeMethodDescriptionstatic ConfigurationOptionsConfigurationOptions.fromIntegerList(IntegerListConfigurationOptions integerList) Create an instance of this class withConfigurationOptions.integerList()initialized to the given value.ConfigurationOptions.Builder.integerList(IntegerListConfigurationOptions integerList) The options for customizing a security control parameter that is a list of integers.