Uses of Interface
software.amazon.awssdk.services.securityhub.model.IntegerListConfigurationOptions.Builder
Packages that use IntegerListConfigurationOptions.Builder
-
Uses of IntegerListConfigurationOptions.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return IntegerListConfigurationOptions.BuilderModifier and TypeMethodDescriptionIntegerListConfigurationOptions.builder()IntegerListConfigurationOptions.Builder.defaultValue(Integer... defaultValue) The Security Hub CSPM default value for a control parameter that is a list of integers.IntegerListConfigurationOptions.Builder.defaultValue(Collection<Integer> defaultValue) The Security Hub CSPM default value for a control parameter that is a list of integers.The maximum valid value for a control parameter that is a list of integers.The maximum number of list items that an interger list control parameter can accept.The minimum valid value for a control parameter that is a list of integers.IntegerListConfigurationOptions.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type IntegerListConfigurationOptions.BuilderModifier and TypeMethodDescriptionstatic Class<? extends IntegerListConfigurationOptions.Builder>IntegerListConfigurationOptions.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type IntegerListConfigurationOptions.BuilderModifier and TypeMethodDescriptionstatic ConfigurationOptionsConfigurationOptions.fromIntegerList(Consumer<IntegerListConfigurationOptions.Builder> integerList) Create an instance of this class withConfigurationOptions.integerList()initialized to the given value.default ConfigurationOptions.BuilderConfigurationOptions.Builder.integerList(Consumer<IntegerListConfigurationOptions.Builder> integerList) The options for customizing a security control parameter that is a list of integers.