Uses of Class
software.amazon.awssdk.services.securityhub.model.ListSecurityControlDefinitionsResponse
Packages that use ListSecurityControlDefinitionsResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of ListSecurityControlDefinitionsResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return ListSecurityControlDefinitionsResponseModifier and TypeMethodDescriptionSecurityHubClient.listSecurityControlDefinitions(Consumer<ListSecurityControlDefinitionsRequest.Builder> listSecurityControlDefinitionsRequest) Lists all of the security controls that apply to a specified standard.SecurityHubClient.listSecurityControlDefinitions(ListSecurityControlDefinitionsRequest listSecurityControlDefinitionsRequest) Lists all of the security controls that apply to a specified standard.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type ListSecurityControlDefinitionsResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.listSecurityControlDefinitions(Consumer<ListSecurityControlDefinitionsRequest.Builder> listSecurityControlDefinitionsRequest) Lists all of the security controls that apply to a specified standard.SecurityHubAsyncClient.listSecurityControlDefinitions(ListSecurityControlDefinitionsRequest listSecurityControlDefinitionsRequest) Lists all of the security controls that apply to a specified standard. -
Uses of ListSecurityControlDefinitionsResponse in software.amazon.awssdk.services.securityhub.paginators
Methods in software.amazon.awssdk.services.securityhub.paginators that return types with arguments of type ListSecurityControlDefinitionsResponseMethod parameters in software.amazon.awssdk.services.securityhub.paginators with type arguments of type ListSecurityControlDefinitionsResponseModifier and TypeMethodDescriptionvoidListSecurityControlDefinitionsPublisher.subscribe(org.reactivestreams.Subscriber<? super ListSecurityControlDefinitionsResponse> subscriber)