Uses of Class
software.amazon.awssdk.services.securityhub.model.NetworkHeader
Packages that use NetworkHeader
-
Uses of NetworkHeader in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return NetworkHeaderModifier and TypeMethodDescriptionfinal NetworkHeaderNetworkPathComponent.egress()Information about the component that comes after the current component in the network path.final NetworkHeaderNetworkPathComponent.ingress()Information about the component that comes before the current node in the network path.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type NetworkHeaderModifier and TypeMethodDescriptionNetworkPathComponent.Builder.egress(NetworkHeader egress) Information about the component that comes after the current component in the network path.NetworkPathComponent.Builder.ingress(NetworkHeader ingress) Information about the component that comes before the current node in the network path.