Uses of Class
software.amazon.awssdk.services.securityhub.model.NetworkPathComponent
Packages that use NetworkPathComponent
-
Uses of NetworkPathComponent in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type NetworkPathComponentModifier and TypeMethodDescriptionfinal List<NetworkPathComponent>AwsSecurityFinding.networkPath()Provides information about a network path that is relevant to a finding.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type NetworkPathComponentModifier and TypeMethodDescriptionAwsSecurityFinding.Builder.networkPath(NetworkPathComponent... networkPath) Provides information about a network path that is relevant to a finding.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type NetworkPathComponentModifier and TypeMethodDescriptionAwsSecurityFinding.Builder.networkPath(Collection<NetworkPathComponent> networkPath) Provides information about a network path that is relevant to a finding.