Uses of Interface
software.amazon.awssdk.services.securityhub.model.NetworkPathComponent.Builder
Packages that use NetworkPathComponent.Builder
-
Uses of NetworkPathComponent.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return NetworkPathComponent.BuilderModifier and TypeMethodDescriptionstatic NetworkPathComponent.BuilderNetworkPathComponent.builder()NetworkPathComponent.Builder.componentId(String componentId) The identifier of a component in the network path.NetworkPathComponent.Builder.componentType(String componentType) The type of component.default NetworkPathComponent.BuilderNetworkPathComponent.Builder.egress(Consumer<NetworkHeader.Builder> egress) Information about the component that comes after the current component in the network path.NetworkPathComponent.Builder.egress(NetworkHeader egress) Information about the component that comes after the current component in the network path.default NetworkPathComponent.BuilderNetworkPathComponent.Builder.ingress(Consumer<NetworkHeader.Builder> ingress) Information about the component that comes before the current node in the network path.NetworkPathComponent.Builder.ingress(NetworkHeader ingress) Information about the component that comes before the current node in the network path.NetworkPathComponent.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type NetworkPathComponent.BuilderModifier and TypeMethodDescriptionstatic Class<? extends NetworkPathComponent.Builder>NetworkPathComponent.serializableBuilderClass()