Uses of Interface
software.amazon.awssdk.services.securityhub.model.Note.Builder
Packages that use Note.Builder
-
Uses of Note.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return Note.BuilderModifier and TypeMethodDescriptionstatic Note.BuilderNote.builder()The text of a note.Note.toBuilder()A timestamp that indicates when the note was updated.The principal that created a note.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type Note.BuilderModifier and TypeMethodDescriptionstatic Class<? extends Note.Builder>Note.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type Note.BuilderModifier and TypeMethodDescriptiondefault AwsSecurityFinding.BuilderAwsSecurityFinding.Builder.note(Consumer<Note.Builder> note) A user-defined note added to a finding.