Uses of Class
software.amazon.awssdk.services.securityhub.model.OcsfBooleanField
-
Packages that use OcsfBooleanField Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of OcsfBooleanField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return OcsfBooleanField Modifier and Type Method Description OcsfBooleanFieldOcsfBooleanFilter. fieldName()The name of the field.static OcsfBooleanFieldOcsfBooleanField. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static OcsfBooleanFieldOcsfBooleanField. valueOf(String name)Returns the enum constant of this type with the specified name.static OcsfBooleanField[]OcsfBooleanField. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type OcsfBooleanField Modifier and Type Method Description static Set<OcsfBooleanField>OcsfBooleanField. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type OcsfBooleanField Modifier and Type Method Description OcsfBooleanFilter.BuilderOcsfBooleanFilter.Builder. fieldName(OcsfBooleanField fieldName)The name of the field.
-