Uses of Enum
software.amazon.awssdk.services.securityhub.model.OcsfMapField
Packages that use OcsfMapField
-
Uses of OcsfMapField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return OcsfMapFieldModifier and TypeMethodDescriptionfinal OcsfMapFieldOcsfMapFilter.fieldName()The name of the field.static OcsfMapFieldUse this in place of valueOf to convert the raw string returned by the service into the enum value.static OcsfMapFieldReturns the enum constant of this type with the specified name.static OcsfMapField[]OcsfMapField.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type OcsfMapFieldMethods in software.amazon.awssdk.services.securityhub.model with parameters of type OcsfMapFieldModifier and TypeMethodDescriptionOcsfMapFilter.Builder.fieldName(OcsfMapField fieldName) The name of the field.