Uses of Class
software.amazon.awssdk.services.securityhub.model.OrganizationalUnitNotFoundException
Packages that use OrganizationalUnitNotFoundException
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of OrganizationalUnitNotFoundException in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that throw OrganizationalUnitNotFoundExceptionModifier and TypeMethodDescriptiondefault GetFindingStatisticsV2ResponseSecurityHubClient.getFindingStatisticsV2(Consumer<GetFindingStatisticsV2Request.Builder> getFindingStatisticsV2Request) Returns aggregated statistical data about findings.default GetFindingStatisticsV2ResponseSecurityHubClient.getFindingStatisticsV2(GetFindingStatisticsV2Request getFindingStatisticsV2Request) Returns aggregated statistical data about findings.default GetFindingsV2ResponseSecurityHubClient.getFindingsV2(Consumer<GetFindingsV2Request.Builder> getFindingsV2Request) Returns a list of findings that match the specified criteria.default GetFindingsV2ResponseSecurityHubClient.getFindingsV2(GetFindingsV2Request getFindingsV2Request) Returns a list of findings that match the specified criteria.default GetFindingsV2IterableSecurityHubClient.getFindingsV2Paginator(Consumer<GetFindingsV2Request.Builder> getFindingsV2Request) This is a variant ofSecurityHubClient.getFindingsV2(software.amazon.awssdk.services.securityhub.model.GetFindingsV2Request)operation.default GetFindingsV2IterableSecurityHubClient.getFindingsV2Paginator(GetFindingsV2Request getFindingsV2Request) This is a variant ofSecurityHubClient.getFindingsV2(software.amazon.awssdk.services.securityhub.model.GetFindingsV2Request)operation.default GetResourcesStatisticsV2ResponseSecurityHubClient.getResourcesStatisticsV2(Consumer<GetResourcesStatisticsV2Request.Builder> getResourcesStatisticsV2Request) Retrieves statistical information about Amazon Web Services resources and their associated security findings.default GetResourcesStatisticsV2ResponseSecurityHubClient.getResourcesStatisticsV2(GetResourcesStatisticsV2Request getResourcesStatisticsV2Request) Retrieves statistical information about Amazon Web Services resources and their associated security findings.default GetResourcesV2ResponseSecurityHubClient.getResourcesV2(Consumer<GetResourcesV2Request.Builder> getResourcesV2Request) Returns a list of resources.default GetResourcesV2ResponseSecurityHubClient.getResourcesV2(GetResourcesV2Request getResourcesV2Request) Returns a list of resources.default GetResourcesV2IterableSecurityHubClient.getResourcesV2Paginator(Consumer<GetResourcesV2Request.Builder> getResourcesV2Request) This is a variant ofSecurityHubClient.getResourcesV2(software.amazon.awssdk.services.securityhub.model.GetResourcesV2Request)operation.default GetResourcesV2IterableSecurityHubClient.getResourcesV2Paginator(GetResourcesV2Request getResourcesV2Request) This is a variant ofSecurityHubClient.getResourcesV2(software.amazon.awssdk.services.securityhub.model.GetResourcesV2Request)operation.