Uses of Class
software.amazon.awssdk.services.securityhub.model.ResourceGroupByRule
Packages that use ResourceGroupByRule
-
Uses of ResourceGroupByRule in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type ResourceGroupByRuleModifier and TypeMethodDescriptionfinal List<ResourceGroupByRule>GetResourcesStatisticsV2Request.groupByRules()How resource statistics should be aggregated and organized in the response.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ResourceGroupByRuleModifier and TypeMethodDescriptionGetResourcesStatisticsV2Request.Builder.groupByRules(ResourceGroupByRule... groupByRules) How resource statistics should be aggregated and organized in the response.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type ResourceGroupByRuleModifier and TypeMethodDescriptionGetResourcesStatisticsV2Request.Builder.groupByRules(Collection<ResourceGroupByRule> groupByRules) How resource statistics should be aggregated and organized in the response.