Uses of Class
software.amazon.awssdk.services.securityhub.model.ResourceInUseException
Packages that use ResourceInUseException
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of ResourceInUseException in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that throw ResourceInUseExceptionModifier and TypeMethodDescriptiondefault UpdateSecurityControlResponseSecurityHubClient.updateSecurityControl(Consumer<UpdateSecurityControlRequest.Builder> updateSecurityControlRequest) Updates the properties of a security control.default UpdateSecurityControlResponseSecurityHubClient.updateSecurityControl(UpdateSecurityControlRequest updateSecurityControlRequest) Updates the properties of a security control.