Uses of Class
software.amazon.awssdk.services.securityhub.model.ResourceResult
-
Packages that use ResourceResult Package Description software.amazon.awssdk.services.securityhub.model software.amazon.awssdk.services.securityhub.paginators -
-
Uses of ResourceResult in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type ResourceResult Modifier and Type Method Description List<ResourceResult>GetResourcesV2Response. resources()Filters resources based on a set of criteria.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ResourceResult Modifier and Type Method Description GetResourcesV2Response.BuilderGetResourcesV2Response.Builder. resources(ResourceResult... resources)Filters resources based on a set of criteria.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type ResourceResult Modifier and Type Method Description GetResourcesV2Response.BuilderGetResourcesV2Response.Builder. resources(Collection<ResourceResult> resources)Filters resources based on a set of criteria. -
Uses of ResourceResult in software.amazon.awssdk.services.securityhub.paginators
Methods in software.amazon.awssdk.services.securityhub.paginators that return types with arguments of type ResourceResult Modifier and Type Method Description SdkIterable<ResourceResult>GetResourcesV2Iterable. resources()Returns an iterable to iterate through the paginatedGetResourcesV2Response.resources()member.SdkPublisher<ResourceResult>GetResourcesV2Publisher. resources()Returns a publisher that can be used to get a stream of data.
-