Uses of Class
software.amazon.awssdk.services.securityhub.model.ResourceScopes
Packages that use ResourceScopes
-
Uses of ResourceScopes in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ResourceScopesModifier and TypeMethodDescriptionfinal ResourceScopesGetResourcesStatisticsV2Request.scopes()Limits the results to resources from specific organizational units or from the delegated administrator's organization.final ResourceScopesGetResourcesV2Request.scopes()Limits the results to resources from specific organizational units or from the delegated administrator's organization.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ResourceScopesModifier and TypeMethodDescriptionGetResourcesStatisticsV2Request.Builder.scopes(ResourceScopes scopes) Limits the results to resources from specific organizational units or from the delegated administrator's organization.GetResourcesV2Request.Builder.scopes(ResourceScopes scopes) Limits the results to resources from specific organizational units or from the delegated administrator's organization.