Uses of Class
software.amazon.awssdk.services.securityhub.model.ResourcesCount
-
Packages that use ResourcesCount Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of ResourcesCount in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ResourcesCount Modifier and Type Method Description ResourcesCountResourcesTrendsValues. resourcesCount()The resource count statistics for this data point in the trend timeline.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ResourcesCount Modifier and Type Method Description ResourcesTrendsValues.BuilderResourcesTrendsValues.Builder. resourcesCount(ResourcesCount resourcesCount)The resource count statistics for this data point in the trend timeline.
-