Uses of Class
software.amazon.awssdk.services.securityhub.model.ResourcesMapField
-
Packages that use ResourcesMapField Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of ResourcesMapField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ResourcesMapField Modifier and Type Method Description ResourcesMapFieldResourcesMapFilter. fieldName()The name of the field.static ResourcesMapFieldResourcesMapField. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static ResourcesMapFieldResourcesMapField. valueOf(String name)Returns the enum constant of this type with the specified name.static ResourcesMapField[]ResourcesMapField. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type ResourcesMapField Modifier and Type Method Description static Set<ResourcesMapField>ResourcesMapField. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ResourcesMapField Modifier and Type Method Description ResourcesMapFilter.BuilderResourcesMapFilter.Builder. fieldName(ResourcesMapField fieldName)The name of the field.
-