Uses of Class
software.amazon.awssdk.services.securityhub.model.ResourcesStringField
-
Packages that use ResourcesStringField Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of ResourcesStringField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ResourcesStringField Modifier and Type Method Description ResourcesStringFieldResourcesStringFilter. fieldName()The name of the field.static ResourcesStringFieldResourcesStringField. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static ResourcesStringFieldResourcesStringField. valueOf(String name)Returns the enum constant of this type with the specified name.static ResourcesStringField[]ResourcesStringField. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type ResourcesStringField Modifier and Type Method Description static Set<ResourcesStringField>ResourcesStringField. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ResourcesStringField Modifier and Type Method Description ResourcesStringFilter.BuilderResourcesStringFilter.Builder. fieldName(ResourcesStringField fieldName)The name of the field.
-