Uses of Enum
software.amazon.awssdk.services.securityhub.model.ResourcesTrendsStringField
Packages that use ResourcesTrendsStringField
-
Uses of ResourcesTrendsStringField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ResourcesTrendsStringFieldModifier and TypeMethodDescriptionResourcesTrendsStringFilter.fieldName()The name of the resources field to filter on, such as resourceType, accountId, or region.static ResourcesTrendsStringFieldUse this in place of valueOf to convert the raw string returned by the service into the enum value.static ResourcesTrendsStringFieldReturns the enum constant of this type with the specified name.static ResourcesTrendsStringField[]ResourcesTrendsStringField.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type ResourcesTrendsStringFieldModifier and TypeMethodDescriptionstatic Set<ResourcesTrendsStringField>ResourcesTrendsStringField.knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ResourcesTrendsStringFieldModifier and TypeMethodDescriptionResourcesTrendsStringFilter.Builder.fieldName(ResourcesTrendsStringField fieldName) The name of the resources field to filter on, such as resourceType, accountId, or region.