Uses of Interface
software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes.Builder
Packages that use RuleGroupSourceStatelessRuleMatchAttributes.Builder
-
Uses of RuleGroupSourceStatelessRuleMatchAttributes.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return RuleGroupSourceStatelessRuleMatchAttributes.BuilderModifier and TypeMethodDescriptionRuleGroupSourceStatelessRuleMatchAttributes.builder()RuleGroupSourceStatelessRuleMatchAttributes.Builder.destinationPorts(Collection<RuleGroupSourceStatelessRuleMatchAttributesDestinationPorts> destinationPorts) A list of port ranges to specify the destination ports to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.destinationPorts(Consumer<RuleGroupSourceStatelessRuleMatchAttributesDestinationPorts.Builder>... destinationPorts) A list of port ranges to specify the destination ports to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.destinationPorts(RuleGroupSourceStatelessRuleMatchAttributesDestinationPorts... destinationPorts) A list of port ranges to specify the destination ports to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.destinations(Collection<RuleGroupSourceStatelessRuleMatchAttributesDestinations> destinations) The destination IP addresses and address ranges to inspect for, in CIDR notation.RuleGroupSourceStatelessRuleMatchAttributes.Builder.destinations(Consumer<RuleGroupSourceStatelessRuleMatchAttributesDestinations.Builder>... destinations) The destination IP addresses and address ranges to inspect for, in CIDR notation.RuleGroupSourceStatelessRuleMatchAttributes.Builder.destinations(RuleGroupSourceStatelessRuleMatchAttributesDestinations... destinations) The destination IP addresses and address ranges to inspect for, in CIDR notation.The protocols to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.protocols(Collection<Integer> protocols) The protocols to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.sourcePorts(Collection<RuleGroupSourceStatelessRuleMatchAttributesSourcePorts> sourcePorts) A list of port ranges to specify the source ports to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.sourcePorts(Consumer<RuleGroupSourceStatelessRuleMatchAttributesSourcePorts.Builder>... sourcePorts) A list of port ranges to specify the source ports to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.sourcePorts(RuleGroupSourceStatelessRuleMatchAttributesSourcePorts... sourcePorts) A list of port ranges to specify the source ports to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.sources(Collection<RuleGroupSourceStatelessRuleMatchAttributesSources> sources) The source IP addresses and address ranges to inspect for, in CIDR notation.RuleGroupSourceStatelessRuleMatchAttributes.Builder.sources(Consumer<RuleGroupSourceStatelessRuleMatchAttributesSources.Builder>... sources) The source IP addresses and address ranges to inspect for, in CIDR notation.RuleGroupSourceStatelessRuleMatchAttributes.Builder.sources(RuleGroupSourceStatelessRuleMatchAttributesSources... sources) The source IP addresses and address ranges to inspect for, in CIDR notation.RuleGroupSourceStatelessRuleMatchAttributes.Builder.tcpFlags(Collection<RuleGroupSourceStatelessRuleMatchAttributesTcpFlags> tcpFlags) The TCP flags and masks to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.tcpFlags(Consumer<RuleGroupSourceStatelessRuleMatchAttributesTcpFlags.Builder>... tcpFlags) The TCP flags and masks to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.Builder.tcpFlags(RuleGroupSourceStatelessRuleMatchAttributesTcpFlags... tcpFlags) The TCP flags and masks to inspect for.RuleGroupSourceStatelessRuleMatchAttributes.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type RuleGroupSourceStatelessRuleMatchAttributes.BuilderModifier and TypeMethodDescriptionstatic Class<? extends RuleGroupSourceStatelessRuleMatchAttributes.Builder>RuleGroupSourceStatelessRuleMatchAttributes.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type RuleGroupSourceStatelessRuleMatchAttributes.BuilderModifier and TypeMethodDescriptionRuleGroupSourceStatelessRuleDefinition.Builder.matchAttributes(Consumer<RuleGroupSourceStatelessRuleMatchAttributes.Builder> matchAttributes) The criteria for Network Firewall to use to inspect an individual packet in a stateless rule inspection.