Uses of Class
software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
Packages that use RuleGroupSourceStatelessRuleMatchAttributesSourcePorts
-
Uses of RuleGroupSourceStatelessRuleMatchAttributesSourcePorts in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type RuleGroupSourceStatelessRuleMatchAttributesSourcePortsModifier and TypeMethodDescriptionRuleGroupSourceStatelessRuleMatchAttributes.sourcePorts()A list of port ranges to specify the source ports to inspect for.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type RuleGroupSourceStatelessRuleMatchAttributesSourcePortsModifier and TypeMethodDescriptionRuleGroupSourceStatelessRuleMatchAttributes.Builder.sourcePorts(RuleGroupSourceStatelessRuleMatchAttributesSourcePorts... sourcePorts) A list of port ranges to specify the source ports to inspect for.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type RuleGroupSourceStatelessRuleMatchAttributesSourcePortsModifier and TypeMethodDescriptionRuleGroupSourceStatelessRuleMatchAttributes.Builder.sourcePorts(Collection<RuleGroupSourceStatelessRuleMatchAttributesSourcePorts> sourcePorts) A list of port ranges to specify the source ports to inspect for.