Uses of Enum
software.amazon.awssdk.services.securityhub.model.RuleStatus
Packages that use RuleStatus
-
Uses of RuleStatus in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return RuleStatusModifier and TypeMethodDescriptionstatic RuleStatusUse this in place of valueOf to convert the raw string returned by the service into the enum value.final RuleStatusAutomationRulesConfig.ruleStatus()Whether the rule is active after it is created.final RuleStatusAutomationRulesMetadata.ruleStatus()Whether the rule is active after it is created.final RuleStatusCreateAutomationRuleRequest.ruleStatus()Whether the rule is active after it is created.final RuleStatusUpdateAutomationRulesRequestItem.ruleStatus()Whether the rule is active after it is created.static RuleStatusReturns the enum constant of this type with the specified name.static RuleStatus[]RuleStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type RuleStatusMethods in software.amazon.awssdk.services.securityhub.model with parameters of type RuleStatusModifier and TypeMethodDescriptionAutomationRulesConfig.Builder.ruleStatus(RuleStatus ruleStatus) Whether the rule is active after it is created.AutomationRulesMetadata.Builder.ruleStatus(RuleStatus ruleStatus) Whether the rule is active after it is created.CreateAutomationRuleRequest.Builder.ruleStatus(RuleStatus ruleStatus) Whether the rule is active after it is created.UpdateAutomationRulesRequestItem.Builder.ruleStatus(RuleStatus ruleStatus) Whether the rule is active after it is created.