Uses of Class
software.amazon.awssdk.services.securityhub.model.RuleStatusV2
-
Packages that use RuleStatusV2 Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of RuleStatusV2 in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return RuleStatusV2 Modifier and Type Method Description static RuleStatusV2RuleStatusV2. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.RuleStatusV2AutomationRulesMetadataV2. ruleStatus()The status of the automation rule.RuleStatusV2CreateAutomationRuleV2Request. ruleStatus()The status of the V2 automation rule.RuleStatusV2GetAutomationRuleV2Response. ruleStatus()The status of the V2 automation automation rule.RuleStatusV2UpdateAutomationRuleV2Request. ruleStatus()The status of the automation rule.static RuleStatusV2RuleStatusV2. valueOf(String name)Returns the enum constant of this type with the specified name.static RuleStatusV2[]RuleStatusV2. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type RuleStatusV2 Modifier and Type Method Description static Set<RuleStatusV2>RuleStatusV2. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type RuleStatusV2 Modifier and Type Method Description AutomationRulesMetadataV2.BuilderAutomationRulesMetadataV2.Builder. ruleStatus(RuleStatusV2 ruleStatus)The status of the automation rule.CreateAutomationRuleV2Request.BuilderCreateAutomationRuleV2Request.Builder. ruleStatus(RuleStatusV2 ruleStatus)The status of the V2 automation rule.GetAutomationRuleV2Response.BuilderGetAutomationRuleV2Response.Builder. ruleStatus(RuleStatusV2 ruleStatus)The status of the V2 automation automation rule.UpdateAutomationRuleV2Request.BuilderUpdateAutomationRuleV2Request.Builder. ruleStatus(RuleStatusV2 ruleStatus)The status of the automation rule.
-