Uses of Class
software.amazon.awssdk.services.securityhub.model.SecurityControl
Packages that use SecurityControl
-
Uses of SecurityControl in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type SecurityControlModifier and TypeMethodDescriptionfinal List<SecurityControl>BatchGetSecurityControlsResponse.securityControls()An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type SecurityControlModifier and TypeMethodDescriptionBatchGetSecurityControlsResponse.Builder.securityControls(SecurityControl... securityControls) An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type SecurityControlModifier and TypeMethodDescriptionBatchGetSecurityControlsResponse.Builder.securityControls(Collection<SecurityControl> securityControls) An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control.