Uses of Interface
software.amazon.awssdk.services.securityhub.model.SecurityControl.Builder
Packages that use SecurityControl.Builder
-
Uses of SecurityControl.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return SecurityControl.BuilderModifier and TypeMethodDescriptionstatic SecurityControl.BuilderSecurityControl.builder()SecurityControl.Builder.description(String description) The description of a security control across standards.SecurityControl.Builder.lastUpdateReason(String lastUpdateReason) The most recent reason for updating the customizable properties of a security control.SecurityControl.Builder.parameters(Map<String, ParameterConfiguration> parameters) An object that identifies the name of a control parameter, its current value, and whether it has been customized.SecurityControl.Builder.remediationUrl(String remediationUrl) A link to Security Hub CSPM documentation that explains how to remediate a failed finding for a security control.SecurityControl.Builder.securityControlArn(String securityControlArn) The Amazon Resource Name (ARN) for a security control across standards, such asarn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1.SecurityControl.Builder.securityControlId(String securityControlId) The unique identifier of a security control across standards.SecurityControl.Builder.securityControlStatus(String securityControlStatus) The enablement status of a security control in a specific standard.SecurityControl.Builder.securityControlStatus(ControlStatus securityControlStatus) The enablement status of a security control in a specific standard.SecurityControl.Builder.severityRating(String severityRating) The severity of a security control.SecurityControl.Builder.severityRating(SeverityRating severityRating) The severity of a security control.The title of a security control.SecurityControl.toBuilder()SecurityControl.Builder.updateStatus(String updateStatus) Identifies whether customizable properties of a security control are reflected in Security Hub CSPM findings.SecurityControl.Builder.updateStatus(UpdateStatus updateStatus) Identifies whether customizable properties of a security control are reflected in Security Hub CSPM findings.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type SecurityControl.BuilderModifier and TypeMethodDescriptionstatic Class<? extends SecurityControl.Builder>SecurityControl.serializableBuilderClass()