Uses of Class
software.amazon.awssdk.services.securityhub.model.SecurityControlParameter
Packages that use SecurityControlParameter
-
Uses of SecurityControlParameter in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type SecurityControlParameterModifier and TypeMethodDescriptionfinal List<SecurityControlParameter>Compliance.securityControlParameters()Typically an object that includes security control parameter names and values.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type SecurityControlParameterModifier and TypeMethodDescriptionCompliance.Builder.securityControlParameters(SecurityControlParameter... securityControlParameters) Typically an object that includes security control parameter names and values.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type SecurityControlParameterModifier and TypeMethodDescriptionCompliance.Builder.securityControlParameters(Collection<SecurityControlParameter> securityControlParameters) Typically an object that includes security control parameter names and values.