Uses of Enum
software.amazon.awssdk.services.securityhub.model.SecurityControlProperty
Packages that use SecurityControlProperty
-
Uses of SecurityControlProperty in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return SecurityControlPropertyModifier and TypeMethodDescriptionstatic SecurityControlPropertyUse this in place of valueOf to convert the raw string returned by the service into the enum value.static SecurityControlPropertyReturns the enum constant of this type with the specified name.static SecurityControlProperty[]SecurityControlProperty.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type SecurityControlPropertyModifier and TypeMethodDescriptionfinal List<SecurityControlProperty>SecurityControlDefinition.customizableProperties()Security control properties that you can customize.static Set<SecurityControlProperty>SecurityControlProperty.knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type SecurityControlPropertyModifier and TypeMethodDescriptionSecurityControlDefinition.Builder.customizableProperties(SecurityControlProperty... customizableProperties) Security control properties that you can customize.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type SecurityControlPropertyModifier and TypeMethodDescriptionSecurityControlDefinition.Builder.customizableProperties(Collection<SecurityControlProperty> customizableProperties) Security control properties that you can customize.