default AcceptAdministratorInvitationResponse |
SecurityHubClient.acceptAdministratorInvitation(Consumer<AcceptAdministratorInvitationRequest.Builder> acceptAdministratorInvitationRequest) |
|
default AcceptAdministratorInvitationResponse |
SecurityHubClient.acceptAdministratorInvitation(AcceptAdministratorInvitationRequest acceptAdministratorInvitationRequest) |
|
default AcceptInvitationResponse |
SecurityHubClient.acceptInvitation(Consumer<AcceptInvitationRequest.Builder> acceptInvitationRequest) |
Deprecated.
|
default AcceptInvitationResponse |
SecurityHubClient.acceptInvitation(AcceptInvitationRequest acceptInvitationRequest) |
Deprecated.
|
default BatchDeleteAutomationRulesResponse |
SecurityHubClient.batchDeleteAutomationRules(Consumer<BatchDeleteAutomationRulesRequest.Builder> batchDeleteAutomationRulesRequest) |
Deletes one or more automation rules.
|
default BatchDeleteAutomationRulesResponse |
SecurityHubClient.batchDeleteAutomationRules(BatchDeleteAutomationRulesRequest batchDeleteAutomationRulesRequest) |
Deletes one or more automation rules.
|
default BatchDisableStandardsResponse |
SecurityHubClient.batchDisableStandards(Consumer<BatchDisableStandardsRequest.Builder> batchDisableStandardsRequest) |
Disables the standards specified by the provided StandardsSubscriptionArns.
|
default BatchDisableStandardsResponse |
SecurityHubClient.batchDisableStandards(BatchDisableStandardsRequest batchDisableStandardsRequest) |
Disables the standards specified by the provided StandardsSubscriptionArns.
|
default BatchEnableStandardsResponse |
SecurityHubClient.batchEnableStandards(Consumer<BatchEnableStandardsRequest.Builder> batchEnableStandardsRequest) |
Enables the standards specified by the provided StandardsArn.
|
default BatchEnableStandardsResponse |
SecurityHubClient.batchEnableStandards(BatchEnableStandardsRequest batchEnableStandardsRequest) |
Enables the standards specified by the provided StandardsArn.
|
default BatchGetAutomationRulesResponse |
SecurityHubClient.batchGetAutomationRules(Consumer<BatchGetAutomationRulesRequest.Builder> batchGetAutomationRulesRequest) |
Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).
|
default BatchGetAutomationRulesResponse |
SecurityHubClient.batchGetAutomationRules(BatchGetAutomationRulesRequest batchGetAutomationRulesRequest) |
Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).
|
default BatchGetConfigurationPolicyAssociationsResponse |
SecurityHubClient.batchGetConfigurationPolicyAssociations(Consumer<BatchGetConfigurationPolicyAssociationsRequest.Builder> batchGetConfigurationPolicyAssociationsRequest) |
Returns associations between an Security Hub configuration and a batch of target accounts, organizational units,
or the root.
|
default BatchGetConfigurationPolicyAssociationsResponse |
SecurityHubClient.batchGetConfigurationPolicyAssociations(BatchGetConfigurationPolicyAssociationsRequest batchGetConfigurationPolicyAssociationsRequest) |
Returns associations between an Security Hub configuration and a batch of target accounts, organizational units,
or the root.
|
default BatchGetSecurityControlsResponse |
SecurityHubClient.batchGetSecurityControls(Consumer<BatchGetSecurityControlsRequest.Builder> batchGetSecurityControlsRequest) |
Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web
Services Region.
|
default BatchGetSecurityControlsResponse |
SecurityHubClient.batchGetSecurityControls(BatchGetSecurityControlsRequest batchGetSecurityControlsRequest) |
Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web
Services Region.
|
default BatchGetStandardsControlAssociationsResponse |
SecurityHubClient.batchGetStandardsControlAssociations(Consumer<BatchGetStandardsControlAssociationsRequest.Builder> batchGetStandardsControlAssociationsRequest) |
For a batch of security controls and standards, identifies whether each control is currently enabled or disabled
in a standard.
|
default BatchGetStandardsControlAssociationsResponse |
SecurityHubClient.batchGetStandardsControlAssociations(BatchGetStandardsControlAssociationsRequest batchGetStandardsControlAssociationsRequest) |
For a batch of security controls and standards, identifies whether each control is currently enabled or disabled
in a standard.
|
default BatchImportFindingsResponse |
SecurityHubClient.batchImportFindings(Consumer<BatchImportFindingsRequest.Builder> batchImportFindingsRequest) |
Imports security findings generated by a finding provider into Security Hub.
|
default BatchImportFindingsResponse |
SecurityHubClient.batchImportFindings(BatchImportFindingsRequest batchImportFindingsRequest) |
Imports security findings generated by a finding provider into Security Hub.
|
default BatchUpdateAutomationRulesResponse |
SecurityHubClient.batchUpdateAutomationRules(Consumer<BatchUpdateAutomationRulesRequest.Builder> batchUpdateAutomationRulesRequest) |
Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.
|
default BatchUpdateAutomationRulesResponse |
SecurityHubClient.batchUpdateAutomationRules(BatchUpdateAutomationRulesRequest batchUpdateAutomationRulesRequest) |
Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.
|
default BatchUpdateFindingsResponse |
SecurityHubClient.batchUpdateFindings(Consumer<BatchUpdateFindingsRequest.Builder> batchUpdateFindingsRequest) |
Used by Security Hub customers to update information about their investigation into one or more findings.
|
default BatchUpdateFindingsResponse |
SecurityHubClient.batchUpdateFindings(BatchUpdateFindingsRequest batchUpdateFindingsRequest) |
Used by Security Hub customers to update information about their investigation into one or more findings.
|
default BatchUpdateFindingsV2Response |
SecurityHubClient.batchUpdateFindingsV2(Consumer<BatchUpdateFindingsV2Request.Builder> batchUpdateFindingsV2Request) |
Used by customers to update information about their investigation into a finding.
|
default BatchUpdateFindingsV2Response |
SecurityHubClient.batchUpdateFindingsV2(BatchUpdateFindingsV2Request batchUpdateFindingsV2Request) |
Used by customers to update information about their investigation into a finding.
|
default BatchUpdateStandardsControlAssociationsResponse |
SecurityHubClient.batchUpdateStandardsControlAssociations(Consumer<BatchUpdateStandardsControlAssociationsRequest.Builder> batchUpdateStandardsControlAssociationsRequest) |
For a batch of security controls and standards, this operation updates the enablement status of a control in a
standard.
|
default BatchUpdateStandardsControlAssociationsResponse |
SecurityHubClient.batchUpdateStandardsControlAssociations(BatchUpdateStandardsControlAssociationsRequest batchUpdateStandardsControlAssociationsRequest) |
For a batch of security controls and standards, this operation updates the enablement status of a control in a
standard.
|
default ConnectorRegistrationsV2Response |
SecurityHubClient.connectorRegistrationsV2(Consumer<ConnectorRegistrationsV2Request.Builder> connectorRegistrationsV2Request) |
Grants permission to complete the authorization based on input parameters.
|
default ConnectorRegistrationsV2Response |
SecurityHubClient.connectorRegistrationsV2(ConnectorRegistrationsV2Request connectorRegistrationsV2Request) |
Grants permission to complete the authorization based on input parameters.
|
default CreateActionTargetResponse |
SecurityHubClient.createActionTarget(Consumer<CreateActionTargetRequest.Builder> createActionTargetRequest) |
Creates a custom action target in Security Hub.
|
default CreateActionTargetResponse |
SecurityHubClient.createActionTarget(CreateActionTargetRequest createActionTargetRequest) |
Creates a custom action target in Security Hub.
|
default CreateAggregatorV2Response |
SecurityHubClient.createAggregatorV2(Consumer<CreateAggregatorV2Request.Builder> createAggregatorV2Request) |
Enables aggregation across Amazon Web Services Regions.
|
default CreateAggregatorV2Response |
SecurityHubClient.createAggregatorV2(CreateAggregatorV2Request createAggregatorV2Request) |
Enables aggregation across Amazon Web Services Regions.
|
default CreateAutomationRuleResponse |
SecurityHubClient.createAutomationRule(Consumer<CreateAutomationRuleRequest.Builder> createAutomationRuleRequest) |
Creates an automation rule based on input parameters.
|
default CreateAutomationRuleResponse |
SecurityHubClient.createAutomationRule(CreateAutomationRuleRequest createAutomationRuleRequest) |
Creates an automation rule based on input parameters.
|
default CreateAutomationRuleV2Response |
SecurityHubClient.createAutomationRuleV2(Consumer<CreateAutomationRuleV2Request.Builder> createAutomationRuleV2Request) |
Creates a V2 automation rule.
|
default CreateAutomationRuleV2Response |
SecurityHubClient.createAutomationRuleV2(CreateAutomationRuleV2Request createAutomationRuleV2Request) |
Creates a V2 automation rule.
|
default CreateConfigurationPolicyResponse |
SecurityHubClient.createConfigurationPolicy(Consumer<CreateConfigurationPolicyRequest.Builder> createConfigurationPolicyRequest) |
Creates a configuration policy with the defined configuration.
|
default CreateConfigurationPolicyResponse |
SecurityHubClient.createConfigurationPolicy(CreateConfigurationPolicyRequest createConfigurationPolicyRequest) |
Creates a configuration policy with the defined configuration.
|
default CreateConnectorV2Response |
SecurityHubClient.createConnectorV2(Consumer<CreateConnectorV2Request.Builder> createConnectorV2Request) |
Grants permission to create a connectorV2 based on input parameters.
|
default CreateConnectorV2Response |
SecurityHubClient.createConnectorV2(CreateConnectorV2Request createConnectorV2Request) |
Grants permission to create a connectorV2 based on input parameters.
|
default CreateFindingAggregatorResponse |
SecurityHubClient.createFindingAggregator(Consumer<CreateFindingAggregatorRequest.Builder> createFindingAggregatorRequest) |
|
default CreateFindingAggregatorResponse |
SecurityHubClient.createFindingAggregator(CreateFindingAggregatorRequest createFindingAggregatorRequest) |
|
default CreateInsightResponse |
SecurityHubClient.createInsight(Consumer<CreateInsightRequest.Builder> createInsightRequest) |
Creates a custom insight in Security Hub.
|
default CreateInsightResponse |
SecurityHubClient.createInsight(CreateInsightRequest createInsightRequest) |
Creates a custom insight in Security Hub.
|
default CreateMembersResponse |
SecurityHubClient.createMembers(Consumer<CreateMembersRequest.Builder> createMembersRequest) |
Creates a member association in Security Hub between the specified accounts and the account used to make the
request, which is the administrator account.
|
default CreateMembersResponse |
SecurityHubClient.createMembers(CreateMembersRequest createMembersRequest) |
Creates a member association in Security Hub between the specified accounts and the account used to make the
request, which is the administrator account.
|
default CreateTicketV2Response |
SecurityHubClient.createTicketV2(Consumer<CreateTicketV2Request.Builder> createTicketV2Request) |
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding
metadata UID.
|
default CreateTicketV2Response |
SecurityHubClient.createTicketV2(CreateTicketV2Request createTicketV2Request) |
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding
metadata UID.
|
default DeclineInvitationsResponse |
SecurityHubClient.declineInvitations(Consumer<DeclineInvitationsRequest.Builder> declineInvitationsRequest) |
|
default DeclineInvitationsResponse |
SecurityHubClient.declineInvitations(DeclineInvitationsRequest declineInvitationsRequest) |
|
default DeleteActionTargetResponse |
SecurityHubClient.deleteActionTarget(Consumer<DeleteActionTargetRequest.Builder> deleteActionTargetRequest) |
Deletes a custom action target from Security Hub.
|
default DeleteActionTargetResponse |
SecurityHubClient.deleteActionTarget(DeleteActionTargetRequest deleteActionTargetRequest) |
Deletes a custom action target from Security Hub.
|
default DeleteAggregatorV2Response |
SecurityHubClient.deleteAggregatorV2(Consumer<DeleteAggregatorV2Request.Builder> deleteAggregatorV2Request) |
Deletes the Aggregator V2.
|
default DeleteAggregatorV2Response |
SecurityHubClient.deleteAggregatorV2(DeleteAggregatorV2Request deleteAggregatorV2Request) |
Deletes the Aggregator V2.
|
default DeleteAutomationRuleV2Response |
SecurityHubClient.deleteAutomationRuleV2(Consumer<DeleteAutomationRuleV2Request.Builder> deleteAutomationRuleV2Request) |
Deletes a V2 automation rule.
|
default DeleteAutomationRuleV2Response |
SecurityHubClient.deleteAutomationRuleV2(DeleteAutomationRuleV2Request deleteAutomationRuleV2Request) |
Deletes a V2 automation rule.
|
default DeleteConfigurationPolicyResponse |
SecurityHubClient.deleteConfigurationPolicy(Consumer<DeleteConfigurationPolicyRequest.Builder> deleteConfigurationPolicyRequest) |
Deletes a configuration policy.
|
default DeleteConfigurationPolicyResponse |
SecurityHubClient.deleteConfigurationPolicy(DeleteConfigurationPolicyRequest deleteConfigurationPolicyRequest) |
Deletes a configuration policy.
|
default DeleteConnectorV2Response |
SecurityHubClient.deleteConnectorV2(Consumer<DeleteConnectorV2Request.Builder> deleteConnectorV2Request) |
Grants permission to delete a connectorV2.
|
default DeleteConnectorV2Response |
SecurityHubClient.deleteConnectorV2(DeleteConnectorV2Request deleteConnectorV2Request) |
Grants permission to delete a connectorV2.
|
default DeleteFindingAggregatorResponse |
SecurityHubClient.deleteFindingAggregator(Consumer<DeleteFindingAggregatorRequest.Builder> deleteFindingAggregatorRequest) |
|
default DeleteFindingAggregatorResponse |
SecurityHubClient.deleteFindingAggregator(DeleteFindingAggregatorRequest deleteFindingAggregatorRequest) |
|
default DeleteInsightResponse |
SecurityHubClient.deleteInsight(Consumer<DeleteInsightRequest.Builder> deleteInsightRequest) |
Deletes the insight specified by the InsightArn.
|
default DeleteInsightResponse |
SecurityHubClient.deleteInsight(DeleteInsightRequest deleteInsightRequest) |
Deletes the insight specified by the InsightArn.
|
default DeleteInvitationsResponse |
SecurityHubClient.deleteInvitations(Consumer<DeleteInvitationsRequest.Builder> deleteInvitationsRequest) |
|
default DeleteInvitationsResponse |
SecurityHubClient.deleteInvitations(DeleteInvitationsRequest deleteInvitationsRequest) |
|
default DeleteMembersResponse |
SecurityHubClient.deleteMembers(Consumer<DeleteMembersRequest.Builder> deleteMembersRequest) |
Deletes the specified member accounts from Security Hub.
|
default DeleteMembersResponse |
SecurityHubClient.deleteMembers(DeleteMembersRequest deleteMembersRequest) |
Deletes the specified member accounts from Security Hub.
|
default DescribeActionTargetsResponse |
SecurityHubClient.describeActionTargets(Consumer<DescribeActionTargetsRequest.Builder> describeActionTargetsRequest) |
Returns a list of the custom action targets in Security Hub in your account.
|
default DescribeActionTargetsResponse |
SecurityHubClient.describeActionTargets(DescribeActionTargetsRequest describeActionTargetsRequest) |
Returns a list of the custom action targets in Security Hub in your account.
|
default DescribeActionTargetsIterable |
SecurityHubClient.describeActionTargetsPaginator(Consumer<DescribeActionTargetsRequest.Builder> describeActionTargetsRequest) |
|
default DescribeActionTargetsIterable |
SecurityHubClient.describeActionTargetsPaginator(DescribeActionTargetsRequest describeActionTargetsRequest) |
|
default DescribeHubResponse |
SecurityHubClient.describeHub(Consumer<DescribeHubRequest.Builder> describeHubRequest) |
Returns details about the Hub resource in your account, including the HubArn and the time when you
enabled Security Hub.
|
default DescribeHubResponse |
SecurityHubClient.describeHub(DescribeHubRequest describeHubRequest) |
Returns details about the Hub resource in your account, including the HubArn and the time when you
enabled Security Hub.
|
default DescribeOrganizationConfigurationResponse |
SecurityHubClient.describeOrganizationConfiguration(Consumer<DescribeOrganizationConfigurationRequest.Builder> describeOrganizationConfigurationRequest) |
Returns information about the way your organization is configured in Security Hub.
|
default DescribeOrganizationConfigurationResponse |
SecurityHubClient.describeOrganizationConfiguration(DescribeOrganizationConfigurationRequest describeOrganizationConfigurationRequest) |
Returns information about the way your organization is configured in Security Hub.
|
default DescribeProductsResponse |
SecurityHubClient.describeProducts(Consumer<DescribeProductsRequest.Builder> describeProductsRequest) |
Returns information about product integrations in Security Hub.
|
default DescribeProductsResponse |
SecurityHubClient.describeProducts(DescribeProductsRequest describeProductsRequest) |
Returns information about product integrations in Security Hub.
|
default DescribeProductsIterable |
SecurityHubClient.describeProductsPaginator(Consumer<DescribeProductsRequest.Builder> describeProductsRequest) |
|
default DescribeProductsIterable |
SecurityHubClient.describeProductsPaginator(DescribeProductsRequest describeProductsRequest) |
|
default DescribeProductsV2Response |
SecurityHubClient.describeProductsV2(Consumer<DescribeProductsV2Request.Builder> describeProductsV2Request) |
Gets information about the product integration.
|
default DescribeProductsV2Response |
SecurityHubClient.describeProductsV2(DescribeProductsV2Request describeProductsV2Request) |
Gets information about the product integration.
|
default DescribeProductsV2Iterable |
SecurityHubClient.describeProductsV2Paginator(Consumer<DescribeProductsV2Request.Builder> describeProductsV2Request) |
|
default DescribeProductsV2Iterable |
SecurityHubClient.describeProductsV2Paginator(DescribeProductsV2Request describeProductsV2Request) |
|
default DescribeSecurityHubV2Response |
SecurityHubClient.describeSecurityHubV2(Consumer<DescribeSecurityHubV2Request.Builder> describeSecurityHubV2Request) |
Returns details about the service resource in your account.
|
default DescribeSecurityHubV2Response |
SecurityHubClient.describeSecurityHubV2(DescribeSecurityHubV2Request describeSecurityHubV2Request) |
Returns details about the service resource in your account.
|
default DescribeStandardsResponse |
SecurityHubClient.describeStandards(Consumer<DescribeStandardsRequest.Builder> describeStandardsRequest) |
Returns a list of the available standards in Security Hub.
|
default DescribeStandardsResponse |
SecurityHubClient.describeStandards(DescribeStandardsRequest describeStandardsRequest) |
Returns a list of the available standards in Security Hub.
|
default DescribeStandardsControlsResponse |
SecurityHubClient.describeStandardsControls(Consumer<DescribeStandardsControlsRequest.Builder> describeStandardsControlsRequest) |
Returns a list of security standards controls.
|
default DescribeStandardsControlsResponse |
SecurityHubClient.describeStandardsControls(DescribeStandardsControlsRequest describeStandardsControlsRequest) |
Returns a list of security standards controls.
|
default DescribeStandardsControlsIterable |
SecurityHubClient.describeStandardsControlsPaginator(Consumer<DescribeStandardsControlsRequest.Builder> describeStandardsControlsRequest) |
|
default DescribeStandardsControlsIterable |
SecurityHubClient.describeStandardsControlsPaginator(DescribeStandardsControlsRequest describeStandardsControlsRequest) |
|
default DescribeStandardsIterable |
SecurityHubClient.describeStandardsPaginator(Consumer<DescribeStandardsRequest.Builder> describeStandardsRequest) |
|
default DescribeStandardsIterable |
SecurityHubClient.describeStandardsPaginator(DescribeStandardsRequest describeStandardsRequest) |
|
default DisableImportFindingsForProductResponse |
SecurityHubClient.disableImportFindingsForProduct(Consumer<DisableImportFindingsForProductRequest.Builder> disableImportFindingsForProductRequest) |
Disables the integration of the specified product with Security Hub.
|
default DisableImportFindingsForProductResponse |
SecurityHubClient.disableImportFindingsForProduct(DisableImportFindingsForProductRequest disableImportFindingsForProductRequest) |
Disables the integration of the specified product with Security Hub.
|
default DisableOrganizationAdminAccountResponse |
SecurityHubClient.disableOrganizationAdminAccount(Consumer<DisableOrganizationAdminAccountRequest.Builder> disableOrganizationAdminAccountRequest) |
Disables a Security Hub administrator account.
|
default DisableOrganizationAdminAccountResponse |
SecurityHubClient.disableOrganizationAdminAccount(DisableOrganizationAdminAccountRequest disableOrganizationAdminAccountRequest) |
Disables a Security Hub administrator account.
|
default DisableSecurityHubResponse |
SecurityHubClient.disableSecurityHub() |
Disables Security Hub in your account only in the current Amazon Web Services Region.
|
default DisableSecurityHubResponse |
SecurityHubClient.disableSecurityHub(Consumer<DisableSecurityHubRequest.Builder> disableSecurityHubRequest) |
Disables Security Hub in your account only in the current Amazon Web Services Region.
|
default DisableSecurityHubResponse |
SecurityHubClient.disableSecurityHub(DisableSecurityHubRequest disableSecurityHubRequest) |
Disables Security Hub in your account only in the current Amazon Web Services Region.
|
default DisableSecurityHubV2Response |
SecurityHubClient.disableSecurityHubV2(Consumer<DisableSecurityHubV2Request.Builder> disableSecurityHubV2Request) |
Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
|
default DisableSecurityHubV2Response |
SecurityHubClient.disableSecurityHubV2(DisableSecurityHubV2Request disableSecurityHubV2Request) |
Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
|
default DisassociateFromAdministratorAccountResponse |
SecurityHubClient.disassociateFromAdministratorAccount(Consumer<DisassociateFromAdministratorAccountRequest.Builder> disassociateFromAdministratorAccountRequest) |
Disassociates the current Security Hub member account from the associated administrator account.
|
default DisassociateFromAdministratorAccountResponse |
SecurityHubClient.disassociateFromAdministratorAccount(DisassociateFromAdministratorAccountRequest disassociateFromAdministratorAccountRequest) |
Disassociates the current Security Hub member account from the associated administrator account.
|
default DisassociateFromMasterAccountResponse |
SecurityHubClient.disassociateFromMasterAccount(Consumer<DisassociateFromMasterAccountRequest.Builder> disassociateFromMasterAccountRequest) |
Deprecated.
|
default DisassociateFromMasterAccountResponse |
SecurityHubClient.disassociateFromMasterAccount(DisassociateFromMasterAccountRequest disassociateFromMasterAccountRequest) |
Deprecated.
|
default DisassociateMembersResponse |
SecurityHubClient.disassociateMembers(Consumer<DisassociateMembersRequest.Builder> disassociateMembersRequest) |
Disassociates the specified member accounts from the associated administrator account.
|
default DisassociateMembersResponse |
SecurityHubClient.disassociateMembers(DisassociateMembersRequest disassociateMembersRequest) |
Disassociates the specified member accounts from the associated administrator account.
|
default EnableImportFindingsForProductResponse |
SecurityHubClient.enableImportFindingsForProduct(Consumer<EnableImportFindingsForProductRequest.Builder> enableImportFindingsForProductRequest) |
Enables the integration of a partner product with Security Hub.
|
default EnableImportFindingsForProductResponse |
SecurityHubClient.enableImportFindingsForProduct(EnableImportFindingsForProductRequest enableImportFindingsForProductRequest) |
Enables the integration of a partner product with Security Hub.
|
default EnableOrganizationAdminAccountResponse |
SecurityHubClient.enableOrganizationAdminAccount(Consumer<EnableOrganizationAdminAccountRequest.Builder> enableOrganizationAdminAccountRequest) |
Designates the Security Hub administrator account for an organization.
|
default EnableOrganizationAdminAccountResponse |
SecurityHubClient.enableOrganizationAdminAccount(EnableOrganizationAdminAccountRequest enableOrganizationAdminAccountRequest) |
Designates the Security Hub administrator account for an organization.
|
default EnableSecurityHubResponse |
SecurityHubClient.enableSecurityHub() |
Enables Security Hub for your account in the current Region or the Region you specify in the request.
|
default EnableSecurityHubResponse |
SecurityHubClient.enableSecurityHub(Consumer<EnableSecurityHubRequest.Builder> enableSecurityHubRequest) |
Enables Security Hub for your account in the current Region or the Region you specify in the request.
|
default EnableSecurityHubResponse |
SecurityHubClient.enableSecurityHub(EnableSecurityHubRequest enableSecurityHubRequest) |
Enables Security Hub for your account in the current Region or the Region you specify in the request.
|
default EnableSecurityHubV2Response |
SecurityHubClient.enableSecurityHubV2(Consumer<EnableSecurityHubV2Request.Builder> enableSecurityHubV2Request) |
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services
Region.
|
default EnableSecurityHubV2Response |
SecurityHubClient.enableSecurityHubV2(EnableSecurityHubV2Request enableSecurityHubV2Request) |
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services
Region.
|
default GetAdministratorAccountResponse |
SecurityHubClient.getAdministratorAccount(Consumer<GetAdministratorAccountRequest.Builder> getAdministratorAccountRequest) |
Provides the details for the Security Hub administrator account for the current member account.
|
default GetAdministratorAccountResponse |
SecurityHubClient.getAdministratorAccount(GetAdministratorAccountRequest getAdministratorAccountRequest) |
Provides the details for the Security Hub administrator account for the current member account.
|
default GetAggregatorV2Response |
SecurityHubClient.getAggregatorV2(Consumer<GetAggregatorV2Request.Builder> getAggregatorV2Request) |
Returns the configuration of the specified Aggregator V2.
|
default GetAggregatorV2Response |
SecurityHubClient.getAggregatorV2(GetAggregatorV2Request getAggregatorV2Request) |
Returns the configuration of the specified Aggregator V2.
|
default GetAutomationRuleV2Response |
SecurityHubClient.getAutomationRuleV2(Consumer<GetAutomationRuleV2Request.Builder> getAutomationRuleV2Request) |
Returns an automation rule for the V2 service.
|
default GetAutomationRuleV2Response |
SecurityHubClient.getAutomationRuleV2(GetAutomationRuleV2Request getAutomationRuleV2Request) |
Returns an automation rule for the V2 service.
|
default GetConfigurationPolicyResponse |
SecurityHubClient.getConfigurationPolicy(Consumer<GetConfigurationPolicyRequest.Builder> getConfigurationPolicyRequest) |
Provides information about a configuration policy.
|
default GetConfigurationPolicyResponse |
SecurityHubClient.getConfigurationPolicy(GetConfigurationPolicyRequest getConfigurationPolicyRequest) |
Provides information about a configuration policy.
|
default GetConfigurationPolicyAssociationResponse |
SecurityHubClient.getConfigurationPolicyAssociation(Consumer<GetConfigurationPolicyAssociationRequest.Builder> getConfigurationPolicyAssociationRequest) |
Returns the association between a configuration and a target account, organizational unit, or the root.
|
default GetConfigurationPolicyAssociationResponse |
SecurityHubClient.getConfigurationPolicyAssociation(GetConfigurationPolicyAssociationRequest getConfigurationPolicyAssociationRequest) |
Returns the association between a configuration and a target account, organizational unit, or the root.
|
default GetConnectorV2Response |
SecurityHubClient.getConnectorV2(Consumer<GetConnectorV2Request.Builder> getConnectorV2Request) |
Grants permission to retrieve details for a connectorV2 based on connector id.
|
default GetConnectorV2Response |
SecurityHubClient.getConnectorV2(GetConnectorV2Request getConnectorV2Request) |
Grants permission to retrieve details for a connectorV2 based on connector id.
|
default GetEnabledStandardsResponse |
SecurityHubClient.getEnabledStandards(Consumer<GetEnabledStandardsRequest.Builder> getEnabledStandardsRequest) |
Returns a list of the standards that are currently enabled.
|
default GetEnabledStandardsResponse |
SecurityHubClient.getEnabledStandards(GetEnabledStandardsRequest getEnabledStandardsRequest) |
Returns a list of the standards that are currently enabled.
|
default GetEnabledStandardsIterable |
SecurityHubClient.getEnabledStandardsPaginator(Consumer<GetEnabledStandardsRequest.Builder> getEnabledStandardsRequest) |
|
default GetEnabledStandardsIterable |
SecurityHubClient.getEnabledStandardsPaginator(GetEnabledStandardsRequest getEnabledStandardsRequest) |
|
default GetFindingAggregatorResponse |
SecurityHubClient.getFindingAggregator(Consumer<GetFindingAggregatorRequest.Builder> getFindingAggregatorRequest) |
|
default GetFindingAggregatorResponse |
SecurityHubClient.getFindingAggregator(GetFindingAggregatorRequest getFindingAggregatorRequest) |
|
default GetFindingHistoryResponse |
SecurityHubClient.getFindingHistory(Consumer<GetFindingHistoryRequest.Builder> getFindingHistoryRequest) |
Returns the history of a Security Hub finding for the past 90 days.
|
default GetFindingHistoryResponse |
SecurityHubClient.getFindingHistory(GetFindingHistoryRequest getFindingHistoryRequest) |
Returns the history of a Security Hub finding for the past 90 days.
|
default GetFindingHistoryIterable |
SecurityHubClient.getFindingHistoryPaginator(Consumer<GetFindingHistoryRequest.Builder> getFindingHistoryRequest) |
|
default GetFindingHistoryIterable |
SecurityHubClient.getFindingHistoryPaginator(GetFindingHistoryRequest getFindingHistoryRequest) |
|
default GetFindingsResponse |
SecurityHubClient.getFindings() |
Returns a list of findings that match the specified criteria.
|
default GetFindingsResponse |
SecurityHubClient.getFindings(Consumer<GetFindingsRequest.Builder> getFindingsRequest) |
Returns a list of findings that match the specified criteria.
|
default GetFindingsResponse |
SecurityHubClient.getFindings(GetFindingsRequest getFindingsRequest) |
Returns a list of findings that match the specified criteria.
|
default GetFindingsIterable |
SecurityHubClient.getFindingsPaginator() |
|
default GetFindingsIterable |
SecurityHubClient.getFindingsPaginator(Consumer<GetFindingsRequest.Builder> getFindingsRequest) |
|
default GetFindingsIterable |
SecurityHubClient.getFindingsPaginator(GetFindingsRequest getFindingsRequest) |
|
default GetFindingStatisticsV2Response |
SecurityHubClient.getFindingStatisticsV2(Consumer<GetFindingStatisticsV2Request.Builder> getFindingStatisticsV2Request) |
Returns aggregated statistical data about findings.
|
default GetFindingStatisticsV2Response |
SecurityHubClient.getFindingStatisticsV2(GetFindingStatisticsV2Request getFindingStatisticsV2Request) |
Returns aggregated statistical data about findings.
|
default GetFindingsV2Response |
SecurityHubClient.getFindingsV2(Consumer<GetFindingsV2Request.Builder> getFindingsV2Request) |
Return a list of findings that match the specified criteria.
|
default GetFindingsV2Response |
SecurityHubClient.getFindingsV2(GetFindingsV2Request getFindingsV2Request) |
Return a list of findings that match the specified criteria.
|
default GetFindingsV2Iterable |
SecurityHubClient.getFindingsV2Paginator(Consumer<GetFindingsV2Request.Builder> getFindingsV2Request) |
|
default GetFindingsV2Iterable |
SecurityHubClient.getFindingsV2Paginator(GetFindingsV2Request getFindingsV2Request) |
|
default GetInsightResultsResponse |
SecurityHubClient.getInsightResults(Consumer<GetInsightResultsRequest.Builder> getInsightResultsRequest) |
Lists the results of the Security Hub insight specified by the insight ARN.
|
default GetInsightResultsResponse |
SecurityHubClient.getInsightResults(GetInsightResultsRequest getInsightResultsRequest) |
Lists the results of the Security Hub insight specified by the insight ARN.
|
default GetInsightsResponse |
SecurityHubClient.getInsights(Consumer<GetInsightsRequest.Builder> getInsightsRequest) |
Lists and describes insights for the specified insight ARNs.
|
default GetInsightsResponse |
SecurityHubClient.getInsights(GetInsightsRequest getInsightsRequest) |
Lists and describes insights for the specified insight ARNs.
|
default GetInsightsIterable |
SecurityHubClient.getInsightsPaginator(Consumer<GetInsightsRequest.Builder> getInsightsRequest) |
|
default GetInsightsIterable |
SecurityHubClient.getInsightsPaginator(GetInsightsRequest getInsightsRequest) |
|
default GetInvitationsCountResponse |
SecurityHubClient.getInvitationsCount() |
|
default GetInvitationsCountResponse |
SecurityHubClient.getInvitationsCount(Consumer<GetInvitationsCountRequest.Builder> getInvitationsCountRequest) |
|
default GetInvitationsCountResponse |
SecurityHubClient.getInvitationsCount(GetInvitationsCountRequest getInvitationsCountRequest) |
|
default GetMasterAccountResponse |
SecurityHubClient.getMasterAccount() |
Deprecated.
|
default GetMasterAccountResponse |
SecurityHubClient.getMasterAccount(Consumer<GetMasterAccountRequest.Builder> getMasterAccountRequest) |
Deprecated.
|
default GetMasterAccountResponse |
SecurityHubClient.getMasterAccount(GetMasterAccountRequest getMasterAccountRequest) |
Deprecated.
|
default GetMembersResponse |
SecurityHubClient.getMembers(Consumer<GetMembersRequest.Builder> getMembersRequest) |
Returns the details for the Security Hub member accounts for the specified account IDs.
|
default GetMembersResponse |
SecurityHubClient.getMembers(GetMembersRequest getMembersRequest) |
Returns the details for the Security Hub member accounts for the specified account IDs.
|
default GetResourcesStatisticsV2Response |
SecurityHubClient.getResourcesStatisticsV2(Consumer<GetResourcesStatisticsV2Request.Builder> getResourcesStatisticsV2Request) |
Retrieves statistical information about Amazon Web Services resources and their associated security findings.
|
default GetResourcesStatisticsV2Response |
SecurityHubClient.getResourcesStatisticsV2(GetResourcesStatisticsV2Request getResourcesStatisticsV2Request) |
Retrieves statistical information about Amazon Web Services resources and their associated security findings.
|
default GetResourcesV2Response |
SecurityHubClient.getResourcesV2(Consumer<GetResourcesV2Request.Builder> getResourcesV2Request) |
Returns a list of resources.
|
default GetResourcesV2Response |
SecurityHubClient.getResourcesV2(GetResourcesV2Request getResourcesV2Request) |
Returns a list of resources.
|
default GetResourcesV2Iterable |
SecurityHubClient.getResourcesV2Paginator(Consumer<GetResourcesV2Request.Builder> getResourcesV2Request) |
|
default GetResourcesV2Iterable |
SecurityHubClient.getResourcesV2Paginator(GetResourcesV2Request getResourcesV2Request) |
|
default GetSecurityControlDefinitionResponse |
SecurityHubClient.getSecurityControlDefinition(Consumer<GetSecurityControlDefinitionRequest.Builder> getSecurityControlDefinitionRequest) |
Retrieves the definition of a security control.
|
default GetSecurityControlDefinitionResponse |
SecurityHubClient.getSecurityControlDefinition(GetSecurityControlDefinitionRequest getSecurityControlDefinitionRequest) |
Retrieves the definition of a security control.
|
default InviteMembersResponse |
SecurityHubClient.inviteMembers(Consumer<InviteMembersRequest.Builder> inviteMembersRequest) |
|
default InviteMembersResponse |
SecurityHubClient.inviteMembers(InviteMembersRequest inviteMembersRequest) |
|
default ListAggregatorsV2Response |
SecurityHubClient.listAggregatorsV2(Consumer<ListAggregatorsV2Request.Builder> listAggregatorsV2Request) |
Retrieves a list of V2 aggregators.
|
default ListAggregatorsV2Response |
SecurityHubClient.listAggregatorsV2(ListAggregatorsV2Request listAggregatorsV2Request) |
Retrieves a list of V2 aggregators.
|
default ListAggregatorsV2Iterable |
SecurityHubClient.listAggregatorsV2Paginator(Consumer<ListAggregatorsV2Request.Builder> listAggregatorsV2Request) |
|
default ListAggregatorsV2Iterable |
SecurityHubClient.listAggregatorsV2Paginator(ListAggregatorsV2Request listAggregatorsV2Request) |
|
default ListAutomationRulesResponse |
SecurityHubClient.listAutomationRules(Consumer<ListAutomationRulesRequest.Builder> listAutomationRulesRequest) |
A list of automation rules and their metadata for the calling account.
|
default ListAutomationRulesResponse |
SecurityHubClient.listAutomationRules(ListAutomationRulesRequest listAutomationRulesRequest) |
A list of automation rules and their metadata for the calling account.
|
default ListAutomationRulesV2Response |
SecurityHubClient.listAutomationRulesV2(Consumer<ListAutomationRulesV2Request.Builder> listAutomationRulesV2Request) |
Returns a list of automation rules and metadata for the calling account.
|
default ListAutomationRulesV2Response |
SecurityHubClient.listAutomationRulesV2(ListAutomationRulesV2Request listAutomationRulesV2Request) |
Returns a list of automation rules and metadata for the calling account.
|
default ListConfigurationPoliciesResponse |
SecurityHubClient.listConfigurationPolicies(Consumer<ListConfigurationPoliciesRequest.Builder> listConfigurationPoliciesRequest) |
Lists the configuration policies that the Security Hub delegated administrator has created for your organization.
|
default ListConfigurationPoliciesResponse |
SecurityHubClient.listConfigurationPolicies(ListConfigurationPoliciesRequest listConfigurationPoliciesRequest) |
Lists the configuration policies that the Security Hub delegated administrator has created for your organization.
|
default ListConfigurationPoliciesIterable |
SecurityHubClient.listConfigurationPoliciesPaginator(Consumer<ListConfigurationPoliciesRequest.Builder> listConfigurationPoliciesRequest) |
|
default ListConfigurationPoliciesIterable |
SecurityHubClient.listConfigurationPoliciesPaginator(ListConfigurationPoliciesRequest listConfigurationPoliciesRequest) |
|
default ListConfigurationPolicyAssociationsResponse |
SecurityHubClient.listConfigurationPolicyAssociations(Consumer<ListConfigurationPolicyAssociationsRequest.Builder> listConfigurationPolicyAssociationsRequest) |
Provides information about the associations for your configuration policies and self-managed behavior.
|
default ListConfigurationPolicyAssociationsResponse |
SecurityHubClient.listConfigurationPolicyAssociations(ListConfigurationPolicyAssociationsRequest listConfigurationPolicyAssociationsRequest) |
Provides information about the associations for your configuration policies and self-managed behavior.
|
default ListConfigurationPolicyAssociationsIterable |
SecurityHubClient.listConfigurationPolicyAssociationsPaginator(Consumer<ListConfigurationPolicyAssociationsRequest.Builder> listConfigurationPolicyAssociationsRequest) |
|
default ListConfigurationPolicyAssociationsIterable |
SecurityHubClient.listConfigurationPolicyAssociationsPaginator(ListConfigurationPolicyAssociationsRequest listConfigurationPolicyAssociationsRequest) |
|
default ListConnectorsV2Response |
SecurityHubClient.listConnectorsV2(Consumer<ListConnectorsV2Request.Builder> listConnectorsV2Request) |
Grants permission to retrieve a list of connectorsV2 and their metadata for the calling account.
|
default ListConnectorsV2Response |
SecurityHubClient.listConnectorsV2(ListConnectorsV2Request listConnectorsV2Request) |
Grants permission to retrieve a list of connectorsV2 and their metadata for the calling account.
|
default ListEnabledProductsForImportResponse |
SecurityHubClient.listEnabledProductsForImport() |
Lists all findings-generating solutions (products) that you are subscribed to receive findings from in Security
Hub.
|
default ListEnabledProductsForImportResponse |
SecurityHubClient.listEnabledProductsForImport(Consumer<ListEnabledProductsForImportRequest.Builder> listEnabledProductsForImportRequest) |
Lists all findings-generating solutions (products) that you are subscribed to receive findings from in Security
Hub.
|
default ListEnabledProductsForImportResponse |
SecurityHubClient.listEnabledProductsForImport(ListEnabledProductsForImportRequest listEnabledProductsForImportRequest) |
Lists all findings-generating solutions (products) that you are subscribed to receive findings from in Security
Hub.
|
default ListEnabledProductsForImportIterable |
SecurityHubClient.listEnabledProductsForImportPaginator() |
|
default ListEnabledProductsForImportIterable |
SecurityHubClient.listEnabledProductsForImportPaginator(Consumer<ListEnabledProductsForImportRequest.Builder> listEnabledProductsForImportRequest) |
|
default ListEnabledProductsForImportIterable |
SecurityHubClient.listEnabledProductsForImportPaginator(ListEnabledProductsForImportRequest listEnabledProductsForImportRequest) |
|
default ListFindingAggregatorsResponse |
SecurityHubClient.listFindingAggregators(Consumer<ListFindingAggregatorsRequest.Builder> listFindingAggregatorsRequest) |
If cross-Region aggregation is enabled, then ListFindingAggregators returns the Amazon Resource Name
(ARN) of the finding aggregator.
|
default ListFindingAggregatorsResponse |
SecurityHubClient.listFindingAggregators(ListFindingAggregatorsRequest listFindingAggregatorsRequest) |
If cross-Region aggregation is enabled, then ListFindingAggregators returns the Amazon Resource Name
(ARN) of the finding aggregator.
|
default ListFindingAggregatorsIterable |
SecurityHubClient.listFindingAggregatorsPaginator(Consumer<ListFindingAggregatorsRequest.Builder> listFindingAggregatorsRequest) |
|
default ListFindingAggregatorsIterable |
SecurityHubClient.listFindingAggregatorsPaginator(ListFindingAggregatorsRequest listFindingAggregatorsRequest) |
|
default ListInvitationsResponse |
SecurityHubClient.listInvitations() |
|
default ListInvitationsResponse |
SecurityHubClient.listInvitations(Consumer<ListInvitationsRequest.Builder> listInvitationsRequest) |
|
default ListInvitationsResponse |
SecurityHubClient.listInvitations(ListInvitationsRequest listInvitationsRequest) |
|
default ListInvitationsIterable |
SecurityHubClient.listInvitationsPaginator() |
|
default ListInvitationsIterable |
SecurityHubClient.listInvitationsPaginator(Consumer<ListInvitationsRequest.Builder> listInvitationsRequest) |
|
default ListInvitationsIterable |
SecurityHubClient.listInvitationsPaginator(ListInvitationsRequest listInvitationsRequest) |
|
default ListMembersResponse |
SecurityHubClient.listMembers() |
Lists details about all member accounts for the current Security Hub administrator account.
|
default ListMembersResponse |
SecurityHubClient.listMembers(Consumer<ListMembersRequest.Builder> listMembersRequest) |
Lists details about all member accounts for the current Security Hub administrator account.
|
default ListMembersResponse |
SecurityHubClient.listMembers(ListMembersRequest listMembersRequest) |
Lists details about all member accounts for the current Security Hub administrator account.
|
default ListMembersIterable |
SecurityHubClient.listMembersPaginator() |
|
default ListMembersIterable |
SecurityHubClient.listMembersPaginator(Consumer<ListMembersRequest.Builder> listMembersRequest) |
|
default ListMembersIterable |
SecurityHubClient.listMembersPaginator(ListMembersRequest listMembersRequest) |
|
default ListOrganizationAdminAccountsResponse |
SecurityHubClient.listOrganizationAdminAccounts(Consumer<ListOrganizationAdminAccountsRequest.Builder> listOrganizationAdminAccountsRequest) |
Lists the Security Hub administrator accounts.
|
default ListOrganizationAdminAccountsResponse |
SecurityHubClient.listOrganizationAdminAccounts(ListOrganizationAdminAccountsRequest listOrganizationAdminAccountsRequest) |
Lists the Security Hub administrator accounts.
|
default ListOrganizationAdminAccountsIterable |
SecurityHubClient.listOrganizationAdminAccountsPaginator(Consumer<ListOrganizationAdminAccountsRequest.Builder> listOrganizationAdminAccountsRequest) |
|
default ListOrganizationAdminAccountsIterable |
SecurityHubClient.listOrganizationAdminAccountsPaginator(ListOrganizationAdminAccountsRequest listOrganizationAdminAccountsRequest) |
|
default ListSecurityControlDefinitionsResponse |
SecurityHubClient.listSecurityControlDefinitions(Consumer<ListSecurityControlDefinitionsRequest.Builder> listSecurityControlDefinitionsRequest) |
Lists all of the security controls that apply to a specified standard.
|
default ListSecurityControlDefinitionsResponse |
SecurityHubClient.listSecurityControlDefinitions(ListSecurityControlDefinitionsRequest listSecurityControlDefinitionsRequest) |
Lists all of the security controls that apply to a specified standard.
|
default ListSecurityControlDefinitionsIterable |
SecurityHubClient.listSecurityControlDefinitionsPaginator(Consumer<ListSecurityControlDefinitionsRequest.Builder> listSecurityControlDefinitionsRequest) |
|
default ListSecurityControlDefinitionsIterable |
SecurityHubClient.listSecurityControlDefinitionsPaginator(ListSecurityControlDefinitionsRequest listSecurityControlDefinitionsRequest) |
|
default ListStandardsControlAssociationsResponse |
SecurityHubClient.listStandardsControlAssociations(Consumer<ListStandardsControlAssociationsRequest.Builder> listStandardsControlAssociationsRequest) |
Specifies whether a control is currently enabled or disabled in each enabled standard in the calling account.
|
default ListStandardsControlAssociationsResponse |
SecurityHubClient.listStandardsControlAssociations(ListStandardsControlAssociationsRequest listStandardsControlAssociationsRequest) |
Specifies whether a control is currently enabled or disabled in each enabled standard in the calling account.
|
default ListStandardsControlAssociationsIterable |
SecurityHubClient.listStandardsControlAssociationsPaginator(Consumer<ListStandardsControlAssociationsRequest.Builder> listStandardsControlAssociationsRequest) |
|
default ListStandardsControlAssociationsIterable |
SecurityHubClient.listStandardsControlAssociationsPaginator(ListStandardsControlAssociationsRequest listStandardsControlAssociationsRequest) |
|
default ListTagsForResourceResponse |
SecurityHubClient.listTagsForResource(Consumer<ListTagsForResourceRequest.Builder> listTagsForResourceRequest) |
Returns a list of tags associated with a resource.
|
default ListTagsForResourceResponse |
SecurityHubClient.listTagsForResource(ListTagsForResourceRequest listTagsForResourceRequest) |
Returns a list of tags associated with a resource.
|
default StartConfigurationPolicyAssociationResponse |
SecurityHubClient.startConfigurationPolicyAssociation(Consumer<StartConfigurationPolicyAssociationRequest.Builder> startConfigurationPolicyAssociationRequest) |
Associates a target account, organizational unit, or the root with a specified configuration.
|
default StartConfigurationPolicyAssociationResponse |
SecurityHubClient.startConfigurationPolicyAssociation(StartConfigurationPolicyAssociationRequest startConfigurationPolicyAssociationRequest) |
Associates a target account, organizational unit, or the root with a specified configuration.
|
default StartConfigurationPolicyDisassociationResponse |
SecurityHubClient.startConfigurationPolicyDisassociation(Consumer<StartConfigurationPolicyDisassociationRequest.Builder> startConfigurationPolicyDisassociationRequest) |
Disassociates a target account, organizational unit, or the root from a specified configuration.
|
default StartConfigurationPolicyDisassociationResponse |
SecurityHubClient.startConfigurationPolicyDisassociation(StartConfigurationPolicyDisassociationRequest startConfigurationPolicyDisassociationRequest) |
Disassociates a target account, organizational unit, or the root from a specified configuration.
|
default TagResourceResponse |
SecurityHubClient.tagResource(Consumer<TagResourceRequest.Builder> tagResourceRequest) |
Adds one or more tags to a resource.
|
default TagResourceResponse |
SecurityHubClient.tagResource(TagResourceRequest tagResourceRequest) |
Adds one or more tags to a resource.
|
default UntagResourceResponse |
SecurityHubClient.untagResource(Consumer<UntagResourceRequest.Builder> untagResourceRequest) |
Removes one or more tags from a resource.
|
default UntagResourceResponse |
SecurityHubClient.untagResource(UntagResourceRequest untagResourceRequest) |
Removes one or more tags from a resource.
|
default UpdateActionTargetResponse |
SecurityHubClient.updateActionTarget(Consumer<UpdateActionTargetRequest.Builder> updateActionTargetRequest) |
Updates the name and description of a custom action target in Security Hub.
|
default UpdateActionTargetResponse |
SecurityHubClient.updateActionTarget(UpdateActionTargetRequest updateActionTargetRequest) |
Updates the name and description of a custom action target in Security Hub.
|
default UpdateAggregatorV2Response |
SecurityHubClient.updateAggregatorV2(Consumer<UpdateAggregatorV2Request.Builder> updateAggregatorV2Request) |
Udpates the configuration for the Aggregator V2.
|
default UpdateAggregatorV2Response |
SecurityHubClient.updateAggregatorV2(UpdateAggregatorV2Request updateAggregatorV2Request) |
Udpates the configuration for the Aggregator V2.
|
default UpdateAutomationRuleV2Response |
SecurityHubClient.updateAutomationRuleV2(Consumer<UpdateAutomationRuleV2Request.Builder> updateAutomationRuleV2Request) |
Updates a V2 automation rule.
|
default UpdateAutomationRuleV2Response |
SecurityHubClient.updateAutomationRuleV2(UpdateAutomationRuleV2Request updateAutomationRuleV2Request) |
Updates a V2 automation rule.
|
default UpdateConfigurationPolicyResponse |
SecurityHubClient.updateConfigurationPolicy(Consumer<UpdateConfigurationPolicyRequest.Builder> updateConfigurationPolicyRequest) |
Updates a configuration policy.
|
default UpdateConfigurationPolicyResponse |
SecurityHubClient.updateConfigurationPolicy(UpdateConfigurationPolicyRequest updateConfigurationPolicyRequest) |
Updates a configuration policy.
|
default UpdateConnectorV2Response |
SecurityHubClient.updateConnectorV2(Consumer<UpdateConnectorV2Request.Builder> updateConnectorV2Request) |
Grants permission to update a connectorV2 based on its id and input parameters.
|
default UpdateConnectorV2Response |
SecurityHubClient.updateConnectorV2(UpdateConnectorV2Request updateConnectorV2Request) |
Grants permission to update a connectorV2 based on its id and input parameters.
|
default UpdateFindingAggregatorResponse |
SecurityHubClient.updateFindingAggregator(Consumer<UpdateFindingAggregatorRequest.Builder> updateFindingAggregatorRequest) |
|
default UpdateFindingAggregatorResponse |
SecurityHubClient.updateFindingAggregator(UpdateFindingAggregatorRequest updateFindingAggregatorRequest) |
|
default UpdateFindingsResponse |
SecurityHubClient.updateFindings(Consumer<UpdateFindingsRequest.Builder> updateFindingsRequest) |
UpdateFindings is a deprecated operation.
|
default UpdateFindingsResponse |
SecurityHubClient.updateFindings(UpdateFindingsRequest updateFindingsRequest) |
UpdateFindings is a deprecated operation.
|
default UpdateInsightResponse |
SecurityHubClient.updateInsight(Consumer<UpdateInsightRequest.Builder> updateInsightRequest) |
Updates the Security Hub insight identified by the specified insight ARN.
|
default UpdateInsightResponse |
SecurityHubClient.updateInsight(UpdateInsightRequest updateInsightRequest) |
Updates the Security Hub insight identified by the specified insight ARN.
|
default UpdateOrganizationConfigurationResponse |
SecurityHubClient.updateOrganizationConfiguration(Consumer<UpdateOrganizationConfigurationRequest.Builder> updateOrganizationConfigurationRequest) |
Updates the configuration of your organization in Security Hub.
|
default UpdateOrganizationConfigurationResponse |
SecurityHubClient.updateOrganizationConfiguration(UpdateOrganizationConfigurationRequest updateOrganizationConfigurationRequest) |
Updates the configuration of your organization in Security Hub.
|
default UpdateSecurityControlResponse |
SecurityHubClient.updateSecurityControl(Consumer<UpdateSecurityControlRequest.Builder> updateSecurityControlRequest) |
Updates the properties of a security control.
|
default UpdateSecurityControlResponse |
SecurityHubClient.updateSecurityControl(UpdateSecurityControlRequest updateSecurityControlRequest) |
Updates the properties of a security control.
|
default UpdateSecurityHubConfigurationResponse |
SecurityHubClient.updateSecurityHubConfiguration(Consumer<UpdateSecurityHubConfigurationRequest.Builder> updateSecurityHubConfigurationRequest) |
Updates configuration options for Security Hub.
|
default UpdateSecurityHubConfigurationResponse |
SecurityHubClient.updateSecurityHubConfiguration(UpdateSecurityHubConfigurationRequest updateSecurityHubConfigurationRequest) |
Updates configuration options for Security Hub.
|
default UpdateStandardsControlResponse |
SecurityHubClient.updateStandardsControl(Consumer<UpdateStandardsControlRequest.Builder> updateStandardsControlRequest) |
Used to control whether an individual security standard control is enabled or disabled.
|
default UpdateStandardsControlResponse |
SecurityHubClient.updateStandardsControl(UpdateStandardsControlRequest updateStandardsControlRequest) |
Used to control whether an individual security standard control is enabled or disabled.
|