Uses of Enum
software.amazon.awssdk.services.securityhub.model.SecurityHubFeature
Packages that use SecurityHubFeature
-
Uses of SecurityHubFeature in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return SecurityHubFeatureModifier and TypeMethodDescriptionfinal SecurityHubFeatureDisableOrganizationAdminAccountRequest.feature()The feature for which the delegated admin account is disabled.final SecurityHubFeatureEnableOrganizationAdminAccountRequest.feature()The feature for which the delegated admin account is enabled.final SecurityHubFeatureEnableOrganizationAdminAccountResponse.feature()The feature where the delegated administrator is enabled.final SecurityHubFeatureListOrganizationAdminAccountsRequest.feature()The feature where the delegated administrator account is listed.final SecurityHubFeatureListOrganizationAdminAccountsResponse.feature()The feature where the delegated administrator account is listed.static SecurityHubFeatureUse this in place of valueOf to convert the raw string returned by the service into the enum value.static SecurityHubFeatureReturns the enum constant of this type with the specified name.static SecurityHubFeature[]SecurityHubFeature.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type SecurityHubFeatureModifier and TypeMethodDescriptionstatic Set<SecurityHubFeature>SecurityHubFeature.knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type SecurityHubFeatureModifier and TypeMethodDescriptionDisableOrganizationAdminAccountRequest.Builder.feature(SecurityHubFeature feature) The feature for which the delegated admin account is disabled.EnableOrganizationAdminAccountRequest.Builder.feature(SecurityHubFeature feature) The feature for which the delegated admin account is enabled.EnableOrganizationAdminAccountResponse.Builder.feature(SecurityHubFeature feature) The feature where the delegated administrator is enabled.ListOrganizationAdminAccountsRequest.Builder.feature(SecurityHubFeature feature) The feature where the delegated administrator account is listed.ListOrganizationAdminAccountsResponse.Builder.feature(SecurityHubFeature feature) The feature where the delegated administrator account is listed.