Uses of Class
software.amazon.awssdk.services.securityhub.model.SensitiveDataResult
Packages that use SensitiveDataResult
-
Uses of SensitiveDataResult in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type SensitiveDataResultModifier and TypeMethodDescriptionfinal List<SensitiveDataResult>ClassificationResult.sensitiveData()Provides details about sensitive data that was identified based on built-in configuration.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type SensitiveDataResultModifier and TypeMethodDescriptionClassificationResult.Builder.sensitiveData(SensitiveDataResult... sensitiveData) Provides details about sensitive data that was identified based on built-in configuration.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type SensitiveDataResultModifier and TypeMethodDescriptionClassificationResult.Builder.sensitiveData(Collection<SensitiveDataResult> sensitiveData) Provides details about sensitive data that was identified based on built-in configuration.