Uses of Class
software.amazon.awssdk.services.securityhub.model.ServiceNowProviderConfiguration
Packages that use ServiceNowProviderConfiguration
-
Uses of ServiceNowProviderConfiguration in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ServiceNowProviderConfigurationModifier and TypeMethodDescriptionProviderConfiguration.serviceNow()The configuration settings required to establish an integration with ServiceNow ITSM.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ServiceNowProviderConfigurationModifier and TypeMethodDescriptionstatic ProviderConfigurationProviderConfiguration.fromServiceNow(ServiceNowProviderConfiguration serviceNow) Create an instance of this class withProviderConfiguration.serviceNow()initialized to the given value.ProviderConfiguration.Builder.serviceNow(ServiceNowProviderConfiguration serviceNow) The configuration settings required to establish an integration with ServiceNow ITSM.