Uses of Class
software.amazon.awssdk.services.securityhub.model.ServiceNowUpdateConfiguration
-
Packages that use ServiceNowUpdateConfiguration Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of ServiceNowUpdateConfiguration in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ServiceNowUpdateConfiguration Modifier and Type Method Description ServiceNowUpdateConfigurationProviderUpdateConfiguration. serviceNow()The parameters required to update the configuration for a ServiceNow integration.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type ServiceNowUpdateConfiguration Modifier and Type Method Description static ProviderUpdateConfigurationProviderUpdateConfiguration. fromServiceNow(ServiceNowUpdateConfiguration serviceNow)Create an instance of this class withProviderUpdateConfiguration.serviceNow()initialized to the given value.ProviderUpdateConfiguration.BuilderProviderUpdateConfiguration.Builder. serviceNow(ServiceNowUpdateConfiguration serviceNow)The parameters required to update the configuration for a ServiceNow integration.
-