Uses of Interface
software.amazon.awssdk.services.securityhub.model.ServiceNowUpdateConfiguration.Builder
Packages that use ServiceNowUpdateConfiguration.Builder
-
Uses of ServiceNowUpdateConfiguration.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return ServiceNowUpdateConfiguration.BuilderModifier and TypeMethodDescriptionServiceNowUpdateConfiguration.builder()The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.ServiceNowUpdateConfiguration.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type ServiceNowUpdateConfiguration.BuilderModifier and TypeMethodDescriptionstatic Class<? extends ServiceNowUpdateConfiguration.Builder>ServiceNowUpdateConfiguration.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type ServiceNowUpdateConfiguration.BuilderModifier and TypeMethodDescriptionstatic ProviderUpdateConfigurationProviderUpdateConfiguration.fromServiceNow(Consumer<ServiceNowUpdateConfiguration.Builder> serviceNow) Create an instance of this class withProviderUpdateConfiguration.serviceNow()initialized to the given value.ProviderUpdateConfiguration.Builder.serviceNow(Consumer<ServiceNowUpdateConfiguration.Builder> serviceNow) The parameters required to update the configuration for a ServiceNow integration.