Uses of Class
software.amazon.awssdk.services.securityhub.model.StandardsControlAssociationSummary
Packages that use StandardsControlAssociationSummary
Package
Description
-
Uses of StandardsControlAssociationSummary in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type StandardsControlAssociationSummaryModifier and TypeMethodDescriptionListStandardsControlAssociationsResponse.standardsControlAssociationSummaries()An array that provides the enablement status and other details for each security control that applies to each enabled standard.Methods in software.amazon.awssdk.services.securityhub.model with parameters of type StandardsControlAssociationSummaryModifier and TypeMethodDescriptionListStandardsControlAssociationsResponse.Builder.standardsControlAssociationSummaries(StandardsControlAssociationSummary... standardsControlAssociationSummaries) An array that provides the enablement status and other details for each security control that applies to each enabled standard.Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type StandardsControlAssociationSummaryModifier and TypeMethodDescriptionListStandardsControlAssociationsResponse.Builder.standardsControlAssociationSummaries(Collection<StandardsControlAssociationSummary> standardsControlAssociationSummaries) An array that provides the enablement status and other details for each security control that applies to each enabled standard. -
Uses of StandardsControlAssociationSummary in software.amazon.awssdk.services.securityhub.paginators
Methods in software.amazon.awssdk.services.securityhub.paginators that return types with arguments of type StandardsControlAssociationSummaryModifier and TypeMethodDescriptionListStandardsControlAssociationsIterable.standardsControlAssociationSummaries()Returns an iterable to iterate through the paginatedListStandardsControlAssociationsResponse.standardsControlAssociationSummaries()member.ListStandardsControlAssociationsPublisher.standardsControlAssociationSummaries()Returns a publisher that can be used to get a stream of data.