Uses of Enum
software.amazon.awssdk.services.securityhub.model.StandardsControlsUpdatable
Packages that use StandardsControlsUpdatable
-
Uses of StandardsControlsUpdatable in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return StandardsControlsUpdatableModifier and TypeMethodDescriptionstatic StandardsControlsUpdatableUse this in place of valueOf to convert the raw string returned by the service into the enum value.StandardsSubscription.standardsControlsUpdatable()Specifies whether you can retrieve information about and configure individual controls that apply to the standard.static StandardsControlsUpdatableReturns the enum constant of this type with the specified name.static StandardsControlsUpdatable[]StandardsControlsUpdatable.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type StandardsControlsUpdatableModifier and TypeMethodDescriptionstatic Set<StandardsControlsUpdatable>StandardsControlsUpdatable.knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type StandardsControlsUpdatableModifier and TypeMethodDescriptionStandardsSubscription.Builder.standardsControlsUpdatable(StandardsControlsUpdatable standardsControlsUpdatable) Specifies whether you can retrieve information about and configure individual controls that apply to the standard.