Uses of Enum
software.amazon.awssdk.services.securityhub.model.StatusReasonCode
Packages that use StatusReasonCode
-
Uses of StatusReasonCode in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return StatusReasonCodeModifier and TypeMethodDescriptionstatic StatusReasonCodeUse this in place of valueOf to convert the raw string returned by the service into the enum value.final StatusReasonCodeStandardsStatusReason.statusReasonCode()The reason code that represents the reason for the current status of a standard subscription.static StatusReasonCodeReturns the enum constant of this type with the specified name.static StatusReasonCode[]StatusReasonCode.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type StatusReasonCodeMethods in software.amazon.awssdk.services.securityhub.model with parameters of type StatusReasonCodeModifier and TypeMethodDescriptionStandardsStatusReason.Builder.statusReasonCode(StatusReasonCode statusReasonCode) The reason code that represents the reason for the current status of a standard subscription.