Uses of Interface
software.amazon.awssdk.services.securityhub.model.Target.Builder
Packages that use Target.Builder
-
Uses of Target.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return Target.BuilderModifier and TypeMethodDescriptionThe Amazon Web Services account ID of the target account.static Target.BuilderTarget.builder()Target.Builder.organizationalUnitId(String organizationalUnitId) The organizational unit ID of the target organizational unit.The ID of the organization root.Target.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type Target.BuilderModifier and TypeMethodDescriptionstatic Class<? extends Target.Builder>Target.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type Target.BuilderModifier and TypeMethodDescriptionConfigurationPolicyAssociation.Builder.target(Consumer<Target.Builder> target) The target account, organizational unit, or the root.GetConfigurationPolicyAssociationRequest.Builder.target(Consumer<Target.Builder> target) The target account ID, organizational unit ID, or the root ID to retrieve the association for.StartConfigurationPolicyAssociationRequest.Builder.target(Consumer<Target.Builder> target) The identifier of the target account, organizational unit, or the root to associate with the specified configuration.StartConfigurationPolicyDisassociationRequest.Builder.target(Consumer<Target.Builder> target) The identifier of the target account, organizational unit, or the root to disassociate from the specified configuration.