Uses of Interface
software.amazon.awssdk.services.securityhub.model.UnprocessedAutomationRule.Builder
Packages that use UnprocessedAutomationRule.Builder
-
Uses of UnprocessedAutomationRule.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return UnprocessedAutomationRule.BuilderModifier and TypeMethodDescriptionUnprocessedAutomationRule.builder()The error code associated with the unprocessed automation rule.UnprocessedAutomationRule.Builder.errorMessage(String errorMessage) An error message describing why a request didn't process a specific rule.The Amazon Resource Name (ARN) for the unprocessed automation rule.UnprocessedAutomationRule.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type UnprocessedAutomationRule.BuilderModifier and TypeMethodDescriptionstatic Class<? extends UnprocessedAutomationRule.Builder>UnprocessedAutomationRule.serializableBuilderClass()