Uses of Interface
software.amazon.awssdk.services.securityhub.model.UnprocessedStandardsControlAssociationUpdate.Builder
Packages that use UnprocessedStandardsControlAssociationUpdate.Builder
-
Uses of UnprocessedStandardsControlAssociationUpdate.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return UnprocessedStandardsControlAssociationUpdate.BuilderModifier and TypeMethodDescriptionUnprocessedStandardsControlAssociationUpdate.builder()The error code for the unprocessed update of the control's enablement status in the specified standard.UnprocessedStandardsControlAssociationUpdate.Builder.errorCode(UnprocessedErrorCode errorCode) The error code for the unprocessed update of the control's enablement status in the specified standard.UnprocessedStandardsControlAssociationUpdate.Builder.errorReason(String errorReason) The reason why a control's enablement status in the specified standard couldn't be updated.UnprocessedStandardsControlAssociationUpdate.Builder.standardsControlAssociationUpdate(Consumer<StandardsControlAssociationUpdate.Builder> standardsControlAssociationUpdate) An array of control and standard associations for which an update failed when calling BatchUpdateStandardsControlAssociations.UnprocessedStandardsControlAssociationUpdate.Builder.standardsControlAssociationUpdate(StandardsControlAssociationUpdate standardsControlAssociationUpdate) An array of control and standard associations for which an update failed when calling BatchUpdateStandardsControlAssociations.UnprocessedStandardsControlAssociationUpdate.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type UnprocessedStandardsControlAssociationUpdate.BuilderModifier and TypeMethodDescriptionstatic Class<? extends UnprocessedStandardsControlAssociationUpdate.Builder>UnprocessedStandardsControlAssociationUpdate.serializableBuilderClass()