Uses of Class
software.amazon.awssdk.services.securityhub.model.UpdateAggregatorV2Request
-
Packages that use UpdateAggregatorV2Request Package Description software.amazon.awssdk.services.securityhub Security Hub provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.software.amazon.awssdk.services.securityhub.transform -
-
Uses of UpdateAggregatorV2Request in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type UpdateAggregatorV2Request Modifier and Type Method Description default CompletableFuture<UpdateAggregatorV2Response>SecurityHubAsyncClient. updateAggregatorV2(UpdateAggregatorV2Request updateAggregatorV2Request)Udpates the configuration for the Aggregator V2.default UpdateAggregatorV2ResponseSecurityHubClient. updateAggregatorV2(UpdateAggregatorV2Request updateAggregatorV2Request)Udpates the configuration for the Aggregator V2. -
Uses of UpdateAggregatorV2Request in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type UpdateAggregatorV2Request Modifier and Type Method Description SdkHttpFullRequestUpdateAggregatorV2RequestMarshaller. marshall(UpdateAggregatorV2Request updateAggregatorV2Request)
-