Uses of Class
software.amazon.awssdk.services.securityhub.model.UpdateAutomationRuleV2Request
-
Packages that use UpdateAutomationRuleV2Request Package Description software.amazon.awssdk.services.securityhub Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.software.amazon.awssdk.services.securityhub.transform -
-
Uses of UpdateAutomationRuleV2Request in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type UpdateAutomationRuleV2Request Modifier and Type Method Description default CompletableFuture<UpdateAutomationRuleV2Response>SecurityHubAsyncClient. updateAutomationRuleV2(UpdateAutomationRuleV2Request updateAutomationRuleV2Request)Updates a V2 automation rule.default UpdateAutomationRuleV2ResponseSecurityHubClient. updateAutomationRuleV2(UpdateAutomationRuleV2Request updateAutomationRuleV2Request)Updates a V2 automation rule. -
Uses of UpdateAutomationRuleV2Request in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type UpdateAutomationRuleV2Request Modifier and Type Method Description SdkHttpFullRequestUpdateAutomationRuleV2RequestMarshaller. marshall(UpdateAutomationRuleV2Request updateAutomationRuleV2Request)
-