Uses of Class
software.amazon.awssdk.services.securityhub.model.UpdateAutomationRuleV2Response
Packages that use UpdateAutomationRuleV2Response
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of UpdateAutomationRuleV2Response in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return UpdateAutomationRuleV2ResponseModifier and TypeMethodDescriptiondefault UpdateAutomationRuleV2ResponseSecurityHubClient.updateAutomationRuleV2(Consumer<UpdateAutomationRuleV2Request.Builder> updateAutomationRuleV2Request) Updates a V2 automation rule.default UpdateAutomationRuleV2ResponseSecurityHubClient.updateAutomationRuleV2(UpdateAutomationRuleV2Request updateAutomationRuleV2Request) Updates a V2 automation rule.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type UpdateAutomationRuleV2ResponseModifier and TypeMethodDescriptionSecurityHubAsyncClient.updateAutomationRuleV2(Consumer<UpdateAutomationRuleV2Request.Builder> updateAutomationRuleV2Request) Updates a V2 automation rule.SecurityHubAsyncClient.updateAutomationRuleV2(UpdateAutomationRuleV2Request updateAutomationRuleV2Request) Updates a V2 automation rule.