Uses of Class
software.amazon.awssdk.services.securityhub.model.UpdateInsightRequest
Packages that use UpdateInsightRequest
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of UpdateInsightRequest in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub with parameters of type UpdateInsightRequestModifier and TypeMethodDescriptiondefault CompletableFuture<UpdateInsightResponse>SecurityHubAsyncClient.updateInsight(UpdateInsightRequest updateInsightRequest) Updates the Security Hub CSPM insight identified by the specified insight ARN.default UpdateInsightResponseSecurityHubClient.updateInsight(UpdateInsightRequest updateInsightRequest) Updates the Security Hub CSPM insight identified by the specified insight ARN. -
Uses of UpdateInsightRequest in software.amazon.awssdk.services.securityhub.transform
Methods in software.amazon.awssdk.services.securityhub.transform with parameters of type UpdateInsightRequestModifier and TypeMethodDescriptionUpdateInsightRequestMarshaller.marshall(UpdateInsightRequest updateInsightRequest)