Uses of Class
software.amazon.awssdk.services.securityhub.model.UpdateInsightResponse
Packages that use UpdateInsightResponse
Package
Description
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you
assess your Amazon Web Services environment against security industry standards and best practices.
-
Uses of UpdateInsightResponse in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return UpdateInsightResponseModifier and TypeMethodDescriptiondefault UpdateInsightResponseSecurityHubClient.updateInsight(Consumer<UpdateInsightRequest.Builder> updateInsightRequest) Updates the Security Hub CSPM insight identified by the specified insight ARN.default UpdateInsightResponseSecurityHubClient.updateInsight(UpdateInsightRequest updateInsightRequest) Updates the Security Hub CSPM insight identified by the specified insight ARN.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type UpdateInsightResponseModifier and TypeMethodDescriptiondefault CompletableFuture<UpdateInsightResponse>SecurityHubAsyncClient.updateInsight(Consumer<UpdateInsightRequest.Builder> updateInsightRequest) Updates the Security Hub CSPM insight identified by the specified insight ARN.default CompletableFuture<UpdateInsightResponse>SecurityHubAsyncClient.updateInsight(UpdateInsightRequest updateInsightRequest) Updates the Security Hub CSPM insight identified by the specified insight ARN.