Uses of Enum
software.amazon.awssdk.services.securityhub.model.UpdateStatus
Packages that use UpdateStatus
-
Uses of UpdateStatus in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return UpdateStatusModifier and TypeMethodDescriptionstatic UpdateStatusUse this in place of valueOf to convert the raw string returned by the service into the enum value.final UpdateStatusSecurityControl.updateStatus()Identifies whether customizable properties of a security control are reflected in Security Hub CSPM findings.static UpdateStatusReturns the enum constant of this type with the specified name.static UpdateStatus[]UpdateStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type UpdateStatusMethods in software.amazon.awssdk.services.securityhub.model with parameters of type UpdateStatusModifier and TypeMethodDescriptionSecurityControl.Builder.updateStatus(UpdateStatus updateStatus) Identifies whether customizable properties of a security control are reflected in Security Hub CSPM findings.