Uses of Interface
software.amazon.awssdk.services.securityhub.model.UserAccount.Builder
Packages that use UserAccount.Builder
-
Uses of UserAccount.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return UserAccount.BuilderModifier and TypeMethodDescriptionstatic UserAccount.BuilderUserAccount.builder()The name of the user account involved in the attack sequence.UserAccount.toBuilder()The unique identifier of the user account involved in the attack sequence.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type UserAccount.BuilderModifier and TypeMethodDescriptionstatic Class<? extends UserAccount.Builder>UserAccount.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type UserAccount.BuilderModifier and TypeMethodDescriptiondefault ActorUser.BuilderActorUser.Builder.account(Consumer<UserAccount.Builder> account) The account of the threat actor.