default BatchUpdateFindingsV2Response |
SecurityHubClient.batchUpdateFindingsV2(Consumer<BatchUpdateFindingsV2Request.Builder> batchUpdateFindingsV2Request) |
Used by customers to update information about their investigation into a finding.
|
default BatchUpdateFindingsV2Response |
SecurityHubClient.batchUpdateFindingsV2(BatchUpdateFindingsV2Request batchUpdateFindingsV2Request) |
Used by customers to update information about their investigation into a finding.
|
default ConnectorRegistrationsV2Response |
SecurityHubClient.connectorRegistrationsV2(Consumer<ConnectorRegistrationsV2Request.Builder> connectorRegistrationsV2Request) |
Grants permission to complete the authorization based on input parameters.
|
default ConnectorRegistrationsV2Response |
SecurityHubClient.connectorRegistrationsV2(ConnectorRegistrationsV2Request connectorRegistrationsV2Request) |
Grants permission to complete the authorization based on input parameters.
|
default CreateAggregatorV2Response |
SecurityHubClient.createAggregatorV2(Consumer<CreateAggregatorV2Request.Builder> createAggregatorV2Request) |
Enables aggregation across Amazon Web Services Regions.
|
default CreateAggregatorV2Response |
SecurityHubClient.createAggregatorV2(CreateAggregatorV2Request createAggregatorV2Request) |
Enables aggregation across Amazon Web Services Regions.
|
default CreateAutomationRuleV2Response |
SecurityHubClient.createAutomationRuleV2(Consumer<CreateAutomationRuleV2Request.Builder> createAutomationRuleV2Request) |
Creates a V2 automation rule.
|
default CreateAutomationRuleV2Response |
SecurityHubClient.createAutomationRuleV2(CreateAutomationRuleV2Request createAutomationRuleV2Request) |
Creates a V2 automation rule.
|
default CreateConnectorV2Response |
SecurityHubClient.createConnectorV2(Consumer<CreateConnectorV2Request.Builder> createConnectorV2Request) |
Grants permission to create a connectorV2 based on input parameters.
|
default CreateConnectorV2Response |
SecurityHubClient.createConnectorV2(CreateConnectorV2Request createConnectorV2Request) |
Grants permission to create a connectorV2 based on input parameters.
|
default CreateTicketV2Response |
SecurityHubClient.createTicketV2(Consumer<CreateTicketV2Request.Builder> createTicketV2Request) |
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding
metadata UID.
|
default CreateTicketV2Response |
SecurityHubClient.createTicketV2(CreateTicketV2Request createTicketV2Request) |
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding
metadata UID.
|
default DeleteAggregatorV2Response |
SecurityHubClient.deleteAggregatorV2(Consumer<DeleteAggregatorV2Request.Builder> deleteAggregatorV2Request) |
Deletes the Aggregator V2.
|
default DeleteAggregatorV2Response |
SecurityHubClient.deleteAggregatorV2(DeleteAggregatorV2Request deleteAggregatorV2Request) |
Deletes the Aggregator V2.
|
default DeleteAutomationRuleV2Response |
SecurityHubClient.deleteAutomationRuleV2(Consumer<DeleteAutomationRuleV2Request.Builder> deleteAutomationRuleV2Request) |
Deletes a V2 automation rule.
|
default DeleteAutomationRuleV2Response |
SecurityHubClient.deleteAutomationRuleV2(DeleteAutomationRuleV2Request deleteAutomationRuleV2Request) |
Deletes a V2 automation rule.
|
default DeleteConnectorV2Response |
SecurityHubClient.deleteConnectorV2(Consumer<DeleteConnectorV2Request.Builder> deleteConnectorV2Request) |
Grants permission to delete a connectorV2.
|
default DeleteConnectorV2Response |
SecurityHubClient.deleteConnectorV2(DeleteConnectorV2Request deleteConnectorV2Request) |
Grants permission to delete a connectorV2.
|
default DescribeProductsV2Response |
SecurityHubClient.describeProductsV2(Consumer<DescribeProductsV2Request.Builder> describeProductsV2Request) |
Gets information about the product integration.
|
default DescribeProductsV2Response |
SecurityHubClient.describeProductsV2(DescribeProductsV2Request describeProductsV2Request) |
Gets information about the product integration.
|
default DescribeProductsV2Iterable |
SecurityHubClient.describeProductsV2Paginator(Consumer<DescribeProductsV2Request.Builder> describeProductsV2Request) |
|
default DescribeProductsV2Iterable |
SecurityHubClient.describeProductsV2Paginator(DescribeProductsV2Request describeProductsV2Request) |
|
default DescribeSecurityHubV2Response |
SecurityHubClient.describeSecurityHubV2(Consumer<DescribeSecurityHubV2Request.Builder> describeSecurityHubV2Request) |
Returns details about the service resource in your account.
|
default DescribeSecurityHubV2Response |
SecurityHubClient.describeSecurityHubV2(DescribeSecurityHubV2Request describeSecurityHubV2Request) |
Returns details about the service resource in your account.
|
default DisableSecurityHubV2Response |
SecurityHubClient.disableSecurityHubV2(Consumer<DisableSecurityHubV2Request.Builder> disableSecurityHubV2Request) |
Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
|
default DisableSecurityHubV2Response |
SecurityHubClient.disableSecurityHubV2(DisableSecurityHubV2Request disableSecurityHubV2Request) |
Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
|
default EnableSecurityHubV2Response |
SecurityHubClient.enableSecurityHubV2(Consumer<EnableSecurityHubV2Request.Builder> enableSecurityHubV2Request) |
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services
Region.
|
default EnableSecurityHubV2Response |
SecurityHubClient.enableSecurityHubV2(EnableSecurityHubV2Request enableSecurityHubV2Request) |
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services
Region.
|
default GetAggregatorV2Response |
SecurityHubClient.getAggregatorV2(Consumer<GetAggregatorV2Request.Builder> getAggregatorV2Request) |
Returns the configuration of the specified Aggregator V2.
|
default GetAggregatorV2Response |
SecurityHubClient.getAggregatorV2(GetAggregatorV2Request getAggregatorV2Request) |
Returns the configuration of the specified Aggregator V2.
|
default GetAutomationRuleV2Response |
SecurityHubClient.getAutomationRuleV2(Consumer<GetAutomationRuleV2Request.Builder> getAutomationRuleV2Request) |
Returns an automation rule for the V2 service.
|
default GetAutomationRuleV2Response |
SecurityHubClient.getAutomationRuleV2(GetAutomationRuleV2Request getAutomationRuleV2Request) |
Returns an automation rule for the V2 service.
|
default GetConnectorV2Response |
SecurityHubClient.getConnectorV2(Consumer<GetConnectorV2Request.Builder> getConnectorV2Request) |
Grants permission to retrieve details for a connectorV2 based on connector id.
|
default GetConnectorV2Response |
SecurityHubClient.getConnectorV2(GetConnectorV2Request getConnectorV2Request) |
Grants permission to retrieve details for a connectorV2 based on connector id.
|
default GetFindingStatisticsV2Response |
SecurityHubClient.getFindingStatisticsV2(Consumer<GetFindingStatisticsV2Request.Builder> getFindingStatisticsV2Request) |
Returns aggregated statistical data about findings.
|
default GetFindingStatisticsV2Response |
SecurityHubClient.getFindingStatisticsV2(GetFindingStatisticsV2Request getFindingStatisticsV2Request) |
Returns aggregated statistical data about findings.
|
default GetFindingsV2Response |
SecurityHubClient.getFindingsV2(Consumer<GetFindingsV2Request.Builder> getFindingsV2Request) |
Return a list of findings that match the specified criteria.
|
default GetFindingsV2Response |
SecurityHubClient.getFindingsV2(GetFindingsV2Request getFindingsV2Request) |
Return a list of findings that match the specified criteria.
|
default GetFindingsV2Iterable |
SecurityHubClient.getFindingsV2Paginator(Consumer<GetFindingsV2Request.Builder> getFindingsV2Request) |
|
default GetFindingsV2Iterable |
SecurityHubClient.getFindingsV2Paginator(GetFindingsV2Request getFindingsV2Request) |
|
default GetResourcesStatisticsV2Response |
SecurityHubClient.getResourcesStatisticsV2(Consumer<GetResourcesStatisticsV2Request.Builder> getResourcesStatisticsV2Request) |
Retrieves statistical information about Amazon Web Services resources and their associated security findings.
|
default GetResourcesStatisticsV2Response |
SecurityHubClient.getResourcesStatisticsV2(GetResourcesStatisticsV2Request getResourcesStatisticsV2Request) |
Retrieves statistical information about Amazon Web Services resources and their associated security findings.
|
default GetResourcesV2Response |
SecurityHubClient.getResourcesV2(Consumer<GetResourcesV2Request.Builder> getResourcesV2Request) |
Returns a list of resources.
|
default GetResourcesV2Response |
SecurityHubClient.getResourcesV2(GetResourcesV2Request getResourcesV2Request) |
Returns a list of resources.
|
default GetResourcesV2Iterable |
SecurityHubClient.getResourcesV2Paginator(Consumer<GetResourcesV2Request.Builder> getResourcesV2Request) |
|
default GetResourcesV2Iterable |
SecurityHubClient.getResourcesV2Paginator(GetResourcesV2Request getResourcesV2Request) |
|
default ListAggregatorsV2Response |
SecurityHubClient.listAggregatorsV2(Consumer<ListAggregatorsV2Request.Builder> listAggregatorsV2Request) |
Retrieves a list of V2 aggregators.
|
default ListAggregatorsV2Response |
SecurityHubClient.listAggregatorsV2(ListAggregatorsV2Request listAggregatorsV2Request) |
Retrieves a list of V2 aggregators.
|
default ListAggregatorsV2Iterable |
SecurityHubClient.listAggregatorsV2Paginator(Consumer<ListAggregatorsV2Request.Builder> listAggregatorsV2Request) |
|
default ListAggregatorsV2Iterable |
SecurityHubClient.listAggregatorsV2Paginator(ListAggregatorsV2Request listAggregatorsV2Request) |
|
default ListAutomationRulesV2Response |
SecurityHubClient.listAutomationRulesV2(Consumer<ListAutomationRulesV2Request.Builder> listAutomationRulesV2Request) |
Returns a list of automation rules and metadata for the calling account.
|
default ListAutomationRulesV2Response |
SecurityHubClient.listAutomationRulesV2(ListAutomationRulesV2Request listAutomationRulesV2Request) |
Returns a list of automation rules and metadata for the calling account.
|
default ListConnectorsV2Response |
SecurityHubClient.listConnectorsV2(Consumer<ListConnectorsV2Request.Builder> listConnectorsV2Request) |
Grants permission to retrieve a list of connectorsV2 and their metadata for the calling account.
|
default ListConnectorsV2Response |
SecurityHubClient.listConnectorsV2(ListConnectorsV2Request listConnectorsV2Request) |
Grants permission to retrieve a list of connectorsV2 and their metadata for the calling account.
|
default UpdateAggregatorV2Response |
SecurityHubClient.updateAggregatorV2(Consumer<UpdateAggregatorV2Request.Builder> updateAggregatorV2Request) |
Udpates the configuration for the Aggregator V2.
|
default UpdateAggregatorV2Response |
SecurityHubClient.updateAggregatorV2(UpdateAggregatorV2Request updateAggregatorV2Request) |
Udpates the configuration for the Aggregator V2.
|
default UpdateAutomationRuleV2Response |
SecurityHubClient.updateAutomationRuleV2(Consumer<UpdateAutomationRuleV2Request.Builder> updateAutomationRuleV2Request) |
Updates a V2 automation rule.
|
default UpdateAutomationRuleV2Response |
SecurityHubClient.updateAutomationRuleV2(UpdateAutomationRuleV2Request updateAutomationRuleV2Request) |
Updates a V2 automation rule.
|
default UpdateConnectorV2Response |
SecurityHubClient.updateConnectorV2(Consumer<UpdateConnectorV2Request.Builder> updateConnectorV2Request) |
Grants permission to update a connectorV2 based on its id and input parameters.
|
default UpdateConnectorV2Response |
SecurityHubClient.updateConnectorV2(UpdateConnectorV2Request updateConnectorV2Request) |
Grants permission to update a connectorV2 based on its id and input parameters.
|