Uses of Interface
software.amazon.awssdk.services.securityhub.model.Workflow.Builder
Packages that use Workflow.Builder
-
Uses of Workflow.Builder in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return Workflow.BuilderModifier and TypeMethodDescriptionstatic Workflow.BuilderWorkflow.builder()The status of the investigation into the finding.Workflow.Builder.status(WorkflowStatus status) The status of the investigation into the finding.Workflow.toBuilder()Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type Workflow.BuilderModifier and TypeMethodDescriptionstatic Class<? extends Workflow.Builder>Workflow.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.securityhub.model with type arguments of type Workflow.BuilderModifier and TypeMethodDescriptiondefault AwsSecurityFinding.BuilderAwsSecurityFinding.Builder.workflow(Consumer<Workflow.Builder> workflow) Provides information about the status of the investigation into a finding.