Uses of Enum
software.amazon.awssdk.services.securityhub.model.WorkflowState
Packages that use WorkflowState
-
Uses of WorkflowState in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return WorkflowStateModifier and TypeMethodDescriptionstatic WorkflowStateDeprecated.Use this in place of valueOf to convert the raw string returned by the service into the enum value.static WorkflowStateDeprecated.Returns the enum constant of this type with the specified name.static WorkflowState[]WorkflowState.values()Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.final WorkflowStateAwsSecurityFinding.workflowState()The workflow state of a finding.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type WorkflowStateMethods in software.amazon.awssdk.services.securityhub.model with parameters of type WorkflowStateModifier and TypeMethodDescriptionAwsSecurityFinding.Builder.workflowState(WorkflowState workflowState) The workflow state of a finding.