Class ActorSession
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ActorSession.Builder,ActorSession>
Contains information about the authenticated session used by the threat actor identified in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ActorSession.Builderbuilder()final LongThe timestamp for when the session was created.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringissuer()The issuer of the session.final ActorSessionMfaStatusIndicates whether multi-factor authentication (MFA) was used for authentication during the session.final StringIndicates whether multi-factor authentication (MFA) was used for authentication during the session.static Class<? extends ActorSession.Builder>final StringtoString()Returns a string representation of this object.final Stringuid()Unique identifier of the session.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
uid
Unique identifier of the session.
- Returns:
- Unique identifier of the session.
-
mfaStatus
Indicates whether multi-factor authentication (MFA) was used for authentication during the session.
In CloudTrail, you can find this value as
userIdentity.sessionContext.attributes.mfaAuthenticated.If the service returns an enum value that is not available in the current SDK version,
mfaStatuswill returnActorSessionMfaStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommfaStatusAsString().- Returns:
- Indicates whether multi-factor authentication (MFA) was used for authentication during the session.
In CloudTrail, you can find this value as
userIdentity.sessionContext.attributes.mfaAuthenticated. - See Also:
-
mfaStatusAsString
Indicates whether multi-factor authentication (MFA) was used for authentication during the session.
In CloudTrail, you can find this value as
userIdentity.sessionContext.attributes.mfaAuthenticated.If the service returns an enum value that is not available in the current SDK version,
mfaStatuswill returnActorSessionMfaStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommfaStatusAsString().- Returns:
- Indicates whether multi-factor authentication (MFA) was used for authentication during the session.
In CloudTrail, you can find this value as
userIdentity.sessionContext.attributes.mfaAuthenticated. - See Also:
-
createdTime
The timestamp for when the session was created.
In CloudTrail, you can find this value as
userIdentity.sessionContext.attributes.creationDate.- Returns:
- The timestamp for when the session was created.
In CloudTrail, you can find this value as
userIdentity.sessionContext.attributes.creationDate.
-
issuer
The issuer of the session.
In CloudTrail, you can find this value as
userIdentity.sessionContext.sessionIssuer.arn.- Returns:
- The issuer of the session.
In CloudTrail, you can find this value as
userIdentity.sessionContext.sessionIssuer.arn.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ActorSession.Builder,ActorSession>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-