Class ActorUser
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ActorUser
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ActorUser.Builder,ActorUser>
@Generated("software.amazon.awssdk:codegen")
public final class ActorUser
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ActorUser.Builder,ActorUser>
Contains information about the credentials used by the threat actor identified in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal UserAccountaccount()The account of the threat actor.static ActorUser.Builderbuilder()final StringUnique identifier of the threat actor’s user credentials.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the threat actor.static Class<? extends ActorUser.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of user.final Stringuid()The unique identifier of the threat actor.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the threat actor.
- Returns:
- The name of the threat actor.
-
uid
The unique identifier of the threat actor.
- Returns:
- The unique identifier of the threat actor.
-
type
The type of user.
- Returns:
- The type of user.
-
credentialUid
Unique identifier of the threat actor’s user credentials.
- Returns:
- Unique identifier of the threat actor’s user credentials.
-
account
The account of the threat actor.
- Returns:
- The account of the threat actor.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ActorUser.Builder,ActorUser>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-