Class AutomationRulesActionV2
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.AutomationRulesActionV2
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>
@Generated("software.amazon.awssdk:codegen") public final class AutomationRulesActionV2 extends Object implements SdkPojo, Serializable, ToCopyableBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>
Allows you to configure automated responses.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceAutomationRulesActionV2.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static AutomationRulesActionV2.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)ExternalIntegrationConfigurationexternalIntegrationConfiguration()The settings for integrating automation rule actions with external systems or service.AutomationRulesFindingFieldsUpdateV2findingFieldsUpdate()The changes to be applied to fields in a security finding when an automation rule is triggered.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends AutomationRulesActionV2.Builder>serializableBuilderClass()AutomationRulesActionV2.BuildertoBuilder()StringtoString()Returns a string representation of this object.AutomationRulesActionTypeV2type()The category of action to be executed by the automation rule.StringtypeAsString()The category of action to be executed by the automation rule.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
type
public final AutomationRulesActionTypeV2 type()
The category of action to be executed by the automation rule.
If the service returns an enum value that is not available in the current SDK version,
typewill returnAutomationRulesActionTypeV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The category of action to be executed by the automation rule.
- See Also:
AutomationRulesActionTypeV2
-
typeAsString
public final String typeAsString()
The category of action to be executed by the automation rule.
If the service returns an enum value that is not available in the current SDK version,
typewill returnAutomationRulesActionTypeV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The category of action to be executed by the automation rule.
- See Also:
AutomationRulesActionTypeV2
-
findingFieldsUpdate
public final AutomationRulesFindingFieldsUpdateV2 findingFieldsUpdate()
The changes to be applied to fields in a security finding when an automation rule is triggered.
- Returns:
- The changes to be applied to fields in a security finding when an automation rule is triggered.
-
externalIntegrationConfiguration
public final ExternalIntegrationConfiguration externalIntegrationConfiguration()
The settings for integrating automation rule actions with external systems or service.
- Returns:
- The settings for integrating automation rule actions with external systems or service.
-
toBuilder
public AutomationRulesActionV2.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<AutomationRulesActionV2.Builder,AutomationRulesActionV2>
-
builder
public static AutomationRulesActionV2.Builder builder()
-
serializableBuilderClass
public static Class<? extends AutomationRulesActionV2.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-