Class AutomationRulesFindingFieldsUpdateV2
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.AutomationRulesFindingFieldsUpdateV2
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>
@Generated("software.amazon.awssdk:codegen") public final class AutomationRulesFindingFieldsUpdateV2 extends Object implements SdkPojo, Serializable, ToCopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>
Allows you to define the structure for modifying specific fields in security findings.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceAutomationRulesFindingFieldsUpdateV2.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static AutomationRulesFindingFieldsUpdateV2.Builderbuilder()Stringcomment()Notes or contextual information for findings that are modified by the automation rule.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends AutomationRulesFindingFieldsUpdateV2.Builder>serializableBuilderClass()IntegerseverityId()The severity level to be assigned to findings that match the automation rule criteria.IntegerstatusId()The status to be applied to findings that match automation rule criteria.AutomationRulesFindingFieldsUpdateV2.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
severityId
public final Integer severityId()
The severity level to be assigned to findings that match the automation rule criteria.
- Returns:
- The severity level to be assigned to findings that match the automation rule criteria.
-
comment
public final String comment()
Notes or contextual information for findings that are modified by the automation rule.
- Returns:
- Notes or contextual information for findings that are modified by the automation rule.
-
statusId
public final Integer statusId()
The status to be applied to findings that match automation rule criteria.
- Returns:
- The status to be applied to findings that match automation rule criteria.
-
toBuilder
public AutomationRulesFindingFieldsUpdateV2.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>
-
builder
public static AutomationRulesFindingFieldsUpdateV2.Builder builder()
-
serializableBuilderClass
public static Class<? extends AutomationRulesFindingFieldsUpdateV2.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-