Interface AutomationRulesFindingFieldsUpdateV2.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>,SdkBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>,SdkPojo
- Enclosing class:
- AutomationRulesFindingFieldsUpdateV2
@Mutable @NotThreadSafe public static interface AutomationRulesFindingFieldsUpdateV2.Builder extends SdkPojo, CopyableBuilder<AutomationRulesFindingFieldsUpdateV2.Builder,AutomationRulesFindingFieldsUpdateV2>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description AutomationRulesFindingFieldsUpdateV2.Buildercomment(String comment)Notes or contextual information for findings that are modified by the automation rule.AutomationRulesFindingFieldsUpdateV2.BuilderseverityId(Integer severityId)The severity level to be assigned to findings that match the automation rule criteria.AutomationRulesFindingFieldsUpdateV2.BuilderstatusId(Integer statusId)The status to be applied to findings that match automation rule criteria.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
severityId
AutomationRulesFindingFieldsUpdateV2.Builder severityId(Integer severityId)
The severity level to be assigned to findings that match the automation rule criteria.
- Parameters:
severityId- The severity level to be assigned to findings that match the automation rule criteria.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
comment
AutomationRulesFindingFieldsUpdateV2.Builder comment(String comment)
Notes or contextual information for findings that are modified by the automation rule.
- Parameters:
comment- Notes or contextual information for findings that are modified by the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
statusId
AutomationRulesFindingFieldsUpdateV2.Builder statusId(Integer statusId)
The status to be applied to findings that match automation rule criteria.
- Parameters:
statusId- The status to be applied to findings that match automation rule criteria.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-