Class AutomationRulesMetadataV2
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.AutomationRulesMetadataV2
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AutomationRulesMetadataV2.Builder,AutomationRulesMetadataV2>
@Generated("software.amazon.awssdk:codegen") public final class AutomationRulesMetadataV2 extends Object implements SdkPojo, Serializable, ToCopyableBuilder<AutomationRulesMetadataV2.Builder,AutomationRulesMetadataV2>
Includes essential metadata information about automation rules.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceAutomationRulesMetadataV2.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description List<AutomationRulesActionTypeObjectV2>actions()The list of action to be performed when the rule criteria is met.static AutomationRulesMetadataV2.Builderbuilder()InstantcreatedAt()The timestamp for when the automation rule was created.Stringdescription()An explanation for the purpose and funcitonality of the automation rule.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasActions()For responses, this returns true if the service returned a value for the Actions property.inthashCode()StringruleArn()The ARN of the automation rule.StringruleId()The ID of the automation rule.StringruleName()The name of the automation rule.FloatruleOrder()The value for the rule priority.RuleStatusV2ruleStatus()The status of the automation rule.StringruleStatusAsString()The status of the automation rule.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends AutomationRulesMetadataV2.Builder>serializableBuilderClass()AutomationRulesMetadataV2.BuildertoBuilder()StringtoString()Returns a string representation of this object.InstantupdatedAt()The timestamp for the most recent modification to the automation rule.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
ruleArn
public final String ruleArn()
The ARN of the automation rule.
- Returns:
- The ARN of the automation rule.
-
ruleId
public final String ruleId()
The ID of the automation rule.
- Returns:
- The ID of the automation rule.
-
ruleOrder
public final Float ruleOrder()
The value for the rule priority.
- Returns:
- The value for the rule priority.
-
ruleName
public final String ruleName()
The name of the automation rule.
- Returns:
- The name of the automation rule.
-
ruleStatus
public final RuleStatusV2 ruleStatus()
The status of the automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the automation rule.
- See Also:
RuleStatusV2
-
ruleStatusAsString
public final String ruleStatusAsString()
The status of the automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the automation rule.
- See Also:
RuleStatusV2
-
description
public final String description()
An explanation for the purpose and funcitonality of the automation rule.
- Returns:
- An explanation for the purpose and funcitonality of the automation rule.
-
hasActions
public final boolean hasActions()
For responses, this returns true if the service returned a value for the Actions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
actions
public final List<AutomationRulesActionTypeObjectV2> actions()
The list of action to be performed when the rule criteria is met.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasActions()method.- Returns:
- The list of action to be performed when the rule criteria is met.
-
createdAt
public final Instant createdAt()
The timestamp for when the automation rule was created.
- Returns:
- The timestamp for when the automation rule was created.
-
updatedAt
public final Instant updatedAt()
The timestamp for the most recent modification to the automation rule.
- Returns:
- The timestamp for the most recent modification to the automation rule.
-
toBuilder
public AutomationRulesMetadataV2.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<AutomationRulesMetadataV2.Builder,AutomationRulesMetadataV2>
-
builder
public static AutomationRulesMetadataV2.Builder builder()
-
serializableBuilderClass
public static Class<? extends AutomationRulesMetadataV2.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-