Interface AutomationRulesMetadataV2.Builder

    • Method Detail

      • ruleArn

        AutomationRulesMetadataV2.Builder ruleArn​(String ruleArn)

        The ARN of the automation rule.

        Parameters:
        ruleArn - The ARN of the automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleId

        AutomationRulesMetadataV2.Builder ruleId​(String ruleId)

        The ID of the automation rule.

        Parameters:
        ruleId - The ID of the automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleOrder

        AutomationRulesMetadataV2.Builder ruleOrder​(Float ruleOrder)

        The value for the rule priority.

        Parameters:
        ruleOrder - The value for the rule priority.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleName

        AutomationRulesMetadataV2.Builder ruleName​(String ruleName)

        The name of the automation rule.

        Parameters:
        ruleName - The name of the automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • description

        AutomationRulesMetadataV2.Builder description​(String description)

        An explanation for the purpose and funcitonality of the automation rule.

        Parameters:
        description - An explanation for the purpose and funcitonality of the automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • actions

        AutomationRulesMetadataV2.Builder actions​(AutomationRulesActionTypeObjectV2... actions)

        The list of action to be performed when the rule criteria is met.

        Parameters:
        actions - The list of action to be performed when the rule criteria is met.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • createdAt

        AutomationRulesMetadataV2.Builder createdAt​(Instant createdAt)

        The timestamp for when the automation rule was created.

        Parameters:
        createdAt - The timestamp for when the automation rule was created.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • updatedAt

        AutomationRulesMetadataV2.Builder updatedAt​(Instant updatedAt)

        The timestamp for the most recent modification to the automation rule.

        Parameters:
        updatedAt - The timestamp for the most recent modification to the automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.