Class AwsCloudFrontDistributionOriginCustomOriginConfig
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsCloudFrontDistributionOriginCustomOriginConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsCloudFrontDistributionOriginCustomOriginConfig.Builder,AwsCloudFrontDistributionOriginCustomOriginConfig>
@Generated("software.amazon.awssdk:codegen")
public final class AwsCloudFrontDistributionOriginCustomOriginConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsCloudFrontDistributionOriginCustomOriginConfig.Builder,AwsCloudFrontDistributionOriginCustomOriginConfig>
A custom origin. A custom origin is any origin that is not an Amazon S3 bucket, with one exception. An Amazon S3 bucket that is configured with static website hosting is a custom origin.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerhttpPort()The HTTP port that CloudFront uses to connect to the origin.final IntegerThe HTTPS port that CloudFront uses to connect to the origin.final IntegerSpecifies how long, in seconds, CloudFront persists its connection to the origin.final StringSpecifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.final IntegerSpecifies how long, in seconds, CloudFront waits for a response from the origin.Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.static Class<? extends AwsCloudFrontDistributionOriginCustomOriginConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
httpPort
The HTTP port that CloudFront uses to connect to the origin.
- Returns:
- The HTTP port that CloudFront uses to connect to the origin.
-
httpsPort
The HTTPS port that CloudFront uses to connect to the origin.
- Returns:
- The HTTPS port that CloudFront uses to connect to the origin.
-
originKeepaliveTimeout
Specifies how long, in seconds, CloudFront persists its connection to the origin.
- Returns:
- Specifies how long, in seconds, CloudFront persists its connection to the origin.
-
originProtocolPolicy
Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.
- Returns:
- Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.
-
originReadTimeout
Specifies how long, in seconds, CloudFront waits for a response from the origin.
- Returns:
- Specifies how long, in seconds, CloudFront waits for a response from the origin.
-
originSslProtocols
Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.
- Returns:
- Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends AwsCloudFrontDistributionOriginCustomOriginConfig.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-