Class AwsDynamoDbTableProvisionedThroughput
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDynamoDbTableProvisionedThroughput.Builder,AwsDynamoDbTableProvisionedThroughput>
Information about the provisioned throughput for the table or for a global secondary index.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringIndicates when the provisioned throughput was last decreased.final StringIndicates when the provisioned throughput was last increased.final IntegerThe number of times during the current UTC calendar day that the provisioned throughput was decreased.final IntegerThe maximum number of strongly consistent reads consumed per second before DynamoDB returns aThrottlingException.static Class<? extends AwsDynamoDbTableProvisionedThroughput.Builder>final StringtoString()Returns a string representation of this object.final IntegerThe maximum number of writes consumed per second before DynamoDB returns aThrottlingException.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
lastDecreaseDateTime
Indicates when the provisioned throughput was last decreased.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the provisioned throughput was last decreased.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
lastIncreaseDateTime
Indicates when the provisioned throughput was last increased.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the provisioned throughput was last increased.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
numberOfDecreasesToday
The number of times during the current UTC calendar day that the provisioned throughput was decreased.
- Returns:
- The number of times during the current UTC calendar day that the provisioned throughput was decreased.
-
readCapacityUnits
The maximum number of strongly consistent reads consumed per second before DynamoDB returns a
ThrottlingException.- Returns:
- The maximum number of strongly consistent reads consumed per second before DynamoDB returns a
ThrottlingException.
-
writeCapacityUnits
The maximum number of writes consumed per second before DynamoDB returns a
ThrottlingException.- Returns:
- The maximum number of writes consumed per second before DynamoDB returns a
ThrottlingException.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDynamoDbTableProvisionedThroughput.Builder,AwsDynamoDbTableProvisionedThroughput>
-
builder
-
serializableBuilderClass
public static Class<? extends AwsDynamoDbTableProvisionedThroughput.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-