Class AwsDynamoDbTableProvisionedThroughput

    • Method Detail

      • lastDecreaseDateTime

        public final String lastDecreaseDateTime()

        Indicates when the provisioned throughput was last decreased.

        For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

        Returns:
        Indicates when the provisioned throughput was last decreased.

        For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      • lastIncreaseDateTime

        public final String lastIncreaseDateTime()

        Indicates when the provisioned throughput was last increased.

        For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

        Returns:
        Indicates when the provisioned throughput was last increased.

        For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

      • numberOfDecreasesToday

        public final Integer numberOfDecreasesToday()

        The number of times during the current UTC calendar day that the provisioned throughput was decreased.

        Returns:
        The number of times during the current UTC calendar day that the provisioned throughput was decreased.
      • readCapacityUnits

        public final Integer readCapacityUnits()

        The maximum number of strongly consistent reads consumed per second before DynamoDB returns a ThrottlingException.

        Returns:
        The maximum number of strongly consistent reads consumed per second before DynamoDB returns a ThrottlingException.
      • writeCapacityUnits

        public final Integer writeCapacityUnits()

        The maximum number of writes consumed per second before DynamoDB returns a ThrottlingException.

        Returns:
        The maximum number of writes consumed per second before DynamoDB returns a ThrottlingException.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)