Class AwsDynamoDbTableRestoreSummary
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsDynamoDbTableRestoreSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsDynamoDbTableRestoreSummary.Builder,AwsDynamoDbTableRestoreSummary>
@Generated("software.amazon.awssdk:codegen")
public final class AwsDynamoDbTableRestoreSummary
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsDynamoDbTableRestoreSummary.Builder,AwsDynamoDbTableRestoreSummary>
Information about the restore for the table.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringIndicates the point in time that the table was restored to.final BooleanWhether a restore is currently in progress.static Class<? extends AwsDynamoDbTableRestoreSummary.Builder>final StringThe ARN of the source backup from which the table was restored.final StringThe ARN of the source table for the backup.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
sourceBackupArn
The ARN of the source backup from which the table was restored.
- Returns:
- The ARN of the source backup from which the table was restored.
-
sourceTableArn
The ARN of the source table for the backup.
- Returns:
- The ARN of the source table for the backup.
-
restoreDateTime
Indicates the point in time that the table was restored to.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates the point in time that the table was restored to.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
restoreInProgress
Whether a restore is currently in progress.
- Returns:
- Whether a restore is currently in progress.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsDynamoDbTableRestoreSummary.Builder,AwsDynamoDbTableRestoreSummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-