Class AwsEcsTaskVolumeDetails
java.lang.Object
software.amazon.awssdk.services.securityhub.model.AwsEcsTaskVolumeDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AwsEcsTaskVolumeDetails.Builder,AwsEcsTaskVolumeDetails>
@Generated("software.amazon.awssdk:codegen")
public final class AwsEcsTaskVolumeDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AwsEcsTaskVolumeDetails.Builder,AwsEcsTaskVolumeDetails>
Provides information about a data volume that's used in a task definition.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()host()This parameter is specified when you use bind mount host volumes.final Stringname()The name of the volume.static Class<? extends AwsEcsTaskVolumeDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the volume. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed. This name is referenced in the
sourceVolumeparameter of container definitionmountPoints.- Returns:
- The name of the volume. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens
are allowed. This name is referenced in the
sourceVolumeparameter of container definitionmountPoints.
-
host
This parameter is specified when you use bind mount host volumes. The contents of the
hostparameter determine whether your bind mount host volume persists on the host container instance and where it's stored.- Returns:
- This parameter is specified when you use bind mount host volumes. The contents of the
hostparameter determine whether your bind mount host volume persists on the host container instance and where it's stored.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AwsEcsTaskVolumeDetails.Builder,AwsEcsTaskVolumeDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-