Interface BatchGetSecurityControlsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<BatchGetSecurityControlsRequest.Builder,,BatchGetSecurityControlsRequest> SdkBuilder<BatchGetSecurityControlsRequest.Builder,,BatchGetSecurityControlsRequest> SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- BatchGetSecurityControlsRequest
@Mutable
@NotThreadSafe
public static interface BatchGetSecurityControlsRequest.Builder
extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<BatchGetSecurityControlsRequest.Builder,BatchGetSecurityControlsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) securityControlIds(String... securityControlIds) A list of security controls (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters).securityControlIds(Collection<String> securityControlIds) A list of security controls (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters).Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
Method Details
-
securityControlIds
A list of security controls (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.- Parameters:
securityControlIds- A list of security controls (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
securityControlIds
A list of security controls (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.- Parameters:
securityControlIds- A list of security controls (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters). The security control ID or Amazon Resource Name (ARN) is the same across standards.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
BatchGetSecurityControlsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
BatchGetSecurityControlsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-