Class BatchGetSecurityControlsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BatchGetSecurityControlsResponse.Builder,BatchGetSecurityControlsResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the SecurityControls property.final booleanFor responses, this returns true if the service returned a value for the UnprocessedIds property.final List<SecurityControl>An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control.static Class<? extends BatchGetSecurityControlsResponse.Builder>final StringtoString()Returns a string representation of this object.final List<UnprocessedSecurityControl>A security control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) for which details cannot be returned.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasSecurityControls
public final boolean hasSecurityControls()For responses, this returns true if the service returned a value for the SecurityControls property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
securityControls
An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security control. The same information is returned whether the request includes
SecurityControlIdorSecurityControlArn.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSecurityControls()method.- Returns:
- An array that returns the identifier, Amazon Resource Name (ARN), and other details about a security
control. The same information is returned whether the request includes
SecurityControlIdorSecurityControlArn.
-
hasUnprocessedIds
public final boolean hasUnprocessedIds()For responses, this returns true if the service returned a value for the UnprocessedIds property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
unprocessedIds
A security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) for which details cannot be returned.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUnprocessedIds()method.- Returns:
- A security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) for which details cannot be returned.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchGetSecurityControlsResponse.Builder,BatchGetSecurityControlsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-