Class BatchGetStandardsControlAssociationsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BatchGetStandardsControlAssociationsResponse.Builder,BatchGetStandardsControlAssociationsResponse>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the StandardsControlAssociationDetails property.final booleanFor responses, this returns true if the service returned a value for the UnprocessedAssociations property.static Class<? extends BatchGetStandardsControlAssociationsResponse.Builder>Provides the enablement status of a security control in a specified standard and other details for the control in relation to the specified standard.final StringtoString()Returns a string representation of this object.A security control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) whose enablement status in a specified standard cannot be returned.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasStandardsControlAssociationDetails
public final boolean hasStandardsControlAssociationDetails()For responses, this returns true if the service returned a value for the StandardsControlAssociationDetails property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
standardsControlAssociationDetails
Provides the enablement status of a security control in a specified standard and other details for the control in relation to the specified standard.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStandardsControlAssociationDetails()method.- Returns:
- Provides the enablement status of a security control in a specified standard and other details for the control in relation to the specified standard.
-
hasUnprocessedAssociations
public final boolean hasUnprocessedAssociations()For responses, this returns true if the service returned a value for the UnprocessedAssociations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
unprocessedAssociations
A security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) whose enablement status in a specified standard cannot be returned.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUnprocessedAssociations()method.- Returns:
- A security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) whose enablement status in a specified standard cannot be returned.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchGetStandardsControlAssociationsResponse.Builder,BatchGetStandardsControlAssociationsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends BatchGetStandardsControlAssociationsResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-