Class BatchUpdateAutomationRulesRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.BatchUpdateAutomationRulesRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BatchUpdateAutomationRulesRequest.Builder,BatchUpdateAutomationRulesRequest>
@Generated("software.amazon.awssdk:codegen")
public final class BatchUpdateAutomationRulesRequest
extends SecurityHubRequest
implements ToCopyableBuilder<BatchUpdateAutomationRulesRequest.Builder,BatchUpdateAutomationRulesRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the UpdateAutomationRulesRequestItems property.static Class<? extends BatchUpdateAutomationRulesRequest.Builder>final StringtoString()Returns a string representation of this object.An array of ARNs for the rules that are to be updated.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasUpdateAutomationRulesRequestItems
public final boolean hasUpdateAutomationRulesRequestItems()For responses, this returns true if the service returned a value for the UpdateAutomationRulesRequestItems property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
updateAutomationRulesRequestItems
An array of ARNs for the rules that are to be updated. Optionally, you can also include
RuleStatusandRuleOrder.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUpdateAutomationRulesRequestItems()method.- Returns:
- An array of ARNs for the rules that are to be updated. Optionally, you can also include
RuleStatusandRuleOrder.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchUpdateAutomationRulesRequest.Builder,BatchUpdateAutomationRulesRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-