Class BatchUpdateFindingsV2Request
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.BatchUpdateFindingsV2Request
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BatchUpdateFindingsV2Request.Builder,BatchUpdateFindingsV2Request>
@Generated("software.amazon.awssdk:codegen") public final class BatchUpdateFindingsV2Request extends SecurityHubRequest implements ToCopyableBuilder<BatchUpdateFindingsV2Request.Builder,BatchUpdateFindingsV2Request>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceBatchUpdateFindingsV2Request.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static BatchUpdateFindingsV2Request.Builderbuilder()Stringcomment()The updated value for a user provided comment about the finding.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)List<OcsfFindingIdentifier>findingIdentifiers()Provides information to identify a specific V2 finding.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasFindingIdentifiers()For responses, this returns true if the service returned a value for the FindingIdentifiers property.inthashCode()booleanhasMetadataUids()For responses, this returns true if the service returned a value for the MetadataUids property.List<String>metadataUids()The list of findingmetadata.uidto indicate findings to update.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends BatchUpdateFindingsV2Request.Builder>serializableBuilderClass()IntegerseverityId()The updated value for the normalized severity identifier.IntegerstatusId()The updated value for the normalized status identifier.BatchUpdateFindingsV2Request.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
hasMetadataUids
public final boolean hasMetadataUids()
For responses, this returns true if the service returned a value for the MetadataUids property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
metadataUids
public final List<String> metadataUids()
The list of finding
metadata.uidto indicate findings to update. Findingmetadata.uidis a globally unique identifier associated with the finding. Customers cannot useMetadataUidstogether withFindingIdentifiers.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasMetadataUids()method.- Returns:
- The list of finding
metadata.uidto indicate findings to update. Findingmetadata.uidis a globally unique identifier associated with the finding. Customers cannot useMetadataUidstogether withFindingIdentifiers.
-
hasFindingIdentifiers
public final boolean hasFindingIdentifiers()
For responses, this returns true if the service returned a value for the FindingIdentifiers property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
findingIdentifiers
public final List<OcsfFindingIdentifier> findingIdentifiers()
Provides information to identify a specific V2 finding.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasFindingIdentifiers()method.- Returns:
- Provides information to identify a specific V2 finding.
-
comment
public final String comment()
The updated value for a user provided comment about the finding. Minimum character length 1. Maximum character length 512.
- Returns:
- The updated value for a user provided comment about the finding. Minimum character length 1. Maximum character length 512.
-
severityId
public final Integer severityId()
The updated value for the normalized severity identifier. The severity ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 99]. When customer provides the updated severity ID, the string sibling severity will automatically be updated in the finding.
- Returns:
- The updated value for the normalized severity identifier. The severity ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 99]. When customer provides the updated severity ID, the string sibling severity will automatically be updated in the finding.
-
statusId
public final Integer statusId()
The updated value for the normalized status identifier. The status ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 6, 99]. When customer provides the updated status ID, the string sibling status will automatically be updated in the finding.
- Returns:
- The updated value for the normalized status identifier. The status ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 6, 99]. When customer provides the updated status ID, the string sibling status will automatically be updated in the finding.
-
toBuilder
public BatchUpdateFindingsV2Request.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchUpdateFindingsV2Request.Builder,BatchUpdateFindingsV2Request>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static BatchUpdateFindingsV2Request.Builder builder()
-
serializableBuilderClass
public static Class<? extends BatchUpdateFindingsV2Request.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-