Class BatchUpdateFindingsV2UnprocessedFinding
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.BatchUpdateFindingsV2UnprocessedFinding
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>
@Generated("software.amazon.awssdk:codegen") public final class BatchUpdateFindingsV2UnprocessedFinding extends Object implements SdkPojo, Serializable, ToCopyableBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>
The list of findings that were not updated.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceBatchUpdateFindingsV2UnprocessedFinding.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static BatchUpdateFindingsV2UnprocessedFinding.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)BatchUpdateFindingsV2UnprocessedFindingErrorCodeerrorCode()Indicates the specific type of error preventing successful processing of a finding during a batch update operation.StringerrorCodeAsString()Indicates the specific type of error preventing successful processing of a finding during a batch update operation.StringerrorMessage()A detailed description of why a finding could not be processed during a batch update operation.OcsfFindingIdentifierfindingIdentifier()The finding identifier of an unprocessed finding.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()StringmetadataUid()The metadata.uid of an unprocessed finding.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends BatchUpdateFindingsV2UnprocessedFinding.Builder>serializableBuilderClass()BatchUpdateFindingsV2UnprocessedFinding.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
findingIdentifier
public final OcsfFindingIdentifier findingIdentifier()
The finding identifier of an unprocessed finding.
- Returns:
- The finding identifier of an unprocessed finding.
-
metadataUid
public final String metadataUid()
The metadata.uid of an unprocessed finding.
- Returns:
- The metadata.uid of an unprocessed finding.
-
errorCode
public final BatchUpdateFindingsV2UnprocessedFindingErrorCode errorCode()
Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnBatchUpdateFindingsV2UnprocessedFindingErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
- See Also:
BatchUpdateFindingsV2UnprocessedFindingErrorCode
-
errorCodeAsString
public final String errorCodeAsString()
Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnBatchUpdateFindingsV2UnprocessedFindingErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- Indicates the specific type of error preventing successful processing of a finding during a batch update operation.
- See Also:
BatchUpdateFindingsV2UnprocessedFindingErrorCode
-
errorMessage
public final String errorMessage()
A detailed description of why a finding could not be processed during a batch update operation.
- Returns:
- A detailed description of why a finding could not be processed during a batch update operation.
-
toBuilder
public BatchUpdateFindingsV2UnprocessedFinding.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<BatchUpdateFindingsV2UnprocessedFinding.Builder,BatchUpdateFindingsV2UnprocessedFinding>
-
builder
public static BatchUpdateFindingsV2UnprocessedFinding.Builder builder()
-
serializableBuilderClass
public static Class<? extends BatchUpdateFindingsV2UnprocessedFinding.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-