Class Cell
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Cell
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Cell.Builder,Cell>
@Generated("software.amazon.awssdk:codegen")
public final class Cell
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Cell.Builder,Cell>
An occurrence of sensitive data detected in a Microsoft Excel workbook, comma-separated value (CSV) file, or tab-separated value (TSV) file.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Cell.Builderbuilder()final StringFor a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data.final Longcolumn()The column number of the column that contains the data.final StringThe name of the column that contains the data.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Longrow()The row number of the row that contains the data.static Class<? extends Cell.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
column
The column number of the column that contains the data. For a Microsoft Excel workbook, the column number corresponds to the alphabetical column identifiers. For example, a value of 1 for Column corresponds to the A column in the workbook.
- Returns:
- The column number of the column that contains the data. For a Microsoft Excel workbook, the column number corresponds to the alphabetical column identifiers. For example, a value of 1 for Column corresponds to the A column in the workbook.
-
row
The row number of the row that contains the data.
- Returns:
- The row number of the row that contains the data.
-
columnName
The name of the column that contains the data.
- Returns:
- The name of the column that contains the data.
-
cellReference
For a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data. For example, Sheet2!C5 for cell C5 on Sheet2.
- Returns:
- For a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data. For example, Sheet2!C5 for cell C5 on Sheet2.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Cell.Builder,Cell>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-