Interface CodeRepositoryDetails.Builder

    • Method Detail

      • providerType

        CodeRepositoryDetails.Builder providerType​(String providerType)

        The type of repository provider.

        Parameters:
        providerType - The type of repository provider.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • projectName

        CodeRepositoryDetails.Builder projectName​(String projectName)

        The name of the project in the code repository.

        Parameters:
        projectName - The name of the project in the code repository.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • codeSecurityIntegrationArn

        CodeRepositoryDetails.Builder codeSecurityIntegrationArn​(String codeSecurityIntegrationArn)

        The Amazon Resource Name (ARN) of the code security integration associated with the repository.

        Parameters:
        codeSecurityIntegrationArn - The Amazon Resource Name (ARN) of the code security integration associated with the repository.
        Returns:
        Returns a reference to this object so that method calls can be chained together.