Interface CodeRepositoryDetails.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<CodeRepositoryDetails.Builder,CodeRepositoryDetails>,SdkBuilder<CodeRepositoryDetails.Builder,CodeRepositoryDetails>,SdkPojo
- Enclosing class:
- CodeRepositoryDetails
@Mutable @NotThreadSafe public static interface CodeRepositoryDetails.Builder extends SdkPojo, CopyableBuilder<CodeRepositoryDetails.Builder,CodeRepositoryDetails>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description CodeRepositoryDetails.BuildercodeSecurityIntegrationArn(String codeSecurityIntegrationArn)The Amazon Resource Name (ARN) of the code security integration associated with the repository.CodeRepositoryDetails.BuilderprojectName(String projectName)The name of the project in the code repository.CodeRepositoryDetails.BuilderproviderType(String providerType)The type of repository provider.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
providerType
CodeRepositoryDetails.Builder providerType(String providerType)
The type of repository provider.
- Parameters:
providerType- The type of repository provider.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
projectName
CodeRepositoryDetails.Builder projectName(String projectName)
The name of the project in the code repository.
- Parameters:
projectName- The name of the project in the code repository.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
codeSecurityIntegrationArn
CodeRepositoryDetails.Builder codeSecurityIntegrationArn(String codeSecurityIntegrationArn)
The Amazon Resource Name (ARN) of the code security integration associated with the repository.
- Parameters:
codeSecurityIntegrationArn- The Amazon Resource Name (ARN) of the code security integration associated with the repository.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-