Class ConnectorSummary
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ConnectorSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>
@Generated("software.amazon.awssdk:codegen")
public final class ConnectorSummary
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>
A condensed overview of the connectorV2..
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ConnectorSummary.Builderbuilder()final StringThe Amazon Resource Name (ARN) of the connectorV2.final StringThe UUID of the connectorV2 to identify connectorV2 resource.final InstantISO 8601 UTC timestamp for the time create the connectorV2.final StringThe description of the connectorV2.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The Name field contains the user-defined name assigned to the integration connector.final ProviderSummaryThe connectorV2 third party provider configuration summary.static Class<? extends ConnectorSummary.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorArn
The Amazon Resource Name (ARN) of the connectorV2.
- Returns:
- The Amazon Resource Name (ARN) of the connectorV2.
-
connectorId
The UUID of the connectorV2 to identify connectorV2 resource.
- Returns:
- The UUID of the connectorV2 to identify connectorV2 resource.
-
name
The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.
- Returns:
- The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.
-
description
The description of the connectorV2.
- Returns:
- The description of the connectorV2.
-
providerSummary
The connectorV2 third party provider configuration summary.
- Returns:
- The connectorV2 third party provider configuration summary.
-
createdAt
ISO 8601 UTC timestamp for the time create the connectorV2.
- Returns:
- ISO 8601 UTC timestamp for the time create the connectorV2.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-