Class ConnectorSummary

    • Method Detail

      • connectorArn

        public final String connectorArn()

        The Amazon Resource Name (ARN) of the connectorV2.

        Returns:
        The Amazon Resource Name (ARN) of the connectorV2.
      • connectorId

        public final String connectorId()

        The UUID of the connectorV2 to identify connectorV2 resource.

        Returns:
        The UUID of the connectorV2 to identify connectorV2 resource.
      • name

        public final String name()

        The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.

        Returns:
        The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.
      • description

        public final String description()

        The description of the connectorV2.

        Returns:
        The description of the connectorV2.
      • providerSummary

        public final ProviderSummary providerSummary()

        The connectorV2 third party provider configuration summary.

        Returns:
        The connectorV2 third party provider configuration summary.
      • createdAt

        public final Instant createdAt()

        ISO 8601 UTC timestamp for the time create the connectorV2.

        Returns:
        ISO 8601 UTC timestamp for the time create the connectorV2.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)