Class ConnectorSummary
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ConnectorSummary
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>
@Generated("software.amazon.awssdk:codegen") public final class ConnectorSummary extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>
A condensed overview of the connectorV2..
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceConnectorSummary.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ConnectorSummary.Builderbuilder()StringconnectorArn()The Amazon Resource Name (ARN) of the connectorV2.StringconnectorId()The UUID of the connectorV2 to identify connectorV2 resource.InstantcreatedAt()ISO 8601 UTC timestamp for the time create the connectorV2.Stringdescription()The description of the connectorV2.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Stringname()The Name field contains the user-defined name assigned to the integration connector.ProviderSummaryproviderSummary()The connectorV2 third party provider configuration summary.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ConnectorSummary.Builder>serializableBuilderClass()ConnectorSummary.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
connectorArn
public final String connectorArn()
The Amazon Resource Name (ARN) of the connectorV2.
- Returns:
- The Amazon Resource Name (ARN) of the connectorV2.
-
connectorId
public final String connectorId()
The UUID of the connectorV2 to identify connectorV2 resource.
- Returns:
- The UUID of the connectorV2 to identify connectorV2 resource.
-
name
public final String name()
The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.
- Returns:
- The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.
-
description
public final String description()
The description of the connectorV2.
- Returns:
- The description of the connectorV2.
-
providerSummary
public final ProviderSummary providerSummary()
The connectorV2 third party provider configuration summary.
- Returns:
- The connectorV2 third party provider configuration summary.
-
createdAt
public final Instant createdAt()
ISO 8601 UTC timestamp for the time create the connectorV2.
- Returns:
- ISO 8601 UTC timestamp for the time create the connectorV2.
-
toBuilder
public ConnectorSummary.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>
-
builder
public static ConnectorSummary.Builder builder()
-
serializableBuilderClass
public static Class<? extends ConnectorSummary.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-