Interface ConnectorSummary.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>,SdkBuilder<ConnectorSummary.Builder,ConnectorSummary>,SdkPojo
- Enclosing class:
- ConnectorSummary
@Mutable @NotThreadSafe public static interface ConnectorSummary.Builder extends SdkPojo, CopyableBuilder<ConnectorSummary.Builder,ConnectorSummary>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description ConnectorSummary.BuilderconnectorArn(String connectorArn)The Amazon Resource Name (ARN) of the connectorV2.ConnectorSummary.BuilderconnectorId(String connectorId)The UUID of the connectorV2 to identify connectorV2 resource.ConnectorSummary.BuildercreatedAt(Instant createdAt)ISO 8601 UTC timestamp for the time create the connectorV2.ConnectorSummary.Builderdescription(String description)The description of the connectorV2.ConnectorSummary.Buildername(String name)The Name field contains the user-defined name assigned to the integration connector.default ConnectorSummary.BuilderproviderSummary(Consumer<ProviderSummary.Builder> providerSummary)The connectorV2 third party provider configuration summary.ConnectorSummary.BuilderproviderSummary(ProviderSummary providerSummary)The connectorV2 third party provider configuration summary.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
connectorArn
ConnectorSummary.Builder connectorArn(String connectorArn)
The Amazon Resource Name (ARN) of the connectorV2.
- Parameters:
connectorArn- The Amazon Resource Name (ARN) of the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
connectorId
ConnectorSummary.Builder connectorId(String connectorId)
The UUID of the connectorV2 to identify connectorV2 resource.
- Parameters:
connectorId- The UUID of the connectorV2 to identify connectorV2 resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
name
ConnectorSummary.Builder name(String name)
The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.
- Parameters:
name- The Name field contains the user-defined name assigned to the integration connector. This helps identify and manage multiple connectors within Security Hub.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
description
ConnectorSummary.Builder description(String description)
The description of the connectorV2.
- Parameters:
description- The description of the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
providerSummary
ConnectorSummary.Builder providerSummary(ProviderSummary providerSummary)
The connectorV2 third party provider configuration summary.
- Parameters:
providerSummary- The connectorV2 third party provider configuration summary.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
providerSummary
default ConnectorSummary.Builder providerSummary(Consumer<ProviderSummary.Builder> providerSummary)
The connectorV2 third party provider configuration summary.
This is a convenience method that creates an instance of theProviderSummary.Builderavoiding the need to create one manually viaProviderSummary.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toproviderSummary(ProviderSummary).- Parameters:
providerSummary- a consumer that will call methods onProviderSummary.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
providerSummary(ProviderSummary)
-
createdAt
ConnectorSummary.Builder createdAt(Instant createdAt)
ISO 8601 UTC timestamp for the time create the connectorV2.
- Parameters:
createdAt- ISO 8601 UTC timestamp for the time create the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-