Class CreateAggregatorV2Request

    • Method Detail

      • regionLinkingMode

        public final String regionLinkingMode()

        Determines how Regions are linked to an Aggregator V2.

        Returns:
        Determines how Regions are linked to an Aggregator V2.
      • hasLinkedRegions

        public final boolean hasLinkedRegions()
        For responses, this returns true if the service returned a value for the LinkedRegions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • linkedRegions

        public final List<String> linkedRegions()

        The list of Regions that are linked to the aggregation Region.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasLinkedRegions() method.

        Returns:
        The list of Regions that are linked to the aggregation Region.
      • hasTags

        public final boolean hasTags()
        For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • tags

        public final Map<String,​String> tags()

        A list of key-value pairs to be applied to the AggregatorV2.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasTags() method.

        Returns:
        A list of key-value pairs to be applied to the AggregatorV2.
      • clientToken

        public final String clientToken()

        A unique identifier used to ensure idempotency.

        Returns:
        A unique identifier used to ensure idempotency.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object