Class CreateAggregatorV2Request
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.CreateAggregatorV2Request
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateAggregatorV2Request.Builder,CreateAggregatorV2Request>
@Generated("software.amazon.awssdk:codegen") public final class CreateAggregatorV2Request extends SecurityHubRequest implements ToCopyableBuilder<CreateAggregatorV2Request.Builder,CreateAggregatorV2Request>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceCreateAggregatorV2Request.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static CreateAggregatorV2Request.Builderbuilder()StringclientToken()A unique identifier used to ensure idempotency.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()booleanhasLinkedRegions()For responses, this returns true if the service returned a value for the LinkedRegions property.booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.List<String>linkedRegions()The list of Regions that are linked to the aggregation Region.StringregionLinkingMode()Determines how Regions are linked to an Aggregator V2.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends CreateAggregatorV2Request.Builder>serializableBuilderClass()Map<String,String>tags()A list of key-value pairs to be applied to the AggregatorV2.CreateAggregatorV2Request.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
regionLinkingMode
public final String regionLinkingMode()
Determines how Regions are linked to an Aggregator V2.
- Returns:
- Determines how Regions are linked to an Aggregator V2.
-
hasLinkedRegions
public final boolean hasLinkedRegions()
For responses, this returns true if the service returned a value for the LinkedRegions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
linkedRegions
public final List<String> linkedRegions()
The list of Regions that are linked to the aggregation Region.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasLinkedRegions()method.- Returns:
- The list of Regions that are linked to the aggregation Region.
-
hasTags
public final boolean hasTags()
For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
tags
public final Map<String,String> tags()
A list of key-value pairs to be applied to the AggregatorV2.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- A list of key-value pairs to be applied to the AggregatorV2.
-
clientToken
public final String clientToken()
A unique identifier used to ensure idempotency.
- Returns:
- A unique identifier used to ensure idempotency.
-
toBuilder
public CreateAggregatorV2Request.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateAggregatorV2Request.Builder,CreateAggregatorV2Request>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static CreateAggregatorV2Request.Builder builder()
-
serializableBuilderClass
public static Class<? extends CreateAggregatorV2Request.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-