Class CreateAggregatorV2Response
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.CreateAggregatorV2Response
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateAggregatorV2Response.Builder,CreateAggregatorV2Response>
@Generated("software.amazon.awssdk:codegen")
public final class CreateAggregatorV2Response
extends SecurityHubResponse
implements ToCopyableBuilder<CreateAggregatorV2Response.Builder,CreateAggregatorV2Response>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe Amazon Web Services Region where data is aggregated.final StringThe ARN of the AggregatorV2.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the LinkedRegions property.The list of Regions that are linked to the aggregation Region.final StringDetermines how Regions are linked to an Aggregator V2.static Class<? extends CreateAggregatorV2Response.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
aggregatorV2Arn
The ARN of the AggregatorV2.
- Returns:
- The ARN of the AggregatorV2.
-
aggregationRegion
The Amazon Web Services Region where data is aggregated.
- Returns:
- The Amazon Web Services Region where data is aggregated.
-
regionLinkingMode
Determines how Regions are linked to an Aggregator V2.
- Returns:
- Determines how Regions are linked to an Aggregator V2.
-
hasLinkedRegions
public final boolean hasLinkedRegions()For responses, this returns true if the service returned a value for the LinkedRegions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
linkedRegions
The list of Regions that are linked to the aggregation Region.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasLinkedRegions()method.- Returns:
- The list of Regions that are linked to the aggregation Region.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateAggregatorV2Response.Builder,CreateAggregatorV2Response> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-