Class CreateAggregatorV2Response
- java.lang.Object
-
- software.amazon.awssdk.core.SdkResponse
-
- software.amazon.awssdk.awscore.AwsResponse
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
-
- software.amazon.awssdk.services.securityhub.model.CreateAggregatorV2Response
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateAggregatorV2Response.Builder,CreateAggregatorV2Response>
@Generated("software.amazon.awssdk:codegen") public final class CreateAggregatorV2Response extends SecurityHubResponse implements ToCopyableBuilder<CreateAggregatorV2Response.Builder,CreateAggregatorV2Response>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceCreateAggregatorV2Response.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description StringaggregationRegion()The Amazon Web Services Region where data is aggregated.StringaggregatorV2Arn()The ARN of the AggregatorV2.static CreateAggregatorV2Response.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()booleanhasLinkedRegions()For responses, this returns true if the service returned a value for the LinkedRegions property.List<String>linkedRegions()The list of Regions that are linked to the aggregation Region.StringregionLinkingMode()Determines how Regions are linked to an Aggregator V2.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends CreateAggregatorV2Response.Builder>serializableBuilderClass()CreateAggregatorV2Response.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadata
-
Methods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponse
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
aggregatorV2Arn
public final String aggregatorV2Arn()
The ARN of the AggregatorV2.
- Returns:
- The ARN of the AggregatorV2.
-
aggregationRegion
public final String aggregationRegion()
The Amazon Web Services Region where data is aggregated.
- Returns:
- The Amazon Web Services Region where data is aggregated.
-
regionLinkingMode
public final String regionLinkingMode()
Determines how Regions are linked to an Aggregator V2.
- Returns:
- Determines how Regions are linked to an Aggregator V2.
-
hasLinkedRegions
public final boolean hasLinkedRegions()
For responses, this returns true if the service returned a value for the LinkedRegions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
linkedRegions
public final List<String> linkedRegions()
The list of Regions that are linked to the aggregation Region.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasLinkedRegions()method.- Returns:
- The list of Regions that are linked to the aggregation Region.
-
toBuilder
public CreateAggregatorV2Response.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateAggregatorV2Response.Builder,CreateAggregatorV2Response>- Specified by:
toBuilderin classAwsResponse
-
builder
public static CreateAggregatorV2Response.Builder builder()
-
serializableBuilderClass
public static Class<? extends CreateAggregatorV2Response.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsResponse
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-