Class CreateAutomationRuleV2Request

    • Method Detail

      • ruleName

        public final String ruleName()

        The name of the V2 automation rule.

        Returns:
        The name of the V2 automation rule.
      • ruleStatusAsString

        public final String ruleStatusAsString()

        The status of the V2 automation rule.

        If the service returns an enum value that is not available in the current SDK version, ruleStatus will return RuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from ruleStatusAsString().

        Returns:
        The status of the V2 automation rule.
        See Also:
        RuleStatusV2
      • description

        public final String description()

        A description of the V2 automation rule.

        Returns:
        A description of the V2 automation rule.
      • ruleOrder

        public final Float ruleOrder()

        The value for the rule priority.

        Returns:
        The value for the rule priority.
      • criteria

        public final Criteria criteria()

        The filtering type and configuration of the automation rule.

        Returns:
        The filtering type and configuration of the automation rule.
      • hasActions

        public final boolean hasActions()
        For responses, this returns true if the service returned a value for the Actions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • actions

        public final List<AutomationRulesActionV2> actions()

        A list of actions to be performed when the rule criteria is met.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasActions() method.

        Returns:
        A list of actions to be performed when the rule criteria is met.
      • hasTags

        public final boolean hasTags()
        For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • tags

        public final Map<String,​String> tags()

        A list of key-value pairs associated with the V2 automation rule.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasTags() method.

        Returns:
        A list of key-value pairs associated with the V2 automation rule.
      • clientToken

        public final String clientToken()

        A unique identifier used to ensure idempotency.

        Returns:
        A unique identifier used to ensure idempotency.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object