Interface CreateAutomationRuleV2Response.Builder

    • Method Detail

      • ruleArn

        CreateAutomationRuleV2Response.Builder ruleArn​(String ruleArn)

        The ARN of the V2 automation rule.

        Parameters:
        ruleArn - The ARN of the V2 automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • ruleId

        CreateAutomationRuleV2Response.Builder ruleId​(String ruleId)

        The ID of the V2 automation rule.

        Parameters:
        ruleId - The ID of the V2 automation rule.
        Returns:
        Returns a reference to this object so that method calls can be chained together.