Interface CreateMembersRequest.Builder

    • Method Detail

      • accountDetails

        CreateMembersRequest.Builder accountDetails​(Collection<AccountDetails> accountDetails)

        The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.

        Parameters:
        accountDetails - The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • accountDetails

        CreateMembersRequest.Builder accountDetails​(AccountDetails... accountDetails)

        The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.

        Parameters:
        accountDetails - The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • accountDetails

        CreateMembersRequest.Builder accountDetails​(Consumer<AccountDetails.Builder>... accountDetails)

        The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.

        This is a convenience method that creates an instance of the AccountDetails.Builder avoiding the need to create one manually via AccountDetails.builder().

        When the Consumer completes, SdkBuilder.build() is called immediately and its result is passed to #accountDetails(List).

        Parameters:
        accountDetails - a consumer that will call methods on AccountDetails.Builder
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        #accountDetails(java.util.Collection)