Class CreateTicketV2Request

    • Method Detail

      • connectorId

        public final String connectorId()

        The UUID of the connectorV2 to identify connectorV2 resource.

        Returns:
        The UUID of the connectorV2 to identify connectorV2 resource.
      • findingMetadataUid

        public final String findingMetadataUid()

        The the unique ID for the finding.

        Returns:
        The the unique ID for the finding.
      • clientToken

        public final String clientToken()

        The client idempotency token.

        Returns:
        The client idempotency token.
      • mode

        public final TicketCreationMode mode()

        The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.

        If the service returns an enum value that is not available in the current SDK version, mode will return TicketCreationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from modeAsString().

        Returns:
        The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
        See Also:
        TicketCreationMode
      • modeAsString

        public final String modeAsString()

        The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.

        If the service returns an enum value that is not available in the current SDK version, mode will return TicketCreationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from modeAsString().

        Returns:
        The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
        See Also:
        TicketCreationMode
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object