Class CreateTicketV2Request
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.CreateTicketV2Request
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateTicketV2Request.Builder,CreateTicketV2Request>
@Generated("software.amazon.awssdk:codegen") public final class CreateTicketV2Request extends SecurityHubRequest implements ToCopyableBuilder<CreateTicketV2Request.Builder,CreateTicketV2Request>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceCreateTicketV2Request.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static CreateTicketV2Request.Builderbuilder()StringclientToken()The client idempotency token.StringconnectorId()The UUID of the connectorV2 to identify connectorV2 resource.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)StringfindingMetadataUid()The the unique ID for the finding.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()TicketCreationModemode()The mode for ticket creation.StringmodeAsString()The mode for ticket creation.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends CreateTicketV2Request.Builder>serializableBuilderClass()CreateTicketV2Request.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
connectorId
public final String connectorId()
The UUID of the connectorV2 to identify connectorV2 resource.
- Returns:
- The UUID of the connectorV2 to identify connectorV2 resource.
-
findingMetadataUid
public final String findingMetadataUid()
The the unique ID for the finding.
- Returns:
- The the unique ID for the finding.
-
clientToken
public final String clientToken()
The client idempotency token.
- Returns:
- The client idempotency token.
-
mode
public final TicketCreationMode mode()
The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
If the service returns an enum value that is not available in the current SDK version,
modewill returnTicketCreationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommodeAsString().- Returns:
- The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
- See Also:
TicketCreationMode
-
modeAsString
public final String modeAsString()
The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
If the service returns an enum value that is not available in the current SDK version,
modewill returnTicketCreationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommodeAsString().- Returns:
- The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.
- See Also:
TicketCreationMode
-
toBuilder
public CreateTicketV2Request.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateTicketV2Request.Builder,CreateTicketV2Request>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static CreateTicketV2Request.Builder builder()
-
serializableBuilderClass
public static Class<? extends CreateTicketV2Request.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-