Class DescribeHubResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeHubResponse.Builder,DescribeHubResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal BooleanWhether to automatically enable new controls when they are added to standards that are enabled.static DescribeHubResponse.Builderbuilder()final ControlFindingGeneratorSpecifies whether the calling account has consolidated control findings turned on.final StringSpecifies whether the calling account has consolidated control findings turned on.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringhubArn()The ARN of the Hub resource that was retrieved.static Class<? extends DescribeHubResponse.Builder>final StringThe date and time when Security Hub CSPM was enabled in the account.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hubArn
The ARN of the Hub resource that was retrieved.
- Returns:
- The ARN of the Hub resource that was retrieved.
-
subscribedAt
The date and time when Security Hub CSPM was enabled in the account.
- Returns:
- The date and time when Security Hub CSPM was enabled in the account.
-
autoEnableControls
Whether to automatically enable new controls when they are added to standards that are enabled.
If set to
true, then new controls for enabled standards are enabled automatically. If set tofalse, then new controls are not enabled.When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of
DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control asENABLEDin your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you haveAutoEnableControlsset totrue.- Returns:
- Whether to automatically enable new controls when they are added to standards that are enabled.
If set to
true, then new controls for enabled standards are enabled automatically. If set tofalse, then new controls are not enabled.When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of
DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control asENABLEDin your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you haveAutoEnableControlsset totrue.
-
controlFindingGenerator
Specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023.If the service returns an enum value that is not available in the current SDK version,
controlFindingGeneratorwill returnControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolFindingGeneratorAsString().- Returns:
- Specifies whether the calling account has consolidated control findings turned on. If the value for this
field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023. - See Also:
-
controlFindingGeneratorAsString
Specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023.If the service returns an enum value that is not available in the current SDK version,
controlFindingGeneratorwill returnControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolFindingGeneratorAsString().- Returns:
- Specifies whether the calling account has consolidated control findings turned on. If the value for this
field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeHubResponse.Builder,DescribeHubResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-