Class DescribeStandardsControlsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.DescribeStandardsControlsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DescribeStandardsControlsRequest
extends SecurityHubRequest
implements ToCopyableBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of security standard controls to return.final StringThe token that is required for pagination.static Class<? extends DescribeStandardsControlsRequest.Builder>final StringThe ARN of a resource that represents your subscription to a supported standard.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsSubscriptionArn
The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the
GetEnabledStandardsoperation.- Returns:
- The ARN of a resource that represents your subscription to a supported standard. To get the subscription
ARNs of the standards you have enabled, use the
GetEnabledStandardsoperation.
-
nextToken
The token that is required for pagination. On your first call to the
DescribeStandardsControlsoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
- Returns:
- The token that is required for pagination. On your first call to the
DescribeStandardsControlsoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
-
maxResults
The maximum number of security standard controls to return.
- Returns:
- The maximum number of security standard controls to return.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeStandardsControlsRequest.Builder,DescribeStandardsControlsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-