Class Detection
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Detection
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Detection.Builder,Detection>
@Generated("software.amazon.awssdk:codegen")
public final class Detection
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Detection.Builder,Detection>
A top-level object field that provides details about an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Detection.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Sequencesequence()Provides details about an attack sequence.static Class<? extends Detection.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
sequence
Provides details about an attack sequence.
- Returns:
- Provides details about an attack sequence.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Detection.Builder,Detection>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-