Class EnableSecurityHubRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<EnableSecurityHubRequest.Builder,EnableSecurityHubRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final ControlFindingGeneratorThis field, used when enabling Security Hub CSPM, specifies whether the calling account has consolidated control findings turned on.final StringThis field, used when enabling Security Hub CSPM, specifies whether the calling account has consolidated control findings turned on.final BooleanWhether to enable the security standards that Security Hub CSPM has designated as automatically enabled.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.static Class<? extends EnableSecurityHubRequest.Builder>tags()The tags to add to the hub resource when you enable Security Hub CSPM.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
The tags to add to the hub resource when you enable Security Hub CSPM.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- The tags to add to the hub resource when you enable Security Hub CSPM.
-
enableDefaultStandards
Whether to enable the security standards that Security Hub CSPM has designated as automatically enabled. If you don't provide a value for
EnableDefaultStandards, it is set totrue. To not enable the automatically enabled standards, setEnableDefaultStandardstofalse.- Returns:
- Whether to enable the security standards that Security Hub CSPM has designated as automatically enabled.
If you don't provide a value for
EnableDefaultStandards, it is set totrue. To not enable the automatically enabled standards, setEnableDefaultStandardstofalse.
-
controlFindingGenerator
This field, used when enabling Security Hub CSPM, specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023.If the service returns an enum value that is not available in the current SDK version,
controlFindingGeneratorwill returnControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolFindingGeneratorAsString().- Returns:
- This field, used when enabling Security Hub CSPM, specifies whether the calling account has consolidated
control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023. - See Also:
-
controlFindingGeneratorAsString
This field, used when enabling Security Hub CSPM, specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023.If the service returns an enum value that is not available in the current SDK version,
controlFindingGeneratorwill returnControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolFindingGeneratorAsString().- Returns:
- This field, used when enabling Security Hub CSPM, specifies whether the calling account has consolidated
control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is
SECURITY_CONTROLif you enabled Security Hub CSPM on or after February 23, 2023. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EnableSecurityHubRequest.Builder,EnableSecurityHubRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-