Class FindingHistoryUpdate
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.FindingHistoryUpdate
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FindingHistoryUpdate.Builder,FindingHistoryUpdate>
@Generated("software.amazon.awssdk:codegen") public final class FindingHistoryUpdate extends Object implements SdkPojo, Serializable, ToCopyableBuilder<FindingHistoryUpdate.Builder,FindingHistoryUpdate>
An array of objects that provides details about a change to a finding, including the Amazon Web Services Security Finding Format (ASFF) field that changed, the value of the field before the change, and the value of the field after the change.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceFindingHistoryUpdate.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static FindingHistoryUpdate.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()StringnewValue()The value of the ASFF field after the finding change event.StringoldValue()The value of the ASFF field before the finding change event.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends FindingHistoryUpdate.Builder>serializableBuilderClass()FindingHistoryUpdate.BuildertoBuilder()StringtoString()Returns a string representation of this object.StringupdatedField()The ASFF field that changed during the finding change event.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
updatedField
public final String updatedField()
The ASFF field that changed during the finding change event.
- Returns:
- The ASFF field that changed during the finding change event.
-
oldValue
public final String oldValue()
The value of the ASFF field before the finding change event.
- Returns:
- The value of the ASFF field before the finding change event.
-
newValue
public final String newValue()
The value of the ASFF field after the finding change event. To preserve storage and readability, Security Hub CSPM omits this value if
FindingHistoryRecordexceeds database limits.- Returns:
- The value of the ASFF field after the finding change event. To preserve storage and readability, Security
Hub CSPM omits this value if
FindingHistoryRecordexceeds database limits.
-
toBuilder
public FindingHistoryUpdate.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<FindingHistoryUpdate.Builder,FindingHistoryUpdate>
-
builder
public static FindingHistoryUpdate.Builder builder()
-
serializableBuilderClass
public static Class<? extends FindingHistoryUpdate.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-