Class GetAutomationRuleV2Response
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal List<AutomationRulesActionV2>actions()A list of actions performed when the rule criteria is met.builder()final InstantThe timestamp when the V2 automation rule was created.final Criteriacriteria()The filtering type and configuration of the V2 automation rule.final StringA description of the automation rule.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Actions property.final inthashCode()final StringruleArn()The ARN of the V2 automation rule.final StringruleId()The ID of the V2 automation rule.final StringruleName()The name of the V2 automation rule.final FloatThe value for the rule priority.final RuleStatusV2The status of the V2 automation automation rule.final StringThe status of the V2 automation automation rule.static Class<? extends GetAutomationRuleV2Response.Builder>final StringtoString()Returns a string representation of this object.final InstantThe timestamp when the V2 automation rule was updated.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
ruleArn
The ARN of the V2 automation rule.
- Returns:
- The ARN of the V2 automation rule.
-
ruleId
The ID of the V2 automation rule.
- Returns:
- The ID of the V2 automation rule.
-
ruleOrder
The value for the rule priority.
- Returns:
- The value for the rule priority.
-
ruleName
The name of the V2 automation rule.
- Returns:
- The name of the V2 automation rule.
-
ruleStatus
The status of the V2 automation automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the V2 automation automation rule.
- See Also:
-
ruleStatusAsString
The status of the V2 automation automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the V2 automation automation rule.
- See Also:
-
description
A description of the automation rule.
- Returns:
- A description of the automation rule.
-
criteria
The filtering type and configuration of the V2 automation rule.
- Returns:
- The filtering type and configuration of the V2 automation rule.
-
hasActions
public final boolean hasActions()For responses, this returns true if the service returned a value for the Actions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
actions
A list of actions performed when the rule criteria is met.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasActions()method.- Returns:
- A list of actions performed when the rule criteria is met.
-
createdAt
The timestamp when the V2 automation rule was created.
- Returns:
- The timestamp when the V2 automation rule was created.
-
updatedAt
The timestamp when the V2 automation rule was updated.
- Returns:
- The timestamp when the V2 automation rule was updated.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-