Class GetAutomationRuleV2Response
- java.lang.Object
-
- software.amazon.awssdk.core.SdkResponse
-
- software.amazon.awssdk.awscore.AwsResponse
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
-
- software.amazon.awssdk.services.securityhub.model.GetAutomationRuleV2Response
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response>
@Generated("software.amazon.awssdk:codegen") public final class GetAutomationRuleV2Response extends SecurityHubResponse implements ToCopyableBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGetAutomationRuleV2Response.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description List<AutomationRulesActionV2>actions()A list of actions performed when the rule criteria is met.static GetAutomationRuleV2Response.Builderbuilder()InstantcreatedAt()The timestamp when the V2 automation rule was created.Criteriacriteria()The filtering type and configuration of the V2 automation rule.Stringdescription()A description of the automation rule.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasActions()For responses, this returns true if the service returned a value for the Actions property.inthashCode()StringruleArn()The ARN of the V2 automation rule.StringruleId()The ID of the V2 automation rule.StringruleName()The name of the V2 automation rule.FloatruleOrder()The value for the rule priority.RuleStatusV2ruleStatus()The status of the V2 automation automation rule.StringruleStatusAsString()The status of the V2 automation automation rule.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GetAutomationRuleV2Response.Builder>serializableBuilderClass()GetAutomationRuleV2Response.BuildertoBuilder()StringtoString()Returns a string representation of this object.InstantupdatedAt()The timestamp when the V2 automation rule was updated.-
Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadata
-
Methods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponse
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
ruleArn
public final String ruleArn()
The ARN of the V2 automation rule.
- Returns:
- The ARN of the V2 automation rule.
-
ruleId
public final String ruleId()
The ID of the V2 automation rule.
- Returns:
- The ID of the V2 automation rule.
-
ruleOrder
public final Float ruleOrder()
The value for the rule priority.
- Returns:
- The value for the rule priority.
-
ruleName
public final String ruleName()
The name of the V2 automation rule.
- Returns:
- The name of the V2 automation rule.
-
ruleStatus
public final RuleStatusV2 ruleStatus()
The status of the V2 automation automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the V2 automation automation rule.
- See Also:
RuleStatusV2
-
ruleStatusAsString
public final String ruleStatusAsString()
The status of the V2 automation automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the V2 automation automation rule.
- See Also:
RuleStatusV2
-
description
public final String description()
A description of the automation rule.
- Returns:
- A description of the automation rule.
-
criteria
public final Criteria criteria()
The filtering type and configuration of the V2 automation rule.
- Returns:
- The filtering type and configuration of the V2 automation rule.
-
hasActions
public final boolean hasActions()
For responses, this returns true if the service returned a value for the Actions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
actions
public final List<AutomationRulesActionV2> actions()
A list of actions performed when the rule criteria is met.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasActions()method.- Returns:
- A list of actions performed when the rule criteria is met.
-
createdAt
public final Instant createdAt()
The timestamp when the V2 automation rule was created.
- Returns:
- The timestamp when the V2 automation rule was created.
-
updatedAt
public final Instant updatedAt()
The timestamp when the V2 automation rule was updated.
- Returns:
- The timestamp when the V2 automation rule was updated.
-
toBuilder
public GetAutomationRuleV2Response.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response>- Specified by:
toBuilderin classAwsResponse
-
builder
public static GetAutomationRuleV2Response.Builder builder()
-
serializableBuilderClass
public static Class<? extends GetAutomationRuleV2Response.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsResponse
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-