Interface GetAutomationRuleV2Response.Builder
-
- All Superinterfaces:
AwsResponse.Builder,Buildable,CopyableBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response>,SdkBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response>,SdkPojo,SdkResponse.Builder,SecurityHubResponse.Builder
- Enclosing class:
- GetAutomationRuleV2Response
@Mutable @NotThreadSafe public static interface GetAutomationRuleV2Response.Builder extends SecurityHubResponse.Builder, SdkPojo, CopyableBuilder<GetAutomationRuleV2Response.Builder,GetAutomationRuleV2Response>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description GetAutomationRuleV2Response.Builderactions(Collection<AutomationRulesActionV2> actions)A list of actions performed when the rule criteria is met.GetAutomationRuleV2Response.Builderactions(Consumer<AutomationRulesActionV2.Builder>... actions)A list of actions performed when the rule criteria is met.GetAutomationRuleV2Response.Builderactions(AutomationRulesActionV2... actions)A list of actions performed when the rule criteria is met.GetAutomationRuleV2Response.BuildercreatedAt(Instant createdAt)The timestamp when the V2 automation rule was created.default GetAutomationRuleV2Response.Buildercriteria(Consumer<Criteria.Builder> criteria)The filtering type and configuration of the V2 automation rule.GetAutomationRuleV2Response.Buildercriteria(Criteria criteria)The filtering type and configuration of the V2 automation rule.GetAutomationRuleV2Response.Builderdescription(String description)A description of the automation rule.GetAutomationRuleV2Response.BuilderruleArn(String ruleArn)The ARN of the V2 automation rule.GetAutomationRuleV2Response.BuilderruleId(String ruleId)The ID of the V2 automation rule.GetAutomationRuleV2Response.BuilderruleName(String ruleName)The name of the V2 automation rule.GetAutomationRuleV2Response.BuilderruleOrder(Float ruleOrder)The value for the rule priority.GetAutomationRuleV2Response.BuilderruleStatus(String ruleStatus)The status of the V2 automation automation rule.GetAutomationRuleV2Response.BuilderruleStatus(RuleStatusV2 ruleStatus)The status of the V2 automation automation rule.GetAutomationRuleV2Response.BuilderupdatedAt(Instant updatedAt)The timestamp when the V2 automation rule was updated.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.core.SdkResponse.Builder
sdkHttpResponse, sdkHttpResponse
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubResponse.Builder
build, responseMetadata, responseMetadata
-
-
-
-
Method Detail
-
ruleArn
GetAutomationRuleV2Response.Builder ruleArn(String ruleArn)
The ARN of the V2 automation rule.
- Parameters:
ruleArn- The ARN of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleId
GetAutomationRuleV2Response.Builder ruleId(String ruleId)
The ID of the V2 automation rule.
- Parameters:
ruleId- The ID of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleOrder
GetAutomationRuleV2Response.Builder ruleOrder(Float ruleOrder)
The value for the rule priority.
- Parameters:
ruleOrder- The value for the rule priority.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleName
GetAutomationRuleV2Response.Builder ruleName(String ruleName)
The name of the V2 automation rule.
- Parameters:
ruleName- The name of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
ruleStatus
GetAutomationRuleV2Response.Builder ruleStatus(String ruleStatus)
The status of the V2 automation automation rule.
- Parameters:
ruleStatus- The status of the V2 automation automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
ruleStatus
GetAutomationRuleV2Response.Builder ruleStatus(RuleStatusV2 ruleStatus)
The status of the V2 automation automation rule.
- Parameters:
ruleStatus- The status of the V2 automation automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
RuleStatusV2,RuleStatusV2
-
description
GetAutomationRuleV2Response.Builder description(String description)
A description of the automation rule.
- Parameters:
description- A description of the automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
criteria
GetAutomationRuleV2Response.Builder criteria(Criteria criteria)
The filtering type and configuration of the V2 automation rule.
- Parameters:
criteria- The filtering type and configuration of the V2 automation rule.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
criteria
default GetAutomationRuleV2Response.Builder criteria(Consumer<Criteria.Builder> criteria)
The filtering type and configuration of the V2 automation rule.
This is a convenience method that creates an instance of theCriteria.Builderavoiding the need to create one manually viaCriteria.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tocriteria(Criteria).- Parameters:
criteria- a consumer that will call methods onCriteria.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
criteria(Criteria)
-
actions
GetAutomationRuleV2Response.Builder actions(Collection<AutomationRulesActionV2> actions)
A list of actions performed when the rule criteria is met.
- Parameters:
actions- A list of actions performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
GetAutomationRuleV2Response.Builder actions(AutomationRulesActionV2... actions)
A list of actions performed when the rule criteria is met.
- Parameters:
actions- A list of actions performed when the rule criteria is met.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
actions
GetAutomationRuleV2Response.Builder actions(Consumer<AutomationRulesActionV2.Builder>... actions)
A list of actions performed when the rule criteria is met.
This is a convenience method that creates an instance of theAutomationRulesActionV2.Builderavoiding the need to create one manually viaAutomationRulesActionV2.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#actions(List.) - Parameters:
actions- a consumer that will call methods onAutomationRulesActionV2.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#actions(java.util.Collection)
-
createdAt
GetAutomationRuleV2Response.Builder createdAt(Instant createdAt)
The timestamp when the V2 automation rule was created.
- Parameters:
createdAt- The timestamp when the V2 automation rule was created.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
updatedAt
GetAutomationRuleV2Response.Builder updatedAt(Instant updatedAt)
The timestamp when the V2 automation rule was updated.
- Parameters:
updatedAt- The timestamp when the V2 automation rule was updated.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-