Class GetConfigurationPolicyAssociationResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetConfigurationPolicyAssociationResponse.Builder,GetConfigurationPolicyAssociationResponse>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionThe current status of the association between the specified target and the configuration.final StringThe current status of the association between the specified target and the configuration.final StringThe explanation for aFAILEDvalue forAssociationStatus.final AssociationTypeIndicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.final StringIndicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.builder()final StringThe universally unique identifier (UUID) of a configuration policy.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends GetConfigurationPolicyAssociationResponse.Builder>final StringtargetId()The target account ID, organizational unit ID, or the root ID for which the association is retrieved.final TargetTypeSpecifies whether the target is an Amazon Web Services account, organizational unit, or the organization root.final StringSpecifies whether the target is an Amazon Web Services account, organizational unit, or the organization root.final StringtoString()Returns a string representation of this object.final InstantThe date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
configurationPolicyId
The universally unique identifier (UUID) of a configuration policy. For self-managed behavior, the value is
SELF_MANAGED_SECURITY_HUB.- Returns:
- The universally unique identifier (UUID) of a configuration policy. For self-managed behavior, the value
is
SELF_MANAGED_SECURITY_HUB.
-
targetId
The target account ID, organizational unit ID, or the root ID for which the association is retrieved.
- Returns:
- The target account ID, organizational unit ID, or the root ID for which the association is retrieved.
-
targetType
Specifies whether the target is an Amazon Web Services account, organizational unit, or the organization root.
If the service returns an enum value that is not available in the current SDK version,
targetTypewill returnTargetType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtargetTypeAsString().- Returns:
- Specifies whether the target is an Amazon Web Services account, organizational unit, or the organization root.
- See Also:
-
targetTypeAsString
Specifies whether the target is an Amazon Web Services account, organizational unit, or the organization root.
If the service returns an enum value that is not available in the current SDK version,
targetTypewill returnTargetType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtargetTypeAsString().- Returns:
- Specifies whether the target is an Amazon Web Services account, organizational unit, or the organization root.
- See Also:
-
associationType
Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
If the service returns an enum value that is not available in the current SDK version,
associationTypewill returnAssociationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationTypeAsString().- Returns:
- Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
- See Also:
-
associationTypeAsString
Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
If the service returns an enum value that is not available in the current SDK version,
associationTypewill returnAssociationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationTypeAsString().- Returns:
- Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub CSPM delegated administrator or inherited from a parent.
- See Also:
-
updatedAt
The date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.
- Returns:
- The date and time, in UTC and ISO 8601 format, that the configuration policy association was last updated.
-
associationStatus
The current status of the association between the specified target and the configuration.
If the service returns an enum value that is not available in the current SDK version,
associationStatuswill returnConfigurationPolicyAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationStatusAsString().- Returns:
- The current status of the association between the specified target and the configuration.
- See Also:
-
associationStatusAsString
The current status of the association between the specified target and the configuration.
If the service returns an enum value that is not available in the current SDK version,
associationStatuswill returnConfigurationPolicyAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationStatusAsString().- Returns:
- The current status of the association between the specified target and the configuration.
- See Also:
-
associationStatusMessage
The explanation for a
FAILEDvalue forAssociationStatus.- Returns:
- The explanation for a
FAILEDvalue forAssociationStatus.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetConfigurationPolicyAssociationResponse.Builder,GetConfigurationPolicyAssociationResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends GetConfigurationPolicyAssociationResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-