Class GetConfigurationPolicyResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetConfigurationPolicyResponse.Builder,GetConfigurationPolicyResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The ARN of the configuration policy.builder()final PolicyAn object that defines how Security Hub CSPM is configured.final InstantThe date and time, in UTC and ISO 8601 format, that the configuration policy was created.final StringThe description of the configuration policy.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The UUID of the configuration policy.final Stringname()The name of the configuration policy.static Class<? extends GetConfigurationPolicyResponse.Builder>final StringtoString()Returns a string representation of this object.final InstantThe date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
arn
The ARN of the configuration policy.
- Returns:
- The ARN of the configuration policy.
-
id
The UUID of the configuration policy.
- Returns:
- The UUID of the configuration policy.
-
name
The name of the configuration policy.
- Returns:
- The name of the configuration policy.
-
description
The description of the configuration policy.
- Returns:
- The description of the configuration policy.
-
updatedAt
The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
- Returns:
- The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
-
createdAt
The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
- Returns:
- The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
-
configurationPolicy
An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the policy includes a list of security controls that are enabled, Security Hub CSPM disables all other controls (including newly released controls). If the policy includes a list of security controls that are disabled, Security Hub CSPM enables all other controls (including newly released controls).
- Returns:
- An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the policy includes a list of security controls that are enabled, Security Hub CSPM disables all other controls (including newly released controls). If the policy includes a list of security controls that are disabled, Security Hub CSPM enables all other controls (including newly released controls).
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetConfigurationPolicyResponse.Builder,GetConfigurationPolicyResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-