Class GetConnectorV2Response
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe Amazon Resource Name (ARN) of the connectorV2.final StringThe UUID of the connectorV2 to identify connectorV2 resource.final InstantISO 8601 UTC timestamp for the time create the connectorV2.final StringThe description of the connectorV2.final EnablementStatusThe enablement status of the connector.final StringThe enablement status of the connector.final StringThe reason for the current enablement status.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final HealthCheckhealth()The current health status for connectorV2final StringThe Amazon Resource Name (ARN) of KMS key used for the connectorV2.final InstantISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.final Stringname()The name of the connectorV2.final ProviderDetailThe third-party provider detail for a service configuration.static Class<? extends GetConnectorV2Response.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
connectorArn
The Amazon Resource Name (ARN) of the connectorV2.
- Returns:
- The Amazon Resource Name (ARN) of the connectorV2.
-
connectorId
The UUID of the connectorV2 to identify connectorV2 resource.
- Returns:
- The UUID of the connectorV2 to identify connectorV2 resource.
-
name
The name of the connectorV2.
- Returns:
- The name of the connectorV2.
-
description
The description of the connectorV2.
- Returns:
- The description of the connectorV2.
-
kmsKeyArn
The Amazon Resource Name (ARN) of KMS key used for the connectorV2.
- Returns:
- The Amazon Resource Name (ARN) of KMS key used for the connectorV2.
-
createdAt
ISO 8601 UTC timestamp for the time create the connectorV2.
- Returns:
- ISO 8601 UTC timestamp for the time create the connectorV2.
-
lastUpdatedAt
ISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.
- Returns:
- ISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.
-
health
The current health status for connectorV2
- Returns:
- The current health status for connectorV2
-
providerDetail
The third-party provider detail for a service configuration.
- Returns:
- The third-party provider detail for a service configuration.
-
enablementStatus
The enablement status of the connector.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector.
- See Also:
-
enablementStatusAsString
The enablement status of the connector.
If the service returns an enum value that is not available in the current SDK version,
enablementStatuswill returnEnablementStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromenablementStatusAsString().- Returns:
- The enablement status of the connector.
- See Also:
-
enablementStatusReason
The reason for the current enablement status. Provides additional context when the connector is in a failed state.
- Returns:
- The reason for the current enablement status. Provides additional context when the connector is in a failed state.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-