Class GetConnectorV2Response
- java.lang.Object
-
- software.amazon.awssdk.core.SdkResponse
-
- software.amazon.awssdk.awscore.AwsResponse
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
-
- software.amazon.awssdk.services.securityhub.model.GetConnectorV2Response
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response>
@Generated("software.amazon.awssdk:codegen") public final class GetConnectorV2Response extends SecurityHubResponse implements ToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGetConnectorV2Response.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static GetConnectorV2Response.Builderbuilder()StringconnectorArn()The Amazon Resource Name (ARN) of the connectorV2.StringconnectorId()The UUID of the connectorV2 to identify connectorV2 resource.InstantcreatedAt()ISO 8601 UTC timestamp for the time create the connectorV2.Stringdescription()The description of the connectorV2.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()HealthCheckhealth()The current health status for connectorV2StringkmsKeyArn()The Amazon Resource Name (ARN) of KMS key used for the connectorV2.InstantlastUpdatedAt()ISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.Stringname()The name of the connectorV2.ProviderDetailproviderDetail()The third-party provider detail for a service configuration.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GetConnectorV2Response.Builder>serializableBuilderClass()GetConnectorV2Response.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadata
-
Methods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponse
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
connectorArn
public final String connectorArn()
The Amazon Resource Name (ARN) of the connectorV2.
- Returns:
- The Amazon Resource Name (ARN) of the connectorV2.
-
connectorId
public final String connectorId()
The UUID of the connectorV2 to identify connectorV2 resource.
- Returns:
- The UUID of the connectorV2 to identify connectorV2 resource.
-
name
public final String name()
The name of the connectorV2.
- Returns:
- The name of the connectorV2.
-
description
public final String description()
The description of the connectorV2.
- Returns:
- The description of the connectorV2.
-
kmsKeyArn
public final String kmsKeyArn()
The Amazon Resource Name (ARN) of KMS key used for the connectorV2.
- Returns:
- The Amazon Resource Name (ARN) of KMS key used for the connectorV2.
-
createdAt
public final Instant createdAt()
ISO 8601 UTC timestamp for the time create the connectorV2.
- Returns:
- ISO 8601 UTC timestamp for the time create the connectorV2.
-
lastUpdatedAt
public final Instant lastUpdatedAt()
ISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.
- Returns:
- ISO 8601 UTC timestamp for the time update the connectorV2 connectorStatus.
-
health
public final HealthCheck health()
The current health status for connectorV2
- Returns:
- The current health status for connectorV2
-
providerDetail
public final ProviderDetail providerDetail()
The third-party provider detail for a service configuration.
- Returns:
- The third-party provider detail for a service configuration.
-
toBuilder
public GetConnectorV2Response.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetConnectorV2Response.Builder,GetConnectorV2Response>- Specified by:
toBuilderin classAwsResponse
-
builder
public static GetConnectorV2Response.Builder builder()
-
serializableBuilderClass
public static Class<? extends GetConnectorV2Response.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsResponse
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-