Class GetFindingHistoryRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetFindingHistoryRequest.Builder,GetFindingHistoryRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final InstantendTime()An ISO 8601-formatted timestamp that indicates the end time of the requested finding history.final booleanfinal booleanequalsBySdkFields(Object obj) Returns the value of the FindingIdentifier property for this object.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of results to be returned.final StringA token for pagination purposes.static Class<? extends GetFindingHistoryRequest.Builder>final InstantA timestamp that indicates the start time of the requested finding history.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
findingIdentifier
Returns the value of the FindingIdentifier property for this object.- Returns:
- The value of the FindingIdentifier property for this object.
-
startTime
A timestamp that indicates the start time of the requested finding history.
If you provide values for both
StartTimeandEndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value forStartTimebut not forEndTime, Security Hub CSPM returns finding history from theStartTimeto the time at which the API is called. If you provide a value forEndTimebut not forStartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to theEndTime. If you provide neitherStartTimenorEndTime, Security Hub CSPM returns finding history from theCreatedAttimestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- A timestamp that indicates the start time of the requested finding history.
If you provide values for both
StartTimeandEndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value forStartTimebut not forEndTime, Security Hub CSPM returns finding history from theStartTimeto the time at which the API is called. If you provide a value forEndTimebut not forStartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to theEndTime. If you provide neitherStartTimenorEndTime, Security Hub CSPM returns finding history from theCreatedAttimestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
endTime
An ISO 8601-formatted timestamp that indicates the end time of the requested finding history.
If you provide values for both
StartTimeandEndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value forStartTimebut not forEndTime, Security Hub CSPM returns finding history from theStartTimeto the time at which the API is called. If you provide a value forEndTimebut not forStartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to theEndTime. If you provide neitherStartTimenorEndTime, Security Hub CSPM returns finding history from theCreatedAttimestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- An ISO 8601-formatted timestamp that indicates the end time of the requested finding history.
If you provide values for both
StartTimeandEndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value forStartTimebut not forEndTime, Security Hub CSPM returns finding history from theStartTimeto the time at which the API is called. If you provide a value forEndTimebut not forStartTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to theEndTime. If you provide neitherStartTimenorEndTime, Security Hub CSPM returns finding history from theCreatedAttimestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
nextToken
A token for pagination purposes. Provide
NULLas the initial value. In subsequent requests, provide the token included in the response to get up to an additional 100 results of finding history. If you don’t provideNextToken, Security Hub CSPM returns up to 100 results of finding history for each request.- Returns:
- A token for pagination purposes. Provide
NULLas the initial value. In subsequent requests, provide the token included in the response to get up to an additional 100 results of finding history. If you don’t provideNextToken, Security Hub CSPM returns up to 100 results of finding history for each request.
-
maxResults
The maximum number of results to be returned. If you don’t provide it, Security Hub CSPM returns up to 100 results of finding history.
- Returns:
- The maximum number of results to be returned. If you don’t provide it, Security Hub CSPM returns up to 100 results of finding history.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetFindingHistoryRequest.Builder,GetFindingHistoryRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-