Class GetFindingHistoryResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
software.amazon.awssdk.services.securityhub.model.GetFindingHistoryResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetFindingHistoryResponse.Builder,GetFindingHistoryResponse>
@Generated("software.amazon.awssdk:codegen")
public final class GetFindingHistoryResponse
extends SecurityHubResponse
implements ToCopyableBuilder<GetFindingHistoryResponse.Builder,GetFindingHistoryResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Records property.final StringA token for pagination purposes.final List<FindingHistoryRecord>records()A list of events that altered the specified finding during the specified time period.static Class<? extends GetFindingHistoryResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasRecords
public final boolean hasRecords()For responses, this returns true if the service returned a value for the Records property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
records
A list of events that altered the specified finding during the specified time period.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasRecords()method.- Returns:
- A list of events that altered the specified finding during the specified time period.
-
nextToken
A token for pagination purposes. Provide this token in the subsequent request to
GetFindingsHistoryto get up to an additional 100 results of history for the same finding that you specified in your initial request.- Returns:
- A token for pagination purposes. Provide this token in the subsequent request to
GetFindingsHistoryto get up to an additional 100 results of history for the same finding that you specified in your initial request.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetFindingHistoryResponse.Builder,GetFindingHistoryResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-