Class GetFindingStatisticsV2Request

    • Method Detail

      • hasGroupByRules

        public final boolean hasGroupByRules()
        For responses, this returns true if the service returned a value for the GroupByRules property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • groupByRules

        public final List<GroupByRule> groupByRules()

        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasGroupByRules() method.

        Returns:
        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
      • sortOrder

        public final SortOrder sortOrder()

        Orders the aggregation count in descending or ascending order. Descending order is the default.

        If the service returns an enum value that is not available in the current SDK version, sortOrder will return SortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from sortOrderAsString().

        Returns:
        Orders the aggregation count in descending or ascending order. Descending order is the default.
        See Also:
        SortOrder
      • sortOrderAsString

        public final String sortOrderAsString()

        Orders the aggregation count in descending or ascending order. Descending order is the default.

        If the service returns an enum value that is not available in the current SDK version, sortOrder will return SortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from sortOrderAsString().

        Returns:
        Orders the aggregation count in descending or ascending order. Descending order is the default.
        See Also:
        SortOrder
      • maxStatisticResults

        public final Integer maxStatisticResults()

        The maximum number of results to be returned.

        Returns:
        The maximum number of results to be returned.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object