Interface GetFindingStatisticsV2Request.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>,SdkBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>,SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- GetFindingStatisticsV2Request
@Mutable @NotThreadSafe public static interface GetFindingStatisticsV2Request.Builder extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description GetFindingStatisticsV2Request.BuildergroupByRules(Collection<GroupByRule> groupByRules)Specifies how security findings should be aggregated and organized in the statistical analysis.GetFindingStatisticsV2Request.BuildergroupByRules(Consumer<GroupByRule.Builder>... groupByRules)Specifies how security findings should be aggregated and organized in the statistical analysis.GetFindingStatisticsV2Request.BuildergroupByRules(GroupByRule... groupByRules)Specifies how security findings should be aggregated and organized in the statistical analysis.GetFindingStatisticsV2Request.BuildermaxStatisticResults(Integer maxStatisticResults)The maximum number of results to be returned.GetFindingStatisticsV2Request.BuilderoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)GetFindingStatisticsV2Request.BuilderoverrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)default GetFindingStatisticsV2Request.Builderscopes(Consumer<FindingScopes.Builder> scopes)Limits the results to findings from specific organizational units or from the delegated administrator's organization.GetFindingStatisticsV2Request.Builderscopes(FindingScopes scopes)Limits the results to findings from specific organizational units or from the delegated administrator's organization.GetFindingStatisticsV2Request.BuildersortOrder(String sortOrder)Orders the aggregation count in descending or ascending order.GetFindingStatisticsV2Request.BuildersortOrder(SortOrder sortOrder)Orders the aggregation count in descending or ascending order.-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
-
-
-
Method Detail
-
groupByRules
GetFindingStatisticsV2Request.Builder groupByRules(Collection<GroupByRule> groupByRules)
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5
groupByfields in a single call.- Parameters:
groupByRules- Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5groupByfields in a single call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
groupByRules
GetFindingStatisticsV2Request.Builder groupByRules(GroupByRule... groupByRules)
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5
groupByfields in a single call.- Parameters:
groupByRules- Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5groupByfields in a single call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
groupByRules
GetFindingStatisticsV2Request.Builder groupByRules(Consumer<GroupByRule.Builder>... groupByRules)
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5
This is a convenience method that creates an instance of thegroupByfields in a single call.GroupByRule.Builderavoiding the need to create one manually viaGroupByRule.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#groupByRules(List.) - Parameters:
groupByRules- a consumer that will call methods onGroupByRule.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#groupByRules(java.util.Collection)
-
scopes
GetFindingStatisticsV2Request.Builder scopes(FindingScopes scopes)
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an
AccessDeniedException.This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in
Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.- Parameters:
scopes- Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive anAccessDeniedException.This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in
Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
scopes
default GetFindingStatisticsV2Request.Builder scopes(Consumer<FindingScopes.Builder> scopes)
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an
AccessDeniedException.This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in
This is a convenience method that creates an instance of theScopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.FindingScopes.Builderavoiding the need to create one manually viaFindingScopes.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toscopes(FindingScopes).- Parameters:
scopes- a consumer that will call methods onFindingScopes.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
scopes(FindingScopes)
-
sortOrder
GetFindingStatisticsV2Request.Builder sortOrder(String sortOrder)
Orders the aggregation count in descending or ascending order. Descending order is the default.
-
sortOrder
GetFindingStatisticsV2Request.Builder sortOrder(SortOrder sortOrder)
Orders the aggregation count in descending or ascending order. Descending order is the default.
-
maxStatisticResults
GetFindingStatisticsV2Request.Builder maxStatisticResults(Integer maxStatisticResults)
The maximum number of results to be returned.
- Parameters:
maxStatisticResults- The maximum number of results to be returned.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetFindingStatisticsV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetFindingStatisticsV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-