Interface GetFindingStatisticsV2Request.Builder

    • Method Detail

      • groupByRules

        GetFindingStatisticsV2Request.Builder groupByRules​(Collection<GroupByRule> groupByRules)

        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

        Parameters:
        groupByRules - Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • groupByRules

        GetFindingStatisticsV2Request.Builder groupByRules​(GroupByRule... groupByRules)

        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

        Parameters:
        groupByRules - Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • groupByRules

        GetFindingStatisticsV2Request.Builder groupByRules​(Consumer<GroupByRule.Builder>... groupByRules)

        Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 groupBy fields in a single call.

        This is a convenience method that creates an instance of the GroupByRule.Builder avoiding the need to create one manually via GroupByRule.builder().

        When the Consumer completes, SdkBuilder.build() is called immediately and its result is passed to #groupByRules(List).

        Parameters:
        groupByRules - a consumer that will call methods on GroupByRule.Builder
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        #groupByRules(java.util.Collection)
      • sortOrder

        GetFindingStatisticsV2Request.Builder sortOrder​(String sortOrder)

        Orders the aggregation count in descending or ascending order. Descending order is the default.

        Parameters:
        sortOrder - Orders the aggregation count in descending or ascending order. Descending order is the default.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        SortOrder, SortOrder
      • sortOrder

        GetFindingStatisticsV2Request.Builder sortOrder​(SortOrder sortOrder)

        Orders the aggregation count in descending or ascending order. Descending order is the default.

        Parameters:
        sortOrder - Orders the aggregation count in descending or ascending order. Descending order is the default.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        SortOrder, SortOrder
      • maxStatisticResults

        GetFindingStatisticsV2Request.Builder maxStatisticResults​(Integer maxStatisticResults)

        The maximum number of results to be returned.

        Parameters:
        maxStatisticResults - The maximum number of results to be returned.
        Returns:
        Returns a reference to this object so that method calls can be chained together.