Interface GetFindingStatisticsV2Request.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>,SdkBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>,SdkPojo,SdkRequest.Builder,SecurityHubRequest.Builder
- Enclosing class:
- GetFindingStatisticsV2Request
@Mutable @NotThreadSafe public static interface GetFindingStatisticsV2Request.Builder extends SecurityHubRequest.Builder, SdkPojo, CopyableBuilder<GetFindingStatisticsV2Request.Builder,GetFindingStatisticsV2Request>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description GetFindingStatisticsV2Request.BuildergroupByRules(Collection<GroupByRule> groupByRules)Specifies how security findings should be aggregated and organized in the statistical analysis.GetFindingStatisticsV2Request.BuildergroupByRules(Consumer<GroupByRule.Builder>... groupByRules)Specifies how security findings should be aggregated and organized in the statistical analysis.GetFindingStatisticsV2Request.BuildergroupByRules(GroupByRule... groupByRules)Specifies how security findings should be aggregated and organized in the statistical analysis.GetFindingStatisticsV2Request.BuildermaxStatisticResults(Integer maxStatisticResults)The maximum number of results to be returned.GetFindingStatisticsV2Request.BuilderoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)GetFindingStatisticsV2Request.BuilderoverrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)GetFindingStatisticsV2Request.BuildersortOrder(String sortOrder)Orders the aggregation count in descending or ascending order.GetFindingStatisticsV2Request.BuildersortOrder(SortOrder sortOrder)Orders the aggregation count in descending or ascending order.-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Methods inherited from interface software.amazon.awssdk.services.securityhub.model.SecurityHubRequest.Builder
build
-
-
-
-
Method Detail
-
groupByRules
GetFindingStatisticsV2Request.Builder groupByRules(Collection<GroupByRule> groupByRules)
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5
groupByfields in a single call.- Parameters:
groupByRules- Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5groupByfields in a single call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
groupByRules
GetFindingStatisticsV2Request.Builder groupByRules(GroupByRule... groupByRules)
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5
groupByfields in a single call.- Parameters:
groupByRules- Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5groupByfields in a single call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
groupByRules
GetFindingStatisticsV2Request.Builder groupByRules(Consumer<GroupByRule.Builder>... groupByRules)
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5
This is a convenience method that creates an instance of thegroupByfields in a single call.GroupByRule.Builderavoiding the need to create one manually viaGroupByRule.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#groupByRules(List.) - Parameters:
groupByRules- a consumer that will call methods onGroupByRule.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#groupByRules(java.util.Collection)
-
sortOrder
GetFindingStatisticsV2Request.Builder sortOrder(String sortOrder)
Orders the aggregation count in descending or ascending order. Descending order is the default.
-
sortOrder
GetFindingStatisticsV2Request.Builder sortOrder(SortOrder sortOrder)
Orders the aggregation count in descending or ascending order. Descending order is the default.
-
maxStatisticResults
GetFindingStatisticsV2Request.Builder maxStatisticResults(Integer maxStatisticResults)
The maximum number of results to be returned.
- Parameters:
maxStatisticResults- The maximum number of results to be returned.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetFindingStatisticsV2Request.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetFindingStatisticsV2Request.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-