Class GetResourcesStatisticsV2Request
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.GetResourcesStatisticsV2Request
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetResourcesStatisticsV2Request.Builder,GetResourcesStatisticsV2Request>
@Generated("software.amazon.awssdk:codegen") public final class GetResourcesStatisticsV2Request extends SecurityHubRequest implements ToCopyableBuilder<GetResourcesStatisticsV2Request.Builder,GetResourcesStatisticsV2Request>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGetResourcesStatisticsV2Request.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static GetResourcesStatisticsV2Request.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)List<ResourceGroupByRule>groupByRules()How resource statistics should be aggregated and organized in the response.booleanhasGroupByRules()For responses, this returns true if the service returned a value for the GroupByRules property.inthashCode()IntegermaxStatisticResults()The maximum number of results to be returned.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GetResourcesStatisticsV2Request.Builder>serializableBuilderClass()SortOrdersortOrder()Sorts aggregated statistics.StringsortOrderAsString()Sorts aggregated statistics.GetResourcesStatisticsV2Request.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
hasGroupByRules
public final boolean hasGroupByRules()
For responses, this returns true if the service returned a value for the GroupByRules property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
groupByRules
public final List<ResourceGroupByRule> groupByRules()
How resource statistics should be aggregated and organized in the response.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasGroupByRules()method.- Returns:
- How resource statistics should be aggregated and organized in the response.
-
sortOrder
public final SortOrder sortOrder()
Sorts aggregated statistics.
If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- Sorts aggregated statistics.
- See Also:
SortOrder
-
sortOrderAsString
public final String sortOrderAsString()
Sorts aggregated statistics.
If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- Sorts aggregated statistics.
- See Also:
SortOrder
-
maxStatisticResults
public final Integer maxStatisticResults()
The maximum number of results to be returned.
- Returns:
- The maximum number of results to be returned.
-
toBuilder
public GetResourcesStatisticsV2Request.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetResourcesStatisticsV2Request.Builder,GetResourcesStatisticsV2Request>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static GetResourcesStatisticsV2Request.Builder builder()
-
serializableBuilderClass
public static Class<? extends GetResourcesStatisticsV2Request.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-