Class GetResourcesV2Request
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final ResourcesFiltersfilters()Filters resources based on a set of criteria.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the SortCriteria property.final IntegerThe maximum number of results to return.final StringThe token required for pagination.final ResourceScopesscopes()Limits the results to resources from specific organizational units or from the delegated administrator's organization.static Class<? extends GetResourcesV2Request.Builder>final List<SortCriterion>The resource attributes used to sort the list of returned resources.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
filters
Filters resources based on a set of criteria.
- Returns:
- Filters resources based on a set of criteria.
-
scopes
Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an
AccessDeniedException.This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.
You can specify up to 10 entries in
Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.- Returns:
- Limits the results to resources from specific organizational units or from the delegated administrator's
organization. Only the delegated administrator account can use this parameter. Other accounts receive an
AccessDeniedException.This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.
You can specify up to 10 entries in
Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.
-
hasSortCriteria
public final boolean hasSortCriteria()For responses, this returns true if the service returned a value for the SortCriteria property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
sortCriteria
The resource attributes used to sort the list of returned resources.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSortCriteria()method.- Returns:
- The resource attributes used to sort the list of returned resources.
-
nextToken
The token required for pagination. On your first call, set the value of this parameter to
NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.- Returns:
- The token required for pagination. On your first call, set the value of this parameter to
NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
-
maxResults
The maximum number of results to return.
- Returns:
- The maximum number of results to return.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-