Class GetResourcesV2Request

    • Method Detail

      • filters

        public final ResourcesFilters filters()

        Filters resources based on a set of criteria.

        Returns:
        Filters resources based on a set of criteria.
      • hasSortCriteria

        public final boolean hasSortCriteria()
        For responses, this returns true if the service returned a value for the SortCriteria property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • sortCriteria

        public final List<SortCriterion> sortCriteria()

        The finding attributes used to sort the list of returned findings.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasSortCriteria() method.

        Returns:
        The finding attributes used to sort the list of returned findings.
      • nextToken

        public final String nextToken()

        The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

        Returns:
        The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
      • maxResults

        public final Integer maxResults()

        The maximum number of results to return.

        Returns:
        The maximum number of results to return.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object