Class GetResourcesV2Request
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.GetResourcesV2Request
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request>
@Generated("software.amazon.awssdk:codegen") public final class GetResourcesV2Request extends SecurityHubRequest implements ToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGetResourcesV2Request.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static GetResourcesV2Request.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)ResourcesFiltersfilters()Filters resources based on a set of criteria.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()booleanhasSortCriteria()For responses, this returns true if the service returned a value for the SortCriteria property.IntegermaxResults()The maximum number of results to return.StringnextToken()The token required for pagination.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GetResourcesV2Request.Builder>serializableBuilderClass()List<SortCriterion>sortCriteria()The finding attributes used to sort the list of returned findings.GetResourcesV2Request.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
filters
public final ResourcesFilters filters()
Filters resources based on a set of criteria.
- Returns:
- Filters resources based on a set of criteria.
-
hasSortCriteria
public final boolean hasSortCriteria()
For responses, this returns true if the service returned a value for the SortCriteria property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
sortCriteria
public final List<SortCriterion> sortCriteria()
The finding attributes used to sort the list of returned findings.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSortCriteria()method.- Returns:
- The finding attributes used to sort the list of returned findings.
-
nextToken
public final String nextToken()
The token required for pagination. On your first call, set the value of this parameter to
NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.- Returns:
- The token required for pagination. On your first call, set the value of this parameter to
NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
-
maxResults
public final Integer maxResults()
The maximum number of results to return.
- Returns:
- The maximum number of results to return.
-
toBuilder
public GetResourcesV2Request.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetResourcesV2Request.Builder,GetResourcesV2Request>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static GetResourcesV2Request.Builder builder()
-
serializableBuilderClass
public static Class<? extends GetResourcesV2Request.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-