Enum GroupByField

    • Enum Constant Detail

      • ACTIVITY_NAME

        public static final GroupByField ACTIVITY_NAME
      • CLOUD_ACCOUNT_UID

        public static final GroupByField CLOUD_ACCOUNT_UID
      • CLOUD_PROVIDER

        public static final GroupByField CLOUD_PROVIDER
      • CLOUD_REGION

        public static final GroupByField CLOUD_REGION
      • COMPLIANCE_ASSESSMENTS_NAME

        public static final GroupByField COMPLIANCE_ASSESSMENTS_NAME
      • COMPLIANCE_STATUS

        public static final GroupByField COMPLIANCE_STATUS
      • COMPLIANCE_CONTROL

        public static final GroupByField COMPLIANCE_CONTROL
      • FINDING_INFO_TITLE

        public static final GroupByField FINDING_INFO_TITLE
      • FINDING_INFO_RELATED_EVENTS_TRAITS_CATEGORY

        public static final GroupByField FINDING_INFO_RELATED_EVENTS_TRAITS_CATEGORY
      • FINDING_INFO_TYPES

        public static final GroupByField FINDING_INFO_TYPES
      • METADATA_PRODUCT_NAME

        public static final GroupByField METADATA_PRODUCT_NAME
      • METADATA_PRODUCT_UID

        public static final GroupByField METADATA_PRODUCT_UID
      • RESOURCES_TYPE

        public static final GroupByField RESOURCES_TYPE
      • RESOURCES_UID

        public static final GroupByField RESOURCES_UID
      • VULNERABILITIES_FIX_COVERAGE

        public static final GroupByField VULNERABILITIES_FIX_COVERAGE
      • VULNERABILITIES_AFFECTED_PACKAGES_NAME

        public static final GroupByField VULNERABILITIES_AFFECTED_PACKAGES_NAME
      • FINDING_INFO_ANALYTIC_NAME

        public static final GroupByField FINDING_INFO_ANALYTIC_NAME
      • COMPLIANCE_STANDARDS

        public static final GroupByField COMPLIANCE_STANDARDS
      • CLOUD_ACCOUNT_NAME

        public static final GroupByField CLOUD_ACCOUNT_NAME
      • VENDOR_ATTRIBUTES_SEVERITY

        public static final GroupByField VENDOR_ATTRIBUTES_SEVERITY
      • METADATA_PRODUCT_VENDOR_NAME

        public static final GroupByField METADATA_PRODUCT_VENDOR_NAME
      • UNKNOWN_TO_SDK_VERSION

        public static final GroupByField UNKNOWN_TO_SDK_VERSION
    • Method Detail

      • values

        public static GroupByField[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (GroupByField c : GroupByField.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static GroupByField valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • fromValue

        public static GroupByField fromValue​(String value)
        Use this in place of valueOf to convert the raw string returned by the service into the enum value.
        Parameters:
        value - real value
        Returns:
        GroupByField corresponding to the value