Class GroupByResult
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.GroupByResult
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<GroupByResult.Builder,GroupByResult>
@Generated("software.amazon.awssdk:codegen") public final class GroupByResult extends Object implements SdkPojo, Serializable, ToCopyableBuilder<GroupByResult.Builder,GroupByResult>
Represents finding statistics grouped by
GroupedByField.- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGroupByResult.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static GroupByResult.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)StringgroupByField()The attribute by which filtered security findings should be grouped.List<GroupByValue>groupByValues()An array of grouped values and their respective counts for eachGroupByField.booleanhasGroupByValues()For responses, this returns true if the service returned a value for the GroupByValues property.inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GroupByResult.Builder>serializableBuilderClass()GroupByResult.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
groupByField
public final String groupByField()
The attribute by which filtered security findings should be grouped.
- Returns:
- The attribute by which filtered security findings should be grouped.
-
hasGroupByValues
public final boolean hasGroupByValues()
For responses, this returns true if the service returned a value for the GroupByValues property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
groupByValues
public final List<GroupByValue> groupByValues()
An array of grouped values and their respective counts for each
GroupByField.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasGroupByValues()method.- Returns:
- An array of grouped values and their respective counts for each
GroupByField.
-
toBuilder
public GroupByResult.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GroupByResult.Builder,GroupByResult>
-
builder
public static GroupByResult.Builder builder()
-
serializableBuilderClass
public static Class<? extends GroupByResult.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-