Class GroupByRule
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.GroupByRule
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<GroupByRule.Builder,GroupByRule>
@Generated("software.amazon.awssdk:codegen") public final class GroupByRule extends Object implements SdkPojo, Serializable, ToCopyableBuilder<GroupByRule.Builder,GroupByRule>
Defines the how the finding attribute should be grouped.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceGroupByRule.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static GroupByRule.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)OcsfFindingFiltersfilters()The criteria used to select which security findings should be included in the grouping operation.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)GroupByFieldgroupByField()The attribute by which filtered findings should be grouped.StringgroupByFieldAsString()The attribute by which filtered findings should be grouped.inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends GroupByRule.Builder>serializableBuilderClass()GroupByRule.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
filters
public final OcsfFindingFilters filters()
The criteria used to select which security findings should be included in the grouping operation.
- Returns:
- The criteria used to select which security findings should be included in the grouping operation.
-
groupByField
public final GroupByField groupByField()
The attribute by which filtered findings should be grouped.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- The attribute by which filtered findings should be grouped.
- See Also:
GroupByField
-
groupByFieldAsString
public final String groupByFieldAsString()
The attribute by which filtered findings should be grouped.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- The attribute by which filtered findings should be grouped.
- See Also:
GroupByField
-
toBuilder
public GroupByRule.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<GroupByRule.Builder,GroupByRule>
-
builder
public static GroupByRule.Builder builder()
-
serializableBuilderClass
public static Class<? extends GroupByRule.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-