Interface GroupByValue.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<GroupByValue.Builder,GroupByValue>,SdkBuilder<GroupByValue.Builder,GroupByValue>,SdkPojo
- Enclosing class:
- GroupByValue
@Mutable @NotThreadSafe public static interface GroupByValue.Builder extends SdkPojo, CopyableBuilder<GroupByValue.Builder,GroupByValue>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description GroupByValue.Buildercount(Integer count)The number of findings for a specificFieldValueandGroupByField.GroupByValue.BuilderfieldValue(String fieldValue)The value of the field by which findings are grouped.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
fieldValue
GroupByValue.Builder fieldValue(String fieldValue)
The value of the field by which findings are grouped.
- Parameters:
fieldValue- The value of the field by which findings are grouped.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
count
GroupByValue.Builder count(Integer count)
The number of findings for a specific
FieldValueandGroupByField.- Parameters:
count- The number of findings for a specificFieldValueandGroupByField.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-