Interface HealthCheck.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<HealthCheck.Builder,HealthCheck>,SdkBuilder<HealthCheck.Builder,HealthCheck>,SdkPojo
- Enclosing class:
- HealthCheck
@Mutable @NotThreadSafe public static interface HealthCheck.Builder extends SdkPojo, CopyableBuilder<HealthCheck.Builder,HealthCheck>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description HealthCheck.BuilderconnectorStatus(String connectorStatus)The status of the connectorV2.HealthCheck.BuilderconnectorStatus(ConnectorStatus connectorStatus)The status of the connectorV2.HealthCheck.BuilderlastCheckedAt(Instant lastCheckedAt)ISO 8601 UTC timestamp for the time check the health status of the connectorV2.HealthCheck.Buildermessage(String message)The message for the reason of connectorStatus change.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
connectorStatus
HealthCheck.Builder connectorStatus(String connectorStatus)
The status of the connectorV2.
- Parameters:
connectorStatus- The status of the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ConnectorStatus,ConnectorStatus
-
connectorStatus
HealthCheck.Builder connectorStatus(ConnectorStatus connectorStatus)
The status of the connectorV2.
- Parameters:
connectorStatus- The status of the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ConnectorStatus,ConnectorStatus
-
message
HealthCheck.Builder message(String message)
The message for the reason of connectorStatus change.
- Parameters:
message- The message for the reason of connectorStatus change.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
lastCheckedAt
HealthCheck.Builder lastCheckedAt(Instant lastCheckedAt)
ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
- Parameters:
lastCheckedAt- ISO 8601 UTC timestamp for the time check the health status of the connectorV2.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-