Class Insight
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Insight
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Insight.Builder,Insight>
@Generated("software.amazon.awssdk:codegen")
public final class Insight
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Insight.Builder,Insight>
Contains information about a Security Hub CSPM insight.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Insight.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) filters()One or more attributes used to filter the findings included in the insight.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe grouping attribute for the insight's findings.final inthashCode()final StringThe ARN of a Security Hub CSPM insight.final Stringname()The name of a Security Hub CSPM insight.static Class<? extends Insight.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
insightArn
The ARN of a Security Hub CSPM insight.
- Returns:
- The ARN of a Security Hub CSPM insight.
-
name
The name of a Security Hub CSPM insight.
- Returns:
- The name of a Security Hub CSPM insight.
-
filters
One or more attributes used to filter the findings included in the insight. You can filter by up to ten finding attributes. For each attribute, you can provide up to 20 filter values. The insight only includes findings that match the criteria defined in the filters.
- Returns:
- One or more attributes used to filter the findings included in the insight. You can filter by up to ten finding attributes. For each attribute, you can provide up to 20 filter values. The insight only includes findings that match the criteria defined in the filters.
-
groupByAttribute
The grouping attribute for the insight's findings. Indicates how to group the matching findings, and identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.
- Returns:
- The grouping attribute for the insight's findings. Indicates how to group the matching findings, and identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Insight.Builder,Insight>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-