Class ListConfigurationPolicyAssociationsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListConfigurationPolicyAssociationsRequest.Builder,ListConfigurationPolicyAssociationsRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final AssociationFiltersfilters()Options for filtering theListConfigurationPolicyAssociationsresponse.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of results that's returned byListConfigurationPoliciesin each page of the response.final StringTheNextTokenvalue that's returned from a previous paginatedListConfigurationPolicyAssociationsrequest whereMaxResultswas used but the results exceeded the value of that parameter.static Class<? extends ListConfigurationPolicyAssociationsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
nextToken
The
NextTokenvalue that's returned from a previous paginatedListConfigurationPolicyAssociationsrequest whereMaxResultswas used but the results exceeded the value of that parameter. Pagination continues from the end of the previous response that returned theNextTokenvalue. This value isnullwhen there are no more results to return.- Returns:
- The
NextTokenvalue that's returned from a previous paginatedListConfigurationPolicyAssociationsrequest whereMaxResultswas used but the results exceeded the value of that parameter. Pagination continues from the end of the previous response that returned theNextTokenvalue. This value isnullwhen there are no more results to return.
-
maxResults
The maximum number of results that's returned by
ListConfigurationPoliciesin each page of the response. When this parameter is used,ListConfigurationPolicyAssociationsreturns the specified number of results in a single page and aNextTokenresponse element. You can see the remaining results of the initial request by sending anotherListConfigurationPolicyAssociationsrequest with the returnedNextTokenvalue. A valid range forMaxResultsis between 1 and 100.- Returns:
- The maximum number of results that's returned by
ListConfigurationPoliciesin each page of the response. When this parameter is used,ListConfigurationPolicyAssociationsreturns the specified number of results in a single page and aNextTokenresponse element. You can see the remaining results of the initial request by sending anotherListConfigurationPolicyAssociationsrequest with the returnedNextTokenvalue. A valid range forMaxResultsis between 1 and 100.
-
filters
Options for filtering the
ListConfigurationPolicyAssociationsresponse. You can filter by the Amazon Resource Name (ARN) or universally unique identifier (UUID) of a configuration,AssociationType, orAssociationStatus.- Returns:
- Options for filtering the
ListConfigurationPolicyAssociationsresponse. You can filter by the Amazon Resource Name (ARN) or universally unique identifier (UUID) of a configuration,AssociationType, orAssociationStatus.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListConfigurationPolicyAssociationsRequest.Builder,ListConfigurationPolicyAssociationsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends ListConfigurationPolicyAssociationsRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-