Class ListInvitationsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
software.amazon.awssdk.services.securityhub.model.ListInvitationsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListInvitationsRequest.Builder,ListInvitationsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class ListInvitationsRequest
extends SecurityHubRequest
implements ToCopyableBuilder<ListInvitationsRequest.Builder,ListInvitationsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of items to return in the response.final StringThe token that is required for pagination.static Class<? extends ListInvitationsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
maxResults
The maximum number of items to return in the response.
- Returns:
- The maximum number of items to return in the response.
-
nextToken
The token that is required for pagination. On your first call to the
ListInvitationsoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
- Returns:
- The token that is required for pagination. On your first call to the
ListInvitationsoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListInvitationsRequest.Builder,ListInvitationsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-