Class ListMembersRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListMembersRequest.Builder,ListMembersRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ListMembersRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of items to return in the response.final StringThe token that is required for pagination.final BooleanSpecifies which member accounts to include in the response based on their relationship status with the administrator account.static Class<? extends ListMembersRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
onlyAssociated
Specifies which member accounts to include in the response based on their relationship status with the administrator account. The default value is
TRUE.If
OnlyAssociatedis set toTRUE, the response includes member accounts whose relationship status with the administrator account is set toENABLED.If
OnlyAssociatedis set toFALSE, the response includes all existing member accounts.- Returns:
- Specifies which member accounts to include in the response based on their relationship status with the
administrator account. The default value is
TRUE.If
OnlyAssociatedis set toTRUE, the response includes member accounts whose relationship status with the administrator account is set toENABLED.If
OnlyAssociatedis set toFALSE, the response includes all existing member accounts.
-
maxResults
The maximum number of items to return in the response.
- Returns:
- The maximum number of items to return in the response.
-
nextToken
The token that is required for pagination. On your first call to the
ListMembersoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
- Returns:
- The token that is required for pagination. On your first call to the
ListMembersoperation, set the value of this parameter toNULL.For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListMembersRequest.Builder,ListMembersRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-