Class ListOrganizationAdminAccountsRequest
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.ListOrganizationAdminAccountsRequest
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListOrganizationAdminAccountsRequest.Builder,ListOrganizationAdminAccountsRequest>
@Generated("software.amazon.awssdk:codegen") public final class ListOrganizationAdminAccountsRequest extends SecurityHubRequest implements ToCopyableBuilder<ListOrganizationAdminAccountsRequest.Builder,ListOrganizationAdminAccountsRequest>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceListOrganizationAdminAccountsRequest.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ListOrganizationAdminAccountsRequest.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)SecurityHubFeaturefeature()The feature where the delegated administrator account is listed.StringfeatureAsString()The feature where the delegated administrator account is listed.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()IntegermaxResults()The maximum number of items to return in the response.StringnextToken()The token that is required for pagination.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ListOrganizationAdminAccountsRequest.Builder>serializableBuilderClass()ListOrganizationAdminAccountsRequest.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
maxResults
public final Integer maxResults()
The maximum number of items to return in the response.
- Returns:
- The maximum number of items to return in the response.
-
nextToken
public final String nextToken()
The token that is required for pagination. On your first call to the
ListOrganizationAdminAccountsoperation, set the value of this parameter toNULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.- Returns:
- The token that is required for pagination. On your first call to the
ListOrganizationAdminAccountsoperation, set the value of this parameter toNULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
-
feature
public final SecurityHubFeature feature()
The feature where the delegated administrator account is listed. Defaults to Security Hub if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature where the delegated administrator account is listed. Defaults to Security Hub if not specified.
- See Also:
SecurityHubFeature
-
featureAsString
public final String featureAsString()
The feature where the delegated administrator account is listed. Defaults to Security Hub if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature where the delegated administrator account is listed. Defaults to Security Hub if not specified.
- See Also:
SecurityHubFeature
-
toBuilder
public ListOrganizationAdminAccountsRequest.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListOrganizationAdminAccountsRequest.Builder,ListOrganizationAdminAccountsRequest>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static ListOrganizationAdminAccountsRequest.Builder builder()
-
serializableBuilderClass
public static Class<? extends ListOrganizationAdminAccountsRequest.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-