Class ListOrganizationAdminAccountsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListOrganizationAdminAccountsResponse.Builder,ListOrganizationAdminAccountsResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal List<AdminAccount>The list of Security Hub CSPM administrator accounts.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final SecurityHubFeaturefeature()The feature where the delegated administrator account is listed.final StringThe feature where the delegated administrator account is listed.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the AdminAccounts property.final inthashCode()final StringThe pagination token to use to request the next page of results.static Class<? extends ListOrganizationAdminAccountsResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.securityhub.model.SecurityHubResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasAdminAccounts
public final boolean hasAdminAccounts()For responses, this returns true if the service returned a value for the AdminAccounts property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
adminAccounts
The list of Security Hub CSPM administrator accounts.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAdminAccounts()method.- Returns:
- The list of Security Hub CSPM administrator accounts.
-
nextToken
The pagination token to use to request the next page of results.
- Returns:
- The pagination token to use to request the next page of results.
-
feature
The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.
- See Also:
-
featureAsString
The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.
If the service returns an enum value that is not available in the current SDK version,
featurewill returnSecurityHubFeature.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfeatureAsString().- Returns:
- The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM CSPM if not specified.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListOrganizationAdminAccountsResponse.Builder,ListOrganizationAdminAccountsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends ListOrganizationAdminAccountsResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-