Class ListSecurityControlDefinitionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Providers property.final IntegerAn optional parameter that limits the total results of the API response to the specified number.final StringOptional pagination parameter.final List<SecurityControlsProvider>A list of cloud providers to filter the security control definitions by.A list of cloud providers to filter the security control definitions by.static Class<? extends ListSecurityControlDefinitionsRequest.Builder>final StringThe Amazon Resource Name (ARN) of the standard that you want to view controls for.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsArn
The Amazon Resource Name (ARN) of the standard that you want to view controls for.
- Returns:
- The Amazon Resource Name (ARN) of the standard that you want to view controls for.
-
nextToken
Optional pagination parameter.
- Returns:
- Optional pagination parameter.
-
maxResults
An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a
NextTokenparameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.- Returns:
- An optional parameter that limits the total results of the API response to the specified number. If this
parameter isn't provided in the request, the results include the first 25 security controls that apply to
the specified standard. The results also include a
NextTokenparameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.
-
providers
A list of cloud providers to filter the security control definitions by. For example, specify
Azureto return only controls that evaluate Azure resources.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasProviders()method.- Returns:
- A list of cloud providers to filter the security control definitions by. For example, specify
Azureto return only controls that evaluate Azure resources.
-
hasProviders
public final boolean hasProviders()For responses, this returns true if the service returned a value for the Providers property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
providersAsStrings
A list of cloud providers to filter the security control definitions by. For example, specify
Azureto return only controls that evaluate Azure resources.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasProviders()method.- Returns:
- A list of cloud providers to filter the security control definitions by. For example, specify
Azureto return only controls that evaluate Azure resources.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends ListSecurityControlDefinitionsRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-