Class ListSecurityControlDefinitionsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListSecurityControlDefinitionsRequest extends SecurityHubRequest implements ToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>
  • Method Details

    • standardsArn

      public final String standardsArn()

      The Amazon Resource Name (ARN) of the standard that you want to view controls for.

      Returns:
      The Amazon Resource Name (ARN) of the standard that you want to view controls for.
    • nextToken

      public final String nextToken()

      Optional pagination parameter.

      Returns:
      Optional pagination parameter.
    • maxResults

      public final Integer maxResults()

      An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.

      Returns:
      An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListSecurityControlDefinitionsRequest.Builder,ListSecurityControlDefinitionsRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends ListSecurityControlDefinitionsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo