Class ListStandardsControlAssociationsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListStandardsControlAssociationsRequest.Builder,ListStandardsControlAssociationsRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListStandardsControlAssociationsRequest extends SecurityHubRequest implements ToCopyableBuilder<ListStandardsControlAssociationsRequest.Builder,ListStandardsControlAssociationsRequest>
  • Method Details

    • securityControlId

      public final String securityControlId()

      The identifier of the control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.

      Returns:
      The identifier of the control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.
    • nextToken

      public final String nextToken()

      Optional pagination parameter.

      Returns:
      Optional pagination parameter.
    • maxResults

      public final Integer maxResults()

      An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 standard and control associations. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 associations. This repeats until all associations for the specified control are returned. The number of results is limited by the number of supported Security Hub CSPM standards that you've enabled in the calling account.

      Returns:
      An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 standard and control associations. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 associations. This repeats until all associations for the specified control are returned. The number of results is limited by the number of supported Security Hub CSPM standards that you've enabled in the calling account.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListStandardsControlAssociationsRequest.Builder,ListStandardsControlAssociationsRequest>
      Specified by:
      toBuilder in class SecurityHubRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends ListStandardsControlAssociationsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo