Class NetworkAutonomousSystem
java.lang.Object
software.amazon.awssdk.services.securityhub.model.NetworkAutonomousSystem
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>
@Generated("software.amazon.awssdk:codegen")
public final class NetworkAutonomousSystem
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>
Contains information about the Autonomous System (AS) of the network endpoints involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name associated with the AS.final Integernumber()The unique number that identifies the AS.static Class<? extends NetworkAutonomousSystem.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name associated with the AS.
- Returns:
- The name associated with the AS.
-
number
The unique number that identifies the AS.
- Returns:
- The unique number that identifies the AS.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<NetworkAutonomousSystem.Builder,NetworkAutonomousSystem>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-