Class NetworkGeoLocation
java.lang.Object
software.amazon.awssdk.services.securityhub.model.NetworkGeoLocation
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>
@Generated("software.amazon.awssdk:codegen")
public final class NetworkGeoLocation
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>
Contains information about the location of a network endpoint involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic NetworkGeoLocation.Builderbuilder()final Stringcity()The name of the city.final Stringcountry()The name of the country.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Doublelat()The latitude information of the endpoint location.final Doublelon()The longitude information of the endpoint location.static Class<? extends NetworkGeoLocation.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
city
The name of the city.
- Returns:
- The name of the city.
-
country
The name of the country.
- Returns:
- The name of the country.
-
lat
The latitude information of the endpoint location.
- Returns:
- The latitude information of the endpoint location.
-
lon
The longitude information of the endpoint location.
- Returns:
- The longitude information of the endpoint location.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<NetworkGeoLocation.Builder,NetworkGeoLocation>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-