Enum OcsfMapField
- java.lang.Object
-
- java.lang.Enum<OcsfMapField>
-
- software.amazon.awssdk.services.securityhub.model.OcsfMapField
-
- All Implemented Interfaces:
Serializable,Comparable<OcsfMapField>
@Generated("software.amazon.awssdk:codegen") public enum OcsfMapField extends Enum<OcsfMapField>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description COMPLIANCE_CONTROL_PARAMETERSDATABUCKET_TAGSFINDING_INFO_TAGSRESOURCES_TAGSUNKNOWN_TO_SDK_VERSION
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static OcsfMapFieldfromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static Set<OcsfMapField>knownValues()StringtoString()static OcsfMapFieldvalueOf(String name)Returns the enum constant of this type with the specified name.static OcsfMapField[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
RESOURCES_TAGS
public static final OcsfMapField RESOURCES_TAGS
-
COMPLIANCE_CONTROL_PARAMETERS
public static final OcsfMapField COMPLIANCE_CONTROL_PARAMETERS
-
DATABUCKET_TAGS
public static final OcsfMapField DATABUCKET_TAGS
-
FINDING_INFO_TAGS
public static final OcsfMapField FINDING_INFO_TAGS
-
UNKNOWN_TO_SDK_VERSION
public static final OcsfMapField UNKNOWN_TO_SDK_VERSION
-
-
Method Detail
-
values
public static OcsfMapField[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (OcsfMapField c : OcsfMapField.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static OcsfMapField valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toString
public String toString()
- Overrides:
toStringin classEnum<OcsfMapField>
-
fromValue
public static OcsfMapField fromValue(String value)
Use this in place of valueOf to convert the raw string returned by the service into the enum value.- Parameters:
value- real value- Returns:
- OcsfMapField corresponding to the value
-
knownValues
public static Set<OcsfMapField> knownValues()
Use this in place ofvalues()to return aSetof all values known to the SDK. This will return all known enum values exceptUNKNOWN_TO_SDK_VERSION.- Returns:
- a
Setof knownOcsfMapFields
-
-