Class ProviderConfiguration
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ProviderConfiguration
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>
@Generated("software.amazon.awssdk:codegen") public final class ProviderConfiguration extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>
The initial configuration settings required to establish an integration between Security Hub and third-party provider.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceProviderConfiguration.Builderstatic classProviderConfiguration.Type
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ProviderConfiguration.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)static ProviderConfigurationfromJiraCloud(Consumer<JiraCloudProviderConfiguration.Builder> jiraCloud)Create an instance of this class withjiraCloud()initialized to the given value.static ProviderConfigurationfromJiraCloud(JiraCloudProviderConfiguration jiraCloud)Create an instance of this class withjiraCloud()initialized to the given value.static ProviderConfigurationfromServiceNow(Consumer<ServiceNowProviderConfiguration.Builder> serviceNow)Create an instance of this class withserviceNow()initialized to the given value.static ProviderConfigurationfromServiceNow(ServiceNowProviderConfiguration serviceNow)Create an instance of this class withserviceNow()initialized to the given value.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()JiraCloudProviderConfigurationjiraCloud()The configuration settings required to establish an integration with Jira Cloud.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ProviderConfiguration.Builder>serializableBuilderClass()ServiceNowProviderConfigurationserviceNow()The configuration settings required to establish an integration with ServiceNow ITSM.ProviderConfiguration.BuildertoBuilder()StringtoString()Returns a string representation of this object.ProviderConfiguration.Typetype()Retrieve an enum value representing which member of this object is populated.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
jiraCloud
public final JiraCloudProviderConfiguration jiraCloud()
The configuration settings required to establish an integration with Jira Cloud.
- Returns:
- The configuration settings required to establish an integration with Jira Cloud.
-
serviceNow
public final ServiceNowProviderConfiguration serviceNow()
The configuration settings required to establish an integration with ServiceNow ITSM.
- Returns:
- The configuration settings required to establish an integration with ServiceNow ITSM.
-
toBuilder
public ProviderConfiguration.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProviderConfiguration.Builder,ProviderConfiguration>
-
builder
public static ProviderConfiguration.Builder builder()
-
serializableBuilderClass
public static Class<? extends ProviderConfiguration.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
fromJiraCloud
public static ProviderConfiguration fromJiraCloud(JiraCloudProviderConfiguration jiraCloud)
Create an instance of this class withjiraCloud()initialized to the given value.The configuration settings required to establish an integration with Jira Cloud.
- Parameters:
jiraCloud- The configuration settings required to establish an integration with Jira Cloud.
-
fromJiraCloud
public static ProviderConfiguration fromJiraCloud(Consumer<JiraCloudProviderConfiguration.Builder> jiraCloud)
Create an instance of this class withjiraCloud()initialized to the given value.The configuration settings required to establish an integration with Jira Cloud.
- Parameters:
jiraCloud- The configuration settings required to establish an integration with Jira Cloud.
-
fromServiceNow
public static ProviderConfiguration fromServiceNow(ServiceNowProviderConfiguration serviceNow)
Create an instance of this class withserviceNow()initialized to the given value.The configuration settings required to establish an integration with ServiceNow ITSM.
- Parameters:
serviceNow- The configuration settings required to establish an integration with ServiceNow ITSM.
-
fromServiceNow
public static ProviderConfiguration fromServiceNow(Consumer<ServiceNowProviderConfiguration.Builder> serviceNow)
Create an instance of this class withserviceNow()initialized to the given value.The configuration settings required to establish an integration with ServiceNow ITSM.
- Parameters:
serviceNow- The configuration settings required to establish an integration with ServiceNow ITSM.
-
type
public ProviderConfiguration.Type type()
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beProviderConfiguration.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beProviderConfiguration.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-