Class ProviderDetail
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ProviderDetail
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProviderDetail.Builder,ProviderDetail>
@Generated("software.amazon.awssdk:codegen") public final class ProviderDetail extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ProviderDetail.Builder,ProviderDetail>
The third-party provider detail for a service configuration.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceProviderDetail.Builderstatic classProviderDetail.Type
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ProviderDetail.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)static ProviderDetailfromJiraCloud(Consumer<JiraCloudDetail.Builder> jiraCloud)Create an instance of this class withjiraCloud()initialized to the given value.static ProviderDetailfromJiraCloud(JiraCloudDetail jiraCloud)Create an instance of this class withjiraCloud()initialized to the given value.static ProviderDetailfromServiceNow(Consumer<ServiceNowDetail.Builder> serviceNow)Create an instance of this class withserviceNow()initialized to the given value.static ProviderDetailfromServiceNow(ServiceNowDetail serviceNow)Create an instance of this class withserviceNow()initialized to the given value.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()JiraCloudDetailjiraCloud()Details about a Jira Cloud integration.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ProviderDetail.Builder>serializableBuilderClass()ServiceNowDetailserviceNow()Details about a ServiceNow ITSM integration.ProviderDetail.BuildertoBuilder()StringtoString()Returns a string representation of this object.ProviderDetail.Typetype()Retrieve an enum value representing which member of this object is populated.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
jiraCloud
public final JiraCloudDetail jiraCloud()
Details about a Jira Cloud integration.
- Returns:
- Details about a Jira Cloud integration.
-
serviceNow
public final ServiceNowDetail serviceNow()
Details about a ServiceNow ITSM integration.
- Returns:
- Details about a ServiceNow ITSM integration.
-
toBuilder
public ProviderDetail.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProviderDetail.Builder,ProviderDetail>
-
builder
public static ProviderDetail.Builder builder()
-
serializableBuilderClass
public static Class<? extends ProviderDetail.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
fromJiraCloud
public static ProviderDetail fromJiraCloud(JiraCloudDetail jiraCloud)
Create an instance of this class withjiraCloud()initialized to the given value.Details about a Jira Cloud integration.
- Parameters:
jiraCloud- Details about a Jira Cloud integration.
-
fromJiraCloud
public static ProviderDetail fromJiraCloud(Consumer<JiraCloudDetail.Builder> jiraCloud)
Create an instance of this class withjiraCloud()initialized to the given value.Details about a Jira Cloud integration.
- Parameters:
jiraCloud- Details about a Jira Cloud integration.
-
fromServiceNow
public static ProviderDetail fromServiceNow(ServiceNowDetail serviceNow)
Create an instance of this class withserviceNow()initialized to the given value.Details about a ServiceNow ITSM integration.
- Parameters:
serviceNow- Details about a ServiceNow ITSM integration.
-
fromServiceNow
public static ProviderDetail fromServiceNow(Consumer<ServiceNowDetail.Builder> serviceNow)
Create an instance of this class withserviceNow()initialized to the given value.Details about a ServiceNow ITSM integration.
- Parameters:
serviceNow- Details about a ServiceNow ITSM integration.
-
type
public ProviderDetail.Type type()
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beProviderDetail.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beProviderDetail.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-