Class ProviderSummary
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ProviderSummary
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProviderSummary.Builder,ProviderSummary>
@Generated("software.amazon.awssdk:codegen") public final class ProviderSummary extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ProviderSummary.Builder,ProviderSummary>
The connectorV2 third-party provider configuration summary.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceProviderSummary.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ProviderSummary.Builderbuilder()ConnectorStatusconnectorStatus()The status for the connectorV2.StringconnectorStatusAsString()The status for the connectorV2.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()ConnectorProviderNameproviderName()The name of the provider.StringproviderNameAsString()The name of the provider.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ProviderSummary.Builder>serializableBuilderClass()ProviderSummary.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
providerName
public final ConnectorProviderName providerName()
The name of the provider.
If the service returns an enum value that is not available in the current SDK version,
providerNamewill returnConnectorProviderName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromproviderNameAsString().- Returns:
- The name of the provider.
- See Also:
ConnectorProviderName
-
providerNameAsString
public final String providerNameAsString()
The name of the provider.
If the service returns an enum value that is not available in the current SDK version,
providerNamewill returnConnectorProviderName.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromproviderNameAsString().- Returns:
- The name of the provider.
- See Also:
ConnectorProviderName
-
connectorStatus
public final ConnectorStatus connectorStatus()
The status for the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status for the connectorV2.
- See Also:
ConnectorStatus
-
connectorStatusAsString
public final String connectorStatusAsString()
The status for the connectorV2.
If the service returns an enum value that is not available in the current SDK version,
connectorStatuswill returnConnectorStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromconnectorStatusAsString().- Returns:
- The status for the connectorV2.
- See Also:
ConnectorStatus
-
toBuilder
public ProviderSummary.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProviderSummary.Builder,ProviderSummary>
-
builder
public static ProviderSummary.Builder builder()
-
serializableBuilderClass
public static Class<? extends ProviderSummary.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-