Class Record
java.lang.Object
software.amazon.awssdk.services.securityhub.model.Record
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Record.Builder,Record>
@Generated("software.amazon.awssdk:codegen")
public final class Record
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<Record.Builder,Record>
An occurrence of sensitive data in an Apache Avro object container or an Apache Parquet file.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Record.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringjsonPath()The path, as a JSONPath expression, to the field in the record that contains the data.final LongThe record index, starting from 0, for the record that contains the data.static Class<? extends Record.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
jsonPath
The path, as a JSONPath expression, to the field in the record that contains the data. If the field name is longer than 20 characters, it is truncated. If the path is longer than 250 characters, it is truncated.
- Returns:
- The path, as a JSONPath expression, to the field in the record that contains the data. If the field name is longer than 20 characters, it is truncated. If the path is longer than 250 characters, it is truncated.
-
recordIndex
The record index, starting from 0, for the record that contains the data.
- Returns:
- The record index, starting from 0, for the record that contains the data.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Record.Builder,Record>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-