Class ResourceFindingsSummary
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ResourceFindingsSummary
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>
@Generated("software.amazon.awssdk:codegen") public final class ResourceFindingsSummary extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>
A list of summaries for all finding types on a resource.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceResourceFindingsSummary.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ResourceFindingsSummary.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)StringfindingType()The category or classification of the security finding.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()StringproductName()The name of the product associated with the security finding.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ResourceFindingsSummary.Builder>serializableBuilderClass()ResourceSeverityBreakdownseverities()A breakdown of security findings by their severity levels.ResourceFindingsSummary.BuildertoBuilder()StringtoString()Returns a string representation of this object.IntegertotalFindings()The total count of security findings.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
findingType
public final String findingType()
The category or classification of the security finding.
- Returns:
- The category or classification of the security finding.
-
productName
public final String productName()
The name of the product associated with the security finding.
- Returns:
- The name of the product associated with the security finding.
-
totalFindings
public final Integer totalFindings()
The total count of security findings.
- Returns:
- The total count of security findings.
-
severities
public final ResourceSeverityBreakdown severities()
A breakdown of security findings by their severity levels.
- Returns:
- A breakdown of security findings by their severity levels.
-
toBuilder
public ResourceFindingsSummary.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceFindingsSummary.Builder,ResourceFindingsSummary>
-
builder
public static ResourceFindingsSummary.Builder builder()
-
serializableBuilderClass
public static Class<? extends ResourceFindingsSummary.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-