Class ResourceGroupByRule
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ResourceGroupByRule
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>
@Generated("software.amazon.awssdk:codegen") public final class ResourceGroupByRule extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>
Defines the configuration for organizing and categorizing Amazon Web Services resources based on associated security findings.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceResourceGroupByRule.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ResourceGroupByRule.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)ResourcesFiltersfilters()The criteria used to select resources and associated security findings.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)ResourceGroupByFieldgroupByField()Specifies the attribute that resources should be grouped by.StringgroupByFieldAsString()Specifies the attribute that resources should be grouped by.inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ResourceGroupByRule.Builder>serializableBuilderClass()ResourceGroupByRule.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
groupByField
public final ResourceGroupByField groupByField()
Specifies the attribute that resources should be grouped by.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnResourceGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- Specifies the attribute that resources should be grouped by.
- See Also:
ResourceGroupByField
-
groupByFieldAsString
public final String groupByFieldAsString()
Specifies the attribute that resources should be grouped by.
If the service returns an enum value that is not available in the current SDK version,
groupByFieldwill returnResourceGroupByField.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgroupByFieldAsString().- Returns:
- Specifies the attribute that resources should be grouped by.
- See Also:
ResourceGroupByField
-
filters
public final ResourcesFilters filters()
The criteria used to select resources and associated security findings.
- Returns:
- The criteria used to select resources and associated security findings.
-
toBuilder
public ResourceGroupByRule.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceGroupByRule.Builder,ResourceGroupByRule>
-
builder
public static ResourceGroupByRule.Builder builder()
-
serializableBuilderClass
public static Class<? extends ResourceGroupByRule.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-