Class ResourceOwner
java.lang.Object
software.amazon.awssdk.services.securityhub.model.ResourceOwner
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceOwner.Builder,ResourceOwner>
@Generated("software.amazon.awssdk:codegen")
public final class ResourceOwner
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ResourceOwner.Builder,ResourceOwner>
Information about the owner of a resource, including the account and organization that the resource belongs to.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal ResourceOwnerAccountaccount()Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.static ResourceOwner.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ResourceOwnerOrgorg()Information about the organization that owns the resource, for example, an Azure Tenant.static Class<? extends ResourceOwner.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
account
Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.
- Returns:
- Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.
-
org
Information about the organization that owns the resource, for example, an Azure Tenant.
- Returns:
- Information about the organization that owns the resource, for example, an Azure Tenant.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceOwner.Builder,ResourceOwner>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-