Class ResourceResult
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ResourceResult
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceResult.Builder,ResourceResult>
@Generated("software.amazon.awssdk:codegen") public final class ResourceResult extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ResourceResult.Builder,ResourceResult>
Provides comprehensive details about an Amazon Web Services resource and its associated security findings.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceResourceResult.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description StringaccountId()The Amazon Web Services account that owns the resource.static ResourceResult.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)List<ResourceFindingsSummary>findingsSummary()An aggregated view of security findings associated with a resource.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasFindingsSummary()For responses, this returns true if the service returned a value for the FindingsSummary property.inthashCode()booleanhasResourceTags()For responses, this returns true if the service returned a value for the ResourceTags property.Stringregion()The Amazon Web Services Region where the resource is located.ResourceCategoryresourceCategory()The grouping where the resource belongs.StringresourceCategoryAsString()The grouping where the resource belongs.DocumentresourceConfig()The configuration details of a resource.StringresourceCreationTimeDt()The time when the resource was created.StringresourceDetailCaptureTimeDt()The timestamp when information about the resource was captured.StringresourceGuid()The global identifier used to identify a resource.StringresourceId()The unique identifier for a resource.StringresourceName()The name of the resource.List<ResourceTag>resourceTags()The key-value pairs associated with a resource.StringresourceType()The type of resource.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ResourceResult.Builder>serializableBuilderClass()ResourceResult.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
resourceGuid
public final String resourceGuid()
The global identifier used to identify a resource.
- Returns:
- The global identifier used to identify a resource.
-
resourceId
public final String resourceId()
The unique identifier for a resource.
- Returns:
- The unique identifier for a resource.
-
accountId
public final String accountId()
The Amazon Web Services account that owns the resource.
- Returns:
- The Amazon Web Services account that owns the resource.
-
region
public final String region()
The Amazon Web Services Region where the resource is located.
- Returns:
- The Amazon Web Services Region where the resource is located.
-
resourceCategory
public final ResourceCategory resourceCategory()
The grouping where the resource belongs.
If the service returns an enum value that is not available in the current SDK version,
resourceCategorywill returnResourceCategory.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromresourceCategoryAsString().- Returns:
- The grouping where the resource belongs.
- See Also:
ResourceCategory
-
resourceCategoryAsString
public final String resourceCategoryAsString()
The grouping where the resource belongs.
If the service returns an enum value that is not available in the current SDK version,
resourceCategorywill returnResourceCategory.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromresourceCategoryAsString().- Returns:
- The grouping where the resource belongs.
- See Also:
ResourceCategory
-
resourceType
public final String resourceType()
The type of resource.
- Returns:
- The type of resource.
-
resourceName
public final String resourceName()
The name of the resource.
- Returns:
- The name of the resource.
-
resourceCreationTimeDt
public final String resourceCreationTimeDt()
The time when the resource was created.
- Returns:
- The time when the resource was created.
-
resourceDetailCaptureTimeDt
public final String resourceDetailCaptureTimeDt()
The timestamp when information about the resource was captured.
- Returns:
- The timestamp when information about the resource was captured.
-
hasFindingsSummary
public final boolean hasFindingsSummary()
For responses, this returns true if the service returned a value for the FindingsSummary property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
findingsSummary
public final List<ResourceFindingsSummary> findingsSummary()
An aggregated view of security findings associated with a resource.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasFindingsSummary()method.- Returns:
- An aggregated view of security findings associated with a resource.
-
hasResourceTags
public final boolean hasResourceTags()
For responses, this returns true if the service returned a value for the ResourceTags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
resourceTags
public final List<ResourceTag> resourceTags()
The key-value pairs associated with a resource.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasResourceTags()method.- Returns:
- The key-value pairs associated with a resource.
-
resourceConfig
public final Document resourceConfig()
The configuration details of a resource.
- Returns:
- The configuration details of a resource.
-
toBuilder
public ResourceResult.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceResult.Builder,ResourceResult>
-
builder
public static ResourceResult.Builder builder()
-
serializableBuilderClass
public static Class<? extends ResourceResult.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-