Interface ResourceResult.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ResourceResult.Builder,ResourceResult>,SdkBuilder<ResourceResult.Builder,ResourceResult>,SdkPojo
- Enclosing class:
- ResourceResult
@Mutable @NotThreadSafe public static interface ResourceResult.Builder extends SdkPojo, CopyableBuilder<ResourceResult.Builder,ResourceResult>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ResourceResult.BuilderaccountId(String accountId)The Amazon Web Services account that owns the resource.ResourceResult.BuilderfindingsSummary(Collection<ResourceFindingsSummary> findingsSummary)An aggregated view of security findings associated with a resource.ResourceResult.BuilderfindingsSummary(Consumer<ResourceFindingsSummary.Builder>... findingsSummary)An aggregated view of security findings associated with a resource.ResourceResult.BuilderfindingsSummary(ResourceFindingsSummary... findingsSummary)An aggregated view of security findings associated with a resource.ResourceResult.Builderregion(String region)The Amazon Web Services Region where the resource is located.ResourceResult.BuilderresourceArn(String resourceArn)Specifies the ARN that uniquely identifies a resource.ResourceResult.BuilderresourceCategory(String resourceCategory)The grouping where the resource belongs.ResourceResult.BuilderresourceCategory(ResourceCategory resourceCategory)The grouping where the resource belongs.ResourceResult.BuilderresourceConfig(Document resourceConfig)The configuration details of a resource.ResourceResult.BuilderresourceCreationTimeDt(String resourceCreationTimeDt)The time when the resource was created.ResourceResult.BuilderresourceDetailCaptureTimeDt(String resourceDetailCaptureTimeDt)The timestamp when information about the resource was captured.ResourceResult.BuilderresourceId(String resourceId)The unique identifier for a resource.ResourceResult.BuilderresourceName(String resourceName)The name of the resource.ResourceResult.BuilderresourceTags(Collection<ResourceTag> resourceTags)The key-value pairs associated with a resource.ResourceResult.BuilderresourceTags(Consumer<ResourceTag.Builder>... resourceTags)The key-value pairs associated with a resource.ResourceResult.BuilderresourceTags(ResourceTag... resourceTags)The key-value pairs associated with a resource.ResourceResult.BuilderresourceType(String resourceType)The type of resource.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
resourceArn
ResourceResult.Builder resourceArn(String resourceArn)
Specifies the ARN that uniquely identifies a resource.
- Parameters:
resourceArn- Specifies the ARN that uniquely identifies a resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceId
ResourceResult.Builder resourceId(String resourceId)
The unique identifier for a resource.
- Parameters:
resourceId- The unique identifier for a resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
accountId
ResourceResult.Builder accountId(String accountId)
The Amazon Web Services account that owns the resource.
- Parameters:
accountId- The Amazon Web Services account that owns the resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
region
ResourceResult.Builder region(String region)
The Amazon Web Services Region where the resource is located.
- Parameters:
region- The Amazon Web Services Region where the resource is located.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceCategory
ResourceResult.Builder resourceCategory(String resourceCategory)
The grouping where the resource belongs.
- Parameters:
resourceCategory- The grouping where the resource belongs.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ResourceCategory,ResourceCategory
-
resourceCategory
ResourceResult.Builder resourceCategory(ResourceCategory resourceCategory)
The grouping where the resource belongs.
- Parameters:
resourceCategory- The grouping where the resource belongs.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ResourceCategory,ResourceCategory
-
resourceType
ResourceResult.Builder resourceType(String resourceType)
The type of resource.
- Parameters:
resourceType- The type of resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceName
ResourceResult.Builder resourceName(String resourceName)
The name of the resource.
- Parameters:
resourceName- The name of the resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceCreationTimeDt
ResourceResult.Builder resourceCreationTimeDt(String resourceCreationTimeDt)
The time when the resource was created.
- Parameters:
resourceCreationTimeDt- The time when the resource was created.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceDetailCaptureTimeDt
ResourceResult.Builder resourceDetailCaptureTimeDt(String resourceDetailCaptureTimeDt)
The timestamp when information about the resource was captured.
- Parameters:
resourceDetailCaptureTimeDt- The timestamp when information about the resource was captured.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingsSummary
ResourceResult.Builder findingsSummary(Collection<ResourceFindingsSummary> findingsSummary)
An aggregated view of security findings associated with a resource.
- Parameters:
findingsSummary- An aggregated view of security findings associated with a resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingsSummary
ResourceResult.Builder findingsSummary(ResourceFindingsSummary... findingsSummary)
An aggregated view of security findings associated with a resource.
- Parameters:
findingsSummary- An aggregated view of security findings associated with a resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
findingsSummary
ResourceResult.Builder findingsSummary(Consumer<ResourceFindingsSummary.Builder>... findingsSummary)
An aggregated view of security findings associated with a resource.
This is a convenience method that creates an instance of theResourceFindingsSummary.Builderavoiding the need to create one manually viaResourceFindingsSummary.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#findingsSummary(List.) - Parameters:
findingsSummary- a consumer that will call methods onResourceFindingsSummary.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#findingsSummary(java.util.Collection)
-
resourceTags
ResourceResult.Builder resourceTags(Collection<ResourceTag> resourceTags)
The key-value pairs associated with a resource.
- Parameters:
resourceTags- The key-value pairs associated with a resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceTags
ResourceResult.Builder resourceTags(ResourceTag... resourceTags)
The key-value pairs associated with a resource.
- Parameters:
resourceTags- The key-value pairs associated with a resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceTags
ResourceResult.Builder resourceTags(Consumer<ResourceTag.Builder>... resourceTags)
The key-value pairs associated with a resource.
This is a convenience method that creates an instance of theResourceTag.Builderavoiding the need to create one manually viaResourceTag.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#resourceTags(List.) - Parameters:
resourceTags- a consumer that will call methods onResourceTag.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#resourceTags(java.util.Collection)
-
resourceConfig
ResourceResult.Builder resourceConfig(Document resourceConfig)
The configuration details of a resource.
- Parameters:
resourceConfig- The configuration details of a resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-