Class ResourceScopes
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ResourceScopes
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourceScopes.Builder,ResourceScopes>
@Generated("software.amazon.awssdk:codegen") public final class ResourceScopes extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ResourceScopes.Builder,ResourceScopes>
Defines the data boundary for a resources query. Scopes determine which organizational units or organizations to retrieve data from.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceResourceScopes.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description List<AwsOrganizationScope>awsOrganizations()A list of Organizations scopes to include in the query results.static ResourceScopes.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasAwsOrganizations()For responses, this returns true if the service returned a value for the AwsOrganizations property.inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ResourceScopes.Builder>serializableBuilderClass()ResourceScopes.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
hasAwsOrganizations
public final boolean hasAwsOrganizations()
For responses, this returns true if the service returned a value for the AwsOrganizations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
awsOrganizations
public final List<AwsOrganizationScope> awsOrganizations()
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAwsOrganizations()method.- Returns:
- A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
-
toBuilder
public ResourceScopes.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourceScopes.Builder,ResourceScopes>
-
builder
public static ResourceScopes.Builder builder()
-
serializableBuilderClass
public static Class<? extends ResourceScopes.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-