Class ResourceSeverityBreakdown

    • Method Detail

      • other

        public final Integer other()

        The number of findings not in any of the severity categories.

        Returns:
        The number of findings not in any of the severity categories.
      • fatal

        public final Integer fatal()

        The number of findings with a severity level of fatal.

        Returns:
        The number of findings with a severity level of fatal.
      • critical

        public final Integer critical()

        The number of findings with a severity level of critical.

        Returns:
        The number of findings with a severity level of critical.
      • high

        public final Integer high()

        The number of findings with a severity level of high.

        Returns:
        The number of findings with a severity level of high.
      • medium

        public final Integer medium()

        The number of findings with a severity level of medium.

        Returns:
        The number of findings with a severity level of medium.
      • low

        public final Integer low()

        The number of findings with a severity level of low.

        Returns:
        The number of findings with a severity level of low.
      • informational

        public final Integer informational()

        The number of findings that provide security-related information.

        Returns:
        The number of findings that provide security-related information.
      • unknown

        public final Integer unknown()

        The number of findings with a severity level cannot be determined.

        Returns:
        The number of findings with a severity level cannot be determined.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)