Class SecurityControl
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.SecurityControl
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SecurityControl.Builder,SecurityControl>
@Generated("software.amazon.awssdk:codegen") public final class SecurityControl extends Object implements SdkPojo, Serializable, ToCopyableBuilder<SecurityControl.Builder,SecurityControl>
A security control in Security Hub describes a security best practice related to a specific resource.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceSecurityControl.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static SecurityControl.Builderbuilder()Stringdescription()The description of a security control across standards.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()StringremediationUrl()A link to Security Hub documentation that explains how to remediate a failed finding for a security control.List<SdkField<?>>sdkFields()StringsecurityControlArn()The Amazon Resource Name (ARN) for a security control across standards, such asarn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1.StringsecurityControlId()The unique identifier of a security control across standards.ControlStatussecurityControlStatus()The enablement status of a security control in a specific standard.StringsecurityControlStatusAsString()The enablement status of a security control in a specific standard.static Class<? extends SecurityControl.Builder>serializableBuilderClass()SeverityRatingseverityRating()The severity of a security control.StringseverityRatingAsString()The severity of a security control.Stringtitle()The title of a security control.SecurityControl.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
securityControlId
public final String securityControlId()
The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number, such as APIGateway.3.
- Returns:
- The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number, such as APIGateway.3.
-
securityControlArn
public final String securityControlArn()
The Amazon Resource Name (ARN) for a security control across standards, such as
arn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1. This parameter doesn't mention a specific standard.- Returns:
- The Amazon Resource Name (ARN) for a security control across standards, such as
arn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1. This parameter doesn't mention a specific standard.
-
title
public final String title()
The title of a security control.
- Returns:
- The title of a security control.
-
description
public final String description()
The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.
- Returns:
- The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.
-
remediationUrl
public final String remediationUrl()
A link to Security Hub documentation that explains how to remediate a failed finding for a security control.
- Returns:
- A link to Security Hub documentation that explains how to remediate a failed finding for a security control.
-
severityRating
public final SeverityRating severityRating()
The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
If the service returns an enum value that is not available in the current SDK version,
severityRatingwill returnSeverityRating.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromseverityRatingAsString().- Returns:
- The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
- See Also:
SeverityRating
-
severityRatingAsString
public final String severityRatingAsString()
The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
If the service returns an enum value that is not available in the current SDK version,
severityRatingwill returnSeverityRating.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromseverityRatingAsString().- Returns:
- The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
- See Also:
SeverityRating
-
securityControlStatus
public final ControlStatus securityControlStatus()
The enablement status of a security control in a specific standard.
If the service returns an enum value that is not available in the current SDK version,
securityControlStatuswill returnControlStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsecurityControlStatusAsString().- Returns:
- The enablement status of a security control in a specific standard.
- See Also:
ControlStatus
-
securityControlStatusAsString
public final String securityControlStatusAsString()
The enablement status of a security control in a specific standard.
If the service returns an enum value that is not available in the current SDK version,
securityControlStatuswill returnControlStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsecurityControlStatusAsString().- Returns:
- The enablement status of a security control in a specific standard.
- See Also:
ControlStatus
-
toBuilder
public SecurityControl.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<SecurityControl.Builder,SecurityControl>
-
builder
public static SecurityControl.Builder builder()
-
serializableBuilderClass
public static Class<? extends SecurityControl.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
-