Interface SecurityControl.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<SecurityControl.Builder,SecurityControl>,SdkBuilder<SecurityControl.Builder,SecurityControl>,SdkPojo
- Enclosing class:
- SecurityControl
public static interface SecurityControl.Builder extends SdkPojo, CopyableBuilder<SecurityControl.Builder,SecurityControl>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description SecurityControl.Builderdescription(String description)The description of a security control across standards.SecurityControl.BuilderremediationUrl(String remediationUrl)A link to Security Hub documentation that explains how to remediate a failed finding for a security control.SecurityControl.BuildersecurityControlArn(String securityControlArn)The Amazon Resource Name (ARN) for a security control across standards, such asarn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1.SecurityControl.BuildersecurityControlId(String securityControlId)The unique identifier of a security control across standards.SecurityControl.BuildersecurityControlStatus(String securityControlStatus)The enablement status of a security control in a specific standard.SecurityControl.BuildersecurityControlStatus(ControlStatus securityControlStatus)The enablement status of a security control in a specific standard.SecurityControl.BuilderseverityRating(String severityRating)The severity of a security control.SecurityControl.BuilderseverityRating(SeverityRating severityRating)The severity of a security control.SecurityControl.Buildertitle(String title)The title of a security control.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFields
-
-
-
-
Method Detail
-
securityControlId
SecurityControl.Builder securityControlId(String securityControlId)
The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number, such as APIGateway.3.
- Parameters:
securityControlId- The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Service name and a number, such as APIGateway.3.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
securityControlArn
SecurityControl.Builder securityControlArn(String securityControlArn)
The Amazon Resource Name (ARN) for a security control across standards, such as
arn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1. This parameter doesn't mention a specific standard.- Parameters:
securityControlArn- The Amazon Resource Name (ARN) for a security control across standards, such asarn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1. This parameter doesn't mention a specific standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
title
SecurityControl.Builder title(String title)
The title of a security control.
- Parameters:
title- The title of a security control.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
description
SecurityControl.Builder description(String description)
The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.
- Parameters:
description- The description of a security control across standards. This typically summarizes how Security Hub evaluates the control and the conditions under which it produces a failed finding. This parameter doesn't reference a specific standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
remediationUrl
SecurityControl.Builder remediationUrl(String remediationUrl)
A link to Security Hub documentation that explains how to remediate a failed finding for a security control.
- Parameters:
remediationUrl- A link to Security Hub documentation that explains how to remediate a failed finding for a security control.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
severityRating
SecurityControl.Builder severityRating(String severityRating)
The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
- Parameters:
severityRating- The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
SeverityRating,SeverityRating
-
severityRating
SecurityControl.Builder severityRating(SeverityRating severityRating)
The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.
- Parameters:
severityRating- The severity of a security control. For more information about how Security Hub determines control severity, see Assigning severity to control findings in the Security Hub User Guide.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
SeverityRating,SeverityRating
-
securityControlStatus
SecurityControl.Builder securityControlStatus(String securityControlStatus)
The enablement status of a security control in a specific standard.
- Parameters:
securityControlStatus- The enablement status of a security control in a specific standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ControlStatus,ControlStatus
-
securityControlStatus
SecurityControl.Builder securityControlStatus(ControlStatus securityControlStatus)
The enablement status of a security control in a specific standard.
- Parameters:
securityControlStatus- The enablement status of a security control in a specific standard.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ControlStatus,ControlStatus
-
-