Class SensitiveDataDetections
java.lang.Object
software.amazon.awssdk.services.securityhub.model.SensitiveDataDetections
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SensitiveDataDetections.Builder,SensitiveDataDetections>
@Generated("software.amazon.awssdk:codegen")
public final class SensitiveDataDetections
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<SensitiveDataDetections.Builder,SensitiveDataDetections>
The list of detected instances of sensitive data.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Longcount()The total number of occurrences of sensitive data that were detected.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final OccurrencesDetails about the sensitive data that was detected.static Class<? extends SensitiveDataDetections.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()The type of sensitive data that was detected.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
count
The total number of occurrences of sensitive data that were detected.
- Returns:
- The total number of occurrences of sensitive data that were detected.
-
type
The type of sensitive data that was detected. For example, the type might indicate that the data is an email address.
- Returns:
- The type of sensitive data that was detected. For example, the type might indicate that the data is an email address.
-
occurrences
Details about the sensitive data that was detected.
- Returns:
- Details about the sensitive data that was detected.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SensitiveDataDetections.Builder,SensitiveDataDetections>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-