Class ServiceNowDetail
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.ServiceNowDetail
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>
@Generated("software.amazon.awssdk:codegen") public final class ServiceNowDetail extends Object implements SdkPojo, Serializable, ToCopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>
Information about a ServiceNow ITSM integration.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceServiceNowDetail.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description ConnectorAuthStatusauthStatus()The status of the authorization between Jira Cloud and the service.StringauthStatusAsString()The status of the authorization between Jira Cloud and the service.static ServiceNowDetail.Builderbuilder()StringclientId()The clientId of ServiceNow ITSM.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()StringinstanceName()The instanceName of ServiceNow ITSM.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends ServiceNowDetail.Builder>serializableBuilderClass()ServiceNowDetail.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
instanceName
public final String instanceName()
The instanceName of ServiceNow ITSM.
- Returns:
- The instanceName of ServiceNow ITSM.
-
clientId
public final String clientId()
The clientId of ServiceNow ITSM.
- Returns:
- The clientId of ServiceNow ITSM.
-
authStatus
public final ConnectorAuthStatus authStatus()
The status of the authorization between Jira Cloud and the service.
If the service returns an enum value that is not available in the current SDK version,
authStatuswill returnConnectorAuthStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromauthStatusAsString().- Returns:
- The status of the authorization between Jira Cloud and the service.
- See Also:
ConnectorAuthStatus
-
authStatusAsString
public final String authStatusAsString()
The status of the authorization between Jira Cloud and the service.
If the service returns an enum value that is not available in the current SDK version,
authStatuswill returnConnectorAuthStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromauthStatusAsString().- Returns:
- The status of the authorization between Jira Cloud and the service.
- See Also:
ConnectorAuthStatus
-
toBuilder
public ServiceNowDetail.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>
-
builder
public static ServiceNowDetail.Builder builder()
-
serializableBuilderClass
public static Class<? extends ServiceNowDetail.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-