Interface ServiceNowDetail.Builder

    • Method Detail

      • instanceName

        ServiceNowDetail.Builder instanceName​(String instanceName)

        The instanceName of ServiceNow ITSM.

        Parameters:
        instanceName - The instanceName of ServiceNow ITSM.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • clientId

        ServiceNowDetail.Builder clientId​(String clientId)

        The clientId of ServiceNow ITSM.

        Parameters:
        clientId - The clientId of ServiceNow ITSM.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • authStatus

        ServiceNowDetail.Builder authStatus​(String authStatus)

        The status of the authorization between Jira Cloud and the service.

        Parameters:
        authStatus - The status of the authorization between Jira Cloud and the service.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
        See Also:
        ConnectorAuthStatus, ConnectorAuthStatus