Interface ServiceNowDetail.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>,SdkBuilder<ServiceNowDetail.Builder,ServiceNowDetail>,SdkPojo
- Enclosing class:
- ServiceNowDetail
@Mutable @NotThreadSafe public static interface ServiceNowDetail.Builder extends SdkPojo, CopyableBuilder<ServiceNowDetail.Builder,ServiceNowDetail>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ServiceNowDetail.BuilderauthStatus(String authStatus)The status of the authorization between Jira Cloud and the service.ServiceNowDetail.BuilderauthStatus(ConnectorAuthStatus authStatus)The status of the authorization between Jira Cloud and the service.ServiceNowDetail.BuilderclientId(String clientId)The clientId of ServiceNow ITSM.ServiceNowDetail.BuilderinstanceName(String instanceName)The instanceName of ServiceNow ITSM.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
instanceName
ServiceNowDetail.Builder instanceName(String instanceName)
The instanceName of ServiceNow ITSM.
- Parameters:
instanceName- The instanceName of ServiceNow ITSM.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
clientId
ServiceNowDetail.Builder clientId(String clientId)
The clientId of ServiceNow ITSM.
- Parameters:
clientId- The clientId of ServiceNow ITSM.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
authStatus
ServiceNowDetail.Builder authStatus(String authStatus)
The status of the authorization between Jira Cloud and the service.
- Parameters:
authStatus- The status of the authorization between Jira Cloud and the service.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ConnectorAuthStatus,ConnectorAuthStatus
-
authStatus
ServiceNowDetail.Builder authStatus(ConnectorAuthStatus authStatus)
The status of the authorization between Jira Cloud and the service.
- Parameters:
authStatus- The status of the authorization between Jira Cloud and the service.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ConnectorAuthStatus,ConnectorAuthStatus
-
-