Interface ServiceNowProviderConfiguration.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ServiceNowProviderConfiguration.Builder,ServiceNowProviderConfiguration>,SdkBuilder<ServiceNowProviderConfiguration.Builder,ServiceNowProviderConfiguration>,SdkPojo
- Enclosing class:
- ServiceNowProviderConfiguration
@Mutable @NotThreadSafe public static interface ServiceNowProviderConfiguration.Builder extends SdkPojo, CopyableBuilder<ServiceNowProviderConfiguration.Builder,ServiceNowProviderConfiguration>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ServiceNowProviderConfiguration.BuilderinstanceName(String instanceName)The instance name of ServiceNow ITSM.ServiceNowProviderConfiguration.BuildersecretArn(String secretArn)The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
instanceName
ServiceNowProviderConfiguration.Builder instanceName(String instanceName)
The instance name of ServiceNow ITSM.
- Parameters:
instanceName- The instance name of ServiceNow ITSM.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
secretArn
ServiceNowProviderConfiguration.Builder secretArn(String secretArn)
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
- Parameters:
secretArn- The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-