Interface ServiceNowProviderConfiguration.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ServiceNowProviderConfiguration.Builder,ServiceNowProviderConfiguration>,SdkBuilder<ServiceNowProviderConfiguration.Builder,ServiceNowProviderConfiguration>,SdkPojo
- Enclosing class:
- ServiceNowProviderConfiguration
@Mutable @NotThreadSafe public static interface ServiceNowProviderConfiguration.Builder extends SdkPojo, CopyableBuilder<ServiceNowProviderConfiguration.Builder,ServiceNowProviderConfiguration>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ServiceNowProviderConfiguration.BuilderclientId(String clientId)The client ID of ServiceNow ITSM.ServiceNowProviderConfiguration.BuilderclientSecret(String clientSecret)The client secret of ServiceNow ITSM.ServiceNowProviderConfiguration.BuilderinstanceName(String instanceName)The instance name of ServiceNow ITSM.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
instanceName
ServiceNowProviderConfiguration.Builder instanceName(String instanceName)
The instance name of ServiceNow ITSM.
- Parameters:
instanceName- The instance name of ServiceNow ITSM.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
clientId
ServiceNowProviderConfiguration.Builder clientId(String clientId)
The client ID of ServiceNow ITSM.
- Parameters:
clientId- The client ID of ServiceNow ITSM.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
clientSecret
ServiceNowProviderConfiguration.Builder clientSecret(String clientSecret)
The client secret of ServiceNow ITSM.
- Parameters:
clientSecret- The client secret of ServiceNow ITSM.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-