Interface ServiceNowProviderConfiguration.Builder

    • Method Detail

      • instanceName

        ServiceNowProviderConfiguration.Builder instanceName​(String instanceName)

        The instance name of ServiceNow ITSM.

        Parameters:
        instanceName - The instance name of ServiceNow ITSM.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • clientId

        ServiceNowProviderConfiguration.Builder clientId​(String clientId)

        The client ID of ServiceNow ITSM.

        Parameters:
        clientId - The client ID of ServiceNow ITSM.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • clientSecret

        ServiceNowProviderConfiguration.Builder clientSecret​(String clientSecret)

        The client secret of ServiceNow ITSM.

        Parameters:
        clientSecret - The client secret of ServiceNow ITSM.
        Returns:
        Returns a reference to this object so that method calls can be chained together.