Interface ServiceNowUpdateConfiguration.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>,SdkBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>,SdkPojo
- Enclosing class:
- ServiceNowUpdateConfiguration
@Mutable @NotThreadSafe public static interface ServiceNowUpdateConfiguration.Builder extends SdkPojo, CopyableBuilder<ServiceNowUpdateConfiguration.Builder,ServiceNowUpdateConfiguration>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ServiceNowUpdateConfiguration.BuildersecretArn(String secretArn)The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
secretArn
ServiceNowUpdateConfiguration.Builder secretArn(String secretArn)
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.
- Parameters:
secretArn- The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the ServiceNow credentials.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-