Class StandardsControlAssociationUpdate
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<StandardsControlAssociationUpdate.Builder,StandardsControlAssociationUpdate>
An array of requested updates to the enablement status of controls in specified standards. The objects in the array include a security control ID, the Amazon Resource Name (ARN) of the standard, the requested enablement status, and the reason for updating the enablement status.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal AssociationStatusThe desired enablement status of the control in the standard.final StringThe desired enablement status of the control in the standard.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe unique identifier for the security control whose enablement status you want to update.static Class<? extends StandardsControlAssociationUpdate.Builder>final StringThe Amazon Resource Name (ARN) of the standard in which you want to update the control's enablement status.final StringtoString()Returns a string representation of this object.final StringThe reason for updating the control's enablement status in the standard.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
standardsArn
The Amazon Resource Name (ARN) of the standard in which you want to update the control's enablement status.
- Returns:
- The Amazon Resource Name (ARN) of the standard in which you want to update the control's enablement status.
-
securityControlId
The unique identifier for the security control whose enablement status you want to update.
- Returns:
- The unique identifier for the security control whose enablement status you want to update.
-
associationStatus
The desired enablement status of the control in the standard.
If the service returns an enum value that is not available in the current SDK version,
associationStatuswill returnAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationStatusAsString().- Returns:
- The desired enablement status of the control in the standard.
- See Also:
-
associationStatusAsString
The desired enablement status of the control in the standard.
If the service returns an enum value that is not available in the current SDK version,
associationStatuswill returnAssociationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromassociationStatusAsString().- Returns:
- The desired enablement status of the control in the standard.
- See Also:
-
updatedReason
The reason for updating the control's enablement status in the standard.
- Returns:
- The reason for updating the control's enablement status in the standard.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<StandardsControlAssociationUpdate.Builder,StandardsControlAssociationUpdate>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-