Class StandardsSubscription

    • Method Detail

      • standardsSubscriptionArn

        public final String standardsSubscriptionArn()

        The ARN of the resource that represents your subscription to the standard.

        Returns:
        The ARN of the resource that represents your subscription to the standard.
      • standardsArn

        public final String standardsArn()

        The ARN of the standard.

        Returns:
        The ARN of the standard.
      • hasStandardsInput

        public final boolean hasStandardsInput()
        For responses, this returns true if the service returned a value for the StandardsInput property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • standardsInput

        public final Map<String,​String> standardsInput()

        A key-value pair of input for the standard.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasStandardsInput() method.

        Returns:
        A key-value pair of input for the standard.
      • standardsStatus

        public final StandardsStatus standardsStatus()

        The status of your subscription to the standard. Possible values are:

        • PENDING - The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard.

        • READY - The standard is enabled.

        • INCOMPLETE - The standard could not be enabled completely. One or more errors ( StandardsStatusReason) occurred when Security Hub attempted to enable the standard.

        • DELETING - The standard is in the process of being disabled.

        • FAILED - The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to disable the standard.

        If the service returns an enum value that is not available in the current SDK version, standardsStatus will return StandardsStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from standardsStatusAsString().

        Returns:
        The status of your subscription to the standard. Possible values are:

        • PENDING - The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard.

        • READY - The standard is enabled.

        • INCOMPLETE - The standard could not be enabled completely. One or more errors ( StandardsStatusReason) occurred when Security Hub attempted to enable the standard.

        • DELETING - The standard is in the process of being disabled.

        • FAILED - The standard could not be disabled. One or more errors ( StandardsStatusReason) occurred when Security Hub attempted to disable the standard.

        See Also:
        StandardsStatus
      • standardsStatusAsString

        public final String standardsStatusAsString()

        The status of your subscription to the standard. Possible values are:

        • PENDING - The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard.

        • READY - The standard is enabled.

        • INCOMPLETE - The standard could not be enabled completely. One or more errors ( StandardsStatusReason) occurred when Security Hub attempted to enable the standard.

        • DELETING - The standard is in the process of being disabled.

        • FAILED - The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub attempted to disable the standard.

        If the service returns an enum value that is not available in the current SDK version, standardsStatus will return StandardsStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from standardsStatusAsString().

        Returns:
        The status of your subscription to the standard. Possible values are:

        • PENDING - The standard is in the process of being enabled. Or the standard is already enabled and Security Hub is adding new controls to the standard.

        • READY - The standard is enabled.

        • INCOMPLETE - The standard could not be enabled completely. One or more errors ( StandardsStatusReason) occurred when Security Hub attempted to enable the standard.

        • DELETING - The standard is in the process of being disabled.

        • FAILED - The standard could not be disabled. One or more errors ( StandardsStatusReason) occurred when Security Hub attempted to disable the standard.

        See Also:
        StandardsStatus
      • standardsControlsUpdatable

        public final StandardsControlsUpdatable standardsControlsUpdatable()

        Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:

        • READY_FOR_UPDATES - Controls in the standard can be retrieved and configured.

        • NOT_READY_FOR_UPDATES - Controls in the standard cannot be retrieved or configured.

        If the service returns an enum value that is not available in the current SDK version, standardsControlsUpdatable will return StandardsControlsUpdatable.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from standardsControlsUpdatableAsString().

        Returns:
        Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:

        • READY_FOR_UPDATES - Controls in the standard can be retrieved and configured.

        • NOT_READY_FOR_UPDATES - Controls in the standard cannot be retrieved or configured.

        See Also:
        StandardsControlsUpdatable
      • standardsControlsUpdatableAsString

        public final String standardsControlsUpdatableAsString()

        Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:

        • READY_FOR_UPDATES - Controls in the standard can be retrieved and configured.

        • NOT_READY_FOR_UPDATES - Controls in the standard cannot be retrieved or configured.

        If the service returns an enum value that is not available in the current SDK version, standardsControlsUpdatable will return StandardsControlsUpdatable.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from standardsControlsUpdatableAsString().

        Returns:
        Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:

        • READY_FOR_UPDATES - Controls in the standard can be retrieved and configured.

        • NOT_READY_FOR_UPDATES - Controls in the standard cannot be retrieved or configured.

        See Also:
        StandardsControlsUpdatable
      • standardsStatusReason

        public final StandardsStatusReason standardsStatusReason()

        The reason for the current status.

        Returns:
        The reason for the current status.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)