Class UnprocessedSecurityControl

    • Method Detail

      • securityControlId

        public final String securityControlId()

        The control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.

        Returns:
        The control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.
      • errorCode

        public final UnprocessedErrorCode errorCode()

        The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.

        If the service returns an enum value that is not available in the current SDK version, errorCode will return UnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from errorCodeAsString().

        Returns:
        The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.
        See Also:
        UnprocessedErrorCode
      • errorCodeAsString

        public final String errorCodeAsString()

        The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.

        If the service returns an enum value that is not available in the current SDK version, errorCode will return UnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from errorCodeAsString().

        Returns:
        The error code for the unprocessed security control. The NOT_FOUND value has been deprecated and replaced by the RESOURCE_NOT_FOUND value.
        See Also:
        UnprocessedErrorCode
      • errorReason

        public final String errorReason()

        The reason why the security control was unprocessed.

        Returns:
        The reason why the security control was unprocessed.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)