Class UnprocessedSecurityControl
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.UnprocessedSecurityControl
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UnprocessedSecurityControl.Builder,UnprocessedSecurityControl>
@Generated("software.amazon.awssdk:codegen") public final class UnprocessedSecurityControl extends Object implements SdkPojo, Serializable, ToCopyableBuilder<UnprocessedSecurityControl.Builder,UnprocessedSecurityControl>
Provides details about a security control for which a response couldn't be returned.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceUnprocessedSecurityControl.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static UnprocessedSecurityControl.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)UnprocessedErrorCodeerrorCode()The error code for the unprocessed security control.StringerrorCodeAsString()The error code for the unprocessed security control.StringerrorReason()The reason why the security control was unprocessed.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()StringsecurityControlId()The control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.static Class<? extends UnprocessedSecurityControl.Builder>serializableBuilderClass()UnprocessedSecurityControl.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
securityControlId
public final String securityControlId()
The control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.- Returns:
- The control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) for which a response couldn't be returned.
-
errorCode
public final UnprocessedErrorCode errorCode()
The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
UnprocessedErrorCode
-
errorCodeAsString
public final String errorCodeAsString()
The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed security control. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
UnprocessedErrorCode
-
errorReason
public final String errorReason()
The reason why the security control was unprocessed.
- Returns:
- The reason why the security control was unprocessed.
-
toBuilder
public UnprocessedSecurityControl.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<UnprocessedSecurityControl.Builder,UnprocessedSecurityControl>
-
builder
public static UnprocessedSecurityControl.Builder builder()
-
serializableBuilderClass
public static Class<? extends UnprocessedSecurityControl.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-