Class UnprocessedStandardsControlAssociation
- java.lang.Object
-
- software.amazon.awssdk.services.securityhub.model.UnprocessedStandardsControlAssociation
-
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UnprocessedStandardsControlAssociation.Builder,UnprocessedStandardsControlAssociation>
@Generated("software.amazon.awssdk:codegen") public final class UnprocessedStandardsControlAssociation extends Object implements SdkPojo, Serializable, ToCopyableBuilder<UnprocessedStandardsControlAssociation.Builder,UnprocessedStandardsControlAssociation>
Provides details about which control's enablement status couldn't be retrieved in a specified standard when calling BatchUpdateStandardsControlAssociations. This parameter also provides details about why the request was unprocessed.
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceUnprocessedStandardsControlAssociation.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static UnprocessedStandardsControlAssociation.Builderbuilder()booleanequals(Object obj)booleanequalsBySdkFields(Object obj)UnprocessedErrorCodeerrorCode()The error code for the unprocessed standard and control association.StringerrorCodeAsString()The error code for the unprocessed standard and control association.StringerrorReason()The reason why the standard and control association was unprocessed.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)inthashCode()Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends UnprocessedStandardsControlAssociation.Builder>serializableBuilderClass()StandardsControlAssociationIdstandardsControlAssociationId()An array with one or more objects that includes a security control (identified withSecurityControlId,SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard.UnprocessedStandardsControlAssociation.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
standardsControlAssociationId
public final StandardsControlAssociationId standardsControlAssociationId()
An array with one or more objects that includes a security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard. This parameter shows the specific controls for which the enablement status couldn't be retrieved in specified standards when calling BatchUpdateStandardsControlAssociations.- Returns:
- An array with one or more objects that includes a security control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) and the Amazon Resource Name (ARN) of a standard. This parameter shows the specific controls for which the enablement status couldn't be retrieved in specified standards when calling BatchUpdateStandardsControlAssociations.
-
errorCode
public final UnprocessedErrorCode errorCode()
The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
UnprocessedErrorCode
-
errorCodeAsString
public final String errorCodeAsString()
The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue.If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnUnprocessedErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code for the unprocessed standard and control association. The
NOT_FOUNDvalue has been deprecated and replaced by theRESOURCE_NOT_FOUNDvalue. - See Also:
UnprocessedErrorCode
-
errorReason
public final String errorReason()
The reason why the standard and control association was unprocessed.
- Returns:
- The reason why the standard and control association was unprocessed.
-
toBuilder
public UnprocessedStandardsControlAssociation.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<UnprocessedStandardsControlAssociation.Builder,UnprocessedStandardsControlAssociation>
-
builder
public static UnprocessedStandardsControlAssociation.Builder builder()
-
serializableBuilderClass
public static Class<? extends UnprocessedStandardsControlAssociation.Builder> serializableBuilderClass()
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-