Class UpdateAutomationRuleV2Request
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal List<AutomationRulesActionV2>actions()A list of actions to be performed when the rule criteria is met.builder()final Criteriacriteria()The filtering type and configuration of the automation rule.final StringA description of the automation rule.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Actions property.final inthashCode()final StringThe ARN of the automation rule.final StringruleName()The name of the automation rule.final FloatRepresents a value for the rule priority.final RuleStatusV2The status of the automation rule.final StringThe status of the automation rule.static Class<? extends UpdateAutomationRuleV2Request.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
identifier
The ARN of the automation rule.
- Returns:
- The ARN of the automation rule.
-
ruleStatus
The status of the automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the automation rule.
- See Also:
-
ruleStatusAsString
The status of the automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the automation rule.
- See Also:
-
ruleOrder
Represents a value for the rule priority.
- Returns:
- Represents a value for the rule priority.
-
description
A description of the automation rule.
- Returns:
- A description of the automation rule.
-
ruleName
The name of the automation rule.
- Returns:
- The name of the automation rule.
-
criteria
The filtering type and configuration of the automation rule.
- Returns:
- The filtering type and configuration of the automation rule.
-
hasActions
public final boolean hasActions()For responses, this returns true if the service returned a value for the Actions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
actions
A list of actions to be performed when the rule criteria is met.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasActions()method.- Returns:
- A list of actions to be performed when the rule criteria is met.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-