Class UpdateAutomationRuleV2Request
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.securityhub.model.SecurityHubRequest
-
- software.amazon.awssdk.services.securityhub.model.UpdateAutomationRuleV2Request
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request>
@Generated("software.amazon.awssdk:codegen") public final class UpdateAutomationRuleV2Request extends SecurityHubRequest implements ToCopyableBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceUpdateAutomationRuleV2Request.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description List<AutomationRulesActionV2>actions()A list of actions to be performed when the rule criteria is met.static UpdateAutomationRuleV2Request.Builderbuilder()Criteriacriteria()The filtering type and configuration of the automation rule.Stringdescription()A description of the automation rule.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasActions()For responses, this returns true if the service returned a value for the Actions property.inthashCode()Stringidentifier()The ARN of the automation rule.StringruleName()The name of the automation rule.FloatruleOrder()Represents a value for the rule priority.RuleStatusV2ruleStatus()The status of the automation rule.StringruleStatusAsString()The status of the automation rule.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends UpdateAutomationRuleV2Request.Builder>serializableBuilderClass()UpdateAutomationRuleV2Request.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
identifier
public final String identifier()
The ARN of the automation rule.
- Returns:
- The ARN of the automation rule.
-
ruleStatus
public final RuleStatusV2 ruleStatus()
The status of the automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the automation rule.
- See Also:
RuleStatusV2
-
ruleStatusAsString
public final String ruleStatusAsString()
The status of the automation rule.
If the service returns an enum value that is not available in the current SDK version,
ruleStatuswill returnRuleStatusV2.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromruleStatusAsString().- Returns:
- The status of the automation rule.
- See Also:
RuleStatusV2
-
ruleOrder
public final Float ruleOrder()
Represents a value for the rule priority.
- Returns:
- Represents a value for the rule priority.
-
description
public final String description()
A description of the automation rule.
- Returns:
- A description of the automation rule.
-
ruleName
public final String ruleName()
The name of the automation rule.
- Returns:
- The name of the automation rule.
-
criteria
public final Criteria criteria()
The filtering type and configuration of the automation rule.
- Returns:
- The filtering type and configuration of the automation rule.
-
hasActions
public final boolean hasActions()
For responses, this returns true if the service returned a value for the Actions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
actions
public final List<AutomationRulesActionV2> actions()
A list of actions to be performed when the rule criteria is met.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasActions()method.- Returns:
- A list of actions to be performed when the rule criteria is met.
-
toBuilder
public UpdateAutomationRuleV2Request.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateAutomationRuleV2Request.Builder,UpdateAutomationRuleV2Request>- Specified by:
toBuilderin classSecurityHubRequest
-
builder
public static UpdateAutomationRuleV2Request.Builder builder()
-
serializableBuilderClass
public static Class<? extends UpdateAutomationRuleV2Request.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-