Class UpdateConfigurationPolicyRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateConfigurationPolicyRequest.Builder,UpdateConfigurationPolicyRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final PolicyAn object that defines how Security Hub CSPM is configured.final StringThe description of the configuration policy.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe Amazon Resource Name (ARN) or universally unique identifier (UUID) of the configuration policy.final Stringname()The name of the configuration policy.static Class<? extends UpdateConfigurationPolicyRequest.Builder>final StringtoString()Returns a string representation of this object.final StringThe reason for updating the configuration policy.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
identifier
The Amazon Resource Name (ARN) or universally unique identifier (UUID) of the configuration policy.
- Returns:
- The Amazon Resource Name (ARN) or universally unique identifier (UUID) of the configuration policy.
-
name
The name of the configuration policy. Alphanumeric characters and the following ASCII characters are permitted:
-, ., !, *, /.- Returns:
- The name of the configuration policy. Alphanumeric characters and the following ASCII characters are
permitted:
-, ., !, *, /.
-
description
The description of the configuration policy.
- Returns:
- The description of the configuration policy.
-
updatedReason
The reason for updating the configuration policy.
- Returns:
- The reason for updating the configuration policy.
-
configurationPolicy
An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
When updating a configuration policy, provide a complete list of standards that you want to enable and a complete list of controls that you want to enable or disable. The updated configuration replaces the current configuration.
- Returns:
- An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is
enabled or disabled, a list of enabled security standards, a list of enabled or disabled security
controls, and a list of custom parameter values for specified controls. If you provide a list of security
controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls
(including newly released controls). If you provide a list of security controls that are disabled in the
configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
When updating a configuration policy, provide a complete list of standards that you want to enable and a complete list of controls that you want to enable or disable. The updated configuration replaces the current configuration.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateConfigurationPolicyRequest.Builder,UpdateConfigurationPolicyRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-