Class UpdateSecurityHubConfigurationRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateSecurityHubConfigurationRequest.Builder,UpdateSecurityHubConfigurationRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal BooleanWhether to automatically enable new controls when they are added to standards that are enabled.builder()final ControlFindingGeneratorUpdates whether the calling account has consolidated control findings turned on.final StringUpdates whether the calling account has consolidated control findings turned on.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UpdateSecurityHubConfigurationRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
autoEnableControls
Whether to automatically enable new controls when they are added to standards that are enabled.
By default, this is set to
true, and new controls are enabled automatically. To not automatically enable new controls, set this tofalse.When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of
DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control asENABLEDin your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you haveAutoEnableControlsset totrue.- Returns:
- Whether to automatically enable new controls when they are added to standards that are enabled.
By default, this is set to
true, and new controls are enabled automatically. To not automatically enable new controls, set this tofalse.When you automatically enable new controls, you can interact with the controls in the console and programmatically immediately after release. However, automatically enabled controls have a temporary default status of
DISABLED. It can take up to several days for Security Hub CSPM to process the control release and designate the control asENABLEDin your account. During the processing period, you can manually enable or disable a control, and Security Hub CSPM will maintain that designation regardless of whether you haveAutoEnableControlsset totrue.
-
controlFindingGenerator
Updates whether the calling account has consolidated control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.For accounts that are part of an organization, this value can only be updated in the administrator account.
If the service returns an enum value that is not available in the current SDK version,
controlFindingGeneratorwill returnControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolFindingGeneratorAsString().- Returns:
- Updates whether the calling account has consolidated control findings turned on. If the value for this
field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.For accounts that are part of an organization, this value can only be updated in the administrator account.
- See Also:
-
controlFindingGeneratorAsString
Updates whether the calling account has consolidated control findings turned on. If the value for this field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.For accounts that are part of an organization, this value can only be updated in the administrator account.
If the service returns an enum value that is not available in the current SDK version,
controlFindingGeneratorwill returnControlFindingGenerator.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcontrolFindingGeneratorAsString().- Returns:
- Updates whether the calling account has consolidated control findings turned on. If the value for this
field is set to
SECURITY_CONTROL, Security Hub CSPM generates a single finding for a control check even when the check applies to multiple enabled standards.If the value for this field is set to
STANDARD_CONTROL, Security Hub CSPM generates separate findings for a control check when the check applies to multiple enabled standards.For accounts that are part of an organization, this value can only be updated in the administrator account.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateSecurityHubConfigurationRequest.Builder,UpdateSecurityHubConfigurationRequest> - Specified by:
toBuilderin classSecurityHubRequest
-
builder
-
serializableBuilderClass
public static Class<? extends UpdateSecurityHubConfigurationRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-