Class VulnerabilityVendor
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<VulnerabilityVendor.Builder,VulnerabilityVendor>
A vendor that generates a vulnerability report.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic VulnerabilityVendor.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the vendor.static Class<? extends VulnerabilityVendor.Builder>final StringtoString()Returns a string representation of this object.final Stringurl()The URL of the vulnerability advisory.final StringIndicates when the vulnerability advisory was created.final StringThe severity that the vendor assigned to the vulnerability.final StringIndicates when the vulnerability advisory was last updated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the vendor.
- Returns:
- The name of the vendor.
-
url
The URL of the vulnerability advisory.
- Returns:
- The URL of the vulnerability advisory.
-
vendorSeverity
The severity that the vendor assigned to the vulnerability.
- Returns:
- The severity that the vendor assigned to the vulnerability.
-
vendorCreatedAt
Indicates when the vulnerability advisory was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the vulnerability advisory was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
vendorUpdatedAt
Indicates when the vulnerability advisory was last updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
- Returns:
- Indicates when the vulnerability advisory was last updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<VulnerabilityVendor.Builder,VulnerabilityVendor>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-