Class WafAction
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<WafAction.Builder,WafAction>
Details about the action that CloudFront or WAF takes when a web request matches the conditions in the rule.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic WafAction.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends WafAction.Builder>final StringtoString()Returns a string representation of this object.final Stringtype()Specifies how you want WAF to respond to requests that match the settings in a rule.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
type
Specifies how you want WAF to respond to requests that match the settings in a rule.
Valid settings include the following:
-
ALLOW- WAF allows requests -
BLOCK- WAF blocks requests -
COUNT- WAF increments a counter of the requests that match all of the conditions in the rule. WAF then continues to inspect the web request based on the remaining rules in the web ACL. You can't specifyCOUNTfor the default action for a web ACL.
- Returns:
- Specifies how you want WAF to respond to requests that match the settings in a rule.
Valid settings include the following:
-
ALLOW- WAF allows requests -
BLOCK- WAF blocks requests -
COUNT- WAF increments a counter of the requests that match all of the conditions in the rule. WAF then continues to inspect the web request based on the remaining rules in the web ACL. You can't specifyCOUNTfor the default action for a web ACL.
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<WafAction.Builder,WafAction>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-