Uses of Class
software.amazon.awssdk.services.securityhub.model.CreateAutomationRuleV2Response
-
Packages that use CreateAutomationRuleV2Response Package Description software.amazon.awssdk.services.securityhub Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices. -
-
Uses of CreateAutomationRuleV2Response in software.amazon.awssdk.services.securityhub
Methods in software.amazon.awssdk.services.securityhub that return CreateAutomationRuleV2Response Modifier and Type Method Description default CreateAutomationRuleV2ResponseSecurityHubClient. createAutomationRuleV2(Consumer<CreateAutomationRuleV2Request.Builder> createAutomationRuleV2Request)Creates a V2 automation rule.default CreateAutomationRuleV2ResponseSecurityHubClient. createAutomationRuleV2(CreateAutomationRuleV2Request createAutomationRuleV2Request)Creates a V2 automation rule.Methods in software.amazon.awssdk.services.securityhub that return types with arguments of type CreateAutomationRuleV2Response Modifier and Type Method Description default CompletableFuture<CreateAutomationRuleV2Response>SecurityHubAsyncClient. createAutomationRuleV2(Consumer<CreateAutomationRuleV2Request.Builder> createAutomationRuleV2Request)Creates a V2 automation rule.default CompletableFuture<CreateAutomationRuleV2Response>SecurityHubAsyncClient. createAutomationRuleV2(CreateAutomationRuleV2Request createAutomationRuleV2Request)Creates a V2 automation rule.
-