Uses of Class
software.amazon.awssdk.services.securityhub.model.OcsfMapField
-
Packages that use OcsfMapField Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of OcsfMapField in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return OcsfMapField Modifier and Type Method Description OcsfMapFieldOcsfMapFilter. fieldName()The name of the field.static OcsfMapFieldOcsfMapField. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static OcsfMapFieldOcsfMapField. valueOf(String name)Returns the enum constant of this type with the specified name.static OcsfMapField[]OcsfMapField. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type OcsfMapField Modifier and Type Method Description static Set<OcsfMapField>OcsfMapField. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type OcsfMapField Modifier and Type Method Description OcsfMapFilter.BuilderOcsfMapFilter.Builder. fieldName(OcsfMapField fieldName)The name of the field.
-