Uses of Class
software.amazon.awssdk.services.securityhub.model.SecurityHubFeature
-
Packages that use SecurityHubFeature Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of SecurityHubFeature in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return SecurityHubFeature Modifier and Type Method Description SecurityHubFeatureDisableOrganizationAdminAccountRequest. feature()The feature for which the delegated admin account is disabled.SecurityHubFeatureEnableOrganizationAdminAccountRequest. feature()The feature for which the delegated admin account is enabled.SecurityHubFeatureEnableOrganizationAdminAccountResponse. feature()The feature where the delegated administrator is enabled.SecurityHubFeatureListOrganizationAdminAccountsRequest. feature()The feature where the delegated administrator account is listed.SecurityHubFeatureListOrganizationAdminAccountsResponse. feature()The feature where the delegated administrator account is listed.static SecurityHubFeatureSecurityHubFeature. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.static SecurityHubFeatureSecurityHubFeature. valueOf(String name)Returns the enum constant of this type with the specified name.static SecurityHubFeature[]SecurityHubFeature. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type SecurityHubFeature Modifier and Type Method Description static Set<SecurityHubFeature>SecurityHubFeature. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type SecurityHubFeature Modifier and Type Method Description DisableOrganizationAdminAccountRequest.BuilderDisableOrganizationAdminAccountRequest.Builder. feature(SecurityHubFeature feature)The feature for which the delegated admin account is disabled.EnableOrganizationAdminAccountRequest.BuilderEnableOrganizationAdminAccountRequest.Builder. feature(SecurityHubFeature feature)The feature for which the delegated admin account is enabled.EnableOrganizationAdminAccountResponse.BuilderEnableOrganizationAdminAccountResponse.Builder. feature(SecurityHubFeature feature)The feature where the delegated administrator is enabled.ListOrganizationAdminAccountsRequest.BuilderListOrganizationAdminAccountsRequest.Builder. feature(SecurityHubFeature feature)The feature where the delegated administrator account is listed.ListOrganizationAdminAccountsResponse.BuilderListOrganizationAdminAccountsResponse.Builder. feature(SecurityHubFeature feature)The feature where the delegated administrator account is listed.
-