Uses of Class
software.amazon.awssdk.services.securityhub.model.StandardsControlsUpdatable
-
Packages that use StandardsControlsUpdatable Package Description software.amazon.awssdk.services.securityhub.model -
-
Uses of StandardsControlsUpdatable in software.amazon.awssdk.services.securityhub.model
Methods in software.amazon.awssdk.services.securityhub.model that return StandardsControlsUpdatable Modifier and Type Method Description static StandardsControlsUpdatableStandardsControlsUpdatable. fromValue(String value)Use this in place of valueOf to convert the raw string returned by the service into the enum value.StandardsControlsUpdatableStandardsSubscription. standardsControlsUpdatable()Indicates whether the controls associated with this standards subscription can be viewed and updated.static StandardsControlsUpdatableStandardsControlsUpdatable. valueOf(String name)Returns the enum constant of this type with the specified name.static StandardsControlsUpdatable[]StandardsControlsUpdatable. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.securityhub.model that return types with arguments of type StandardsControlsUpdatable Modifier and Type Method Description static Set<StandardsControlsUpdatable>StandardsControlsUpdatable. knownValues()Methods in software.amazon.awssdk.services.securityhub.model with parameters of type StandardsControlsUpdatable Modifier and Type Method Description StandardsSubscription.BuilderStandardsSubscription.Builder. standardsControlsUpdatable(StandardsControlsUpdatable standardsControlsUpdatable)Indicates whether the controls associated with this standards subscription can be viewed and updated.
-